tinymce.addI18n('nl_BE',{
"Redo": "Opnieuw doen",
"Undo": "Ongedaan maken",
"Cut": "Knippen",
"Copy": "Kopi\u00ebren",
"Paste": "Plakken",
"Select all": "Alles selecteren",
"New document": "Nieuw document",
"Ok": "Ok",
"Cancel": "Annuleren",
"Visual aids": "Visuele hulpmiddelen",
"Bold": "Vet",
"Italic": "Cursief",
"Underline": "Onderlijnd",
"Strikethrough": "Doorstreept",
"Superscript": "Superscript",
"Subscript": "Subscript",
"Clear formatting": "Opmaak verwijderen",
"Align left": "Links uitlijnen",
"Align center": "Centreren",
"Align right": "Rechts uitlijnen",
"Justify": "Distribueren",
"Bullet list": "Ongeordende lijst",
"Numbered list": "Geordende lijst",
"Decrease indent": "Inspringing verkleinen",
"Increase indent": "Inspringing vergroten",
"Close": "Sluiten",
"Formats": "Formaten",
"Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X\/C\/V keyboard shortcuts instead.": "Uw browser ondersteunt geen directe toegang tot het klembord. Gelieve de CTRL+X\/C\/V toetsen te gebruiken.",
"Headers": "Kopteksten",
"Header 1": "Koptekst 1",
"Header 2": "Koptekst 2",
"Header 3": "Koptekst 3",
"Header 4": "Koptekst 4",
"Header 5": "Koptekst 5",
"Header 6": "Koptekst 6",
"Headings": "Hoofdingen",
"Heading 1": "Hoofding 1",
"Heading 2": "Hoofding 2",
"Heading 3": "Hoofding 3",
"Heading 4": "Hoofding 4",
"Heading 5": "Hoofding 5",
"Heading 6": "Hoofding 6",
"Preformatted": "Gepreformateerd",
"Div": "Div",
"Pre": "Pre",
"Code": "Code",
"Paragraph": "Paragraaf",
"Blockquote": "Citaat",
"Inline": "In tekstregel",
"Blocks": "Blokken",
"Paste is now in plain text mode. Contents will now be pasted as plain text until you toggle this option off.": "Plakken is nu in gewone tekst modus. Elementen zullen nu als gewone tekst geplakt worden tot u deze optie uit schakelt.",
"Fonts": "Lettertypen",
"Font Sizes": "Lettergrootte",
"Class": "Class",
"Browse for an image": "Een afbeelding zoeken",
"OR": "OF",
"Drop an image here": "Plaats hier een afbeelding",
"Upload": "Uploaden",
"Block": "Vierkant",
"Align": "Aligneer",
"Default": "Standaard",
"Circle": "Cirkel",
"Disc": "Schijf",
"Square": "Vierkant",
"Lower Alpha": "Kleine letters",
"Lower Greek": "Klein Grieks schrift",
"Lower Roman": "Klein Latijns schrift",
"Upper Alpha": "Hoofdletters",
"Upper Roman": "Hoofdletters Latijns",
"Anchor...": "Anker...",
"Name": "Naam",
"Id": "Id",
"Id should start with a letter, followed only by letters, numbers, dashes, dots, colons or underscores.": "Een id moet met een letter beginnen, gevolgd door letters, nummers, strepen, punten, dubbele punten of liggende streepjes.",
"You have unsaved changes are you sure you want to navigate away?": "U heeft niet opgeslagen wijzigingen bent u zeker dat u de pagina wilt verlaten?",
"Restore last draft": "Laatste concept herstellen",
"Special character...": "Speciaal karakter...",
"Source code": "Broncode",
"Insert\/Edit code sample": "Codevoorbeeld invoegen\/bewerken",
"Language": "Taal",
"Code sample...": "Codevoorbeeld...",
"Color Picker": "Kleurenkiezer",
"R": "R",
"G": "G",
"B": "B",
"Left to right": "Links naar rechts",
"Right to left": "Rechts naar links",
"Emoticons": "Emoticons",
"Emoticons...": "Emoticons...",
"Metadata and Document Properties": "Metadata en Document Eigenschappen",
"Title": "Titel",
"Keywords": "Sleutelwoorden",
"Description": "Omschrijving",
"Robots": "Robots",
"Author": "Auteur",
"Encoding": "Bestandscodering",
"Fullscreen": "Schermvullend",
"Action": "Actie",
"Shortcut": "Snelkoppeling",
"Help": "Help",
"Address": "Adres",
"Focus to menubar": "Focus naar menubalk",
"Focus to toolbar": "Focus naar werkbalk",
"Focus to element path": "Focus naar elementenpad",
"Focus to contextual toolbar": "Focus naar contextuele werkbalk",
"Insert link (if link plugin activated)": "Link invoegen (als link plug-in geactiveerd is)",
"Save (if save plugin activated)": "Opslaan (als opslaan plug-in geactiveerd is)",
"Find (if searchreplace plugin activated)": "Zoeken (als zoeken\/vervangen plug-in geactiveerd is)",
"Plugins installed ({0}):": "Ge\u00efnstalleerde plugins ({0}):",
"Premium plugins:": "Premium plug-ins:",
"Learn more...": "Leer meer...",
"You are using {0}": "U gebruikt {0}",
"Plugins": "Plug-ins",
"Handy Shortcuts": "Handige snelkoppelingen",
"Horizontal line": "Horizontale lijn",
"Insert\/edit image": "Afbeelding invoegen\/bewerken",
"Alternative description": "Alternatieve beschrijving",
"Accessibility": "Toegankelijkheid",
"Image is decorative": "Afbeelding is decoratief",
"Source": "Bron",
"Dimensions": "Afmetingen",
"Constrain proportions": "Verhoudingen begrenzen",
"General": "Algemeen",
"Advanced": "Geavanceerd",
"Style": "Stijl",
"Vertical space": "Verticale ruimte",
"Horizontal space": "Horizontale ruimte",
"Border": "Rand",
"Insert image": "Afbeelding invoegen",
"Image...": "Afbeelding...",
"Image list": "Afbeeldingenlijst",
"Rotate counterclockwise": "Linksom draaien",
"Rotate clockwise": "Rechtsom draaien",
"Flip vertically": "Verticaal spiegelen",
"Flip horizontally": "Horizontaal spiegelen",
"Edit image": "Afbeelding bewerken",
"Image options": "Afbeeldingsopties",
"Zoom in": "Inzoomen",
"Zoom out": "Uitzoomen",
"Crop": "Bijsnijden",
"Resize": "Herschalen",
"Orientation": "Ori\u00ebntatie",
"Brightness": "Helderheid",
"Sharpen": "Verscherpen",
"Contrast": "Contrast",
"Color levels": "Kleurniveau's",
"Gamma": "Gamma",
"Invert": "Omkeren",
"Apply": "Toepassen",
"Back": "Terug",
"Insert date\/time": "Datum\/tijd invoegen",
"Date\/time": "Datum\/tijd",
"Insert\/edit link": "Link invoegen\/bewerken",
"Text to display": "Weer te geven tekst",
"Url": "Url",
"Open link in...": "Link openen in...",
"Current window": "Huidig venster",
"None": "Geen",
"New window": "Nieuw venster",
"Open link": "Link openen",
"Remove link": "Link verwijderen",
"Anchors": "Ankers",
"Link...": "Link...",
"Paste or type a link": "Link plakken of typen",
"The URL you entered seems to be an email address. Do you want to add the required mailto: prefix?": "De ingevoerde URL lijkt op een e-mailadres. Wilt u er het vereiste voorvoegsel mailto: aan toevoegen?",
"The URL you entered seems to be an external link. Do you want to add the required http:\/\/ prefix?": "De ingevoerde URL lijkt op een externe link. Wilt u er het vereiste voorvoegsel http:\/\/ aan toevoegen?",
"The URL you entered seems to be an external link. Do you want to add the required https:\/\/ prefix?": "De ingevoerde URL lijkt op een externe link. Wilt u er het vereiste voorvoegsel https:\/\/ aan toevoegen?",
"Link list": "Link lijst",
"Insert video": "Video invoegen",
"Insert\/edit video": "Video invoegen\/bewerken",
"Insert\/edit media": "Media invoegen\/bewerken",
"Alternative source": "Alternatieve bron",
"Alternative source URL": "Alternatieve bron URL",
"Media poster (Image URL)": "Mediaposter (Afbeelding URL)",
"Paste your embed code below:": "Plak de in te sluiten code hieronder:",
"Embed": "Insluiten",
"Media...": "Media...",
"Nonbreaking space": "Vaste spatie",
"Page break": "Pagina-einde",
"Paste as text": "Plakken als tekst",
"Preview": "Voorbeeld",
"Print...": "Afdrukken...",
"Save": "Opslaan",
"Find": "Zoeken",
"Replace with": "Vervangen door",
"Replace": "Vervangen",
"Replace all": "Alles vervangen",
"Previous": "Vorige",
"Next": "Volgende",
"Find and Replace": "Zoeken en Vervangen",
"Find and replace...": "Zoeken en vervangen...",
"Could not find the specified string.": "Kon de gespecificeerde string niet vinden.",
"Match case": "Hoofdlettergevoelig",
"Find whole words only": "Enkel volledige woorden",
"Find in selection": "Zoeken in selectie",
"Spellcheck": "Spellingscontrole",
"Spellcheck Language": "Spellingscontrole Taal",
"No misspellings found.": "Geen spelfouten gevonden.",
"Ignore": "Negeren",
"Ignore all": "Alles negeren",
"Finish": "Voltooien",
"Add to Dictionary": "Aan woordenboek toevoegen",
"Insert table": "Tabel invoegen",
"Table properties": "Tabeleigenschappen",
"Delete table": "Tabel verwijderen",
"Cell": "Cel",
"Row": "Rij",
"Column": "Kolom",
"Cell properties": "Celeigenschappen",
"Merge cells": "Cellen samenvoegen",
"Split cell": "Cel splitsen",
"Insert row before": "Rij boven invoegen",
"Insert row after": "Rij onder invoegen",
"Delete row": "Rij verwijderen",
"Row properties": "Rijeigenschappen",
"Cut row": "Rij knippen",
"Copy row": "Rij kopi\u00ebren",
"Paste row before": "Rij boven plakken",
"Paste row after": "Rij onder plakken",
"Insert column before": "Kolom invoegen voor",
"Insert column after": "Kolom invoegen na",
"Delete column": "Kolom verwijderen",
"Cols": "Kolommen",
"Rows": "Rijen",
"Width": "Breedte\\v",
"Height": "Hoogte",
"Cell spacing": "Celafstand",
"Cell padding": "Celopvulling",
"Caption": "Bijschrift",
"Show caption": "Bijschrift tonen",
"Left": "Links",
"Center": "Midden",
"Right": "Rechts",
"Cell type": "Celtype",
"Scope": "Bereik",
"Alignment": "Uitlijning",
"H Align": "H uitlijnen",
"V Align": "V uitlijnen",
"Top": "Boven",
"Middle": "Midden",
"Bottom": "Onder",
"Header cell": "Koptekstcel",
"Row group": "Rijgroep",
"Column group": "Kolomgroep",
"Row type": "Rijtype",
"Header": "Koptekst",
"Body": "Hoofdtekst",
"Footer": "Voettekst",
"Border color": "Randkleur",
"Insert template...": "Sjabloon invoegen...",
"Templates": "Sjablonen",
"Template": "Sjabloon",
"Text color": "Tekstkleur",
"Background color": "Achtergrondkleur",
"Custom...": "Aangepast...",
"Custom color": "Aangepaste kleur",
"No color": "Geen kleur",
"Remove color": "Kleur verwijderen",
"Table of Contents": "Inhoudsopgave",
"Show blocks": "Blokken tonen",
"Show invisible characters": "Onzichtbare tekens tonen",
"Word count": "Aantal woorden",
"Count": "Tellen",
"Document": "Document",
"Selection": "Selectie",
"Words": "Woorden",
"Words: {0}": "Woorden: {0}",
"{0} words": "{0} woorden",
"File": "Bestand",
"Edit": "Bewerken",
"Insert": "Invoegen",
"View": "Tonen",
"Format": "Formaat",
"Table": "Tabel",
"Tools": "Gereedschappen",
"Powered by {0}": "Aangedreven door {0}",
"Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help": "Rich Text Area. Druk op Alt-F9 voor menu. Druk op Alt-F10 voor gereedschapsbalk. Druk op Alt-0 voor help",
"Image title": "Afbeeldingstitel",
"Border width": "Randbreedte",
"Border style": "Randstijl",
"Error": "Fout",
"Warn": "Waarschuwen",
"Valid": "Geldig",
"To open the popup, press Shift+Enter": "Druk op Shift+Enter om de pop-up te openen",
"Rich Text Area. Press ALT-0 for help.": "Rich Text Area. Druk op Alt-0 voor help.",
"System Font": "Systeemlettertype",
"Failed to upload image: {0}": "Afbeelding uploaden niet gelukt: {0}",
"Failed to load plugin: {0} from url {1}": "Plug-in laden niet gelukt: {0} vanaf url {1}",
"Failed to load plugin url: {0}": "Plug-in URL laden niet gelukt: {0}",
"Failed to initialize plugin: {0}": "Plug-in initialiseren niet gelukt: {0}",
"example": "voorbeeld",
"Search": "Zoeken",
"All": "Alle",
"Currency": "Valuta",
"Text": "Tekst",
"Quotations": "Citaten",
"Mathematical": "Wiskundig",
"Extended Latin": "Latijn uitgebreid",
"Symbols": "Symbolen",
"Arrows": "Pijlen",
"User Defined": "Gebruiker Gedefinieerd",
"dollar sign": "dollar teken",
"currency sign": "valuta teken",
"euro-currency sign": "euro valuta teken",
"colon sign": "colon teken",
"cruzeiro sign": "cruzeiro teken",
"french franc sign": "franse frank teken",
"lira sign": "lire teken",
"mill sign": "mill teken",
"naira sign": "naira teken",
"peseta sign": "peseta teken",
"rupee sign": "roepie teken",
"won sign": "won teken",
"new sheqel sign": "nieuwe shekel teken",
"dong sign": "dong teken",
"kip sign": "kip teken",
"tugrik sign": "tugrik teken",
"drachma sign": "drachme teken",
"german penny symbol": "duitse pfennig teken",
"peso sign": "peso teken",
"guarani sign": "guarani teken",
"austral sign": "austral teken",
"hryvnia sign": "hryvnia teken",
"cedi sign": "cedi teken",
"livre tournois sign": "tours pond teken",
"spesmilo sign": "spesmilo teken",
"tenge sign": "tenge teken",
"indian rupee sign": "indische roepie teken",
"turkish lira sign": "turkse lira teken",
"nordic mark sign": "noordse mark teken",
"manat sign": "manat teken",
"ruble sign": "roebel teken",
"yen character": "yen karakter",
"yuan character": "yuan karakter",
"yuan character, in hong kong and taiwan": "yuan karakter, in hong kong en taiwan",
"yen\/yuan character variant one": "yen\/yuan karakter variant een",
"Loading emoticons...": "Emoticons laden...",
"Could not load emoticons": "Kon emoticons niet laden",
"People": "Mensen",
"Animals and Nature": "Dieren en natuur",
"Food and Drink": "Voedsel en drank",
"Activity": "Activiteit",
"Travel and Places": "Reizen en plaatsen",
"Objects": "Voorwerpen",
"Flags": "Vlaggen",
"Characters": "Karakters",
"Characters (no spaces)": "Karakters (zonder spaties)",
"{0} characters": "{0} karakters",
"Error: Form submit field collision.": "Fout: Veldconflict bij versturen formulier.",
"Error: No form element found.": "Fout: Geen formulierelement gevonden.",
"Update": "Updaten",
"Color swatch": "Kleurenstaal",
"Turquoise": "Turkoois",
"Green": "Groen",
"Blue": "Blauw",
"Purple": "Paars",
"Navy Blue": "Marineblauw",
"Dark Turquoise": "Donker turkoois",
"Dark Green": "Donker groen",
"Medium Blue": "Middelblauw",
"Medium Purple": "Middelpaars",
"Midnight Blue": "Middernachtblauw",
"Yellow": "Geel",
"Orange": "Oranje",
"Red": "Rood",
"Light Gray": "Lichtgrijs",
"Gray": "Grijs",
"Dark Yellow": "Donker Geel",
"Dark Orange": "Donker Oranje",
"Dark Red": "Donker Rood",
"Medium Gray": "Middel Grijs",
"Dark Gray": "Donker Grijs",
"Light Green": "Licht Groen",
"Light Yellow": "Licht Geel",
"Light Red": "Licht Rood",
"Light Purple": "Licht Paars",
"Light Blue": "Licht Blauw",
"Dark Purple": "Donker Paars",
"Dark Blue": "Donker Blauw",
"Black": "Zwart",
"White": "Wit",
"Switch to or from fullscreen mode": "Schakelen naar of vanuit volledige schermmodus",
"Open help dialog": "Helpdialoog openen",
"history": "geschiedenis",
"styles": "stijlen",
"formatting": "opmaak",
"alignment": "uitlijning",
"indentation": "inspringing",
"Font": "Lettertype",
"Size": "Grootte",
"More...": "Meer...",
"Select...": "Selecteren...",
"Preferences": "Voorkeuren",
"Yes": "Ja",
"No": "Nee",
"Keyboard Navigation": "Toetsenbord navigatie",
"Version": "Versie",
"Code view": "Codeweergave",
"Open popup menu for split buttons": "Open pop-up menu voor gesplitste knoppen",
"List Properties": "Lijst Eigenschappen",
"List properties...": "Lijst eigenschappen...",
"Start list at number": "Begin lijst bij nummer",
"Line height": "Regelhoogte",
"comments": "opmerkingen",
"Format Painter": "Format Painter",
"Insert\/edit iframe": "iFrame invoegen\/bewerken",
"Capitalization": "Hoofdlettergebruik",
"lowercase": "kleine letters",
"UPPERCASE": "HOOFDLETTERS",
"Title Case": "Titel hoofdlettergebruik",
"permanent pen": "permanente pen",
"Permanent Pen Properties": "Permanent Pen Eigenschappen",
"Permanent pen properties...": "Permanent pen eigenschappen...",
"case change": "hoofdlettergebruik veranderen",
"page embed": "pagina insluiten",
"Advanced sort...": "Geavanceerd sorteren...",
"Advanced Sort": "Geavanceerd Sorteren",
"Sort table by column ascending": "Sorteer tabel per kolom in oplopende volgorde",
"Sort table by column descending": "Sorteer tabel per kolom in aflopende volgorde",
"Sort": "Sorteren",
"Order": "Ordenen",
"Sort by": "Sorteren op",
"Ascending": "Oplopend",
"Descending": "Aflopend",
"Column {0}": "Kolom {0}",
"Row {0}": "Rij {0}",
"Spellcheck...": "Spellingscontrole...",
"Misspelled word": "Fout gespeld woord",
"Suggestions": "Suggesties",
"Change": "Wijzigen",
"Finding word suggestions": "Woordsuggesties zoeken",
"Success": "Gelukt",
"Repair": "Herstellen",
"Issue {0} of {1}": "Probleem {0} van {1}",
"Images must be marked as decorative or have an alternative text description": "Afbeeldingen markeren als decoratief of alternatieve tekstbeschrijving geven",
"Images must have an alternative text description. Decorative images are not allowed.": "Afbeeldingen moeten een alternatieve tekstbeschrijving hebben. Decoratieve afbeeldingen zijn niet toegelaten.",
"Or provide alternative text:": "Of voorzie alternatieve tekst:",
"Make image decorative:": "Afbeelding decoratief maken",
"ID attribute must be unique": "ID attribuut moet uniek zijn",
"Make ID unique": "ID uniek maken",
"Keep this ID and remove all others": "Dit ID behouden en alle andere verwijderen",
"Remove this ID": "Dit ID verwijderen",
"Remove all IDs": "Alle IDs verwijderen",
"Checklist": "Controlelijst"
});