<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Archive plugin             |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['buttontext'] = 'Arhiveeri';
$labels['buttontitle'] = 'Arhiveeri see kiri';
$labels['archived'] = 'Edukalt arhiveeritud';
$labels['archivedreload'] = 'Arhiveerimine õnnestus. Uute arhiivi kaustada nägemiseks laadi leht uuesti.';
$labels['archiveerror'] = 'Mõnda kirja ei õnnestusnud arhiveerida';
$labels['archivefolder'] = 'Arhiiv';
$labels['settingstitle'] = 'Arhiiv';
$labels['archivetype'] = 'Jaga arhiiv';
$labels['archivetypeyear'] = 'Aasta (nt. Arhiiv/2012)';
$labels['archivetypemonth'] = 'Kuu (nt. Arhiiv/2012/06)';
$labels['archivetypefolder'] = 'Esialgne kaust';
$labels['archivetypefolderyear'] = 'Aasta ja algne kaust (nt. Arhiiv/2012/...)';
$labels['archivetypesender'] = 'Saatja e-post';
$labels['unkownsender'] = 'teadmata';
$labels['readonarchive'] = 'Märgi kiri arhiveerimisel loetuks';
