<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail MarkdownEditor plugin      |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['editor_icon_alt'] = 'Markdown-ritill';
$labels['editor_button_title'] = 'Skrifaðu skilaboð í Markdown og láttu senda þau sem HTML';
$labels['toolbar_button_quit'] = 'Til baka í ritil með hreinum texta';
$labels['toolbar_button_help'] = 'Opna leiðbeiningar fyrir Markdown-málskipan í nýjum glugga';
$labels['toolbar_button_preview'] = 'Forskoða HTML eins og það myndi verða sent';
$labels['toolbar_button_bold'] = 'Feitletrað';
$labels['toolbar_button_italic'] = 'Skáletrað';
$labels['toolbar_button_strike'] = 'Gegnumstrikað';
$labels['toolbar_button_h1'] = 'Fyrirsögn stig 1';
$labels['toolbar_button_h2'] = 'Fyrirsögn stig 2';
$labels['toolbar_button_h3'] = 'Fyrirsögn stig 3';
$labels['toolbar_button_h4'] = 'Fyrirsögn stig 4';
$labels['toolbar_button_h5'] = 'Fyrirsögn stig 5';
$labels['toolbar_button_h6'] = 'Fyrirsögn stig 6';
$labels['toolbar_button_blockquote'] = 'Tilvitnun';
$labels['toolbar_button_unordered_list'] = 'Óraðaður listi';
$labels['toolbar_button_ordered_list'] = 'Raðaður listi';
$labels['toolbar_button_link'] = 'Tengill';
$labels['toolbar_button_image'] = 'Mynd';
$labels['toolbar_button_undo'] = 'Afturkalla';
$labels['toolbar_button_redo'] = 'Endurgera';
