<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Archive plugin             |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['buttontext'] = 'Archyvuoti';
$labels['buttontitle'] = 'Perkelti šį laišką į archyvą';
$labels['archived'] = 'Laiškas sėkmingai perkeltas į archyvą';
$labels['archivedreload'] = 'Sėkmingai perkelta į archyvą. Iš naujo įkelkite puslapį, kad pamatytumėt pasikeitimus.';
$labels['archiveerror'] = 'Į archyvą nepavyko perkelti keleto laiškų.';
$labels['archivefolder'] = 'Archyvuoti';
$labels['settingstitle'] = 'Archyvuoti';
$labels['archivetype'] = 'Padalinti archyvą pagal';
$labels['archivetypeyear'] = 'Metai (pvz. Archyvas/2012)';
$labels['archivetypemonth'] = 'Mėnesis (pvz. Archyvas/2012/06)';
$labels['archivetypetbmonth'] = 'Mėnesis - Suderinama su Thunderbird (pvz., Archyvas/2012/2012-06)';
$labels['archivetypefolder'] = 'Tikrasis aplankas';
$labels['archivetypefolderyear'] = 'Metai ir pradinis aplankas (pvz., Archyvas/2012/...)';
$labels['archivetypefoldermonth'] = 'Metai, mėnuo ir pradinis aplankas (pvz., Archyvas/2012/06/...)';
$labels['archivetypesender'] = 'Siuntėjo el. pašto adresas';
$labels['unkownsender'] = 'nežinomas';
$labels['readonarchive'] = 'Archyvuojant, žymėti laišką kaip skaitytą';
