<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail MarkdownEditor plugin      |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['editor_icon_alt'] = 'Markdown 編輯器';
$labels['editor_button_title'] = '以 Markdown 撰寫訊息，並將其轉換為 HTML 格式傳送';
$labels['toolbar_button_quit'] = '回到純文字編輯器';
$labels['toolbar_button_help'] = '在新視窗中開啟 Markdown 語法指南';
$labels['toolbar_button_preview'] = '預覽要傳送的 HTML';
$labels['toolbar_button_bold'] = '粗體';
$labels['toolbar_button_italic'] = '義式斜體';
$labels['toolbar_button_strike'] = '刪除線';
$labels['toolbar_button_h1'] = '標題層級 1';
$labels['toolbar_button_h2'] = '標題層級 2';
$labels['toolbar_button_h3'] = '標題層級 3';
$labels['toolbar_button_h4'] = '標題層級 4';
$labels['toolbar_button_h5'] = '標題層級 5';
$labels['toolbar_button_h6'] = '標題層級 6';
$labels['toolbar_button_blockquote'] = '區塊引用';
$labels['toolbar_button_unordered_list'] = '無序清單';
$labels['toolbar_button_ordered_list'] = '有序清單';
$labels['toolbar_button_link'] = '連結';
$labels['toolbar_button_image'] = '影像';
$labels['toolbar_button_undo'] = '復原';
$labels['toolbar_button_redo'] = '重做';
