<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$messages['errortitle']  = 'დაფიქსირდა შეცდომა!';
$messages['loginfailed']  = 'შესვლა შეუძლებელია';
$messages['cookiesdisabled'] = 'თქვენი ბროუზერი კუკიებს არ პასუხობს';
$messages['sessionerror'] = 'თქვენი სესია არის მცდარი ან ვადაგასული';
$messages['storageerror'] = 'IMAP სერვერთან დაკავშირება შეუძლებელია';
$messages['servererror'] = 'შეცდომა სერვერზე!';
$messages['servererrormsg'] = 'სერვერის შეცდომა: $msg';
$messages['accountlocked'] = 'ძალიან ბევრი წარუმატებელი შესვლის მცდელობა. მოგვიანებით სცადეთ.';
$messages['connerror'] = 'კავშირის შეცდომა (სერვერთან კავშირი შეუძლებელია)!';
$messages['dberror'] = 'მონაცემთა ბაზის შეცდომა!';
$messages['requesttimedout'] = 'მოთხოვნას ვადა გაუვიდა';
$messages['errorreadonly'] = 'ოპერაციის შესრულება შეუძლებელია. საქაღალდე არის მხოლოდ წაწკითხვის რეჟიმში.';
$messages['errornoperm'] = 'მოქმედების შესრულება შეუძლებალია. წვდომა აკრძალულია.';
$messages['erroroverquota'] = 'მოქმედების შესრულება შეუძლებალია. დისკზე არ დარჩა თავისუფალი ადგილი.';
$messages['erroroverquotadelete'] = 'დისკზე არ დარჩა თავისუფალი ადგილი. გამოიყენეთ SHIFT+DEL შეტყობინების წასასშლელად.';
$messages['invalidrequest'] = 'არასწორი მოთხოვნა! მონაცემების შენახვა არ მოხერხდა.';
$messages['invalidhost'] = 'არასწორი სერვერის სახელი';
$messages['nomessagesfound'] = 'არ არის ახალი შეტყობინება';
$messages['mailboxempty'] = 'საფოსტო ყუთი ცარიელია';
$messages['nomessages'] = 'არ არის შეტყობინებები';
$messages['refreshing'] = 'განახლება...';
$messages['loading'] = 'იტვირთება...';
$messages['uploading'] = 'ფაილი იტვირთება...';
$messages['attaching'] = 'ფაილის მიმაგრება...';
$messages['uploadingmany'] = 'ფაილების ატვირთვა...';
$messages['loadingdata'] = 'მონაცემების ჩატვირთვა...';
$messages['checkingmail'] = 'ახალი შეტყობინების ნახვა';
$messages['sendingmessage'] = 'შეტყობინების გაგზავნა';
$messages['messagesent'] = 'შეტყობინება გაიგზავნა წარმატებით';
$messages['savingmessage'] = 'შეტყობინების შენახვა...';
$messages['messagesaved'] = 'შეტყობინების დროებით შენახვა';
$messages['successfullysaved'] = 'წარმატებით შეინახა';
$messages['addedsuccessfully'] = 'კონტაქტი წარმატებით დაემატა მისამართებში';
$messages['contactnameexists'] = 'კონტაქტი იგივე სახელით უკვე არსებობს.';
$messages['blockedimages'] = 'უსაფრთხოების მიზნით სურათების ჩვენება შეზღუდულია';
$messages['encryptedmessage'] = 'შეტყობინება დაშიფრულია და სამწუხაროდ ჩვენება შეუძლებელია';
$messages['nocontactsfound'] = 'კონტაქტი ვერ მოიძებნა';
$messages['contactnotfound'] = 'მოთხოვნილი კონტაქტი ვერ მოიძებნა';
$messages['sendingfailed'] = 'შეტყობინება ვერ გაიგზავნა';
$messages['senttooquickly'] = 'გთხოვთ მოიცადოთ $sec წამი. სანამ იგზავნება შეტყობინება';
$messages['errorsavingsent'] = 'გაგზავნილი შეტყობინების შენახვის დროს მოხდა შეცდომა.';
$messages['errorsaving'] = 'შეტყობინების შენახვის დროს მოხდა შეცდომა';
$messages['errormoving'] = 'შეტყობინების გადატანა შეუძლებელია';
$messages['errorcopying'] = 'შეტყობინების კოპირება შეუძლებელია.';
$messages['errordeleting'] = 'შეტყობინების წაშლა შეუძლებელია';
$messages['errormarking'] = 'შეტყობინების მონიშვნა შეუძლებელია';
$messages['alerttitle'] = 'ყურადღება';
$messages['deletecontactconfirm']  = 'ნამდვილად გსურთ მონიშნული კონტაქტების წაშლა?';
$messages['deletegroupconfirm']  = 'ნამდვილად გსურთ მონიშნული ჯგუფის წაშლა?';
$messages['deletemessagesconfirm'] = 'ნამდვილად გსურთ მონიშნული შეტყობინებების წაშლა?';
$messages['deletefolderconfirm']  = 'ნამდვილად გსურთ ამ საქაღალდის წაშლა?';
$messages['purgefolderconfirm']  = 'ნამდვილად გსურთ ყველა შეტყობინების წაშლა აღნიშნულ საქაღალდეში?';
$messages['contactdeleting'] = 'კონტაქტის წაშლა...';
$messages['groupdeleting'] = 'ჯგუფის წაშლა...';
$messages['folderdeleting'] = 'საქაღალდის წაშლა...';
$messages['foldermoving'] = 'საქაღალდის გადატანა...';
$messages['foldersubscribing'] = 'საქაღალდის გამოწერა...';
$messages['folderunsubscribing'] = 'საქაღალდის გამოწერაის გაუქმება...';
$messages['formincomplete'] = 'ყველა ველი არ არის შევსებული';
$messages['noemailwarning'] = 'მიუთითეთ სწორი ელ–ფოსტის მისამართი';
$messages['nonamewarning']  = 'მიუთითეთ სახელი';
$messages['nopagesizewarning'] = 'მიუთითეთ ფურცლის ზომა';
$messages['norecipientwarning'] = 'მიუთითეთ მიმღები';
$messages['nosubjectwarning']  = 'გსურთ თუ არა შეტყობინების გაგზავნა უსათაუროდ?';
$messages['nobodywarning'] = 'გსურთ თუ არა შეტყობინების გაგზავნა უტექსტოდ?';
$messages['nosearchname'] = 'მიუთითეთ სახელი ან ელ–ფოსტის მისამართი';
$messages['notuploadedwarning'] = 'ჯერ არ ატვირთულა ყველა მიმაგრებული ფაილი. დაელოდეთ ან გააუქმეთ ატვირთვა.';
$messages['searchsuccessful'] = '$nr შეტყობინეა მოიძებნა';
$messages['contactsearchsuccessful'] = 'ნაპოვნია $nr კონტაქტი';
$messages['searchnomatch'] = 'შეტყობინება ვერ მოიძებნა';
$messages['searching'] = 'ძიება...';
$messages['checking'] = 'შემოწმება...';
$messages['stillsearching'] = 'ჯერ კიდევ ეძებს ...';
$messages['nospellerrors'] = 'ორთოგრაფიული შეცდომა არ არის';
$messages['folderdeleted'] = 'საქაღალდე წარმატებით წაიშალა';
$messages['foldersubscribed'] = 'საქაღალდე წარმატებით გამოწერილია.';
$messages['folderunsubscribed'] = 'საქაღალდის გამოწერა წარმატებით გაუქმებულია.';
$messages['deletedsuccessfully'] = 'წარმატებით წაიშალა';
$messages['converting'] = 'შეტყობინების ფორმატირების გაუქმება...';
$messages['messageopenerror'] = 'შეტყობინება ვერ ჩაიტვირთა სერვერიდან';
$messages['filelinkerror'] = 'ფაილის მიმაგრება ვერ მოხდა.';
$messages['fileuploaderror'] = 'ფაილი ვერ აიტვირთა';
$messages['filesizeerror'] = 'ატვირთული ფაილის ზომა მეტია დასაშვებ ფაილის მაქსიმალურ ზომაზე ($size)';
$messages['copysuccess'] = 'წარმატებულად დაკოპირდა $nr კონტაქტი.';
$messages['movesuccess'] = 'წარმატებულად გადატანილია $nr კონტაქტი.';
$messages['copyerror'] = 'ვერცერთი კონტაქტის კოპირება ვერ მოხერხდა.';
$messages['moveerror'] = 'ვერცერთი კონტაქტის გადატანა ვერ მოხერხდა.';
$messages['sourceisreadonly'] = 'აღნიშნული მისამართის მხოლოდ წაკითხვაა შესაძლებელი';
$messages['errorsavingcontact'] = 'საკონტაქტო მისამართის შენახვა შეუძლებელია';
$messages['movingmessage'] = 'შეტყობინების გადატანა...';
$messages['copyingmessage'] = 'შეტყობინების კოპოირება...';
$messages['copyingcontact'] = 'კონტაქტის კოპირება...';
$messages['movingcontact'] = 'კონტაქტის გადატანა...';
$messages['deletingmessage'] = 'შეტყობინების წაშლა...';
$messages['markingmessage'] = 'შეტყობინების მონიშვნა...';
$messages['addingmember'] = 'კონტაქტების დამატება ჯგუფში...';
$messages['removingmember'] = 'კონტაქტების წაშლა ჯგუფიდან...';
$messages['receiptsent'] = 'წარმატებით გაიგზავნა';
$messages['errorsendingreceipt'] = 'არ გაიგზავნა';
$messages['nodeletelastidentity'] = 'წაშლა შეუძლებელია, ის თქვენთვის ერთადერთია';
$messages['forbiddencharacter'] = 'საქაღალდის სახელი შეიცავს აკრძალულ სიმბოლოებს';
$messages['selectimportfile'] = 'გთხოვთ მონიშნოთ ფაილი ასატვირთად';
$messages['addresswriterror'] = 'მონიშნულ მისამართებში ჩაწერა შეუძლებელია';
$messages['contactaddedtogroup'] = 'წარმატებულად დაემატა კონტაქტები ჯგუფში.';
$messages['contactremovedfromgroup'] = 'წარმატებულად წაიშალა კონტაქტები ჯგუფიდან.';
$messages['nogroupassignmentschanged'] = 'ჯგუფების მიმაგრება არ შეცვლილა.';
$messages['importwait'] = 'გთხოვთ მოიცადოთ, მიმდინარეობს შემოტანა';
$messages['importconfirm'] = '<b>წარმატებით დასრულდა $inserted კონტაქტების შემოტანა, $skipped არსებულის გამოტოვება</b>:<p><em>$names</em></p>';
$messages['opnotpermitted'] = 'ოპერაცია შეზღუდულია';
$messages['httpreceivedencrypterror'] = 'სერვერზე მოხდა შეცდომა. დაუყონებლივ დაუკავშირდით ადმინისტრატორს. <b>თქვენი შეტყობინება შესაძლოა ვერ გაიგზავნა.</b>';
$messages['smtpconnerror'] = 'SMTP Error ($code): სერვერთან დაკავშირება ვერ მოხერხდა';
$messages['smtpautherror'] = 'SMTP Error ($code): ავტორიზაციის შეცდომა';
$messages['smtpfromerror'] = 'SMTP Error ($code): ვერ მიეთითა გამგზავნი "$from" ($msg)';
$messages['smtptoerror'] = 'SMTP Error ($code): ვერ დაემატა მიმღები "$to" ($msg)';
$messages['smtprecipientserror'] = 'SMTP Error: მიმღებთა ჩამონათვალის დამუშავება ვერ მოხერხდა';
$messages['smtperror'] = 'SMTP Error: $msg';
$messages['maxgroupmembersreached'] = 'ჯგუფის წევრების რაოდენობა მეტია დასაშვებ ($size)-ზე';
$messages['internalerror'] = 'დაფიქსირდა შეცდომა. გთხოვთ სცადოთ მოგვიანებით.';
$messages['contactdelerror'] = 'კონტაქტის წაშლა არ მოხერხდა.';
$messages['contactdeleted'] = 'კონტაქტ(ებ)ი წარმატებით წაიშალა.';
$messages['contactrestoreerror'] = 'წაშლილი კონტაქტების აღდგენა არ მოხერხდა.';
$messages['contactrestored'] = 'კონრაქტ(ებ)ი წარმატებით აღდგა,';
$messages['groupdeleted'] = 'ჯგუფი წარმატებით წაიშალა.';
$messages['grouprenamed'] = 'ჯგუფს წარმატებულად გადაერქვა სახელი.';
$messages['groupcreated'] = 'ჯგუფი წარმატებით შეიქმნა.';
$messages['savedsearchdeleted'] = 'შენახული ძიება წარმატებულად წაშლილია.';
$messages['savedsearchdeleteerror'] = 'შენახული ძიების წაშლა ვერ მოხერხდა.';
$messages['savedsearchcreated'] = 'შენახული ძიების შექმნილია წარმატებულად.';
$messages['savedsearchcreateerror'] = 'შენახული ძიების შექმნა ვერ მოხერხდა.';
$messages['messagedeleted'] = 'შეტყობინებები წარმატებით წაიშალა.';
$messages['messagemoved'] = 'შეტყობინებები გადატანილია წარმატებით.';
$messages['messagecopied'] = 'შეტყობინება დაკოპირებულია წარმატებით.';
$messages['messagemarked'] = 'შეტყობინებები წარმატებით მოინიშნა.';
$messages['autocompletechars'] = 'შეიყვანეთ მინიმუმ $min სიმბოლო ავტომატური დაბოლოებისათვის.';
$messages['autocompletemore'] = 'დამთხვევა ვერ მოხერხდა. გთხოვთ კიდევ შეიყვანოთ სიმბოლოები.  ';
$messages['namecannotbeempty'] = 'სახელი არ შეიძლება იყოს ცარიელი.';
$messages['nametoolong'] = 'სახელი ძალიან მოკლეა.';
$messages['namedotforbidden'] = 'საქაღალდის სახელი არ შეიძლება იწყებოდეს წერტილით.';
$messages['folderupdated'] = 'დასტა წარმატებით განახლდა.';
$messages['foldercreated'] = 'დასტა წარმატებით შეიქმნა.';
$messages['invalidimageformat'] = 'გამოსახულების ფორმატი არასწორია.';
$messages['mispellingsfound'] = 'გრამატიკული შეცდომები დაფიქსირდა შეტყობინებაში.';
$messages['errnotfound'] = 'ფაილი არ მოიძებნა.';
$messages['errnotfoundexplain'] = 'მოთხოვნილი რესურსი ვერ მოიძებნა!';
$messages['errcontactserveradmin'] = 'გთხოვთ დაუკავშირდეთ სერვერის ადმინისტრატორს.';
$messages['clicktoresumesession'] = 'დააჭირეთ აქ რომ განაგრძოთ წინა სესია.';
$messages['clicktocompose'] = 'დააჭირეთ აქ რომ შექმნათ ახალი შეტყობინება.';
