<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail ACL plugin                 |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['sharing'] = 'ការ​ចែក​រំលែក';
$labels['myrights'] = 'សិទ្ធិ​ចូល';
$labels['username'] = 'អ្នក​ប្រើ៖';
$labels['advanced'] = 'បែប​កម្រិត​ខ្ពស់';
$labels['add'] = 'បន្ថែម';
$labels['newuser'] = 'បន្ថែម​ធាតុ';
$labels['actions'] = 'សកម្មភាព​សិទ្ធិ​ចូល...';
$labels['anyone'] = 'អ្នក​ប្រើ​ទាំង​អស់ (នរណា​ម្នាក់)';
$labels['anonymous'] = 'ភ្ញៀវ (អនាមិក)';
$labels['acll'] = 'ស្វែងរក';
$labels['aclr'] = 'អាន​សារ';
$labels['acli'] = 'បញ្ចូល (ចម្លង​មក​ដាក់)';
$labels['aclp'] = 'ប្រកាស';
$labels['aclc'] = 'បង្កើត​ថត​រង';
$labels['aclk'] = 'បង្កើត​ថត​រង';
$labels['acld'] = 'លុប​សារ';
$labels['aclt'] = 'លុប​សារ';
$labels['acle'] = 'ដកចេញ';
$labels['aclx'] = 'លុប​ថត';
$labels['acla'] = 'អភិបាល';
$labels['aclfull'] = 'បញ្ជា​ទាំង​អស់';
$labels['aclother'] = 'ផ្សេងៗ';
$labels['aclread'] = 'អាន';
$labels['aclwrite'] = 'សរសេរ';
$labels['acldelete'] = 'លុប';
$labels['shortacll'] = 'ស្វែងរក';
$labels['shortaclr'] = 'អាន';
$labels['shortacls'] = 'រក្សា';
$labels['shortaclw'] = 'សរសេរ';
$labels['shortacli'] = 'បញ្ចូល';
$labels['shortaclp'] = 'ប្រកាស';
$labels['shortaclc'] = 'បង្កើត';
$labels['shortaclk'] = 'បង្កើត';
$labels['shortacld'] = 'លុប';
$labels['shortaclt'] = 'លុប';
$labels['shortacle'] = 'ដកចេញ';
$labels['shortaclx'] = 'ការ​លុប​ថត';
$labels['shortacla'] = 'អភិបាល';
$labels['shortaclother'] = 'ផ្សេងៗ';
$labels['shortaclread'] = 'អាន';
$labels['shortaclwrite'] = 'សរសេរ';
$labels['shortacldelete'] = 'លុប';
$labels['longaclr'] = 'ថត​នេះ​អាច​បើក​សម្រាប់​អាន';
$labels['longacle'] = 'សារ​នេះ​អាច​ត្រូវ​បាន​ដក​ចេញ';
$labels['longaclx'] = 'ថត​នេះ អាច​ត្រូវ​បាន​លុប ឬ​ ប្ដូរ​ឈ្មោះ';
$labels['longacla'] = 'សិទ្ធិ​ចូល​ទៅ​កាន់​ថត​នេះ​អាច​ត្រូវ​បាន​​ផ្លាស់​ប្ដូរ​';
$labels['longaclread'] = 'ថត​នេះ​អាច​បើក​សម្រាប់​អាន';
$labels['longacldelete'] = 'សារ​នេះ​អាច​ត្រូវ​បាន​លុប';
$messages['deleting'] = 'កំពុង​លុប​សិទ្ធិ​ចូល...';
$messages['saving'] = 'រក្សា​ទុក​សិទ្ធិ​ចូល...';
$messages['deletesuccess'] = 'លុប​សិទ្ធិ​ចូល​ដោយ​ជោគជ័យ​';
$messages['createsuccess'] = 'បន្ថែម​សិទ្ធិ​ចូល​ដោយ​ជោគជ័យ';
$messages['updateerror'] = 'មិន​អាច​ធ្វើ​បច្ចុប្បន្នភាព​សិទ្ធិ​ចូល';
$messages['deleteerror'] = 'មិន​អាច​លុប​សិទ្ធិ​ចូល';
$messages['createerror'] = 'មិន​អាច​បន្ថែម​សិទ្ធិ​ចូល';
$messages['deleteconfirm'] = 'តើ​អ្នក​ពិត​ជា​ចង់​ដក​សិទ្ធ​ចូល​ពី​អ្នក​ប្រើប្រាស់​ដែល​បាន​រើស​មែនទេ?';
$messages['norights'] = 'មិន​បាន​បញ្ជាក់​សិទ្ធិ​ច្បាស់​លាស់!';
$messages['nouser'] = 'មិន​បាន​បញ្ជាក់​ឈ្មោះ​អ្នក​ប្រើ!';
