<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Managesieve plugin         |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['filters'] = 'Filteren';
$labels['managefilters'] = 'Filtere geréieren fir Mailen déi erakommen';
$labels['filtername'] = 'Numm vum Filter';
$labels['newfilter'] = 'Neie Filter';
$labels['filteradd'] = 'Filter dobäisetzen';
$labels['filterdel'] = 'Filter läschen';
$labels['scope'] = 'Ëmfang';
$labels['moveup'] = 'Eropréckelen';
$labels['movedown'] = 'Erofréckelen';
$labels['filterallof'] = 'all dës Reegele mussen zoutreffen';
$labels['filteranyof'] = 'just eng vun de Reegele muss zoutreffen';
$labels['filterany'] = 'all d\'Messagen';
$labels['filtercontains'] = 'enthält';
$labels['filternotcontains'] = 'enthält net';
$labels['filteris'] = 'ass gläich';
$labels['filterisnot'] = 'ass net gläich';
$labels['filterexists'] = 'existéiert';
$labels['filternotexists'] = 'existéiert net';
$labels['filterunder'] = 'ënner';
$labels['filterover'] = 'iwwer';
$labels['addrule'] = 'Reegel dobäisetzen';
$labels['delrule'] = 'Reegel läschen';
$labels['messagemoveto'] = 'Message verréckelen an';
$labels['messageredirect'] = 'Message ëmleeden an';
$labels['messagecopyto'] = 'Message kopéieren an';
$labels['messagesendcopy'] = 'Kopie vum Message schécken un';
$labels['messagereply'] = 'Mat dësem Message äntweren';
$labels['messagedelete'] = 'Message läschen';
$labels['add'] = 'Dobäisetzen';
$labels['del'] = 'Läschen';
$labels['sender'] = 'Ofsender';
$labels['recipient'] = 'Empfänger';
$labels['flagread'] = 'Gelies';
$labels['flagdeleted'] = 'Geläscht';
$labels['flagflagged'] = 'Mat Fändel';
$labels['notifymethodmailto'] = 'E-Mail';
$labels['notifymethodtel'] = 'Telefon';
$labels['datetest'] = 'Datum';
$labels['advancedopts'] = 'Avancéiert Optiounen';
$labels['body'] = 'Kierper';
$labels['spamtestequals'] = 'ass gläich';
$labels['spamtestnotequals'] = 'ass net gläich';
$labels['vacation.subject'] = 'Sujet';
$labels['vacation.body'] = 'Kierper';
$labels['vacation.keep'] = 'Halen';
