<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail ACL plugin                 |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['sharing'] = 'การแชร์ข้อมูล';
$labels['myrights'] = 'สิทธิ์การเข้าใช้';
$labels['username'] = 'ผู้ใช้งาน:';
$labels['add'] = 'เพิ่ม';
$labels['newuser'] = 'เพิ่มรายการ';
$labels['anyone'] = 'ผู้ใช้งานทั้งหมด (ใครก็ได้)';
$labels['anonymous'] = 'ผู้เยี่ยมชม (คนแปลกหน้า)';
$labels['acll'] = 'ดู';
$labels['aclr'] = 'อ่านข้อความ';
$labels['acli'] = 'แทรก (คัดลอกไปไว้)';
$labels['aclp'] = 'โพสต์';
$labels['aclc'] = 'สร้างโฟลเดอร์ย่อย';
$labels['aclk'] = 'สร้างโฟลเดอร์ย่อย';
$labels['acld'] = 'ลบข้อความ';
$labels['aclt'] = 'ลบข้อความ';
$labels['aclx'] = 'ลบโฟลเดอร์';
$labels['acla'] = 'Administer';
$labels['aclfull'] = 'Full control';
$labels['aclother'] = 'อื่นๆ';
$labels['aclread'] = 'อ่าน';
$labels['aclwrite'] = 'เขียน';
$labels['acldelete'] = 'ลบ';
$labels['shortacll'] = 'ดู';
$labels['shortaclr'] = 'อ่าน';
$labels['shortacls'] = 'เก็บ';
$labels['shortaclw'] = 'เขียน';
$labels['shortacli'] = 'แทรก';
$labels['shortaclp'] = 'โพสต์';
$labels['shortaclc'] = 'สร้าง';
$labels['shortaclk'] = 'สร้าง';
$labels['shortacld'] = 'ลบ';
$labels['shortaclt'] = 'ลบ';
$labels['shortaclx'] = 'ลบโฟลเดอร์';
$labels['shortacla'] = 'Administer';
$labels['shortaclother'] = 'อื่นๆ';
$labels['shortaclread'] = 'อ่าน';
$labels['shortaclwrite'] = 'เขียน';
$labels['shortacldelete'] = 'ลบ';
