<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['welcome'] = 'Ongi etorri $product-ra';
$labels['username'] = 'Erabiltzaile-izena';
$labels['password'] = 'Pasahitza';
$labels['server'] = 'Zerbitzaria';
$labels['login'] = 'Saio hasiera';
$labels['oauthlogin'] = 'Hasi saioa &hornitzaile batekin';
$labels['menu'] = 'Menua';
$labels['logout'] = 'Amaitu saioa';
$labels['mail'] = 'E-posta';
$labels['settings'] = 'Ezarpenak';
$labels['addressbook'] = 'Helbide liburua';
$labels['darkmode'] = 'Modu iluna';
$labels['lightmode'] = 'Modu argia';
$labels['inbox'] = 'Sarrera ontzia';
$labels['drafts'] = 'Zirriborroak';
$labels['sent'] = 'Bidalitakoak';
$labels['trash'] = 'Zakarrontzia';
$labels['junk'] = 'Zabor-posta';
$labels['show_real_foldernames'] = 'Erakutsi karpeta berezien benetako izenak';
$labels['subject'] = 'Gaia';
$labels['from'] = 'Nork';
$labels['sender'] = 'Igorlea';
$labels['to'] = 'Nori';
$labels['cc'] = 'Kopia';
$labels['bcc'] = 'Bcc';
$labels['replyto'] = 'Erantzun honi';
$labels['followupto'] = 'Jarraipena honi';
$labels['date'] = 'Data';
$labels['size'] = 'Tamaina';
$labels['priority'] = 'Lehentasuna';
$labels['organization'] = 'Erakundea';
$labels['readstatus'] = 'Irakurri egoera';
$labels['listoptions'] = 'Zerrendatu aukerak...';
$labels['listoptionstitle'] = 'Zerrendatu aukerak';
$labels['mailboxlist'] = 'Karpetak';
$labels['messagesfromto'] = '$from -tik $to -ra $count mezuetatik';
$labels['threadsfromto'] = '$from -etik $to -rako hariak (guztira $count)';
$labels['messagenrof'] = '$nr mezua $count -tik';
$labels['fromtoshort'] = '$from - $to , guztira $count';
$labels['copy'] = 'Kopiatu';
$labels['move'] = 'Mugitu';
$labels['moveto'] = 'Mugitu hona...';
$labels['copyto'] = 'Kopiatu hona...';
$labels['download'] = 'Deskargatu';
$labels['open'] = 'Ireki';
$labels['showattachment'] = 'Erakutsi';
$labels['showanyway'] = 'Erakutsi edonola';
$labels['filename'] = 'Fitxategi-izena';
$labels['filesize'] = 'Fitxategi-tamaina';
$labels['addtoaddressbook'] = 'Gehitu helbide liburura';
$labels['sun'] = 'Ig';
$labels['mon'] = 'Al';
$labels['tue'] = 'As';
$labels['wed'] = 'Azt';
$labels['thu'] = 'Og';
$labels['fri'] = 'Or';
$labels['sat'] = 'Lar';
$labels['sunday'] = 'Igandea';
$labels['monday'] = 'Astelehena';
$labels['tuesday'] = 'Asteartea';
$labels['wednesday'] = 'Asteazkena';
$labels['thursday'] = 'Osteguna';
$labels['friday'] = 'Ostirala';
$labels['saturday'] = 'Larunbata';
$labels['jan'] = 'Urt';
$labels['feb'] = 'Ots';
$labels['mar'] = 'Mar';
$labels['apr'] = 'Api';
$labels['may'] = 'Mai';
$labels['jun'] = 'Eka';
$labels['jul'] = 'Uzt';
$labels['aug'] = 'Abu';
$labels['sep'] = 'Ira';
$labels['oct'] = 'Urr';
$labels['nov'] = 'Aza';
$labels['dec'] = 'Abe';
$labels['longjan'] = 'Urtarrila';
$labels['longfeb'] = 'Otsaila';
$labels['longmar'] = 'Martxoa';
$labels['longapr'] = 'Apirila';
$labels['longmay'] = 'Maiatza';
$labels['longjun'] = 'Ekaina';
$labels['longjul'] = 'Uztaila';
$labels['longaug'] = 'Abuztua';
$labels['longsep'] = 'Iraila';
$labels['longoct'] = 'Urria';
$labels['longnov'] = 'Azaroa';
$labels['longdec'] = 'Abendua';
$labels['today'] = 'Gaur';
$labels['refresh'] = 'Freskatu';
$labels['checkmail'] = 'Arakatu mezu berrien bila';
$labels['compose'] = 'Idatzi mezu bat';
$labels['writenewmessage'] = 'Sortu mezu berri bat';
$labels['reply'] = 'Erantzun';
$labels['replytomessage'] = 'Mezuari erantzun';
$labels['replytoallmessage'] = 'Bidaltzaileari eta hartzaile guztiei erantzun';
$labels['replyall'] = 'Guztiei erantzun';
$labels['replylist'] = 'Erantzun zerrenda';
$labels['forward'] = 'Birbidali';
$labels['forwardinline'] = 'Birbidali barnean';
$labels['forwardattachment'] = 'Birbidali eranskin gisa';
$labels['forwardmessage'] = 'Birbidali mezua';
$labels['bouncemsg'] = 'Bidali berriro (errebotatu)';
$labels['bounce'] = 'Bidali berriro';
$labels['deletemessage'] = 'Ezabatu mezua';
$labels['undeletemessage'] = 'Berreskuratu mezua';
$labels['movemessagetotrash'] = 'Mugitu mezua zakarrontzira';
$labels['printmessage'] = 'Inprimatu mezu hau';
$labels['previousmessage'] = 'Erakutsi aurreko mezuak';
$labels['firstmessage'] = 'Erakutsi lehenengo mezua';
$labels['nextmessage'] = 'Erakutsi hurrengo mezua';
$labels['lastmessage'] = 'Erakutsi azken mezua';
$labels['backtolist'] = 'Mezu zerrendara itzuli';
$labels['viewsource'] = 'Erakutsi kodea';
$labels['mark'] = 'Markatu';
$labels['markmessages'] = 'Markatu mezuak';
$labels['markread'] = 'Irakurria bezala';
$labels['markunread'] = 'Ez-irakurria bezala';
$labels['markflagged'] = 'Markatua bezala';
$labels['markunflagged'] = 'Ez-markatua bezala';
$labels['markundeleted'] = 'Ezabatu gabe gisa';
$labels['markasread'] = 'Markatu irakurrita gisa';
$labels['markasunread'] = 'Markatu ez irakurrita gisa';
$labels['markasflagged'] = 'Markatu seinalatu gisa';
$labels['markasunflagged'] = 'Markatu ez seinalatu gisa';
$labels['moreactions'] = 'Ekintza gehiago...';
$labels['markallread'] = 'Markatu dena irakurrita bezala';
$labels['folders-cur'] = 'Hautatutako karpeta bakarrik';
$labels['folders-sub'] = 'Hautatutako karpeta eta haren azpikarpetak ';
$labels['folders-all'] = 'Karpeta guztiak';
$labels['more'] = 'Gehiago';
$labels['back'] = 'Atzera';
$labels['options'] = 'Aukerak';
$labels['composeoptions'] = 'Konposatu aukerak';
$labels['optionsandattachments'] = 'Aukerak eta eranskinak';
$labels['actions'] = 'Ekintzak';
$labels['first'] = 'Lehenengoa';
$labels['last'] = 'Azkena';
$labels['previous'] = 'Aurrekoa';
$labels['next'] = 'Hurrengoa';
$labels['select'] = 'Hautatu';
$labels['selection'] = 'Hautapena';
$labels['all'] = 'Denak';
$labels['none'] = 'Bat ere ez';
$labels['currpage'] = 'Uneko orrialdea';
$labels['isread'] = 'Irakurri';
$labels['unread'] = 'Irakurri gabeak';
$labels['flagged'] = 'Banderaduna';
$labels['unflagged'] = 'Etiketatu gabe';
$labels['unanswered'] = 'Erantzun gabea';
$labels['withattachment'] = 'Eranskinarekin';
$labels['deleted'] = 'Ezabatuak';
$labels['undeleted'] = 'Ezabatu gabeak';
$labels['replied'] = 'Erantzunda';
$labels['forwarded'] = 'Birbidalita';
$labels['invert'] = 'Alderantzizkatu';
$labels['filter'] = 'Iragazkia';
$labels['list'] = 'Zerrenda';
$labels['threads'] = 'Hariak';
$labels['expand-all'] = 'Hedatu denak';
$labels['expand-unread'] = 'Ireki irakurri gabeak';
$labels['collapse-all'] = 'Tolestu guztiak';
$labels['threaded'] = 'Harian';
$labels['showunread'] = 'Erakutsi irakurri gabeko mezuak';
$labels['autoexpand_threads'] = 'Hedatu mezu hariak';
$labels['do_expand'] = 'hari guztiak';
$labels['expand_only_unread'] = 'soilik irakurri gabeko mezuak dituztenak';
$labels['fromto'] = 'Nork/Nori';
$labels['flag'] = 'Bandera';
$labels['attachment'] = 'Eranskina';
$labels['nonesort'] = 'Bat ere ez';
$labels['sentdate'] = 'Bidalketa data';
$labels['arrival'] = 'Jasotze data';
$labels['asc'] = 'gorantz';
$labels['desc'] = 'beheruntz';
$labels['listcolumns'] = 'Zerrenda-zutabeak';
$labels['listsorting'] = 'Zutabea ordenatzen';
$labels['listorder'] = 'Ordenatze irizpidea';
$labels['listmode'] = 'Zerrenda ikuspegiko modua';
$labels['lmode'] = 'Zerrenda modua';
$labels['layout'] = 'Diseinua';
$labels['layoutwidescreen'] = 'Panoramikoa';
$labels['layoutdesktop'] = 'Mahaigaina';
$labels['layoutlist'] = 'Zerrenda';
$labels['layoutwidescreendesc'] = 'Panoramikoa (3-zutabeko ikuspegia)';
$labels['layoutdesktopdesc'] = 'Mahaigaina (zerrenda zabalean eta postaren aurrebista behean)';
$labels['layoutlistdesc'] = 'Zerrenda (postaren aurrebistarik gabe)';
$labels['folderactions'] = 'Karpeta-ekintzak...';
$labels['compact'] = 'Trinkotu';
$labels['empty'] = 'Hustu';
$labels['importmessages'] = 'Inportatu mezuak';
$labels['mailimportdesc'] = 'Kargatu dezakezu mezua fitxategiak erabiliaz <a href="https://en.wikipedia.org/wiki/Email#Message_format">MIME</a> edo <a href="https://en.wikipedia.org/wiki/Mbox">Mbox</a> formatuetan.';
$labels['mailimportzip'] = 'Hainbat fitxategi konprimatu daiteke zip fitxategietan.';
$labels['quota'] = 'Disko erabilera';
$labels['unknown'] = 'ezezaguna';
$labels['unlimited'] = 'mugagabea';
$labels['quotatype'] = 'Kuota mota';
$labels['quotatotal'] = 'Muga';
$labels['quotaused'] = 'Erabilita';
$labels['quotastorage'] = 'Diskoko tokia';
$labels['quotamessage'] = 'Mezu kopurua';
$labels['shortheaderdate'] = '$date egunean';
$labels['shortheaderto'] = ' $date -ko $to -etara';
$labels['shortheaderfrom'] = '$date -ko $from -etatik';
$labels['quicksearch'] = 'Bilaketa azkarra';
$labels['searchplaceholder'] = 'Bilatu...';
$labels['resetsearch'] = 'Berrabiarazi bilaketa';
$labels['searchmod'] = 'Bilatu modifikadoreak';
$labels['msgtext'] = 'Mezu osoa';
$labels['body'] = 'Gorputza';
$labels['type'] = 'Mota';
$labels['namex'] = 'Izena';
$labels['searchscope'] = 'Esparrua';
$labels['currentfolder'] = 'Uneko karpeta';
$labels['subfolders'] = 'Hau eta azpikarpetak';
$labels['allfolders'] = 'Karpeta guztiak';
$labels['searchinterval-1W'] = 'astebete baino zaharragoak';
$labels['searchinterval-1M'] = 'hilabete baino zaharragoak';
$labels['searchinterval-1Y'] = 'urtebete baino zaharragoak';
$labels['searchinterval1W'] = 'astebetea baino berriagoak';
$labels['searchinterval1M'] = 'hilabetea baino berriagoak';
$labels['searchinterval1Y'] = 'urtebetea baino berriagoak';
$labels['infolder'] = 'Karpeta: $folder';
$labels['currentaddressbook'] = 'Egungo helbide-liburua';
$labels['alladdressbooks'] = 'Helbide liburu guztiak';
$labels['openinextwin'] = 'Ireki leiho berrian';
$labels['emlsave'] = 'Deskargatu (.eml)';
$labels['changeformattext'] = 'Bistaratu formaturik gabeko testuan';
$labels['changeformathtml'] = 'Bistaratu HTML formatuan';
$labels['editasnew'] = 'Editatu berri bezala';
$labels['send'] = 'Bidali';
$labels['sendmessage'] = 'Bidali mezua';
$labels['savemessage'] = 'Gorde zirriborro gisa';
$labels['addattachment'] = 'Erantsi fitxategia';
$labels['charset'] = 'Karaktere jokoa';
$labels['editortype'] = 'Editore mota';
$labels['returnreceipt'] = 'Bidali jasotze-agiria';
$labels['dsn'] = 'Entrega-egoeraren jakinarazpena';
$labels['keepformatting'] = 'Segi formateatzen';
$labels['mailreplyintro'] = '$date egunean, $sender-(e)k idatzi du:';
$labels['originalmessage'] = 'Jatorrizko mezua';
$labels['selectimage'] = 'Hautatu irudia';
$labels['addimage'] = 'Gehitu irudia';
$labels['selectmedia'] = 'Hautatu bideoa';
$labels['addmedia'] = 'Gehitu bideoa';
$labels['encrypt'] = 'Zifratu';
$labels['encryptmessage'] = 'Zifratu mezua';
$labels['encryptmessagemailvelope'] = 'Zifratu mezua Mailvelope-ren bidez';
$labels['importpubkeys'] = 'Inportatu gako publikoak';
$labels['encryptedsendialog'] = 'Zifratutako mezua bidaltzen';
$labels['encryptandsign'] = 'Zifratu eta sinatu';
$labels['keyid'] = 'Gakoaren IDa';
$labels['keylength'] = 'Bitak';
$labels['keyexpired'] = 'Iraungita';
$labels['keyrevoked'] = 'Ukatua';
$labels['bccinstead'] = 'Erabili Bcc';
$labels['addheader'] = 'Gehitu eremua (Cc, Bcc, ...)';
$labels['insert'] = 'Txertatu';
$labels['insertcontact'] = 'Txertatu kontaktua(k)';
$labels['recipient'] = 'Hartzailea';
$labels['recipientedit'] = 'Hartzailearen edizioa';
$labels['editidents'] = 'Editatu identitateak';
$labels['spellcheck'] = 'Ortografia-egiaztatu';
$labels['checkspelling'] = 'Egiaztaketa ortografikoa';
$labels['resumeediting'] = 'Editatzen jarraitu';
$labels['revertto'] = 'Itzuli hona';
$labels['restore'] = 'Berrezarri';
$labels['restoremessage'] = 'Leheneratu mezua?';
$labels['ignore'] = 'Ezikusi';
$labels['responses'] = 'Erantzunak';
$labels['insertresponse'] = 'Txertatu erantzun bat';
$labels['manageresponses'] = 'Kudeatu erantzunak';
$labels['newresponse'] = 'Sortu erantzun berria';
$labels['addresponse'] = 'Gehitu erantzuna';
$labels['editresponse'] = 'Editatu erantzuna';
$labels['editresponses'] = 'Editatu erantzunak';
$labels['responsename'] = 'Izena';
$labels['responsetext'] = 'Erantzun testua';
$labels['attach'] = 'Erantsi';
$labels['attachments'] = 'Eranskinak';
$labels['upload'] = 'Kargatu';
$labels['uploadprogress'] = '$percent ($total-etik $current)';
$labels['close'] = 'Itxi';
$labels['messageoptions'] = 'Mezu-aukerak...';
$labels['togglecomposeoptions'] = 'Aktibatu/desaktibatu konposizio aukerak';
$labels['attachmentrename'] = 'Berrizendatu eranskina';
$labels['low'] = 'Baxua';
$labels['lowest'] = 'Baxuena';
$labels['normal'] = 'Normala';
$labels['high'] = 'Altua';
$labels['highest'] = 'Altuena';
$labels['nosubject'] = '(gairik gabea)';
$labels['showimages'] = 'Bistaratu irudiak';
$labels['allow'] = 'Baimendu';
$labels['alwaysshow'] = 'Beti ikusi $sender -en irudiak';
$labels['alwaysallow'] = 'Baimendu beti $sender -engandik';
$labels['isdraft'] = 'Hau zirriborro bat da';
$labels['andnmore'] = '$nr gehiago...';
$labels['details'] = 'Zehaztasunak';
$labels['summary'] = 'Laburpena';
$labels['headers'] = 'Goiburuak';
$labels['allheaders'] = 'Goiburu guztiak...';
$labels['togglemoreheaders'] = 'Erakutsi mezu mezu-goiburu gehiago';
$labels['togglefullheaders'] = 'Erakutsi/Ezkutatu mezuen goiburuak';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'Formaturik gabeko testua';
$labels['savesentmessagein'] = 'Gorde mezua hemen';
$labels['dontsave'] = 'ez gorde';
$labels['maxuploadsize'] = 'Baimendutako gehienezko fitxategi tamaina: $size';
$labels['addcc'] = 'Gehitu Cc (kopia)';
$labels['addbcc'] = 'Gehitu Bcc (kopia ezkutua)';
$labels['addreplyto'] = 'Gehitu erantzun-honi';
$labels['addfollowupto'] = 'Gehitu Jarraitu honi';
$labels['sendreceipt'] = 'Bidali irakurragiria?';
$labels['mdnrequest'] = 'Mezu honen bidaltzaileak mezua irakurtzen duzunean jakinaraztea eskatu du. Bidaltzailea ohartu nahi duzu?';
$labels['receiptread'] = 'Bidali jasotze-agiria (irakurria)';
$labels['yourmessage'] = 'Hau zure mezuaren jasotze-agiria da';
$labels['receiptnote'] = 'Oharra:  jasotze-agiri honek hartzailearen ordenagailuan mezua bistaratu dela adierazten du besterik gabe. Honek ez du esan nahi hartzaileak mezua irakurri edo/eta ulertu duenik:';
$labels['sendalwaysto'] = 'Bidali beti $email-ri';
$labels['zoomin'] = 'Handiagotu';
$labels['zoomout'] = 'Txikiagotu';
$labels['rotate'] = 'Biratu';
$labels['increaseimage'] = 'Handiagotu irudiaren tamaina';
$labels['decreaseimage'] = 'Txikiagotu irudiaren tamaina';
$labels['rotateimage'] = 'Biratu irudia';
$labels['showtools'] = 'Erakutsi irudi-tresnak';
$labels['hidetools'] = 'Ezkutatu irudi-tresnak';
$labels['name'] = 'Bistaratu izena';
$labels['firstname'] = 'Izena';
$labels['surname'] = 'Abizena';
$labels['middlename'] = 'Izenaren bigarren partea';
$labels['nameprefix'] = 'Aurrizkia';
$labels['namesuffix'] = 'Atzizkia';
$labels['nickname'] = 'Ezizena';
$labels['jobtitle'] = 'Lanpostua ';
$labels['department'] = 'Departamentoa';
$labels['gender'] = 'Generoa';
$labels['maidenname'] = 'Ezkondu aurreko izena';
$labels['email'] = 'E-posta';
$labels['phone'] = 'Telefonoa';
$labels['address'] = 'Helbidea';
$labels['street'] = 'Kalea';
$labels['locality'] = 'Herria';
$labels['zipcode'] = 'Posta kodea';
$labels['region'] = 'Estatua/Probintzia';
$labels['country'] = 'Herrialdea';
$labels['birthday'] = 'Urtebetetze-eguna';
$labels['anniversary'] = 'Urteurren-eguna';
$labels['website'] = 'Webgunea';
$labels['instantmessenger'] = 'Txata';
$labels['notes'] = 'Oharrak';
$labels['male'] = 'gizon';
$labels['female'] = 'emakume';
$labels['nonbinary'] = 'ez binarioa';
$labels['othergender'] = 'bestelakoa';
$labels['manager'] = 'Kudeatzailea';
$labels['assistant'] = 'Laguntzailea';
$labels['spouse'] = 'Ezkontidea';
$labels['allfields'] = 'Eremu guztiak';
$labels['search'] = 'Bilatu';
$labels['searchresult'] = 'Bilaketaren emaitza';
$labels['advsearch'] = 'Bilaketa aurreratua';
$labels['advanced'] = 'Aurreratua';
$labels['other'] = 'Beste';
$labels['printcontact'] = 'Inprimatu kontaktua';
$labels['qrcode'] = 'QR kodea';
$labels['typehome'] = 'Etxekoa';
$labels['typework'] = 'Lanekoa';
$labels['typeother'] = 'Bestelakoa';
$labels['typemobile'] = 'Mugikorra';
$labels['typemain'] = 'Nagusia';
$labels['typehomefax'] = 'Etxeko faxa';
$labels['typeworkfax'] = 'Laneko faxa';
$labels['typecar'] = 'Autoa';
$labels['typepager'] = 'Pertsona bilagailua';
$labels['typevideo'] = 'Bideo';
$labels['typeassistant'] = 'Laguntzailea';
$labels['typehomepage'] = 'Etxeko orria';
$labels['typeblog'] = 'Bloga';
$labels['typeprofile'] = 'Profila';
$labels['addfield'] = 'Gehitu eremua...';
$labels['addcontact'] = 'Gehitu kontaktua';
$labels['editcontact'] = 'Editatu kontaktua';
$labels['contacts'] = 'Kontaktuak';
$labels['contactproperties'] = 'Kontaktuen ezaugarriak';
$labels['contactnameandorg'] = 'Izena eta erakundea';
$labels['personalinfo'] = 'Informazio pertsonala';
$labels['personal'] = 'Pertsonala';
$labels['contactphoto'] = 'Kontaktuaren argazkia';
$labels['edit'] = 'Editatu';
$labels['cancel'] = 'Utzi';
$labels['save'] = 'Gorde';
$labels['delete'] = 'Ezabatu';
$labels['discard'] = 'Baztertu';
$labels['continue'] = 'Jarraitu';
$labels['ok'] = 'Ados';
$labels['rename'] = 'Berrizendatu';
$labels['addphoto'] = 'Gehitu';
$labels['replacephoto'] = 'Ordeztu';
$labels['uploadphoto'] = 'Kargatu argazkia';
$labels['choosefile'] = 'Aukeratu fitxategia...';
$labels['choosefiles'] = 'Aukeratu fitxategiak...';
$labels['browse'] = 'Arakatu';
$labels['newcontact'] = 'Sortu kontaktu berria';
$labels['deletecontact'] = 'Ezabatu hautatutako kontaktuak';
$labels['composeto'] = 'Idatzi mezua honi:';
$labels['contactsfromto'] = '$from -tik $to -ra $count kontaktuak';
$labels['print'] = 'Inprimatu';
$labels['export'] = 'Esportatu';
$labels['exportall'] = 'Esportatu dena';
$labels['exportsel'] = 'Esportatu hautaketa';
$labels['exportvcards'] = 'Esportatu kontaktuak vCard formatuan';
$labels['newgroup'] = 'Sortu talde berria';
$labels['addgroup'] = 'Gehitu taldea';
$labels['grouprename'] = 'Berrizendatu taldea';
$labels['groupdelete'] = 'Ezabatu taldea';
$labels['groupassign'] = 'Gehitu taldean...';
$labels['groupremove'] = 'Kendu taldetik';
$labels['groupremoveselected'] = 'Ezabatu taldetik hautatutako kontaktuak';
$labels['uponelevel'] = 'Igo maila bat';
$labels['previouspage'] = 'Erakutsi aurreko orria';
$labels['firstpage'] = 'Erakutsi lehenengo orria';
$labels['nextpage'] = 'Erakutsi hurrengo orria';
$labels['lastpage'] = 'Erakutsi azken orria';
$labels['group'] = 'Taldea';
$labels['groups'] = 'Taldeak';
$labels['listgroup'] = 'Zerrendatu taldeko partaideak';
$labels['personaladrbook'] = 'Helbide pertsonalak';
$labels['searchsave'] = 'Gorde bilaketa';
$labels['searchdelete'] = 'Ezabatu bilaketa';
$labels['import'] = 'Inportatu';
$labels['importcontacts'] = 'Inportatu kontaktuak';
$labels['importfromfile'] = 'Inportatu fitxategitik';
$labels['importtarget'] = 'Gehitu kontaktuak hona:';
$labels['importreplace'] = 'Ordezkatu helbide-liburu osoa';
$labels['importgroups'] = 'Inportatu talde-esleipenak';
$labels['importgroupsall'] = 'Dena (sortu taldeak behar izatekotan)';
$labels['importgroupsexisting'] = 'Existitzen diren taldeentzat soilik';
$labels['importdesc'] = 'Kargatu ditzakezu kontaktuak dagoen helbide liburu batetik.<br/>Une honetan onartzen dugu helbideen inportazioa <a href="https://en.wikipedia.org/wiki/VCard">vCard</a> edo CSV (komaz bereizita) datu formatuetan.';
$labels['importmapdesc'] = 'Baieztatu beheko eremuen mapen informazioa zuzena dela CSV (komaz bereizita) datuak inportatzen jarraitu aurretik.';
$labels['fieldnotmapped'] = 'Eremua ez da mapatu (ez inportatu)';
$labels['skipheader'] = 'Ez inportatu lehenengo lerroa (goiburuak)';
$labels['done'] = 'Egina';
$labels['birth_day'] = 'Jaiotze eguna';
$labels['birth_month'] = 'Jaiotze hilabetea';
$labels['birth_year'] = 'Jaiotze urtea';
$labels['settingsfor'] = 'Honen ezarpenak:';
$labels['about'] = 'Honi buruz';
$labels['preferences'] = 'Hobespenak';
$labels['userpreferences'] = 'Erabiltzailearen hobespenak';
$labels['editpreferences'] = 'Editatu erabiltzailearen hobespenak';
$labels['identities'] = 'Identitateak';
$labels['manageidentities'] = 'Kudeatu identitateak';
$labels['newidentity'] = 'Sortu identitate berria';
$labels['addidentity'] = 'Gehitu identitatea';
$labels['editidentity'] = 'Editatu identitatea';
$labels['identityencryption'] = 'Zifraketa';
$labels['preferhtml'] = 'Bistaratu HTML';
$labels['defaultcharset'] = 'Lehenetsitako karaktere-jokoa';
$labels['htmlmessage'] = 'HTML mezua';
$labels['messagepart'] = 'Zatia';
$labels['digitalsig'] = 'Sinadura digitala';
$labels['dateformat'] = 'Data-formatua';
$labels['timeformat'] = 'Ordu-formatua';
$labels['prettydate'] = 'Data politak';
$labels['setdefault'] = 'Ezarri lehenetsia';
$labels['autodetect'] = 'Automatikoa';
$labels['language'] = 'Hizkuntza';
$labels['timezone'] = 'Ordu zonaldea';
$labels['pagesize'] = 'Lerro orrialdeko';
$labels['signature'] = 'Sinadura';
$labels['dstactive'] = 'Udako ordutegia';
$labels['showinextwin'] = 'Ireki mezua leiho berrian';
$labels['composeextwin'] = 'Idatzi leiho berrian';
$labels['htmleditor'] = 'Idatzi HTML mezuak';
$labels['htmlonreply'] = 'HTML mezua erantzuteko';
$labels['htmlonreplyandforward'] = 'HTML mezua erantzuteko edo birbidaltzeko';
$labels['htmlsignature'] = 'HTML sinadura';
$labels['showemail'] = 'Erakutsi helbide elektronikoa bere bistaratze izenarekin';
$labels['previewpane'] = 'Aurrebista panela ikusi';
$labels['skin'] = 'Azal-interfazea';
$labels['logoutclear'] = 'Garbitu Zakarronzia irtetean';
$labels['logoutcompact'] = 'Trinkotu Sarrera irtetean';
$labels['uisettings'] = 'Erabiltzaile-interfazea';
$labels['serversettings'] = 'Zerbitzariaren ezarpenak';
$labels['mailboxview'] = 'Posta-kutxatila ikuspegia';
$labels['mdnrequests'] = 'Bidaltzailearen jakinarazpena';
$labels['askuser'] = 'galdetu erabiltzaileari';
$labels['autosend'] = 'bidali irakurragiria';
$labels['autosendknown'] = 'bidali irakurragiria nire kontaktuei, bestela galdetu niri';
$labels['autosendknownignore'] = 'bidali irakurragiria nire kontaktuei, bestela ez ikusi egin';
$labels['autosendtrusted'] = 'bidali irakurragiria konfiantzazko igorleei, bestela galdetu iezadazu';
$labels['autosendtrustedignore'] = 'bidali irakurragiria konfiantzazko igorleei, bestela ezikusi';
$labels['ignorerequest'] = 'Ez ikusi eskaera';
$labels['readwhendeleted'] = 'Markatu mezua irakurrita bezala ezabatzerakoan';
$labels['flagfordeletion'] = 'Markatu mezua ezabatzeko ezabatu beharrean';
$labels['skipdeleted'] = 'Ez erakutsi ezabatutako mezuak';
$labels['deletealways'] = 'Zakarrontzira bidaltzeak huts egiten badu, ezabatu';
$labels['deletejunk'] = 'Ezabatu zuzenean 
zabor-mezuak';
$labels['showremoteimages'] = 'Erakutsi konektatutako urrutiko irudiak';
$labels['allowremoteresources'] = 'Baimendu urrutiko baliabideak (irudia, estiloak)';
$labels['fromknownsenders'] = 'bidaltzaile ezagunengandik';
$labels['fromtrustedsenders'] = 'konfiantzazko igorleengandik';
$labels['frommycontacts'] = 'nire kontaktuengandik';
$labels['always'] = 'beti';
$labels['alwaysbutplain'] = 'beti, testu lauari erantzutean izan ezik';
$labels['showinlineimages'] = 'Erakutsi erantzitako irudiak mezuaren azpian';
$labels['autosavedraft'] = 'Zirriborroa automatikoki gorde';
$labels['everynminutes'] = '$n minuturo';
$labels['refreshinterval'] = 'Freskatu (bilatu mezu berriak eta abar)';
$labels['never'] = 'inoiz ez';
$labels['immediately'] = 'berehala';
$labels['messagesdisplaying'] = 'Mezuak bistaratzen';
$labels['messagescomposition'] = 'Mezuak idazten';
$labels['mimeparamfolding'] = 'Eranskinen izenak';
$labels['2231folding'] = 'Full RFC 2231 (Thunderbird)';
$labels['miscfolding'] = 'RFC 2047/2231 (MS Outlook)';
$labels['2047folding'] = 'Full RFC 2047 (beste batzuk)';
$labels['force7bit'] = 'Erabili MIME kodeketa 8 bitekok karakterentzat';
$labels['savelocalstorage'] = "Gorde nabigatzailearen biltegi lokalean (behin behinean)";
$labels['advancedoptions'] = 'Aukera aurreratuak';
$labels['toggleadvancedoptions'] = 'Toggle aukera aurreratuak';
$labels['focusonnewmessage'] = 'Fokatu leihoa mezu berrian';
$labels['checkallfolders'] = 'Egiaztatu karpeta guztiak mezu berrien bila';
$labels['displaynext'] = 'Bistaratu  zerrendako hurrengo sarrera ezabatu/lekuz aldatu ondoren';
$labels['defaultfont'] = 'Lehenetsitako letra-mota HTML mezuetarako';
$labels['mainoptions'] = 'Aukera nagusiak';
$labels['browseroptions'] = 'Nabigatze-aukerak';
$labels['section'] = 'Atala';
$labels['maintenance'] = 'Mantenua';
$labels['newmessage'] = 'Mezu berria';
$labels['signatureoptions'] = 'Sinadura-aukerak';
$labels['whenreplying'] = 'Erantzutean';
$labels['replyempty'] = 'ez aipatu jatorrizko mezua';
$labels['replytopposting'] = 'hasi mezu berria aipamenaren gainean';
$labels['replytoppostingnoindent'] = 'hasi mezu berria aipamenaren gainean (koskarik gabe)';
$labels['replybottomposting'] = 'hasi mezu berria aipamenaren azpian';
$labels['replyremovesignature'] = 'Erantzutean ezabatu mezuaren jatorrizko sinadura';
$labels['autoaddsignature'] = 'Gehitu sinadura automatikoki';
$labels['newmessageonly'] = 'bakarrik mezu berria';
$labels['replyandforwardonly'] = 'bakarri erantzun eta birbidalketak';
$labels['insertsignature'] = 'Txertatu sinadura';
$labels['sigbelow'] = 'Kokatu sinadura aipamenaren azpian';
$labels['sigseparator'] = 'Behartu banatzaile estandarra sinaduretan';
$labels['automarkread'] = 'Markatu mezuak irakurrita gisa';
$labels['afternseconds'] = '$n segundo eta gero';
$labels['reqmdn'] = 'Eskatu beti irakurragiria';
$labels['reqdsn'] = 'Eskatu beti entrega-egoeraren jakinarazpena';
$labels['alwayskeepformatting'] = 'Mantendu beti jatorrizko testuaren formatua';
$labels['replysamefolder'] = 'Kokatu erantzunak erantzuten ari den mezuarenkarpeta berean';
$labels['defaultabook'] = 'Lehenetsitako helbide-liburua';
$labels['autocompletesingle'] = 'Saltatu helbide elektroniko alternatiboak  osatze automatikoan';
$labels['listnamedisplay'] = 'Zerrendatu kontaktuak honela';
$labels['contactformmode'] = 'Kontaktuen formulario modua';
$labels['privatemode'] = 'Pribatua (etxekoa)';
$labels['businessmode'] = 'Lanekoa';
$labels['collectedaddresses'] = 'Bildutako helbideak';
$labels['collectedrecipients'] = 'Bildutako hartzaileak';
$labels['collectedrecipientsopt'] = 'Gorde irteerako email hartzaileak hemen';
$labels['collectedsendersopt'] = 'Gorde konfiantzazko igorleak hemen';
$labels['trustedsenders'] = 'Konfiantzako igorleak';
$labels['spellcheckbeforesend'] = 'Egiaztatu ortografia mezua bidali aurretik';
$labels['spellcheckoptions'] = 'Ortografia-egiaztatzearen aukerak';
$labels['spellcheckignoresyms'] = 'Ez ikusi sinboloak dituzten hitzak';
$labels['spellcheckignorenums'] = 'Ez ikusi zenbakiak dituzten hitzak';
$labels['spellcheckignorecaps'] = 'Ez ikusi letra kapitalak dituzten hitzak';
$labels['addtodict'] = 'Gehitu hiztegira';
$labels['editoroptions'] = 'Editorearen aukerak';
$labels['enableautolink'] = 'Bihurtu automatikoki baliozko URLak hiperesteka';
$labels['mailtoprotohandler'] = 'Erregistratu mailto protokoloaren kudeatzailea:  estekak';
$labels['standardwindows'] = 'Tratatu popup leihoak leiho estandar gisa';
$labels['forwardmode'] = 'Mezuak birbidaltzen';
$labels['inline'] = 'Konektatua';
$labels['asattachment'] = 'eranskin moduan';
$labels['replyallmode'] = '[Erantzun denei] botoiaren lehenetsitako ekintza';
$labels['replyalldefault'] = 'erantzun denei';
$labels['replyalllist'] = 'erantzun posta zerrendara soilik (aurkitzekotan)';
$labels['allmessages'] = 'mezu guztiak';
$labels['olderxdays'] = '$x egun baino zaharrago';
$labels['folder'] = 'Karpeta';
$labels['folders'] = 'Karpetak';
$labels['foldername'] = 'Karpetaren izena';
$labels['subscribed'] = 'Harpideturik';
$labels['messagecount'] = 'Mezuak';
$labels['create'] = 'Sortu';
$labels['createfolder'] = 'Sortu karpeta berria';
$labels['managefolders'] = 'Kudeatu karpetak';
$labels['specialfolders'] = 'Karpeta bereziak';
$labels['properties'] = 'Ezaugarriak';
$labels['folderproperties'] = 'Karpeta-ezaugarriak';
$labels['parentfolder'] = 'Goragoko karpeta';
$labels['location'] = 'Kokalekua';
$labels['info'] = 'Informazioa';
$labels['getfoldersize'] = 'Klikatu ikusteko karpetaren tamaina';
$labels['changesubscription'] = 'Klikatu harpidetza aldatzeko';
$labels['foldertype'] = 'Karpeta mota';
$labels['personalfolder'] = 'Karpeta pribatua';
$labels['otherfolder'] = 'Beste erabiltzaileen karpetak';
$labels['sharedfolder'] = 'Karpeta publikoa';
$labels['findfolders'] = 'Bilatu karpetak';
$labels['findcontacts'] = 'Bilatu kontaktuak';
$labels['findmail'] = 'Bilatu posta mezuak';
$labels['namespace.personal'] = 'Pertsonala';
$labels['namespace.other'] = 'Beste erabiltzaileak';
$labels['namespace.shared'] = 'Partekatua';
$labels['dualuselabel'] = 'Bakarrik eduki dezake';
$labels['dualusemail'] = 'mezuak';
$labels['dualusefolder'] = 'karpetak';
$labels['generate'] = 'Sortu';
$labels['encryptioncreatekey'] = 'Sortu gako pare berria';
$labels['openmailvelopesettings'] = 'Ireki Mailvelope ezarpenak';
$labels['encryptionprivkeysinmailvelope'] = ' Badaukazu bat datozen $nr gako pribatu zure Mailvelope giltzarrian gordeta:';
$labels['encryptionnoprivkeysinmailvelope'] = 'Bidaltzaile identitate honek jada ez dauka PGP gako pribaturik gordeta zure Mailvelope gehigarrian. Nahi al duzu bat sortzea mezuak zifratu ahal izateko?';
$labels['encryption'] = 'Zifraketa';
$labels['mailvelopeoptions'] = 'Mailvelope aukerak';
$labels['mailvelopemainkeyring'] = 'Erabili Mailvelope gako-sorta nagusia';
$labels['mailvelopenotfound'] = 'Mailvelope gehigarria ez dago gaituta/instalatuta zure nabigatzailean';
$labels['mailvelopeenable'] = 'Gaitu';
$labels['sortby'] = 'Honela ordenatu';
$labels['sortasc'] = 'Goraka ordenatu';
$labels['sortdesc'] = 'Ordenatu beherantz';
$labels['undo'] = 'Desegin';
$labels['installedplugins'] = 'Instalatutako plugin-ak';
$labels['plugin'] = 'Plugin';
$labels['version'] = 'Bertsioa';
$labels['source'] = 'Iturria';
$labels['destination'] = 'Helmuga';
$labels['license'] = 'Lizentzia';
$labels['skinauthor'] = '$egilearen arabera';
$labels['support'] = 'Eskuratu laguntza';
$labels['savedsearches'] = 'Gordetako bilaketak';
$labels['dateformatY'] = 'UUUU';
$labels['dateformaty'] = 'UU';
$labels['dateformatm'] = 'HH';
$labels['dateformatd'] = 'EE';
$labels['dateformatj'] = 'E';
$labels['dateformatn'] = 'H';
$labels['B'] = 'B';
$labels['KB'] = 'KB';
$labels['MB'] = 'MB';
$labels['GB'] = 'GB';
$labels['unicode'] = 'Unicode';
$labels['english'] = 'Ingelesa';
$labels['westerneuropean'] = 'Mendebaldeko europearra';
$labels['easterneuropean'] = 'Ekialdeko europearra';
$labels['southeasterneuropean'] = 'Hego-ekialdeko europearra';
$labels['baltic'] = 'Baltikoa';
$labels['cyrillic'] = 'Zirilikoa';
$labels['arabic'] = 'Arabiarra';
$labels['greek'] = 'Grekoa';
$labels['hebrew'] = 'Hebrearra';
$labels['turkish'] = 'Turkiarra';
$labels['nordic'] = 'Nordikoa';
$labels['thai'] = 'Thai';
$labels['celtic'] = 'Zeltiar';
$labels['vietnamese'] = 'Vietnamdarra';
$labels['japanese'] = 'Japoniarra';
$labels['korean'] = 'Korearra';
$labels['chinese'] = 'Txinatarra';
$labels['arialabeltopnav'] = 'Leihoen kontrola';
$labels['arialabeltasknav'] = 'Aplikazioaren atazak';
$labels['arialabeltoolbar'] = 'Aplikazioaren tresna barra';
$labels['arialabellistnav'] = 'Zerrendako nabigazioa';
$labels['arialabelactivetask'] = 'Ataza aktiboa';
$labels['arialabelmessagessearchfilter'] = 'E-posten zerrendako iragazkia';
$labels['arialabelmailsearchform'] = 'Mezu elektronikoak bilatzeko formularioa';
$labels['arialabelcontactsearchform'] = 'Kontaktuak bilatzeko formularioa';
$labels['arialabelmailquicksearchbox'] = 'E-posta bilaketa sarrera';
$labels['arialabelquicksearchbox'] = 'Bilaketa sarrera';
$labels['arialabelfoldersearchfilter'] = 'Karpenten zerrendatze iragazkia';
$labels['arialabelfoldersearchform'] = 'Karpeten bilateta formularioa';
$labels['arialabelfolderlist'] = 'E-posta karpeta hautaketa';
$labels['arialabelmessagelist'] = 'E-posta mezuen zerrendatzea';
$labels['arialabelmailpreviewframe'] = 'Mezuaren aurrebista';
$labels['arialabelmailboxmenu'] = 'Karpetako ekintzen menua';
$labels['arialabellistselectmenu'] = 'Zerrenda hautatzeko menua';
$labels['arialabelthreadselectmenu'] = 'Hariak zerrendatzeko menua';
$labels['arialabelmessagelistoptions'] = 'Mezuen zerrenda bistaratzeko eta ordenatzeko aukerak';
$labels['arialabelmailimportdialog'] = 'Mezuak inportatzeko elkarrizketa';
$labels['arialabelmessagenav'] = 'Mezu nabigazioa';
$labels['arialabelmessagebody'] = 'Mezuaren gorputza';
$labels['arialabelmessageactions'] = 'Mezuen ekintzak';
$labels['arialabelcontactquicksearch'] = 'Kontaktuak bilatzeko formularioa';
$labels['arialabelcontactsearchbox'] = 'Kontaktuak bilatzeko sarrera';
$labels['arialabelmessageheaders'] = 'Mezuen goiburuak';
$labels['arialabelforwardingoptions'] = 'Birbidaltzeko aukerak';
$labels['arialabelreplyalloptions'] = 'Guztiei erantzuteko aukerak';
$labels['arialabelmoremessageactions'] = 'Mezu ekintza gehiago';
$labels['arialabelmorecontactactions'] = 'Kontaktuen ekintza gehiago';
$labels['arialabelmarkmessagesas'] = 'Markatu hautatutako mezua gisa honetara...';
$labels['arialabelcomposeoptions'] = 'Konposizio aukerak';
$labels['arialabelresponsesmenu'] = 'Erantzun finkoen menua';
$labels['arialabelattachmentuploadform'] = 'Eranskinak kargatzeko formularioa';
$labels['arialabelattachmentmenu'] = 'Eranskinaren aukerak';
$labels['arialabelmailtomenu'] = 'Helbide elektronikoaren aukerak';
$labels['arialabelattachmentpreview'] = 'Eranskinaren aurrebista';
$labels['ariasummarycomposecontacts'] = 'Kontaktuak eta taldeak hartzaile gisa hautatzeko zerrenda';
$labels['arialabelcontactexportoptions'] = 'Kontaktuak esportatzeko aukerak';
$labels['arialabelabookgroupoptions'] = 'Kontaktu eta taldeen helbide-liburuaren aukerak';
$labels['arialabelpreferencesform'] = 'Hobespenen formularioa';
$labels['arialabelidentityeditfrom'] = 'Identitatea editatzeko formularioa';
$labels['arialabelresponseeditfrom'] = 'Erantzuna editatzeko formularioa';
$labels['arialabelsearchterms'] = 'Bilatu terminoak';
$labels['arialabeldropactionmenu'] = 'Arrastatu eta jaregin ekintzaren menua';
$labels['arialabelheadersmenu'] = 'Hartzailea (goiburua) menua gehituz';
$labels['arialabelimagetools'] = 'Irudi-tresnak';
$labels['helplistnavigation'] = 'Zerrendatu teklatuaren nabigazioa';
$labels['helplistkeyboardnavigation'] = "Gezia gora/behera: Mugitu ilararen fokua/hautaketa.
Zuriunea: Hautatu fokatutako ilara.
Maius + gora/behera: Hautatu beste ilara goian/behean.
Ctrl + Zuriunea: Gehitu fokatutako ilara hautaketara/ezabatu hautaketatik.";
$labels['helplistkeyboardnavmessages'] = "Gezia eskuin/ezker: zabaldu/tolestu mezuaren haria (bakarrik haria moduan).
Sartu: Ireki hautatutako/fokatutako mezua.
Ezabatu: Eraman hautatutako mezuak zakarrontzira.
";
$labels['helplistkeyboardnavcontacts'] = "Sartu: Ireki hautatutako/fokatutako kontaktua.";
