<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Zipdownload plugin         |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['downloadall'] = 'Niðurhala öllum viðhengjum';
$labels['export'] = 'Flytja út...';
$labels['downloadmbox'] = 'Mbox snið (.zip)';
$labels['downloadmaildir'] = 'Maildir snið (.zip)';
$labels['downloademl'] = 'Upprunalegt (.eml)';
$labels['sizelimiterror'] = 'Heildarstærð valinna skilaboða fer fram yfir ($size) takmörkin';
$labels['exportmenu'] = 'Valmynd valkosta við útflutning skilaboða';
$labels['download'] = 'Hlaða niður...';
