<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Managesieve plugin         |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['filters'] = 'Filter';
$labels['managefilters'] = 'Rediger filter for innkommande e-post';
$labels['filtername'] = 'Filternamn';
$labels['newfilter'] = 'Nytt filter';
$labels['filteradd'] = 'Legg til filter';
$labels['filterdel'] = 'Slett filter';
$labels['moveup'] = 'Flytt opp';
$labels['movedown'] = 'Flytt ned';
$labels['filterallof'] = 'som treffer alle følgjande regler';
$labels['filteranyof'] = 'som treffer ein av følgjande regler';
$labels['filterany'] = 'alle meldingar';
$labels['filtercontains'] = 'inneheld';
$labels['filternotcontains'] = 'ikkje inneheld';
$labels['filteris'] = 'er lik';
$labels['filterisnot'] = 'er ikkje lik';
$labels['filterexists'] = 'eksisterer';
$labels['filternotexists'] = 'ikkje eksisterer';
$labels['filtermatches'] = 'treffer uttrykk';
$labels['filternotmatches'] = 'ikkje treffer uttrykk';
$labels['filterregex'] = 'treffer regulært uttrykk';
$labels['filternotregex'] = 'ikkje treffer regulært uttrykk';
$labels['filterunder'] = 'under';
$labels['filterover'] = 'over';
$labels['addrule'] = 'Legg til regel';
$labels['delrule'] = 'Slett regel';
$labels['messagemoveto'] = 'Flytt meldinga til';
$labels['messageredirect'] = 'Vidaresend meldinga til';
$labels['messagecopyto'] = 'Kopier meldinga til';
$labels['messagesendcopy'] = 'Send ein kopi av meldinga til';
$labels['messagereply'] = 'Svar med melding';
$labels['messagedelete'] = 'Slett melding';
$labels['messagediscard'] = 'Avvis med melding';
$labels['messagesrules'] = 'For innkommande e-post';
$labels['messagesactions'] = '…gjer følgjande:';
$labels['add'] = 'Legg til';
$labels['del'] = 'Slett';
$labels['sender'] = 'Avsendar';
$labels['recipient'] = 'Mottakar';
$labels['vacationdays'] = 'Periode mellom meldingar (i dagar):';
$labels['vacationreason'] = 'Innhald (grunngjeving for fråvær)';
$labels['vacationsubject'] = 'Meldingsemne:';
$labels['rulestop'] = 'Stopp evaluering av regler';
$labels['enable'] = 'Aktiver/Deaktiver';
$labels['filtersets'] = 'Filtersett';
$labels['filterdef'] = 'Filterdefinisjon';
$labels['active'] = 'aktiv';
$labels['none'] = 'ingen';
$labels['fromset'] = 'frå sett';
$labels['fromfile'] = 'frå fil';
$labels['filterdisabled'] = 'Filter deaktivert';
$labels['countisgreaterthan'] = 'mengd er fleire enn';
$labels['countisgreaterthanequal'] = 'mengd er fleire enn eller lik';
$labels['countislessthan'] = 'mengd er færre enn';
$labels['countislessthanequal'] = 'mengd er færre enn eller lik';
$labels['countequals'] = 'mengd er lik';
$labels['valueisgreaterthan'] = 'verdien er høgare enn';
$labels['valueisgreaterthanequal'] = 'verdien er høgare eller lik';
$labels['valueislessthan'] = 'verdien er lågare enn';
$labels['valueislessthanequal'] = 'verdien er lågare eller lik';
$labels['valueequals'] = 'verdien er lik';
$labels['setflags'] = 'Sett meldingsflagg';
$labels['addflags'] = 'Legg til flagg på meldinga';
$labels['removeflags'] = 'Fjern flagg fra meldinga';
$labels['flagread'] = 'Lese';
$labels['flagdeleted'] = 'Sletta';
$labels['flaganswered'] = 'Svart på';
$labels['flagflagged'] = 'Flagga';
$labels['flagdraft'] = 'Skisse';
$labels['setvariable'] = 'Sett variabel:';
$labels['setvarname'] = 'Variabelnamn:';
$labels['setvarvalue'] = 'Variabelverdi:';
$labels['setvarmodifiers'] = 'Modifikator:';
$labels['varlower'] = 'med små bokstavar';
$labels['varupper'] = 'med store bokstavar';
$labels['varlowerfirst'] = 'med liten forbokstav';
$labels['varupperfirst'] = 'med stor forbokstav';
$labels['varlength'] = 'lengde';
$labels['notify'] = 'Send varsel';
$labels['notifyimportance'] = 'Betyding:';
$labels['notifyimportancelow'] = 'låg';
$labels['notifyimportancenormal'] = 'normal';
$labels['notifyimportancehigh'] = 'høg';
$labels['notifymethodmailto'] = 'E-post';
$labels['notifymethodtel'] = 'Telefon';
$labels['filtercreate'] = 'Opprett filter';
$labels['usedata'] = 'Bruk følgande data i filteret:';
$labels['nextstep'] = 'Neste steg';
$labels['...'] = '…';
$labels['datetest'] = 'Dato';
$labels['advancedopts'] = 'Avanserte val';
$labels['body'] = 'Meldingstekst';
$labels['address'] = 'adresse';
$labels['envelope'] = 'konvolutt';
$labels['modifier'] = 'modifikator:';
$labels['text'] = 'tekst';
$labels['undecoded'] = 'ikkje dekoda (rå)';
$labels['contenttype'] = 'innhaldstype';
$labels['modtype'] = 'type:';
$labels['allparts'] = 'alle';
$labels['domain'] = 'domene';
$labels['localpart'] = 'lokal del (local part)';
$labels['user'] = 'brukar';
$labels['detail'] = 'detalj';
$labels['comparator'] = 'samanlikning:';
$labels['default'] = 'standard';
$labels['octet'] = 'streng (oktett)';
$labels['asciicasemap'] = 'ikkje skil mellom store og små bokstavar (ascii-casemap)';
$labels['asciinumeric'] = 'numerisk (ascii-numeric)';
$labels['spamtestequals'] = 'er lik';
$labels['spamtestnotequals'] = 'er ikkje lik';
$labels['vacation.subject'] = 'Emne';
$labels['vacation.body'] = 'Meldingstekst';
$labels['vacation.keep'] = 'Behald';
$messages['filterunknownerror'] = 'Ukjent problem med tenar.';
$messages['filterconnerror'] = 'Kunne ikkje kople til tenaren.';
$messages['filterdeleted'] = 'Filteret er blitt sletta.';
$messages['filtersaved'] = 'Filteret er blitt lagra.';
$messages['filterdeleteconfirm'] = 'Vil du verkeleg slette det valde filteret?';
$messages['ruledeleteconfirm'] = 'Er du sikker på at du vil slette vald regel?';
$messages['actiondeleteconfirm'] = 'Er du sikker på at du vil slette vald hending?';
$messages['forbiddenchars'] = 'Ugyldige teikn i felt.';
$messages['cannotbeempty'] = 'Feltet kan ikkje stå tomt.';
$messages['ruleexist'] = 'Det finst alt eit filter med dette namnet.';
$messages['deactivated'] = 'Filter skrudd på.';
$messages['activated'] = 'Filter skrudd av.';
$messages['moved'] = 'Filter vart flytta.';
$messages['nametoolong'] = 'Namnet er for langt.';
$messages['namereserved'] = 'Namnet er reservert.';
$messages['setexist'] = 'Settet eksisterer alt.';
$messages['nodata'] = 'Du må velje minst éin posisjon!';
