<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Managesieve plugin         |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['filters'] = 'Filtur';
$labels['managefilters'] = 'Umsit mótakandi teldupost filtur';
$labels['filtername'] = 'Navn á filtri';
$labels['newfilter'] = 'Nýtt filtur';
$labels['filteradd'] = 'Nýtt filtur';
$labels['filterdel'] = 'Strika filtur';
$labels['actions'] = 'Gerðir';
$labels['scope'] = 'Leita frá';
$labels['moveup'] = 'Flyt upp';
$labels['movedown'] = 'Flyt niður';
$labels['filterallof'] = 'samsvarar allar fylgjandi reglur';
$labels['filteranyof'] = 'samsvarar onkrar av fylgjandi reglum';
$labels['filterany'] = 'øll boð';
$labels['filtercontains'] = 'inniheldur';
$labels['filternotcontains'] = 'inniheldur ikki';
$labels['filteris'] = 'er tað sama sum';
$labels['filterisnot'] = 'er ikki tað sama sum';
$labels['filterexists'] = 'er til';
$labels['filternotexists'] = 'er ikki til';
$labels['filtermatches'] = 'samsvarar við orðafelli';
$labels['filternotmatches'] = 'Samsvarar ikki við orðafelli';
$labels['filterregex'] = 'Samsvarar við "regular expression"';
$labels['filternotregex'] = 'Samsvarar ikki við "regular expression"';
$labels['filterunder'] = 'undur';
$labels['filterover'] = 'yvir';
$labels['addrule'] = 'Stovna regul';
$labels['delrule'] = 'Strika regul';
$labels['messagemoveto'] = 'Flyt boð til';
$labels['messageredirect'] = 'Leið boð til';
$labels['messagecopyto'] = 'Tvítak boð til';
$labels['messagesendcopy'] = 'Send boð avrit til';
$labels['messagereply'] = 'Svara við boðum';
$labels['messagedelete'] = 'Strika boð';
$labels['messagediscard'] = 'Strika boð við boðum';
$labels['messagekeep'] = 'Goym boð í postkassa';
$labels['messagesrules'] = 'Fyri móttiknan post:';
$labels['messagesactions'] = '...koyr fylgjandi gerðir';
$labels['add'] = 'Legg aftrat';
$labels['del'] = 'Strika';
$labels['sender'] = 'Sendari';
$labels['recipient'] = 'Móttakari';
$labels['vacationaddr'] = 'Mínir teldupost bústaðir:';
$labels['vacationdays'] = 'Hvussu ofta skal sendast (í døgum):';
$labels['vacationinterval'] = 'Hvussu ofta skulu boðini sendast:';
$labels['vacationreason'] = 'Breyðtekstur (feriu orsøk):';
$labels['vacationfrom'] = 'Svara sendara bústaði:';
$labels['vacationsubject'] = 'Evni á boðum:';
$labels['days'] = 'dagar';
$labels['seconds'] = 'sekund';
$labels['rulestop'] = 'Steðga við at eftirmeta reglur';
$labels['enable'] = 'Tendra/Sløkk';
$labels['filtersets'] = 'Sílu sett';
$labels['filterdef'] = 'Sílu avmarking ';
$labels['active'] = 'tendra';
$labels['none'] = 'einki';
$labels['fromset'] = 'frá sett';
$labels['fromfile'] = 'frá fílu';
$labels['filterdisabled'] = 'Síla óvirkin';
$labels['countisgreaterthan'] = 'talið er hægri enn';
$labels['countisgreaterthanequal'] = 'talið er stórri ella tað sama sum';
$labels['countislessthan'] = 'talið er minni enn';
$labels['countislessthanequal'] = 'talið er minni enn ella tað sama sum';
$labels['countequals'] = 'talið er tað sama sum';
$labels['countnotequals'] = 'talið er ikki tað sama sum';
$labels['valueisgreaterthan'] = 'virði er hægri enn';
$labels['valueisgreaterthanequal'] = 'virði er hægri enn ella tað sama sum';
$labels['valueislessthan'] = 'virði er minnni enn';
$labels['valueislessthanequal'] = 'virði er minni enn ella tað sama sum';
$labels['valueequals'] = 'virði er tað sama sum';
$labels['valuenotequals'] = 'virði er ikki tað sama sum';
$labels['setflags'] = 'Set mørk á boðini';
$labels['addflags'] = 'Legg mørk á boðini';
$labels['removeflags'] = 'Strika mørk frá boðunum';
$labels['flagread'] = 'Les';
$labels['flagdeleted'] = 'Strika';
$labels['flaganswered'] = 'Svara';
$labels['flagflagged'] = 'Markera';
$labels['flagdraft'] = 'Kladda';
$labels['setvariable'] = 'Set variabul';
$labels['setvarname'] = 'Navn á variabli';
$labels['setvarvalue'] = 'Virði á variabli';
$labels['setvarmodifiers'] = 'Avmarkari:';
$labels['varlower'] = 'við lítlum';
$labels['varupper'] = 'við stórum';
$labels['varlowerfirst'] = 'fyrsti bókstavur við lítlum';
$labels['varupperfirst'] = 'fyrsti bókstavur við stórum';
$labels['varquotewildcard'] = 'kvota fyri serlig tekin';
$labels['varlength'] = 'longd';
$labels['notify'] = 'send kunngerð';
$labels['notifytarget'] = 'Kunngerð mál:';
$labels['notifymessage'] = 'Boð í kunngerð (ikki oblikatorist):';
$labels['notifyoptions'] = 'Kunngerðis møguleikar (valmøguligt):';
$labels['notifyfrom'] = 'Sendari av kunngerð (valfríur):';
$labels['notifyimportance'] = 'Týdningur:';
$labels['notifyimportancelow'] = 'lágt';
$labels['notifyimportancenormal'] = 'vanligt';
$labels['notifyimportancehigh'] = 'høgt';
$labels['notifymethodmailto'] = 'Teldupost';
$labels['notifymethodtel'] = 'Telefon';
$labels['notifymethodsms'] = 'SMS';
$labels['filtercreate'] = 'Stovna sílu';
$labels['usedata'] = 'Brúka fylgjandi dátu í sílu';
$labels['nextstep'] = 'Næsta stig';
$labels['...'] = '...';
$labels['currdate'] = 'dagsins dato';
$labels['datetest'] = 'Dato';
$labels['dateheader'] = 'Teksthøvd ';
$labels['year'] = 'ár';
$labels['month'] = 'mánið';
$labels['day'] = 'dagur';
$labels['date'] = 'dato (yyyy-mm-dd)';
$labels['julian'] = 'dato (julianskur)';
$labels['hour'] = 'tími';
$labels['minute'] = 'minuttur';
$labels['second'] = 'sekund';
$labels['time'] = 'klokkan (tt:mm:ss)';
$labels['iso8601'] = 'dato (ISO8601)';
$labels['std11'] = 'dato (RFC2822)';
$labels['zone'] = 'tíðarøki';
$labels['weekday'] = 'vikudagur (0-6)';
$labels['advancedopts'] = 'Víðkaðir valmøguleikar';
$labels['body'] = 'Breyðtekstur';
$labels['address'] = 'Bústaður';
$labels['envelope'] = 'brævbjálvi ';
$labels['modifier'] = 'Broytari:';
$labels['text'] = 'tekstur';
$labels['undecoded'] = 'umskriva (raw)';
$labels['contenttype'] = 'innihalds slag';
$labels['modtype'] = 'slag:';
$labels['allparts'] = 'alt';
$labels['domain'] = 'økisnavn';
$labels['localpart'] = 'heima partur';
$labels['user'] = 'brúkari';
$labels['detail'] = 'detaljur';
$labels['comparator'] = 'Comparator:';
$labels['default'] = 'vanligt';
$labels['octet'] = 'strangt (octet)';
$labels['asciicasemap'] = 'óstavbundin (asciii-casemap)';
$labels['asciinumeric'] = 'tøl (ascii-numeric)';
$labels['index'] = 'skrá:';
$labels['indexlast'] = 'aftureftir';
$labels['spamtestequals'] = 'er tað sama sum';
$labels['spamtestnotequals'] = 'er ikki tað sama sum';
$labels['vacation.reply'] = 'Svar innihald';
$labels['vacation.advanced'] = 'Víðkaðir valmøguleikar';
$labels['vacation.from'] = 'Svara sendara bústaði';
$labels['vacation.subject'] = 'Evni';
$labels['vacation.body'] = 'Breyðtekstur';
$labels['vacation.status'] = 'Støða';
$labels['vacation.on'] = 'Tendra';
$labels['vacation.off'] = 'Sløkt';
$labels['vacation.addresses'] = 'Mín teldupost bústaður';
$labels['vacation.interval'] = 'Svar millumbil';
$labels['vacation.saving'] = 'Goymur dáta...';
$labels['vacation.action'] = 'Ger fyri móttikin boð';
$labels['vacation.keep'] = 'Goym';
$labels['vacation.discard'] = 'Strika';
$labels['vacation.redirect'] = 'Leið ti';
$labels['vacation.copy'] = 'Send avrit ti';
$labels['forward.redirect'] = 'Leið ti';
$labels['forward.copy'] = 'Send avrit ti';
$labels['forward.on'] = 'Tendra';
$labels['forward.off'] = 'Sløkt';
$labels['forward.saving'] = 'Goymur dátur...';
$labels['filladdresses'] = 'Fyll við øllum mínum bústaðum';
$labels['arialabelfiltersetactions'] = 'Sílu sett gerðir';
$labels['arialabelfilteractions'] = 'Sílu gerðir';
$labels['arialabelfilterform'] = 'Sílu skilvísi';
$labels['ariasummaryfilterslist'] = 'Listi yvir sílur';
$labels['ariasummaryfiltersetslist'] = 'Skrá av sílu sett';
$labels['filterstitle'] = 'Broyt mótakandi sílur fyri móttiknan post';
$labels['vacationtitle'] = 'Broyt out-of-office regul';
$labels['duplicate.header'] = 'Teksthøvd ';
$messages['filterunknownerror'] = 'Ókendur ambætara feilur';
$messages['filterconnerror'] = 'Einki samband við ambætara.';
$messages['filterdeleteerror'] = 'Tað bar ikki til at strika sílu. Ambætara feilur kom fyri';
$messages['filterdeleted'] = 'Sílan var strika';
$messages['filtersaved'] = 'Sílan var goymd';
$messages['filtersaveerror'] = 'Tað ber ikki til at goyma valdu sílur. Ambætara feilur kom fyri.';
$messages['filterdeleteconfirm'] = 'Ert tú vísur í at tú vilt strika valdu sílu?';
$messages['ruledeleteconfirm'] = 'Ert tú vísur í, at tú vilt strika valda regul?';
$messages['actiondeleteconfirm'] = 'Ert tú vísur í, at tú vilt strika valdu gerð?';
$messages['forbiddenchars'] = 'Óloyvd tekin í feltinum.';
$messages['cannotbeempty'] = 'Felt kann ikki verða tómt';
$messages['ruleexist'] = 'Síla við givna navni er longu til';
$messages['activateerror'] = 'Tað ber ikki til at tendra valdu sílur. Ambætara feilur kom fyri.';
$messages['deactivateerror'] = 'Tað ber ikki til at sløkkja valdu sílur. Ambætara feilur kom fyri.';
$messages['deactivated'] = 'Filtur sløkt';
$messages['activated'] = 'Filtur tendra.';
$messages['moved'] = 'Síla flutt.';
$messages['moveerror'] = 'Tað ber ikki til at flyta valdu sílur. Ambætara feilur kom fyri.';
$messages['nametoolong'] = 'Navni er ov langt';
$messages['namereserved'] = 'Reservera navn.';
$messages['setexist'] = 'Sett er longu til';
$messages['nodata'] = 'Minst eitt stað má verða valt!';
$messages['invaliddateformat'] = 'Ógildugt dato ella formulering av dato';
$messages['saveerror'] = 'Tað bar ikki til at goyma dáta. Ambætara feilur kom fyri.';
$messages['emptyvacationbody'] = 'Breyðtekstur er kravdur í feriuboðum!';
