<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['welcome'] = '歡迎使用 $product';
$labels['username'] = '使用者名稱';
$labels['password'] = '使用者密碼';
$labels['server'] = '伺服器';
$labels['login'] = '登入';
$labels['oauthlogin'] = '使用 $provider 登入';
$labels['menu'] = '選單';
$labels['logout'] = '登出';
$labels['mail'] = '電子郵件';
$labels['settings'] = '設定';
$labels['addressbook'] = '通訊錄';
$labels['darkmode'] = '深色模式';
$labels['lightmode'] = '淺色模式';
$labels['inbox'] = '收件匣';
$labels['drafts'] = '草稿匣';
$labels['sent'] = '寄件備份';
$labels['trash'] = '垃圾桶';
$labels['junk'] = '垃圾郵件';
$labels['show_real_foldernames'] = '顯示特殊資料夾的實際名稱';
$labels['subject'] = '主旨';
$labels['from'] = '寄件者';
$labels['sender'] = '寄件者';
$labels['to'] = '收件者';
$labels['cc'] = '副本';
$labels['bcc'] = '密件副本';
$labels['replyto'] = '回覆至';
$labels['followupto'] = '郵件列表回覆地址';
$labels['date'] = '日期';
$labels['size'] = '大小';
$labels['priority'] = '優先次序';
$labels['organization'] = '組織/公司';
$labels['readstatus'] = '讀信狀態';
$labels['listoptions'] = '列表選項...';
$labels['listoptionstitle'] = '列表選項';
$labels['mailboxlist'] = '資料夾';
$labels['messagesfromto'] = '郵件 $from 至 $to，共 $count 封';
$labels['threadsfromto'] = '郵件串 $from 至 $to，共 $count 個';
$labels['messagenrof'] = '第 $nr 封郵件，共有 $count 封';
$labels['fromtoshort'] = '$from – $to 共 $count 個';
$labels['copy'] = '複製';
$labels['move'] = '移動';
$labels['moveto'] = '移至...';
$labels['copyto'] = '複製到...';
$labels['download'] = '下載';
$labels['open'] = '開啟';
$labels['showattachment'] = '顯示';
$labels['showanyway'] = '總是顯示';
$labels['filename'] = '檔案名稱';
$labels['filesize'] = '檔案大小';
$labels['addtoaddressbook'] = '新增至通訊錄';
$labels['sun'] = '週日';
$labels['mon'] = '週一';
$labels['tue'] = '週二';
$labels['wed'] = '週三';
$labels['thu'] = '週四';
$labels['fri'] = '週五';
$labels['sat'] = '週六';
$labels['sunday'] = '星期日';
$labels['monday'] = '星期一';
$labels['tuesday'] = '星期二';
$labels['wednesday'] = '星期三';
$labels['thursday'] = '星期四';
$labels['friday'] = '星期五';
$labels['saturday'] = '星期六';
$labels['jan'] = '一';
$labels['feb'] = '二';
$labels['mar'] = '三';
$labels['apr'] = '四';
$labels['may'] = '五';
$labels['jun'] = '六';
$labels['jul'] = '七';
$labels['aug'] = '八';
$labels['sep'] = '九';
$labels['oct'] = '十';
$labels['nov'] = '十一';
$labels['dec'] = '十二';
$labels['longjan'] = '1 月';
$labels['longfeb'] = '2 月';
$labels['longmar'] = '3 月';
$labels['longapr'] = '4 月';
$labels['longmay'] = '5 月';
$labels['longjun'] = '6 月';
$labels['longjul'] = '7 月';
$labels['longaug'] = '8 月';
$labels['longsep'] = '9 月';
$labels['longoct'] = '10 月';
$labels['longnov'] = '11 月';
$labels['longdec'] = '12 月';
$labels['today'] = '今日';
$labels['refresh'] = '重新整理';
$labels['checkmail'] = '檢查新郵件';
$labels['compose'] = '撰寫新郵件';
$labels['writenewmessage'] = '撰寫新郵件';
$labels['reply'] = '回覆';
$labels['replytomessage'] = '回覆';
$labels['replytoallmessage'] = '全部回覆';
$labels['replyall'] = '全部回覆';
$labels['replylist'] = '清單回覆';
$labels['forward'] = '轉寄';
$labels['forwardinline'] = '以內文方式轉寄';
$labels['forwardattachment'] = '以附件方式轉寄';
$labels['forwardmessage'] = '轉寄';
$labels['bouncemsg'] = '重寄 (退回郵件)';
$labels['bounce'] = '重寄';
$labels['deletemessage'] = '刪除郵件';
$labels['movemessagetotrash'] = '移動郵件至垃圾桶';
$labels['printmessage'] = '列印此郵件';
$labels['previousmessage'] = '顯示上一封郵件';
$labels['firstmessage'] = '顯示第一封郵件';
$labels['nextmessage'] = '顯示下一封郵件';
$labels['lastmessage'] = '顯示最後一封郵件';
$labels['backtolist'] = '回到郵件清單';
$labels['viewsource'] = '顯示郵件原始內容';
$labels['mark'] = '標記';
$labels['markmessages'] = '標記選取的郵件';
$labels['markread'] = '標示為已讀取';
$labels['markunread'] = '標示為未讀取';
$labels['markflagged'] = '標上旗標';
$labels['markunflagged'] = '移除旗標';
$labels['moreactions'] = '更多動作...';
$labels['markallread'] = '全部標示為已讀取';
$labels['folders-cur'] = '僅選取的資料夾';
$labels['folders-sub'] = '選取的資料夾及其子資料夾';
$labels['folders-all'] = '所有資料夾';
$labels['more'] = '更多';
$labels['back'] = '返回';
$labels['options'] = '選項';
$labels['composeoptions'] = '撰寫選項';
$labels['optionsandattachments'] = '選項及附件';
$labels['actions'] = '動作';
$labels['first'] = '第一個';
$labels['last'] = '最後一個';
$labels['previous'] = '前一個';
$labels['next'] = '後一個';
$labels['select'] = '選取';
$labels['selection'] = '選取範圍';
$labels['all'] = '全部郵件';
$labels['none'] = '無';
$labels['currpage'] = '目前頁面';
$labels['isread'] = '已讀';
$labels['unread'] = '未讀取的郵件';
$labels['flagged'] = '已加旗標';
$labels['unflagged'] = '無旗標';
$labels['unanswered'] = '未回覆的郵件';
$labels['withattachment'] = '包含附件';
$labels['deleted'] = '已刪除的郵件';
$labels['undeleted'] = '未刪除的郵件';
$labels['replied'] = '已回覆';
$labels['forwarded'] = '已轉寄';
$labels['invert'] = '反選';
$labels['filter'] = '篩選範圍';
$labels['list'] = '清單';
$labels['threads'] = '郵件串';
$labels['expand-all'] = '全部展開';
$labels['expand-unread'] = '展開未讀取';
$labels['collapse-all'] = '全部收起';
$labels['threaded'] = '郵件串';
$labels['showunread'] = '顯示未讀郵件';
$labels['autoexpand_threads'] = '展開郵件串';
$labels['do_expand'] = '所有郵件串';
$labels['expand_only_unread'] = '只展開未讀郵件';
$labels['fromto'] = '寄件者/收件者';
$labels['flag'] = '旗標';
$labels['attachment'] = '附件';
$labels['nonesort'] = '無';
$labels['sentdate'] = '寄送時間';
$labels['arrival'] = '到達時間';
$labels['asc'] = '遞增';
$labels['desc'] = '遞減';
$labels['listcolumns'] = '列出欄位';
$labels['listsorting'] = '排序欄位';
$labels['listorder'] = '排序順序';
$labels['listmode'] = '列表檢視模式';
$labels['lmode'] = '列表模式';
$labels['layout'] = '畫面配置';
$labels['layoutwidescreen'] = '寬螢幕';
$labels['layoutdesktop'] = '桌面';
$labels['layoutlist'] = '清單';
$labels['layoutwidescreendesc'] = '寬螢幕 (3欄檢視)';
$labels['layoutdesktopdesc'] = '桌面 (寬列表，下面是郵件預覽)';
$labels['layoutlistdesc'] = '列表 (無郵件預覽)';
$labels['folderactions'] = '資料夾動作...';
$labels['compact'] = '壓緊';
$labels['empty'] = '清空';
$labels['importmessages'] = '匯入郵件';
$labels['mailimportdesc'] = '可以用 <a href="https://en.wikipedia.org/wiki/Email#Message_format">MIME</a> 或 <a href="https://en.wikipedia.org/wiki/Mbox">Mbox</a> 格式檔案上傳郵件。';
$labels['mailimportzip'] = '多個檔案可以壓縮為 ZIP 檔案。';
$labels['quota'] = '磁碟使用量';
$labels['unknown'] = '未知';
$labels['unlimited'] = '無限制';
$labels['quotatype'] = '配額類型';
$labels['quotatotal'] = '上限';
$labels['quotaused'] = '已使用';
$labels['quotastorage'] = '儲存空間';
$labels['quotamessage'] = '郵件數目';
$labels['shortheaderdate'] = '於 $date';
$labels['shortheaderto'] = '於 $date，寄給 $to';
$labels['shortheaderfrom'] = '於 $date，寄自 $from';
$labels['quicksearch'] = '快速搜尋';
$labels['searchplaceholder'] = '搜尋...';
$labels['resetsearch'] = '重設搜尋';
$labels['searchmod'] = '修改搜尋';
$labels['msgtext'] = '整封郵件';
$labels['body'] = '內文';
$labels['type'] = '類型';
$labels['namex'] = '名稱';
$labels['searchscope'] = '範圍';
$labels['currentfolder'] = '目前的資料夾';
$labels['subfolders'] = '目前的資料夾 (含子資料夾)';
$labels['allfolders'] = '所有資料夾';
$labels['searchinterval-1W'] = '超過一週';
$labels['searchinterval-1M'] = '超過一個月';
$labels['searchinterval-1Y'] = '超過一年';
$labels['searchinterval1W'] = '一週之內';
$labels['searchinterval1M'] = '一個月之內';
$labels['searchinterval1Y'] = '一年之內';
$labels['openinextwin'] = '在新視窗開啟';
$labels['emlsave'] = '下載 (.eml)';
$labels['changeformattext'] = '以純文字格式顯示';
$labels['changeformathtml'] = '以 HTML 格式顯示';
$labels['editasnew'] = '以新郵件編輯';
$labels['send'] = '寄出';
$labels['sendmessage'] = '立即寄出';
$labels['savemessage'] = '儲存成草稿';
$labels['addattachment'] = '加入附件檔案';
$labels['charset'] = '郵件編碼';
$labels['editortype'] = '編輯器類型';
$labels['returnreceipt'] = '要求讀取回條';
$labels['dsn'] = '傳送狀態通知';
$labels['mailreplyintro'] = '$sender 於 $date 寫到:';
$labels['originalmessage'] = '原始郵件';
$labels['selectimage'] = ' 選擇圖片';
$labels['addimage'] = '加入圖片';
$labels['selectmedia'] = '選擇影片';
$labels['addmedia'] = '加入影片';
$labels['encrypt'] = '加密';
$labels['encryptmessage'] = '加密郵件';
$labels['encryptmessagemailvelope'] = '以 Mailvelope 加密郵件';
$labels['importpubkeys'] = '匯入公鑰';
$labels['encryptedsendialog'] = '發送加密郵件';
$labels['encryptandsign'] = '加密並簽署';
$labels['keyid'] = '金鑰 ID';
$labels['keylength'] = '位元';
$labels['keyexpired'] = '已過期';
$labels['keyrevoked'] = '已撤銷';
$labels['bccinstead'] = '使用「密件副本」';
$labels['insert'] = '插入';
$labels['insertcontact'] = '插入聯絡人';
$labels['recipient'] = '收件者';
$labels['recipientedit'] = '收件者編輯';
$labels['editidents'] = '編輯身份資訊';
$labels['spellcheck'] = '拼字';
$labels['checkspelling'] = '拼字檢查';
$labels['resumeediting'] = '繼續編輯';
$labels['revertto'] = '恢復至';
$labels['restore'] = '回復';
$labels['restoremessage'] = '回復郵件？';
$labels['ignore'] = ' 忽略';
$labels['responses'] = '預設回應';
$labels['insertresponse'] = '插入預設回應';
$labels['manageresponses'] = '管理預設回應';
$labels['newresponse'] = '建立預設回應';
$labels['addresponse'] = ' 加入預設回應';
$labels['editresponse'] = '編輯預設回應';
$labels['editresponses'] = '編輯預設回應';
$labels['responsename'] = '名稱';
$labels['responsetext'] = '預設回應內容';
$labels['attach'] = '附件';
$labels['attachments'] = '附件檔案';
$labels['upload'] = '上傳';
$labels['uploadprogress'] = '$percent ($total 中的 $current)';
$labels['close'] = '關閉';
$labels['messageoptions'] = '郵件選項...';
$labels['togglecomposeoptions'] = ' 切換撰寫選項';
$labels['attachmentrename'] = '重新命名附件';
$labels['low'] = '低';
$labels['lowest'] = '最低';
$labels['normal'] = '普通';
$labels['high'] = '高';
$labels['highest'] = '最高';
$labels['nosubject'] = '（沒有主旨）';
$labels['showimages'] = '顯示圖片';
$labels['allow'] = '允許';
$labels['alwaysshow'] = '總是顯示來自 $sender 的圖片';
$labels['alwaysallow'] = '必定允許寄自 $sender 的郵件';
$labels['isdraft'] = '這是草稿';
$labels['andnmore'] = '第$nr封或是更多...';
$labels['details'] = '詳情';
$labels['summary'] = '概覽';
$labels['headers'] = '標頭';
$labels['allheaders'] = '所有標頭...';
$labels['togglemoreheaders'] = '顯示更多的郵件標頭';
$labels['togglefullheaders'] = '切換原始郵件標頭';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = '純文字';
$labels['savesentmessagein'] = '儲存寄件備份至';
$labels['dontsave'] = '不要儲存';
$labels['maxuploadsize'] = '上傳檔案大小限制為 $size';
$labels['addcc'] = '新增副本';
$labels['addbcc'] = '新增密件副本';
$labels['addreplyto'] = '新增回覆地址';
$labels['addfollowupto'] = '新增郵件列表回覆地址';
$labels['sendreceipt'] = '傳送讀取回條？';
$labels['mdnrequest'] = '此郵件的寄件者希望在你閱讀此郵件時受到通知。你想要通知寄件者嗎？';
$labels['receiptread'] = '郵件回條（已閱讀）';
$labels['yourmessage'] = '這是你郵件的郵件回條';
$labels['receiptnote'] = '注意：此回條只能確認收件者的電腦顯示了郵件，並不能保證收件者已閱讀或了解郵件的內容。';
$labels['sendalwaysto'] = '總是傳送給 $email';
$labels['zoomin'] = '放大';
$labels['zoomout'] = '縮小';
$labels['rotate'] = '旋轉';
$labels['increaseimage'] = '放大圖像';
$labels['decreaseimage'] = '縮小圖像';
$labels['rotateimage'] = '旋轉圖像';
$labels['showtools'] = '顯示圖像工具';
$labels['hidetools'] = '隱藏圖像工具';
$labels['name'] = '顯示名稱';
$labels['firstname'] = '名字';
$labels['surname'] = '姓氏';
$labels['middlename'] = '中名';
$labels['nameprefix'] = '頭銜 (例如 Dr.)';
$labels['namesuffix'] = '後綴 (例如 Jr.)';
$labels['nickname'] = '暱稱';
$labels['jobtitle'] = '職位';
$labels['department'] = '部門';
$labels['gender'] = '性別';
$labels['maidenname'] = '閨姓';
$labels['email'] = '電子郵件';
$labels['phone'] = '電話';
$labels['address'] = '地址';
$labels['street'] = '街道';
$labels['locality'] = '城市';
$labels['zipcode'] = '郵遞區號';
$labels['region'] = '州/省';
$labels['country'] = '國家/地區';
$labels['birthday'] = '生日';
$labels['anniversary'] = '周年紀念日';
$labels['website'] = '網站';
$labels['instantmessenger'] = '即時通訊';
$labels['notes'] = '註解';
$labels['male'] = '男';
$labels['female'] = '女';
$labels['manager'] = '上司';
$labels['assistant'] = '助理';
$labels['spouse'] = '配偶';
$labels['allfields'] = '所有欄位';
$labels['search'] = '搜尋';
$labels['searchresult'] = ' 搜尋結果';
$labels['advsearch'] = '進階搜尋';
$labels['advanced'] = '進階';
$labels['other'] = '其他';
$labels['printcontact'] = ' 列印聯絡人';
$labels['qrcode'] = 'QR 碼';
$labels['typehome'] = '住家';
$labels['typework'] = '工作';
$labels['typeother'] = '其他';
$labels['typemobile'] = '行動電話';
$labels['typemain'] = '主要';
$labels['typehomefax'] = '住家傳真';
$labels['typeworkfax'] = '工作傳真';
$labels['typecar'] = '汽車';
$labels['typepager'] = '傳呼機';
$labels['typevideo'] = '影片';
$labels['typeassistant'] = '助理';
$labels['typehomepage'] = '首頁';
$labels['typeblog'] = '部落格';
$labels['typeprofile'] = '設定檔';
$labels['addfield'] = '加入欄位...';
$labels['addcontact'] = '加入聯絡人';
$labels['editcontact'] = '編輯聯絡人';
$labels['contacts'] = '聯絡人';
$labels['contactproperties'] = '聯絡人資訊';
$labels['contactnameandorg'] = ' 姓名和組織/公司';
$labels['personalinfo'] = '個人資訊';
$labels['personal'] = '個人';
$labels['contactphoto'] = '聯絡人相片';
$labels['edit'] = '編輯';
$labels['cancel'] = '取消';
$labels['save'] = '儲存';
$labels['delete'] = '刪除';
$labels['discard'] = '丟棄';
$labels['continue'] = '繼續';
$labels['ok'] = '確定';
$labels['rename'] = '重新命名';
$labels['addphoto'] = '加入';
$labels['replacephoto'] = '取代';
$labels['uploadphoto'] = '上傳相片';
$labels['choosefile'] = '選擇檔案...';
$labels['choosefiles'] = '選擇檔案...';
$labels['browse'] = '瀏覽';
$labels['newcontact'] = ' 新建聯絡人';
$labels['deletecontact'] = '刪除所選擇的聯絡人';
$labels['composeto'] = '寄信至所選擇的聯絡人';
$labels['contactsfromto'] = '聯絡人 $from 至 $to，共 $count 人';
$labels['print'] = '列印';
$labels['export'] = '匯出';
$labels['exportall'] = '全部匯出';
$labels['exportsel'] = '匯出所選項目';
$labels['exportvcards'] = '匯出通訊錄為 vCard 格式';
$labels['newgroup'] = '新建群組';
$labels['addgroup'] = '加入群組';
$labels['grouprename'] = '重新命名群組';
$labels['groupdelete'] = '刪除群組';
$labels['groupassign'] = '分配到群組...';
$labels['groupremove'] = '從群組移除';
$labels['groupremoveselected'] = '於群組刪除所選的聯絡人';
$labels['uponelevel'] = '回到上一層';
$labels['previouspage'] = '顯示上一頁';
$labels['firstpage'] = '顯示第一頁';
$labels['nextpage'] = '顯示下一頁';
$labels['lastpage'] = '顯示最後一頁';
$labels['group'] = '群組';
$labels['groups'] = '群組';
$labels['listgroup'] = '列出群組成員';
$labels['personaladrbook'] = '個人通訊錄';
$labels['searchsave'] = '儲存搜尋結果';
$labels['searchdelete'] = '刪除搜尋結果';
$labels['import'] = '匯入';
$labels['importcontacts'] = '匯入聯絡人';
$labels['importfromfile'] = '從檔案匯入';
$labels['importtarget'] = '新增聯絡人到';
$labels['importreplace'] = '取代整個通訊錄';
$labels['importgroups'] = '匯入群組';
$labels['importgroupsall'] = '全部 (必要時新增群組)';
$labels['importgroupsexisting'] = '僅限於既有群組';
$labels['importdesc'] = '可以上傳通訊錄的所有聯絡人。<br/>現時支援 <a href="https://en.wikipedia.org/wiki/VCard">vCard</a> 或 CSV 格式。';
$labels['importmapdesc'] = '在繼續進行 CSV（逗號分隔）資料匯入前，請先確認下方的欄位對映資訊正確無誤。';
$labels['fieldnotmapped'] = '欄位未對映（不匯入）';
$labels['skipheader'] = '不匯入第一行（標頭）';
$labels['done'] = '完成';
$labels['settingsfor'] = '設定';
$labels['about'] = '關於';
$labels['preferences'] = '設定';
$labels['userpreferences'] = '個人設定';
$labels['editpreferences'] = '編輯個人設定';
$labels['identities'] = '身份資訊';
$labels['manageidentities'] = '管理識別身份';
$labels['newidentity'] = '新增識別身份';
$labels['addidentity'] = '加入識別身份';
$labels['editidentity'] = '編輯識別身份';
$labels['identityencryption'] = '加密';
$labels['preferhtml'] = '使用 HTML 顯示';
$labels['defaultcharset'] = '預設編碼';
$labels['htmlmessage'] = 'HTML 郵件';
$labels['messagepart'] = '部分';
$labels['digitalsig'] = '數位簽章';
$labels['dateformat'] = '日期格式';
$labels['timeformat'] = '時間格式';
$labels['prettydate'] = '簡短日期顯示';
$labels['setdefault'] = '設成預設值';
$labels['autodetect'] = '自動選擇';
$labels['language'] = '語言';
$labels['timezone'] = '時區';
$labels['pagesize'] = '每頁顯示列數';
$labels['signature'] = '簽名檔';
$labels['dstactive'] = '日光節約時間';
$labels['showinextwin'] = '在新視窗顯示郵件';
$labels['composeextwin'] = '在新視窗撰寫郵件';
$labels['htmleditor'] = '使用 HTML 撰寫郵件';
$labels['htmlonreply'] = '僅在回覆 HTML 信件時';
$labels['htmlonreplyandforward'] = '僅在轉寄或回覆 HTML 信件時';
$labels['htmlsignature'] = 'HTML 簽名檔';
$labels['showemail'] = '一併顯示名稱和電郵地址';
$labels['previewpane'] = '顯示預覽窗格';
$labels['skin'] = '版面風格';
$labels['logoutclear'] = '登出時清空垃圾桶';
$labels['logoutcompact'] = '登出時壓緊收件匣';
$labels['uisettings'] = '使用者介面';
$labels['serversettings'] = '伺服器設定';
$labels['mailboxview'] = '信箱顯示';
$labels['mdnrequests'] = '讀取回條回應';
$labels['askuser'] = '詢問我';
$labels['autosend'] = '自動送出';
$labels['autosendknown'] = '傳送回條給我的聯絡人，其他則詢問我';
$labels['autosendknownignore'] = '傳送回條給我的聯絡人，其他則忽略';
$labels['autosendtrusted'] = '傳送回條給受信任的寄件者，否則請問我';
$labels['autosendtrustedignore'] = '傳送回條給受信任的寄件者，否則請忽略';
$labels['ignorerequest'] = '忽略要求';
$labels['readwhendeleted'] = '將刪除的郵件標示為已讀取';
$labels['flagfordeletion'] = '只將郵件標示為刪除，而非真的刪除';
$labels['skipdeleted'] = '不要顯示已刪除的郵件';
$labels['deletealways'] = '如果移動郵件到垃圾桶失敗，就直接刪除';
$labels['deletejunk'] = '直接刪除「垃圾郵件」中的郵件';
$labels['showremoteimages'] = '顯示遠端郵件內文的圖片';
$labels['allowremoteresources'] = '允許遠端資源 (圖像、樣式)';
$labels['fromknownsenders'] = '從已知的寄件者';
$labels['fromtrustedsenders'] = '來自受信任的寄件者';
$labels['frommycontacts'] = '來自我的聯絡人';
$labels['always'] = '總是';
$labels['alwaysbutplain'] = '總是，除非回覆純文字郵件';
$labels['showinlineimages'] = '將附加檔案的圖片顯示於郵件最後';
$labels['autosavedraft'] = '自動儲存草稿';
$labels['everynminutes'] = '每 $n 分鐘';
$labels['refreshinterval'] = '重新整理 (檢查新郵件等)';
$labels['never'] = '永不';
$labels['immediately'] = '立即';
$labels['messagesdisplaying'] = '郵件顯示';
$labels['messagescomposition'] = '撰寫郵件';
$labels['mimeparamfolding'] = '附加檔案名稱的編碼方式';
$labels['2231folding'] = '完全 RFC 2231 模式（Thunderbird）';
$labels['miscfolding'] = 'RFC 2047/2231 混合模式（MS Outlook）';
$labels['2047folding'] = '完全 RFC 2047 模式（其他）';
$labels['force7bit'] = '對 8 位元字元使用 MIME 編碼';
$labels['savelocalstorage'] = "( 暫時 ) 保存在瀏覽器的本機儲存";
$labels['advancedoptions'] = '進階選項';
$labels['toggleadvancedoptions'] = '切換高級選項';
$labels['focusonnewmessage'] = '收到新郵件時使瀏覽器獲得焦點';
$labels['checkallfolders'] = '對於所有資料夾，都要檢查有否新郵件';
$labels['displaynext'] = '刪除/移動之後，顯示下一個清單項目';
$labels['defaultfont'] = 'HTML 郵件的預設字型';
$labels['mainoptions'] = '主要選項';
$labels['browseroptions'] = '瀏覽器選項';
$labels['section'] = '分類';
$labels['maintenance'] = '管理';
$labels['newmessage'] = '新郵件';
$labels['signatureoptions'] = '簽名檔選項';
$labels['whenreplying'] = '回覆時';
$labels['replyempty'] = '不要包含原來的信件內容';
$labels['replytopposting'] = '在原文上方開始新郵件';
$labels['replytoppostingnoindent'] = '在原文上方開始新郵件 (無縮排)';
$labels['replybottomposting'] = '在原文下方開始新郵件';
$labels['replyremovesignature'] = '回覆時移除原有簽名檔';
$labels['autoaddsignature'] = '自動附加簽名';
$labels['newmessageonly'] = '僅新郵件';
$labels['replyandforwardonly'] = '僅回覆或轉寄時';
$labels['insertsignature'] = '插入簽名檔';
$labels['sigbelow'] = '將簽名置於引用郵件之後';
$labels['sigseparator'] = '在簽名強制使用標準分隔符號';
$labels['automarkread'] = '將郵件標記為已讀';
$labels['afternseconds'] = '$n 秒之後';
$labels['reqmdn'] = '總是索取讀取回條';
$labels['reqdsn'] = '總是要求傳送狀態通知';
$labels['replysamefolder'] = '將回信放在與原信件相同的資料夾';
$labels['defaultabook'] = '預設通訊錄';
$labels['autocompletesingle'] = '在自動完成時略過其他電郵地址';
$labels['listnamedisplay'] = '聯絡人顯示方式';
$labels['contactformmode'] = '聯絡人表單模式';
$labels['privatemode'] = '私人（家）';
$labels['businessmode'] = '商務（工作）';
$labels['collectedaddresses'] = '已蒐集的地址';
$labels['collectedrecipients'] = '已蒐集的收件者';
$labels['collectedrecipientsopt'] = '將寄送電子郵件收件者儲存於';
$labels['collectedsendersopt'] = '將受信任的寄件者儲存於';
$labels['trustedsenders'] = '受信任的寄件者';
$labels['spellcheckbeforesend'] = '寄送前執行拼字檢查';
$labels['spellcheckoptions'] = '拼字檢查選項';
$labels['spellcheckignoresyms'] = '忽略有符號的字';
$labels['spellcheckignorenums'] = '忽略有數字的字';
$labels['spellcheckignorecaps'] = '忽略全大寫字母的字';
$labels['addtodict'] = '加入詞典';
$labels['mailtoprotohandler'] = '註冊為 mailto: 連結的預設處理常式';
$labels['standardwindows'] = '以新視窗顯示彈出式對話框';
$labels['forwardmode'] = '郵件轉寄方式';
$labels['inline'] = '放入內文';
$labels['asattachment'] = '當成附件';
$labels['replyallmode'] = '「全部回覆」按鈕的預設動作';
$labels['replyalldefault'] = '全部回覆';
$labels['replyalllist'] = '只回覆郵件列表 (如有)';
$labels['allmessages'] = '所有郵件';
$labels['folder'] = '資料夾';
$labels['folders'] = '資料夾';
$labels['foldername'] = '資料夾名稱';
$labels['subscribed'] = '訂閱';
$labels['messagecount'] = '郵件數目';
$labels['create'] = '建立';
$labels['createfolder'] = '建立新資料夾';
$labels['managefolders'] = '管理資料夾';
$labels['specialfolders'] = '特殊資料夾';
$labels['properties'] = '屬性';
$labels['folderproperties'] = '資料夾屬性';
$labels['parentfolder'] = '上一層資料夾';
$labels['location'] = '位置';
$labels['info'] = '資訊';
$labels['getfoldersize'] = '點擊顯示資料夾大小';
$labels['changesubscription'] = '點擊以改變訂閱';
$labels['foldertype'] = '資料夾類型';
$labels['personalfolder'] = '私人資料夾';
$labels['otherfolder'] = '其他使用者資料夾';
$labels['sharedfolder'] = '公用資料夾';
$labels['findfolders'] = '尋找資料夾';
$labels['findcontacts'] = '尋找聯絡人';
$labels['findmail'] = '尋找郵件';
$labels['namespace.personal'] = '個人';
$labels['namespace.other'] = '其他使用者';
$labels['namespace.shared'] = '共享';
$labels['dualuselabel'] = '僅可包含';
$labels['dualusemail'] = '郵件';
$labels['dualusefolder'] = '資料夾';
$labels['generate'] = '建立';
$labels['encryptioncreatekey'] = '建立新的金鑰對';
$labels['openmailvelopesettings'] = '開啟 Mailvelope 設定';
$labels['encryptionprivkeysinmailvelope'] = '有 $nr 個符合的私鑰儲存於 Mailvelope 鑰匙圈：';
$labels['encryptionnoprivkeysinmailvelope'] = '未有在 Mailvelope 附加程式找到寄件者的身分的 PGP 私鑰。是否建立一個新的，以啟用郵件加密？';
$labels['encryption'] = '加密';
$labels['mailvelopeoptions'] = 'Mailvelope 選項';
$labels['mailvelopemainkeyring'] = '使用 Mailvelope 主鑰匙圈';
$labels['mailvelopenotfound'] = '您的瀏覽器未啟用／安裝 Mailvelope 擴充套件';
$labels['sortby'] = '排序';
$labels['sortasc'] = '遞增排序';
$labels['sortdesc'] = '遞減排序';
$labels['undo'] = '復原';
$labels['installedplugins'] = '已安裝的擴充套件';
$labels['plugin'] = '擴充套件';
$labels['version'] = '版本';
$labels['source'] = '來源';
$labels['destination'] = '目的地';
$labels['license'] = '授權許可';
$labels['support'] = '取得支援';
$labels['savedsearches'] = '儲存的搜尋樣式';
$labels['dateformatY'] = 'YYYY';
$labels['dateformaty'] = 'YY';
$labels['dateformatm'] = 'MM';
$labels['dateformatd'] = 'DD';
$labels['dateformatj'] = 'D';
$labels['dateformatn'] = 'M';
$labels['B'] = 'B';
$labels['KB'] = 'KB';
$labels['MB'] = 'MB';
$labels['GB'] = 'GB';
$labels['unicode'] = '萬國碼';
$labels['english'] = '英文';
$labels['westerneuropean'] = '西歐語系';
$labels['easterneuropean'] = '東歐語系';
$labels['southeasterneuropean'] = '東南歐語系';
$labels['baltic'] = '波羅的海語系';
$labels['cyrillic'] = '西里爾字母';
$labels['arabic'] = '阿拉伯文';
$labels['greek'] = '希臘文';
$labels['hebrew'] = '希伯來文';
$labels['turkish'] = '土耳其文';
$labels['nordic'] = '北歐語系';
$labels['thai'] = '泰文';
$labels['celtic'] = '塞爾特語系';
$labels['vietnamese'] = '越南文';
$labels['japanese'] = '日文';
$labels['korean'] = '韓文';
$labels['chinese'] = '中文';
$labels['arialabeltopnav'] = '視窗控制';
$labels['arialabeltasknav'] = '應用程式任務';
$labels['arialabeltoolbar'] = '應用程式工具列';
$labels['arialabellistnav'] = '清單導覽';
$labels['arialabelactivetask'] = '現行的任務';
$labels['arialabelmessagessearchfilter'] = '電子郵件列表篩選';
$labels['arialabelmailsearchform'] = '電子郵件搜索表單';
$labels['arialabelcontactsearchform'] = '聯絡人搜索表單';
$labels['arialabelmailquicksearchbox'] = ' 電子郵件搜索輸入';
$labels['arialabelquicksearchbox'] = '搜索輸入';
$labels['arialabelfoldersearchfilter'] = '文件夾列表過濾器';
$labels['arialabelfoldersearchform'] = '文件夾搜索表單';
$labels['arialabelfolderlist'] = '電郵資料夾選擇';
$labels['arialabelmessagelist'] = '電郵列表';
$labels['arialabelmailpreviewframe'] = '郵件預覽';
$labels['arialabelmailboxmenu'] = '資料夾動作選單';
$labels['arialabellistselectmenu'] = '清單選擇選單';
$labels['arialabelthreadselectmenu'] = '郵件串列表選單';
$labels['arialabelmessagelistoptions'] = '郵件清單顯示及排序選項';
$labels['arialabelmailimportdialog'] = '郵件匯入對話匣';
$labels['arialabelmessagenav'] = '郵件導覽';
$labels['arialabelmessagebody'] = '郵件正文';
$labels['arialabelmessageactions'] = '郵件動作';
$labels['arialabelcontactquicksearch'] = '聯絡人搜尋表單';
$labels['arialabelcontactsearchbox'] = '聯絡人搜尋輸入';
$labels['arialabelmessageheaders'] = '郵件標頭';
$labels['arialabelforwardingoptions'] = '轉寄選項';
$labels['arialabelreplyalloptions'] = '「全部回覆」選項';
$labels['arialabelmoremessageactions'] = '更多郵件動作';
$labels['arialabelmorecontactactions'] = '更多聯絡人動作';
$labels['arialabelmarkmessagesas'] = '將所選郵件標示為...';
$labels['arialabelcomposeoptions'] = '撰寫選項';
$labels['arialabelresponsesmenu'] = '「罐頭」預設回應選單';
$labels['arialabelattachmentuploadform'] = '附件上載表單';
$labels['arialabelattachmentmenu'] = '附件選項';
$labels['arialabelmailtomenu'] = '電郵位址選項';
$labels['arialabelattachmentpreview'] = '附件預覽';
$labels['ariasummarycomposecontacts'] = '可以選取為收件者的聯絡人和群組清單';
$labels['arialabelcontactexportoptions'] = '聯絡人匯出選項';
$labels['arialabelabookgroupoptions'] = '通訊錄/群組選項';
$labels['arialabelpreferencesform'] = '設定表單';
$labels['arialabelidentityeditfrom'] = '身份編輯表單';
$labels['arialabelresponseeditfrom'] = '預設回應編輯表單';
$labels['arialabelsearchterms'] = '搜尋項目';
$labels['arialabeldropactionmenu'] = '拖曳動作選單';
$labels['arialabelheadersmenu'] = '收件者 (標頭) 加入選單';
$labels['arialabelimagetools'] = '圖像工具';
$labels['helplistnavigation'] = '清單鍵盤導覽';
$labels['helplistkeyboardnavigation'] = "上下箭嘴：移動焦點／選取列
空格鍵：選取焦點列
Shift + 上／下：額外選取上面或下面的列
Ctrl + 空格鍵：將焦點列加入選取／將焦點列移出選取";
$labels['helplistkeyboardnavmessages'] = "左／右箭嘴：展開／收起郵件串 (僅在郵件串模式有效)
Enter：開啟所選／焦點郵件
Del：將所選郵件移至垃圾桶";
$labels['helplistkeyboardnavcontacts'] = "Enter：開啟所選／焦點聯絡人";
