<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Vcard Attachments plugin   |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['addvcardmsg'] = '주소록에 vCard 추가';
$labels['vcardsavefailed'] = 'vCard를 저장할 수 없음';
$labels['attachvcard'] = 'vCard 첨부';
$labels['vcardattached'] = 'vCard 파일을 첨부했습니다.';
$labels['vcard'] = 'vCard';
$labels['forwardvcard'] = 'vCard 전달';
$labels['contactsattached'] = '이 메시지에 첨부된 $num개의 연락처가 있습니다.';
$labels['importedsuccessfully'] = '연락처를 주소록에 성공적으로 가져왔습니다.';
