<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail ACL plugin                 |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['sharing'] = 'Parvekirin';
$labels['myrights'] = 'Mafên gihiştinê';
$labels['username'] = 'Bikarhêner:';
$labels['advanced'] = 'Awayê pêşketî';
$labels['add'] = 'Tevlî bike';
$labels['newuser'] = 'Têketinê tevlî bike';
$labels['editperms'] = 'Mafdayînan biguherîne';
$labels['actions'] = 'Çalakiyên mafê gihiştinê...';
$labels['anyone'] = 'Hemû bikarhêneran (her kes)';
$labels['anonymous'] = 'Mêvan (anonyim)';
$labels['identifier'] = 'Danasîner';
$labels['acll'] = 'Bigere';
$labels['aclr'] = 'Peyaman bixwîne';
$labels['acls'] = 'Rewşa dîtî bihêle';
$labels['aclw'] = 'Alayan binivîse';
$labels['acli'] = 'Têxîne (Jê bigire bo)';
$labels['aclp'] = 'Bişîne';
$labels['aclc'] = 'Binpeldankan biafrîne';
$labels['aclk'] = 'Binpeldankan biafrîne';
$labels['acld'] = 'Peyaman jê bibe';
$labels['aclt'] = 'Peyaman jê bibe';
$labels['acle'] = 'Pak bike';
$labels['aclx'] = 'Peldankê jê bibe';
$labels['acla'] = 'Rêvebir';
$labels['acln'] = 'Peyaman şîrove bike';
$labels['aclfull'] = 'Kontrola tevahî';
$labels['aclother'] = 'Ên din';
$labels['aclread'] = 'Bixwîne';
$labels['aclwrite'] = 'Binivîse';
$labels['acldelete'] = 'Jê bibe';
$labels['shortacll'] = 'Bigere';
$labels['shortaclr'] = 'Bixwîne';
$labels['shortacls'] = 'Bihêle';
$labels['shortaclw'] = 'Binivîse';
$labels['shortacli'] = 'Têxîne';
$labels['shortaclp'] = 'Bişîne';
$labels['shortaclc'] = 'Biafrîne';
$labels['shortaclk'] = 'Biafrîne';
$labels['shortacld'] = 'Jê bibe';
$labels['shortaclt'] = 'Jê bibe';
$labels['shortacle'] = 'Pak bike';
$labels['shortaclx'] = 'Peldankê jê bibe';
$labels['shortacla'] = 'Rêvebir';
$labels['shortacln'] = 'Şîrove bike';
$labels['shortaclother'] = 'Ên din';
$labels['shortaclread'] = 'Bixwîne';
$labels['shortaclwrite'] = 'Binivîse';
$labels['shortacldelete'] = 'Jê bibe';
$labels['longacll'] = 'Peldank di lîsteyan de xuya ye û dikare bibe endam wê';
$labels['longaclr'] = 'Peldank ji bo xwendinê dikare were vekirin';
$labels['longacls'] = 'Alaya peyamên dîtî dikare were guhertin';
$labels['longaclw'] = 'Al û peyvên sereke yên peyaman dikarin werin guhertin, ji bilî dîtî û hatiye jêbirin.';
$labels['longacli'] = 'Peyam dikarin di peldankê de werin nivîsandin an jî werin jêgiritin';
$labels['longaclp'] = 'Peyam dikarin di vê peldankê de werin şandin';
$labels['longaclc'] = 'Peldank dikarin rasterast di bin vê peldankê de werin afirandin (an jî navê wan were guhertin)';
$labels['longaclk'] = 'Peldank dikarin rasterast di bin vê peldankê de werin afirandin (an jî navê wan were guhertin)';
$labels['longacld'] = 'Ala jêbirina peyaman dikare were guhertin';
$labels['longaclt'] = 'Ala jêbirina peyaman dikare were guhertin';
$labels['longacle'] = 'Peyam dikarin werin pakkirin';
$labels['longaclx'] = 'Peldank dikare were jêbirin an jî navê wê were guhertin';
$labels['longacla'] = 'Mafên gihîştina peldankan dikarin werin guhertin';
$labels['longacln'] = 'Metadatayên parvekirî (Şîrove) dikarin werin guhertin';
$labels['longaclfull'] = 'Kontrola tevahî, tevlî rêveberiya peldankan';
$labels['longaclread'] = 'Peldank dikare ji bo xwendinê were vekirin';
$labels['longaclwrite'] = 'Peyam dikarin bo peldankê werin nîşankirin, nivîsandin an jî jêgiritin';
$labels['longacldelete'] = 'Peyam dikarin werin jêbirin';
$labels['longaclother'] = 'Mafên têketinê yên din';
$labels['ariasummaryacltable'] = 'Lîsteya mafên têketinê';
$labels['arialabelaclactions'] = 'Çalakiyan lîste bike';
$labels['arialabelaclform'] = 'Awaya mafên têketinê';
$messages['deleting'] = 'Mafên têketinê tên jêbirin...';
$messages['saving'] = 'Mafên têketinê tên tomarkirin...';
$messages['updatesuccess'] = 'Mafên têketinê bi serkeftin hatin guhertin';
$messages['deletesuccess'] = 'Mafên têketinê bi serkeftin hatin jêbirin';
$messages['createsuccess'] = 'Mafên têketinê bi serkeftin hatin tevlîkirin';
$messages['updateerror'] = 'Nikare mafên gihîştinê nû bike';
$messages['deleteerror'] = 'Nikare mafên gihîştinê jê bibe';
$messages['createerror'] = 'Nikare mafên gihîştinê tevlî bike';
$messages['deleteconfirm'] = 'Tu bawer î, ku dixwazî mafên têketinê yên bikarhênerên hilbijartî rakî?';
$messages['norights'] = 'Ti maf nehat diyarkirin!';
$messages['nouser'] = 'Ti bikarhêner nehat diyarkirin!';
