<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$messages['errortitle']  = 'Der opstod en fejl!';
$messages['loginfailed']  = 'Det lykkedes ikke at logge på.';
$messages['cookiesdisabled'] = 'Din browser accepterer ikke cookies.';
$messages['sessionerror'] = 'Din session er ugyldig eller udløbet.';
$messages['cookiesmismatch'] = 'Cookie uoverensstemmelse fundet. Venligst tøm din browser\'s cookies.';
$messages['storageerror'] = 'Forbindelse til e-mailserveren fejlede.';
$messages['servererror'] = 'Serverfejl!';
$messages['servererrormsg'] = 'Serverfejl: $msg';
$messages['accountlocked'] = 'For mange mislykkede login-forsøg. Prøv igen senere.';
$messages['connerror'] = 'Forbindelsesfejl (kunne ikke oprette forbindelse til server)!';
$messages['dberror'] = 'Databasefejl!';
$messages['dbconnerror'] = 'Kan ikke forbinde til databasen!';
$messages['windowopenerror'] = 'Pop op-vinduet blev blokeret!';
$messages['requesttimedout'] = 'Forespørgslen tog for lang tid';
$messages['errorreadonly'] = 'Kunne ikke udføre den ønskede handling. Mappen er skrivebeskyttet.';
$messages['errornoperm'] = 'Kunne ikke udføre den ønskede handling. Tilladelse nægtet.';
$messages['erroroverquota'] = 'Kan ikke udføre handlingen. Der er ikke nok ledig diskplads.';
$messages['erroroverquotadelete'] = 'Der er ikke nok ledig diskplads. Brug Shift+Delete til at slette en meddelelse.';
$messages['invalidrequest'] = 'Ugyldig forespørgsel! Ingen data blev gemt.';
$messages['invalidhost'] = 'Ugyldigt servernavn.';
$messages['nomessagesfound'] = 'Ingen beskeder fundet i denne postkasse.';
$messages['loggedout'] = 'Du har afsluttet sessionen. Farvel!';
$messages['mailboxempty'] = 'Postkassen er tom.';
$messages['nomessages'] = 'Ingen beskeder';
$messages['refreshing'] = 'Opdaterer...';
$messages['loading'] = 'Indlæser...';
$messages['uploading'] = 'Uploader fil...';
$messages['attaching'] = 'Vedhæfter fil...';
$messages['uploadingmany'] = 'Uploader filer...';
$messages['loadingdata'] = 'Indlæser data...';
$messages['checkingmail'] = 'Tjekker for nye beskeder...';
$messages['sendingmessage'] = 'Sender besked...';
$messages['messagesent'] = 'Beskeden blev sendt.';
$messages['savingmessage'] = 'Gemmer besked...';
$messages['messagesaved'] = 'Beskeden er gemt i Kladder.';
$messages['successfullysaved'] = 'Gemt.';
$messages['savingresponse'] = 'Gemmer svartekst...';
$messages['deleteresponseconfirm'] = 'Er du sikker på, at du vil slette denne svartekst?';
$messages['nocontactselected'] = 'Du har ikke valgt en kontakt endnu.';
$messages['addedsuccessfully'] = 'Kontakten blev tilføjet adressebogen.';
$messages['contactexists'] = 'En kontakt med samme navn eksisterer allerede.';
$messages['contactnameexists'] = 'En kontakt med samme navn eksisterer allerede.';
$messages['blockedimages'] = 'For at beskytte dit privatliv er billeder fra eksterne internetservere blokeret.';
$messages['blockedresources'] = 'For at beskytte dit privatliv er fjernressourcer blevet blokeret.';
$messages['suspiciousemail'] = 'Denne meddelelse indeholder mistænkelige email adresser, der kan være svigagtige.';
$messages['encryptedmessage'] = 'Beskeden er krypteret og kan ikke vises. Beklager!';
$messages['externalmessagedecryption'] = 'Dette er en krypteret meddelelse og kan dekrypteres med din browser-udvidelse.';
$messages['encryptpubkeysfound'] = 'Følgende offentlige nøgler blev fundet:';
$messages['nocontactsfound'] = 'Ingen kontakter fundet.';
$messages['contactnotfound'] = 'Den ønskede kontakt blev ikke fundet.';
$messages['contactsearchonly'] = 'Du skal bruge et søgefelt for at se kontakter i den valgte adressebog.';
$messages['sendingfailed'] = 'Det lykkedes ikke at sende beskeden.';
$messages['senttooquickly'] = 'Vent venligst $sec sekunder før du sender denne besked.';
$messages['errorsavingsent'] = 'Der opstod en fejl, da den sendte besked blev forsøgt gemt.';
$messages['errorsaving'] = 'Der opstod en fejl mens der blev gemt.';
$messages['errormoving'] = 'Beskeden/beskederne kunne ikke flyttes.';
$messages['errorcopying'] = 'Beskeden/beskederne kunne ikke kopieres.';
$messages['errordeleting'] = 'Beskeden/beskederne kunne ikke slettes.';
$messages['errormarking'] = 'Beskeden/beskederne kunne ikke markeres.';
$messages['alerttitle'] = 'Opmærksomhed';
$messages['confirmationtitle'] = 'Er du sikker...';
$messages['deletecontactconfirm']  = 'Vil du virkelig slette den/de valgte kontakt(er)?';
$messages['deletegroupconfirm']  = 'Vil du virkelig slette den/de valgte gruppe(r)?';
$messages['deletemessagesconfirm'] = 'Vil du virkelig slette den/de valgte besked(er)?';
$messages['deletefolderconfirm']  = 'Vil du virkelig slette denne mappe?';
$messages['movefolderconfirm']  = 'Vil du virkelig flytte mappen?';
$messages['purgefolderconfirm']  = 'Vil du virkelig slette alle beskeder i denne mappe?';
$messages['contactdeleting'] = 'Sletter kontakt(er)...';
$messages['groupdeleting'] = 'Sletter gruppe...';
$messages['folderdeleting'] = 'Sletter mappe...';
$messages['foldermoving'] = 'Flytter mappen...';
$messages['foldersubscribing'] = 'Abonnerer på mappen...';
$messages['folderunsubscribing'] = 'Fjerner abonnement på mappen...';
$messages['formincomplete'] = 'Formularen var ikke fuldstændig udfyldt.';
$messages['noemailwarning'] = 'Indtast venligst en gyldig e-mailadresse.';
$messages['nonamewarning']  = 'Angiv venligst et navn.';
$messages['nopagesizewarning'] = 'Angiv venligst en sidestørrelse.';
$messages['nosenderwarning'] = 'Indtast venligst e-mailadresse for afsender.';
$messages['recipientsadded'] = 'Modtager(e) tilføjet med succes.';
$messages['norecipientwarning'] = 'Indtast venligst mindst én modtager.';
$messages['disclosedreciptitle'] = 'For mange offentlige modtagere';
$messages['nosubjectwarning']  = '\'Emne\'-feltet er tomt. Vil du skrive et emne nu?';
$messages['nosubjecttitle']  = 'Intet emne';
$messages['nobodywarning'] = 'Send denne besked uden tekst?';
$messages['notsentwarning'] = 'Beskeden er ikke sendt, og ændringerne er ikke gemt endnu. Vil du kassere beskeden?';
$messages['restoresavedcomposedata'] = 'En tidligere skreven men usendt besked blev fundet.\n\nEmne: $subject\nGemt: $date\n\nØnsker du at gendanne denne besked?';
$messages['nosearchname'] = 'Indtast venligst et kontaktnavn eller en e-mailadresse.';
$messages['notuploadedwarning'] = 'Ikke alle vedhæftede filer er blevet uploadet endnu. Vent venligst eller afbryd upload.';
$messages['searchsuccessful'] = 'Fandt $nr beskeder.';
$messages['contactsearchsuccessful'] = 'Fandt $nr kontakter.';
$messages['searchnomatch'] = 'Søgningen fandt ingen beskeder.';
$messages['searching'] = 'Søger...';
$messages['checking'] = 'Tjekker...';
$messages['stillsearching'] = 'Søger stadig...';
$messages['nospellerrors'] = 'Ingen stavefejl fundet.';
$messages['folderdeleted'] = 'Mappen blev slettet.';
$messages['foldersubscribed'] = 'Mappe-abonnement oprettet.';
$messages['folderunsubscribed'] = 'Mappe-abonnement opsagt.';
$messages['folderpurged'] = 'Mappen blev tømt.';
$messages['folderexpunged'] = 'Mappen blev komprimeret';
$messages['deletedsuccessfully'] = 'Slettet.';
$messages['converting'] = 'Fjerner formatering...';
$messages['messageopenerror'] = 'Beskeden kunne ikke hentes fra serveren.';
$messages['filelinkerror'] = 'Vedhæftning af filen mislykkedes.';
$messages['fileuploaderror'] = 'Upload mislykkedes.';
$messages['filesizeerror'] = 'Den uploadede fil overskrider den maksimalt tilladte størrelse på $size.';
$messages['msgsizeerror'] = 'Filen kunne ikke vedhæftes. Størrelsen på en meddelelse må ikke overstige $size.';
$messages['copysuccess'] = '$nr kontakter blev kopieret.';
$messages['movesuccess'] = '$nr kontakter blev flyttet.';
$messages['copyerror'] = 'Kunne ikke kopiere nogen kontakter.';
$messages['moveerror'] = 'Kunne ikke flytte nogen kontakter.';
$messages['sourceisreadonly'] = 'Denne adressekilde er kun til læsning.';
$messages['errorsavingcontact'] = 'Kunne ikke gemme kontaktadressen.';
$messages['movingmessage'] = 'Flytter besked(er)...';
$messages['copyingmessage'] = 'Kopierer besked(er)...';
$messages['copyingcontact'] = 'Kopierer kontakt(er)...';
$messages['movingcontact'] = 'Flytter kontakt(er)...';
$messages['deletingmessage'] = 'Sletter besked(er)...';
$messages['markingmessage'] = 'Markerer besked(er)...';
$messages['addingmember'] = 'Føjer kontakt(er) til gruppen...';
$messages['removingmember'] = 'Fjerner kontakt(er) fra gruppen...';
$messages['receiptsent'] = 'Kvittering for læsning blev sendt.';
$messages['errorsendingreceipt'] = 'Kvitteringen kunne ikke sendes.';
$messages['deleteidentityconfirm'] = 'Vil du virkelig slette denne identitet?';
$messages['nodeletelastidentity'] = 'Du kan ikke slette denne identitet, da det er den eneste der er tilbage.';
$messages['forbiddencharacter'] = 'Mappenavnet indeholder et ugyldigt tegn.';
$messages['selectimportfile'] = 'Vælg venligst den fil der skal overføres.';
$messages['addresswriterror'] = 'Der kan ikke skrives i den valgte adressebog.';
$messages['contactaddedtogroup'] = 'Kontakterne blev tilføjet denne gruppe';
$messages['contactremovedfromgroup'] = 'Kontakterne blev fjernet fra denne gruppe';
$messages['nogroupassignmentschanged'] = 'Ingen gruppetildelinger ændret.';
$messages['importwait'] = 'Importerer, vent venligst...';
$messages['importformaterror'] = 'Importering mislykkedes! Den uploadede fil er ikke en gyldig import-datafil.';
$messages['importconfirm'] = '<b>Importerede $inserted kontakter</b>';
$messages['importmessagesuccess'] = 'Importerede $nr beskeder';
$messages['importmessageerror'] = 'Import mislykkedes! Den uploadede fil er ikke en gyldig besked- eller mailbox-fil.';
$messages['opnotpermitted'] = 'Handling ikke tilladt!';
$messages['nofromaddress'] = 'Der mangler en e-mailadresse i den valgte identitet.';
$messages['editorwarning'] = 'Al formatering af teksten kan forsvinde, hvis der skiftes editor. Vil du fortsætte?';
$messages['httpreceivedencrypterror'] = 'Der er opstået en fatal konfigurationsfejl. Kontakt venligst din system-administrator med det samme. <b>Din besked kunne ikke afsendes.</b>';
$messages['smtpconnerror'] = 'SMTP-fejl ($code): Forbindelsen til serveren afbrudt';
$messages['smtpautherror'] = 'SMTP-fejl ($code): Autenticering fejlede';
$messages['smtpfromerror'] = 'SMTP-fejl ($code): Kunne ikke indstille afsender "$from" ($msg)';
$messages['smtptoerror'] = 'SMTP-fejl ($code): Kunne ikke tilføje modtageren "$to" ($msg)';
$messages['smtprecipientserror'] = 'SMTP-fejl: Kan ikke fortolke listen af modtagere.';
$messages['smtpsizeerror'] = 'SMTP fejl: Beskedens størrelse overskrider serverenes grænse ($limit)';
$messages['smtperror'] = 'SMTP-fejl: $msg';
$messages['emailformaterror'] = 'Ugyldig e-mailadresse: $email';
$messages['toomanyrecipients'] = 'For mange modtagere. Reducer antallet af modtagere til $max.';
$messages['maxgroupmembersreached'] = 'Antallet af gruppemedlemmer overstiger det tilladte maksimum på $max.';
$messages['internalerror'] = 'En intern fejl opstod. Prøv venligst igen.';
$messages['contactdelerror'] = 'Kunne ikke slette kontakt(er).';
$messages['contactdeleted'] = 'Kontakt(er) slettet.';
$messages['contactrestoreerror'] = 'Kunne ikke gendanne slettede kontakt(er).';
$messages['contactrestored'] = 'Kontakt(er) gendannet.';
$messages['groupdeleted'] = 'Gruppen blev slettet.';
$messages['grouprenamed'] = 'Gruppen blev omdøbt.';
$messages['groupcreated'] = 'Gruppen blev oprettet.';
$messages['savedsearchdeleted'] = 'Gemt søgning slettet.';
$messages['savedsearchdeleteerror'] = 'Kunne ikke slette gemt søgning.';
$messages['savedsearchcreated'] = 'Gemt søgning oprettet.';
$messages['savedsearchcreateerror'] = 'Kunne ikke oprette gemt søgning.';
$messages['messagedeleted'] = 'Besked(er) blev slettet.';
$messages['messagemoved'] = 'Besked(er) blev flyttet.';
$messages['messagemovedtotrash'] = 'Meddelelser(ne) blev flyttet til skraldespanden.';
$messages['messagecopied'] = 'Besked(er) kopieret.';
$messages['messagemarked'] = 'Besked(er) markeret.';
$messages['autocompletechars'] = 'Du skal indtaste mindst $min tegn for at benytte autoopslag.';
$messages['autocompletemore'] = 'Flere emner fundet. Indtast flere tegn.';
$messages['namecannotbeempty'] = 'Navn må ikke være tomt.';
$messages['nametoolong'] = 'Navnet er for langt.';
$messages['namedotforbidden'] = 'Mappenavnet kan ikke starte med et punktum.';
$messages['folderupdated'] = 'Mappen er opdateret.';
$messages['foldercreated'] = 'Mappen er oprettet.';
$messages['invalidimageformat'] = 'Ikke et gyldigt billedformat.';
$messages['mispellingsfound'] = 'Der er fundet stavefejl i beskeden.';
$messages['parentnotwritable'] = 'Kan ikke oprette/flytte mappe ind i valgt mappe. Ingen adgangsrettigheder.';
$messages['messagetoobig'] = 'Denne del af beskeden er for stor til at blive behandlet.';
$messages['noscriptwarning'] = 'Advarsel: Denne webmailclient kræver Javascript! For at kunne bruge den slå venligst Javascripts til i din browserindstillinger.';
$messages['messageissent'] = 'Beskeden er allerede sendt, men ikke gemt endnu. Vil du gemme den nu?';
$messages['errnotfound'] = 'Filen blev ikke fundet';
$messages['errnotfoundexplain'] = 'Den efterspurgte ressource blev ikke fundet!';
$messages['errfailedrequest'] = 'Efterspørgslen fejlede';
$messages['errauthorizationfailed'] = 'Godkendelse fejlede';
$messages['errunauthorizedexplain'] = 'Kunne ikke verificere, at du har ret til adgang til denne service!';
$messages['errcontactserveradmin'] = 'Kontakt venligst din serveradministrator.';
$messages['clicktoresumesession'] = 'Klik her for at genoptage din tidligere session';
$messages['clicktocompose'] = 'Klik her for at skrive en ny besked';
$messages['siginserted'] = 'Signaturen er indsat med succes.';
$messages['responseinserted'] = 'Svar indsat.';
$messages['noresponsesavailable'] = 'Ingen tilgængelige svar';
$messages['listempty'] = 'Mappen er tom.';
$messages['listusebutton'] = 'Brug knappen Opret til at tilføje en ny post.';
