<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail New Mail Notifier plugin   |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['basic'] = '當有新郵件，顯示瀏覽器通知';
$labels['desktop'] = '當有新郵件，顯示桌面通知';
$labels['sound'] = '當有新郵件，播放音效';
$labels['test'] = '測試';
$labels['title'] = '有新郵件！';
$labels['body'] = '收到一封新郵件';
$labels['testbody'] = '這是測試通知';
$labels['desktopdisabled'] = '您的瀏覽器已停用桌面通知功能';
$labels['desktopunsupported'] = '您的瀏覽器不支援桌面通知功能';
$labels['desktoptimeout'] = '關閉桌面通知';
