<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Managesieve plugin         |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['filters'] = 'ตัวกรองข้อมูล';
$labels['managefilters'] = 'จัดการตัวกรองอีเมลขาเข้า';
$labels['filtername'] = 'ชื่อตัวกรองข้อมูล';
$labels['newfilter'] = 'สร้างตัวกรองข้อมูลใหม่';
$labels['filteradd'] = 'เพิ่มตัวกรองข้อมูล';
$labels['filterdel'] = 'ลบตัวกรองข้อมูล';
$labels['scope'] = 'ขอบเขต';
$labels['moveup'] = 'เลื่อนขึ้น';
$labels['movedown'] = 'เลื่อนลง';
$labels['filterallof'] = 'จับคู่กฎทั้งหมดต่อไปนี้';
$labels['filteranyof'] = 'จับคู่กฎใด ๆ ต่อไปนี้';
$labels['filterany'] = 'ข้อความทั้งหมด';
$labels['filtercontains'] = 'ที่มีคำว่า';
$labels['filternotcontains'] = 'ไม่มีคำว่า';
$labels['filteris'] = 'ที่มีค่าเท่ากับ';
$labels['filterisnot'] = 'ที่มีค่าไม่เท่ากับ';
$labels['filterexists'] = 'ที่มีอยู่';
$labels['filternotexists'] = 'ไม่มีอยู่';
$labels['filtermatches'] = 'ตรงกับนิพจน์';
$labels['filternotmatches'] = 'ไม่ตรงกับนิพจน์';
$labels['addrule'] = 'เพิ่มกฏ';
$labels['delrule'] = 'ลบกฏ';
$labels['messagemoveto'] = 'ย้ายข้อความไปที่';
$labels['messageredirect'] = 'เปลียนเส้นทางข้อความไปที่';
$labels['messagecopyto'] = 'คัดลอกข้อความไปที่';
$labels['messagesendcopy'] = 'ส่งข้อความคัดลอกไปที่';
$labels['messagedelete'] = 'ลบข้อความ';
$labels['messagediscard'] = 'ยกเลิกข้อความ';
$labels['messagesrules'] = 'สำหรับอีเมลขาเข้า:';
$labels['add'] = 'เพิ่ม';
$labels['del'] = 'ลบ';
$labels['sender'] = 'ผู้ส่ง';
$labels['recipient'] = 'ผู้รับ';
$labels['vacationsubject'] = 'หัวเรื่องข้อความ:';
$labels['enable'] = 'เปิดใช้งาน/ปิดใช้งาน';
$labels['flagread'] = 'อ่าน';
$labels['flagdeleted'] = 'ลบแล้ว';
$labels['flagflagged'] = 'ปักธง';
$labels['notifymethodmailto'] = 'อีเมล์';
$labels['notifymethodtel'] = 'โทรศัพท์';
$labels['datetest'] = 'วันที่';
$labels['advancedopts'] = 'ตัวเลือกขั้นสูง';
$labels['body'] = 'เนื้อหา';
$labels['spamtestequals'] = 'ที่มีค่าเท่ากับ';
$labels['spamtestnotequals'] = 'ที่มีค่าไม่เท่ากับ';
$labels['vacation.subject'] = 'หัวจดหมาย';
$labels['vacation.body'] = 'เนื้อหา';
$labels['vacation.keep'] = 'เก็บ';
