<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Mark-As-Junk plugin        |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['buttonjunk'] = '이 메시지를 스팸으로 처리';
$labels['asjunk'] = '스팸 처리';
$labels['markasjunk'] = '스팸으로 표시';
$labels['buttonnotjunk'] = '이 메시지는 정상임';
$labels['asnotjunk'] = '정상 처리';
$labels['markasnotjunk'] = '정상으로 표시';
$labels['notjunk'] = '정상';
$messages['reportedasjunk'] = '스팸 메일로 성공적으로 보고함';
$messages['reportedasnotjunk'] = '정상 메일로 성공적으로 보고함';
