<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Managesieve plugin         |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['filters'] = 'Filtros';
$labels['managefilters'] = 'Gerer filtros de e-mail entrante';
$labels['filtername'] = 'Nomine de filtro';
$labels['newfilter'] = 'Nove filtro';
$labels['filteradd'] = 'Adder filtro';
$labels['filterdel'] = 'Deler filtro';
$labels['rules'] = 'Regulas';
$labels['actions'] = 'Actiones';
$labels['scope'] = 'Ambito';
$labels['moveup'] = 'Displaciar in alto';
$labels['movedown'] = 'Displaciar a basso';
$labels['filterallof'] = 'que satisface tote le sequente regulas';
$labels['filteranyof'] = 'que satisface qualcunque del sequente regulas';
$labels['filterany'] = 'tote le messages';
$labels['filtercontains'] = 'contine';
$labels['filternotcontains'] = 'non contine';
$labels['filteris'] = 'es equal a';
$labels['filterisnot'] = 'non es equal a';
$labels['filterexists'] = 'existe';
$labels['filternotexists'] = 'non existe';
$labels['filtermatches'] = 'corresponde al expression';
$labels['filternotmatches'] = 'non corresponde al expression';
$labels['filterregex'] = 'corresponde al expression regular';
$labels['filternotregex'] = 'non corresponde al expression regular';
$labels['filterunder'] = 'sub';
$labels['filterover'] = 'super';
$labels['mime'] = 'MIME:';
$labels['mimepart'] = 'Parte MIME:';
$labels['mime-message'] = 'message';
$labels['mime-anychild'] = 'qualcunque';
$labels['mime-type'] = 'typo';
$labels['mime-subtype'] = 'subtypo';
$labels['mime-contenttype'] = 'typo-de-contento';
$labels['mime-param'] = 'parametro';
$labels['addrule'] = 'Adder regula';
$labels['delrule'] = 'Deler regula';
$labels['messagemoveto'] = 'Displaciar message a';
$labels['messageredirect'] = 'Rediriger message a';
$labels['messagecopyto'] = 'Copiar message a';
$labels['messagesendcopy'] = 'Inviar copia del message a';
$labels['messagereply'] = 'Responder con message';
$labels['messagedelete'] = 'Deler message';
$labels['messagediscard'] = 'Abandonar con message';
$labels['messagekeep'] = 'Conservar message in cassa de entrata';
$labels['messagesrules'] = 'Pro messages entrante:';
$labels['messagesactions'] = '…exequer le sequente actiones:';
$labels['add'] = 'Adder';
$labels['del'] = 'Deler';
$labels['sender'] = 'Expeditor';
$labels['recipient'] = 'Destinatario';
$labels['vacationaddr'] = 'Mi adresses de e-mail:';
$labels['vacationdays'] = 'Frequentia de invio de messages (in dies):';
$labels['vacationinterval'] = 'Frequentia de invio de messages:';
$labels['vacationreason'] = 'Texto del message (motivo del absentia):';
$labels['vacationfrom'] = 'Adresse del expeditor pro responder:';
$labels['vacationsubject'] = 'Subjecto del message:';
$labels['days'] = 'dies';
$labels['seconds'] = 'secundas';
$labels['rulestop'] = 'Cessar de evalutar regulas';
$labels['enable'] = 'Activar/Disactivar';
$labels['filterset'] = 'Insimul de filtros';
$labels['filtersets'] = 'Insimules de filtros';
$labels['filtersetadd'] = 'Adder un insimul de filtros';
$labels['filtersetdel'] = 'Deler le insimul de filtros';
$labels['filtersetact'] = 'Activar le insimul actual de filtros';
$labels['filtersetdeact'] = 'Disactivar le insimul actual de filtros';
$labels['filterseteditraw'] = 'Modificar insimul de filtros';
$labels['filtersetswitch'] = 'Activar/disactivar le insimul de filtros';
$labels['filterdef'] = 'Definition del filtro';
$labels['filtersetname'] = 'Nomine del insimul de filtros';
$labels['newfilterset'] = 'Nove insimul de filtros';
$labels['active'] = 'active';
$labels['none'] = 'nulle';
$labels['fromset'] = 'del insimul';
$labels['fromfile'] = 'ab file';
$labels['filterdisabled'] = 'Filtro disactivate';
$labels['filterenabled'] = 'Filtro activate';
$labels['countisgreaterthan'] = 'numero es superior a';
$labels['countisgreaterthanequal'] = 'numero es superior o equal a';
$labels['countislessthan'] = 'numero es inferior a';
$labels['countislessthanequal'] = 'numero es inferior o equal a';
$labels['countequals'] = 'numero es equal a';
$labels['countnotequals'] = 'numero non es equal a';
$labels['valueisgreaterthan'] = 'valor es superior a';
$labels['valueisgreaterthanequal'] = 'valor es superior o equal a';
$labels['valueislessthan'] = 'valor es inferior a';
$labels['valueislessthanequal'] = 'valor es inferior o equal a';
$labels['valueequals'] = 'valor es equal a';
$labels['valuenotequals'] = 'valor non es equal a';
$labels['setflags'] = 'Mitter signales al message';
$labels['addflags'] = 'Adder signales al message';
$labels['removeflags'] = 'Remover signales del message';
$labels['flagread'] = 'Legite';
$labels['flagdeleted'] = 'Delite';
$labels['flaganswered'] = 'Respondite';
$labels['flagflagged'] = 'Signalate';
$labels['flagdraft'] = 'Version provisori';
$labels['addheader'] = 'Adder un capite al message';
$labels['deleteheader'] = 'Remover le capite del message';
$labels['headername'] = 'Nomine del capite';
$labels['headervalue'] = 'Valor del capite';
$labels['headerpos'] = 'Position del capite';
$labels['headeratstart'] = 'al initio';
$labels['headeratend'] = 'fin';
$labels['headeroccurrence'] = 'Occurrentia/position del capite';
$labels['headerfromstart'] = 'ab initio';
$labels['headerfromend'] = 'ab fin';
$labels['headerpatterns'] = 'Patronos de valor del capite';
$labels['headermatchtype'] = 'typo de correspondentia:';
$labels['setvariable'] = 'Definir variabile';
$labels['setvarname'] = 'Nomine del variabile:';
$labels['setvarvalue'] = 'Valor del variabile:';
$labels['setvarmodifiers'] = 'Modificatores:';
$labels['varlower'] = 'minusculas';
$labels['varupper'] = 'majusculas';
$labels['varlowerfirst'] = 'prime character es minuscula';
$labels['varupperfirst'] = 'prime character es majuscula';
$labels['varquotewildcard'] = 'mitter characteres special inter virgulettas';
$labels['varlength'] = 'longitude';
$labels['varencodeurl'] = 'codificate con signos de percentage (pro URLs)';
$labels['notify'] = 'Inviar notification';
$labels['notifytarget'] = 'Scopo del notification:';
$labels['notifymessage'] = 'Message del notification (optional):';
$labels['notifyoptions'] = 'Optiones de notification (optional):';
$labels['notifyfrom'] = 'Expeditor del notification (optional):';
$labels['notifyimportance'] = 'Importantia:';
$labels['notifyimportancelow'] = 'basse';
$labels['notifyimportancenormal'] = 'normal';
$labels['notifyimportancehigh'] = 'alte';
$labels['notifymethodmailto'] = 'E-mail';
$labels['notifymethodtel'] = 'Telephono';
$labels['notifymethodsms'] = 'SMS';
$labels['filtercreate'] = 'Crear filtro';
$labels['usedata'] = 'Usar le sequente datos in le filtro:';
$labels['nextstep'] = 'Proxime passo';
$labels['...'] = '…';
$labels['string'] = 'Catena';
$labels['currdate'] = 'Data actual';
$labels['datetest'] = 'Data';
$labels['dateheader'] = 'capite:';
$labels['year'] = 'anno';
$labels['month'] = 'mense';
$labels['day'] = 'die';
$labels['date'] = 'data (aaaa-mm-dd)';
$labels['julian'] = 'data (julian)';
$labels['hour'] = 'hora';
$labels['minute'] = 'minuta';
$labels['second'] = 'secunda';
$labels['time'] = 'hora (hh:mm:ss)';
$labels['iso8601'] = 'data (ISO8601)';
$labels['std11'] = 'data (RFC2822)';
$labels['zone'] = 'fuso horari';
$labels['weekday'] = 'die del septimana (0-6)';
$labels['advancedopts'] = 'Optiones avantiate';
$labels['body'] = 'Texto';
$labels['address'] = 'adresse';
$labels['envelope'] = 'inveloppe';
$labels['modifier'] = 'modificator:';
$labels['text'] = 'texto';
$labels['undecoded'] = 'non decodificate (crude)';
$labels['contenttype'] = 'typo de contento';
$labels['modtype'] = 'typo:';
$labels['allparts'] = 'totes';
$labels['domain'] = 'dominio';
$labels['localpart'] = 'parte local';
$labels['user'] = 'usator';
$labels['detail'] = 'detalio';
$labels['comparator'] = 'comparator:';
$labels['default'] = 'predefinite';
$labels['octet'] = 'stricte (octetto)';
$labels['asciicasemap'] = 'non sensibile al differentia inter majusculas e minusculas (ascii-casemap)';
$labels['asciinumeric'] = 'numeric (ascii-numeric)';
$labels['index'] = 'indice:';
$labels['indexlast'] = 'a retro';
$labels['spamtest'] = 'Nivello de spam';
$labels['spamtestisgreaterthan'] = 'es plus grande de';
$labels['spamtestisgreaterthanequal'] = 'es plus grande de o equal a';
$labels['spamtestislessthan'] = 'es minus de';
$labels['spamtestislessthanequal'] = 'es minus de o equal a';
$labels['spamtestequals'] = 'es equal a';
$labels['spamtestnotequals'] = 'non es equal a';
$labels['spamtestisunknown'] = 'es incognite';
$labels['vacation'] = 'Vacantias';
$labels['vacation.reply'] = 'Message de responsa';
$labels['vacation.advanced'] = 'Configuration avantiate';
$labels['vacation.from'] = 'Adresse del expeditor pro responder';
$labels['vacation.subject'] = 'Subjecto';
$labels['vacation.body'] = 'Texto';
$labels['vacation.start'] = 'Hora de initio';
$labels['vacation.end'] = 'Hora de fin';
$labels['vacation.status'] = 'Stato';
$labels['vacation.on'] = 'Active';
$labels['vacation.off'] = 'Non active';
$labels['vacation.addresses'] = 'Mi adresses de e-mail';
$labels['vacation.interval'] = 'Intervallo de responsa';
$labels['vacation.after'] = 'Mitter le regula de vacantias post';
$labels['vacation.saving'] = 'Salveguardante datos…';
$labels['vacation.action'] = 'Action pro message entrante';
$labels['vacation.keep'] = 'Conservar';
$labels['vacation.discard'] = 'Abandonar';
$labels['vacation.redirect'] = 'Rediriger a';
$labels['vacation.copy'] = 'Inviar copia a';
$labels['forward'] = 'Retransmission';
$labels['forward.redirect'] = 'Rediriger a';
$labels['forward.copy'] = 'Inviar copia a';
$labels['forward.on'] = 'Active';
$labels['forward.off'] = 'Non active';
$labels['forward.status'] = 'Stato:';
$labels['forward.action'] = 'Pro le messages entrante, exequer le sequente action:';
$labels['forward.saving'] = 'Salveguardante datos…';
$labels['filladdresses'] = 'Plenar con tote mi adresses';
$labels['arialabelfiltersetactions'] = 'Actiones de insimul de filtros';
$labels['arialabelfilteractions'] = 'Actiones de filtro';
$labels['arialabelfilterform'] = 'Proprietates de filtro';
$labels['ariasummaryfilterslist'] = 'Lista de filtros';
$labels['ariasummaryfiltersetslist'] = 'Lista de insimules de filtros';
$labels['filterstitle'] = 'Modificar filtros de e-mail entrante';
$labels['vacationtitle'] = 'Modificar regula de absentia';
$labels['forwardtitle'] = 'Modificar le regula de retransmission de message';
$labels['message'] = 'Message';
$labels['duplicate'] = 'es duplicate';
$labels['notduplicate'] = 'non es duplicate';
$labels['duplicate.handle'] = 'pseudonymo:';
$labels['duplicate.header'] = 'capite:';
$labels['duplicate.uniqueid'] = 'identificator:';
$labels['duplicate.seconds'] = 'expiration (secundas):';
$labels['duplicate.last'] = 'relative al ultime execution';
$messages['filterunknownerror'] = 'Error de servitor incognite.';
$messages['filterconnerror'] = 'Impossibile connecter al servitor.';
$messages['filterdeleteerror'] = 'Impossibile deler le filtro. Un error de servitor ha occurrite.';
$messages['filterdeleted'] = 'Le filtro ha essite delite.';
$messages['filtersaved'] = 'Le filtro ha essite salveguardate.';
$messages['filtersaveerror'] = 'Impossibile salveguardar le filtro. Un error de servitor ha occurrite.';
$messages['filterformerror'] = 'Le forma del filtro contine errores.';
$messages['filterdeleteconfirm'] = 'Es tu secur de voler deler le filtro seligite?';
$messages['ruledeleteconfirm'] = 'Es tu secur de voler deler le regula seligite?';
$messages['actiondeleteconfirm'] = 'Es tu secur de voler deler le action seligite?';
$messages['forbiddenchars'] = 'Le campo contine characteres interdicte.';
$messages['cannotbeempty'] = 'Le campo non pote esser vacue.';
$messages['ruleexist'] = 'Un filtro con le nomine specificate jam existe.';
$messages['setactivateerror'] = 'Impossibile activar le insimul de filtros seligite. Un error de servitor ha occurrite.';
$messages['setdeactivateerror'] = 'Impossibile disactivar le insimul de filtros seligite. Un error de servitor ha occurrite.';
$messages['setdeleteerror'] = 'Impossibile deler le insimul de filtros seligite. Un error de servitor ha occurrite.';
$messages['setactivated'] = 'Le insimul de filtros ha essite activate.';
$messages['setdeactivated'] = 'Le insimul de filtros ha essite disactivate.';
$messages['setdeleted'] = 'Le insimul de filtros ha essite delite.';
$messages['setupdated'] = 'Le insimul de filtros ha essite actualisate.';
$messages['setdeleteconfirm'] = 'Es tu secur de voler deler le insimul de filtros seligite?';
$messages['setcreateerror'] = 'Impossibile crear le insimul de filtros. Un error de servitor ha occurrite.';
$messages['setcreated'] = 'Le insimul de filtros ha essite create.';
$messages['activateerror'] = 'Impossibile activar le filtro(s) seligite. Un error de servitor ha occurrite.';
$messages['deactivateerror'] = 'Impossibile disactivar le filtro(s) seligite. Un error de servitor ha occurrite.';
$messages['deactivated'] = 'Le filtro(s) ha essite disactivate.';
$messages['activated'] = 'Le filtro(s) ha essite activate.';
$messages['moved'] = 'Le filtro ha essite displaciate.';
$messages['moveerror'] = 'Impossibile displaciar le filtro seligite. Un error de servitor ha occurrite.';
$messages['nametoolong'] = 'Le nomine es troppo longe.';
$messages['namereserved'] = 'Nomine reservate.';
$messages['setexist'] = 'Le insimul ja existe.';
$messages['nodata'] = 'Al minus un position debe esser seligite.';
$messages['invaliddateformat'] = 'Le formato del data o del parte de data non es valide';
$messages['saveerror'] = 'Impossibile salveguardar le datos. Un error de servitor ha occurrite.';
$messages['vacationsaved'] = 'Le datos del vacantias ha essite salveguardate.';
$messages['forwardsaved'] = 'Le datos de retransmission ha essite salveguardate.';
$messages['emptyvacationbody'] = 'Le texto del message de vacantias es obligatori.';
$messages['duplicate.conflict.err'] = 'Ambe le capite e le identificator unic non es permittite.';
$messages['disabledaction'] = 'Action non permittite.';
$messages['lastindexempty'] = 'Le indice es necessari quando se conta ab le fin';
$messages['noflagset'] = 'Al minus un signal debe esser seligite.';
