<roundcube:include file="includes/layout.html" />

<h1 class="voice"><roundcube:object name="sectionname" /></h1>

<div class="formcontent">
	<roundcube:object name="userprefs" form="form" class="propform cols-sm-6-6" />
</div>

<div class="formbuttons">
	<roundcube:button command="save" class="btn btn-primary submit" label="save" />
</div>

<roundcube:include file="includes/footer.html" />
