<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$messages['errortitle']  = 'Şaşetiyek pêk hat!';
$messages['loginfailed']  = 'Têketin têk çû.';
$messages['cookiesdisabled'] = 'Geroka te mafê nade kiloran';
$messages['sessionerror'] = 'Danişîna te nederbasdar e an jî dema wê qediyaye.';
$messages['cookiesmismatch'] = 'Nelihevhatina kiloran hat dîtin. Ji kerema xwe, kilorên geroka xwe pak bike.';
$messages['storageerror'] = 'Girêdana bo bîrdanka rajekarê têk çû.';
$messages['servererror'] = 'Şaşetiya rajekarê!';
$messages['servererrormsg'] = 'Şaşetiya rajekarê: $msg';
$messages['accountlocked'] = 'Gelek hewldanên têketinê yên têkçûyî. Paşê dîsa hewl bide.';
$messages['connerror'] = 'Şaşetiya dirêdanê (Gihîştina rajekar têk çû)!';
$messages['dberror'] = 'Şaşetiya danegehê!';
$messages['dbconnerror'] = 'Nikare bi danegehê re girêdanê pêk bîne!';
$messages['windowopenerror'] = 'Çarçoveya hilpekok hat astengkirin!';
$messages['requesttimedout'] = 'Dema xwestinê hat derbaskirin';
$messages['errorreadonly'] = 'Ev kar pêk nehat. Peldankê tenê bo xwendinê ye.';
$messages['errornoperm'] = 'Ev kar pêk nehat. Destûr nehat dayîn.';
$messages['erroroverquota'] = 'Ev kara pêk nehat. Di dîskê de cihê vala nîn e.';
$messages['erroroverquotadelete'] = 'Di dîskê de cihê vala nîn e. SHIFT+DELê bi kar bîne da ku peyamekê jê bibî.';
$messages['invalidrequest'] = 'Dawxaza nederbasdar! Tu dane nehat tomarkirin.';
$messages['invalidhost'] = 'Navê pêşkêş ê nederbasdar.';
$messages['nomessagesfound'] = 'Di vê peyamdankê de tu peyam nehat dîtin';
$messages['loggedout'] = 'Te danaşîn bi serkeftî bi dawî kir. Bi xatirê te!';
$messages['mailboxempty'] = 'Peyamdank vala ye';
$messages['nomessages'] = 'Peyam tune ne';
$messages['refreshing'] = 'Tê rojanekirin...';
$messages['loading'] = 'Tê barkirin...';
$messages['uploading'] = 'Pel tê barkirin...';
$messages['attaching'] = 'Pelê tê pêvekirin...';
$messages['uploadingmany'] = 'Pel tên barkirin...';
$messages['loadingdata'] = 'Dane tên barkirin...';
$messages['checkingmail'] = 'Li peyamên nû digere...';
$messages['sendingmessage'] = 'Peyamê tê şandin...';
$messages['messagesent'] = 'Peyam hat şandin';
$messages['savingmessage'] = 'Peyam tê tomarkirin...';
$messages['messagesaved'] = 'Peyam di reşnivîsê de hat tomarkirin';
$messages['successfullysaved'] = 'Bi serkeftî hat tomarkirin.';
$messages['savingresponse'] = 'Nivîsa bersivê tê tomarkirin...';
$messages['deleteresponseconfirm'] = 'Tu bi rastî dixwazî vê nivîsa bersivê jê bibî?';
$messages['nocontactselected'] = 'Te hîn têkîliyeke hilnebijartiye.';
$messages['addedsuccessfully'] = 'Têkilî li navnîşanan hat tevlîkirin';
$messages['contactexists'] = 'Têkîliyek bi heman navnîşana e-nameyê jixwe heye.';
$messages['contactnameexists'] = 'Têkîliyek bi heman nav jixwe heye.';
$messages['blockedimages'] = 'Ji bo parastina taybetiya te, wêneyên ji dûr ve di vê peyamê de hatin astengkirin.';
$messages['blockedresources'] = 'Ji bo parastina taybetiya te, çavkaniyên ji dûr ve di vê peyamê de hatin astengkirin.';
$messages['suspiciousemail'] = 'Ev e-peyam gumanbar e!';
$messages['bccemail'] = 'Navnîşana Bcc nederbasdar e.';
$messages['bouncehint'] = 'Ev kar dê peyamê wekî peyameke vegeriyayî ji nû ve bişîne.';
$messages['encryptedmessage'] = 'Ev peyamenek şîfrekirî ye, bibore, nayê vekirin!';
$messages['externalmessagedecryption'] = 'Şîfrekirina dervayî tê meşandin...';
$messages['nopubkeyfor'] = 'Ji bo $email tu mifteya giştî nehat dîtin.';
$messages['nopubkeyforsender'] = 'Ji bo şanderî tu mifteya giştî nehat dîtin.';
$messages['encryptnoattachments'] = 'Pelên pêvekirî nikarin werin şîfrekirin.';
$messages['searchpubkeyservers'] = 'Li mifteyên giştî yên li ser rajekaran tê gerandin...';
$messages['encryptpubkeysfound'] = 'Mifteyên giştî hatin dîtin û tomarkirin.';
$messages['keyservererror'] = 'Girêdana bi rajekara mifteyan re têk çû.';
$messages['keyimportsuccess'] = 'Mifte bi serkeftî hat hawîrdakirin.';
$messages['nocontactsfound'] = 'Tu têkiliyek nehat dîtin';
$messages['contactnotfound'] = 'Têkiliya dihat xwestin nehat dîtin';
$messages['contactsearchonly'] = 'Ji bo lêgerîna têkiliyan tenê qadên diyarkirî bi kar bîne.';
$messages['sendingfailed'] = 'Peyam nehat şandin';
$messages['senttooquickly'] = 'Ji kerema xwe, bo $ saniyek saniye(yan) bisekine beriya şandina vê peyamê.';
$messages['errorsavingsent'] = 'Dema ku peyama şandî hat tomarkirin çewtiyek pêk hat.';
$messages['errorsaving'] = 'Wextê tomarkirinê çewtiyek çêbû. ';
$messages['errormoving'] = 'Ciyê peyamê nehat guherandin';
$messages['errorcopying'] = 'Peyam(gel) nehat(in) hemankirin. ';
$messages['errordeleting'] = 'Peyam nehat jêbirin';
$messages['errormarking'] = 'Nîşankirina peyamê têk çû.';
$messages['alerttitle'] = 'Hişyarî';
$messages['confirmationtitle'] = 'Tu bawer î?';
$messages['deletecontactconfirm']  = 'Ji dil dixwazî têkiliya/ên nîşankirî jê bibî?';
$messages['deletegroupconfirm']  = 'Tu bi rastî dixwazî vê komê jê bibî?';
$messages['deletemessagesconfirm'] = 'Ji dil dixwazî peya/ên nîşankirî jê bibî?';
$messages['deletefolderconfirm']  = 'Ji dil dixwazî vê peldankê jê bibî?';
$messages['movefolderconfirm']  = 'Tu dixwazî vê peldankê bilivînî?';
$messages['purgefolderconfirm']  = 'Ji dil dixwazî hemû peyamên di vê peldankê de jê bibî?';
$messages['contactdeleting'] = 'Têkîlî(yan) tên jêbirin...';
$messages['groupdeleting'] = 'Kom tê rakirin...';
$messages['folderdeleting'] = 'Peldank tê jêbirin...';
$messages['foldermoving'] = 'Peldank tê livandin...';
$messages['foldersubscribing'] = 'Abonebûna peldankê pêk tê...';
$messages['folderunsubscribing'] = 'Betalkirina aboneyê pêk tê...';
$messages['formincomplete'] = 'Form bi temamî nehat tijekirin';
$messages['noemailwarning'] = 'Tika ye, navnîşaneke rast têkevê';
$messages['nonamewarning']  = 'Tika ye, navekî têkevê';
$messages['nopagesizewarning'] = 'Tika ye, mezinahiyeke pelê têkevê';
$messages['nosenderwarning'] = 'Tika navnîşana enameya şander têxe';
$messages['recipientsadded'] = 'Wergir bi serkeftî hatin tevlîkirin.';
$messages['norecipientwarning'] = 'Tika ye, herî kêm standyarekê têkevê';
$messages['disclosedrecipwarning'] = 'Haydar be! Hemû wergir dê navnîşanên hev bibînin.';
$messages['disclosedreciptitle'] = 'Wergirên eşkere';
$messages['nosubjectwarning']  = 'Qada "Mijar"ê vala ye. Dixwazî niha tiştekî lê binivîsî?';
$messages['nosubjecttitle']  = 'Mijar tune ye';
$messages['nobodywarning'] = 'Peyamê bê nivîs bişeyînî?';
$messages['notsentwarning'] = 'Peyam nehat şandin. Tu dixwazî reşnivîsê biparêzî?';
$messages['restoresavedcomposedata'] = 'Çavkaniya peyama dawî hat dîtin. Tu dixwazî daneyan vegerînî?';
$messages['nosearchname'] = 'Tika ye, naveke têkiliyê yan jî navnîşaneke enameyê têxîne.';
$messages['notuploadedwarning'] = 'Hîn hemû pel nehatine barkirin. Ji kerema xwe bisekine.';
$messages['searchsuccessful'] = '$nr peyam hatin dîtin.';
$messages['contactsearchsuccessful'] = '$nr têkîlî hatin dîtin.';
$messages['searchnomatch'] = 'Di lêgerînê de tu tişt nehat dîtin';
$messages['searching'] = 'Digere...';
$messages['checking'] = 'Tê kontrolkirin...';
$messages['stillsearching'] = 'Hîn lêgerin didome...';
$messages['nospellerrors'] = 'Tu şaşiyeke rastnivîsê nehat dîtin';
$messages['folderdeleted'] = 'Peldank bi serkeftî hat jêbirin.';
$messages['foldersubscribed'] = 'Abonebûn bi serkeftî pêk hat.';
$messages['folderunsubscribed'] = 'Abonebûn bi serkeftî hat betalkirin.';
$messages['folderpurged'] = 'Peldank bi serkeftî hat valakirirn.';
$messages['folderexpunged'] = 'Peldank bi serkeftî hat paqijdirin.';
$messages['deletedsuccessfully'] = 'Bi serkeftî hat jêbirin.';
$messages['converting'] = 'Formatkirin ji peyamê tê birin...';
$messages['messageopenerror'] = 'Peyam ji pêşkêşkar nehat barkirin';
$messages['filelinkerror'] = 'Lînkandina pelê bi ser neket.';
$messages['fileuploaderror'] = 'Barkirina pelê têk çû';
$messages['csvfilemismatch'] = 'Lihevhatina strukturên pelê CSV tune ye.';
$messages['filesizeerror'] = 'Pel pir mezin e. Herî zêde divê $size be';
$messages['filecounterror'] = 'Hejmara pelên hatî barkirin pir zêde ye.';
$messages['msgsizeerror'] = 'Mezinahiya peyamê ji sînorê herî zêde derbas dibe ($size).';
$messages['msgsizeerrorfwd'] = 'Mezinahiya peyama ku tê şandin ji sînorê herî zêde derbas dibe ($size).';
$messages['copysuccess'] = 'Bi serkeftî hat jêgirtin.';
$messages['movesuccess'] = 'Bi serkeftî hat livandin.';
$messages['copyerror'] = 'Têkilî nehatin jêgirtin.';
$messages['moveerror'] = 'Têkilî nehatin livandin.';
$messages['sourceisreadonly'] = 'Çavkaniya vê navnîşanê tenê-xwendin e';
$messages['errorsavingcontact'] = 'Navnîşana têkiliyê nehat barkirin';
$messages['movingmessage'] = 'Ciyê peyamê tê guhertin...';
$messages['copyingmessage'] = 'Peyam templates jêgirtin... ';
$messages['copyingcontact'] = 'Têkilî tên jêgirtin..';
$messages['movingcontact'] = 'Têkilî tên livandin..';
$messages['deletingmessage'] = 'Peyam  tên jêbirin...';
$messages['markingmessage'] = 'Peyam tên nîşankirin..';
$messages['addingmember'] = 'Têkilî bo komê templates tevlîkirin..';
$messages['removingmember'] = 'Têkilî ji komê templates rakirin..';
$messages['receiptsent'] = 'Rapora şandina serkeftî';
$messages['errorsendingreceipt'] = 'Rapor nehat şandin';
$messages['deleteidentityconfirm'] = 'Tu bi rastî dixwazî vê nasnameyê jê bibî?';
$messages['nodeletelastidentity'] = 'Nikarî vê nasnameyê jê bibî. Ew ya dawî ye.';
$messages['forbiddencharacter'] = 'Di navê peldankê de tîpên qedexekirî hene.';
$messages['selectimportfile'] = 'Ji kerema xwe pelê ku dê were hawîrdakirin hilbijêre.';
$messages['addresswriterror'] = 'Pelê navnîşanan tenê ji bo xwendinê ye, nayê guhertin.';
$messages['contactaddedtogroup'] = 'Têkilî bi serkeftî li vê komê hat tevlîkirin.';
$messages['contactremovedfromgroup'] = 'Têkilî bi serkeftî ji vê komê hat rakirin.';
$messages['nogroupassignmentschanged'] = 'Tu guhartin di endamtiya komê de çênenû.';
$messages['importwait'] = 'Hawîrdakirin didome, ji kerema xwe bisekine...';
$messages['importformaterror'] = 'Formata pelê hawîrdakirinê nederbasdar e.';
$messages['importconfirm'] = 'Tu bi rastî dixwazî van daneyan hawîr bikî?';
$messages['importconfirmskipped'] = 'Dûbarekirin hatin dîtin û jê hatin derbaskirin.';
$messages['importconfirminvalid'] = 'Daneyên nederbasdar nehatin girtin.';
$messages['importconfirmerrors'] = 'Di dema hawîrdakirinê de şaşetî çêbûn.';
$messages['importmessagesuccess'] = 'Peyam bi serkeftî hatin hawîrdakirin.';
$messages['importmessageerror'] = 'Hawîrdakirina peyaman bi ser neket.';
$messages['opnotpermitted'] = 'Ev kar nayê qebûlkirin!';
$messages['nofromaddress'] = 'Di nasnameya hilbijartî de navnîşana e-peyamê tune ye.';
$messages['editorwarning'] = 'Guhertina formata edîtorê dibe ku bibe sedema windabûna hinek nivîsan.';
$messages['httpreceivedencrypterror'] = 'Şaşetiyeke şîfrekirinê ya ewlehiyê çêbû.';
$messages['smtpconnerror'] = 'Şaşetiya girêdana SMTP ($code): Girêdan bi rajekar re çênenû.';
$messages['smtpautherror'] = 'Şaşetiya pejirandina SMTP ($code): Têketin bi ser neket.';
$messages['smtpfromerror'] = 'Şaşetiya şanderê SMTP ($code): Navnîşana şander nehat qebûlkirin ($msg).';
$messages['smtptoerror'] = 'Şaşetiya wergirê SMTP ($code): Navnîşana wergir nehat qebûlkirin ($msg).';
$messages['smtprecipientserror'] = 'Şaşetiya SMTP: Nikarî lîsteya wergiran bixwîne.';
$messages['smtputf8error'] = 'Rajekarê SMTP piştgiriya navnîşanên UTF-8 nake.';
$messages['smtpsizeerror'] = 'Mezinahiya peyamê ji sînorê SMTP derbas dibe ($size).';
$messages['smtperror'] = 'Şaşetiya SMTP: $msg';
$messages['emailformaterror'] = 'Navnîşana e-peyamê ya nederbasdar: $email';
$messages['toomanyrecipients'] = 'Gelek wergir hene. Herî zêde her e-peyam dikare bibe xwediyê $max wergiran.';
$messages['maxgroupmembersreached'] = 'Hejmara endamên komê gihîşt sînorê herî zêde ($max).';
$messages['internalerror'] = 'Şaşetiya navxweyî pêk hat. Ji nû ve biceribîne.';
$messages['contactdelerror'] = 'Jêbirina têkiliyan bi ser neket.';
$messages['contactdeleted'] = 'Têkilî bi serkeftî hatin jêbirin.';
$messages['contactrestoreerror'] = 'Vegerandina têkiliyên jêbirî bi ser neket.';
$messages['contactrestored'] = 'Têkilî bi serkeftî hatin vegerandin.';
$messages['groupdeleted'] = 'Kom bi serkeftî hat jêbirin.';
$messages['grouprenamed'] = 'Navê komê bi serkeftî hat guhertin';
$messages['groupcreated'] = 'Kom bi serkeftin hat afirandin.';
$messages['savedsearchdeleted'] = 'Lêgerîna tomarkirî bi serkeftî hat jêbirin.';
$messages['savedsearchdeleteerror'] = 'Jêbirina lêgerîna tomarkirî bi ser neket.';
$messages['savedsearchcreated'] = 'Lêgerîna tomarkirî bi serkeftî hat afirandin.';
$messages['savedsearchcreateerror'] = 'Afirandina lêgerîna tomarkirî bi ser neket.';
$messages['messagedeleted'] = 'Peyam bi serkeftî hatin jêbirin.';
$messages['messagemoved'] = 'Peyam bi serkeftî hatin livandin.';
$messages['messagemovedtotrash'] = 'Peyam bi serkeftî bo jêbiranedakê hatin livandin.';
$messages['messagecopied'] = 'Peyam bi serkeftî hatin jêgirtin.';
$messages['messagemarked'] = 'Peyam bi serkeftî hatin nîşankirin.';
$messages['autocompletechars'] = 'Herî kêm $min tîpan têkeve ji bo temamkirina otomatîk.';
$messages['autocompletemore'] = 'Gelek encamên dîtî hene, ji kerema xwe tîpên din têkeve.';
$messages['namecannotbeempty'] = 'Nav nabe ku vala be.';
$messages['nametoolong'] = 'Nav pir dirêj e.';
$messages['namedotforbidden'] = 'Navî peldankê bi xalekê nayê destpêkkirin.';
$messages['folderupdated'] = 'Peldank bi serkeftî hat rojanekirin.';
$messages['foldercreated'] = 'Peldank bi serkeftî hat afirandin.';
$messages['invalidimageformat'] = 'Formata wêneyê nederbasdar e.';
$messages['mispellingsfound'] = 'Di metnê de çewtiyên rastnivîsê hatin dîtin.';
$messages['parentnotwritable'] = 'Nikarî di bin vê peldankê de tiştekî biafirînî, destûr nîn e.';
$messages['messagetoobig'] = 'Mezinahiya peyamê ji bo barkirinê pir zêde ye.';
$messages['noscriptwarning'] = 'Hişyarî: Ji bo bikaranîna rajekarê vê webmailê, pêdivî bi çalakkirina Javascript heye. Tika ye Javascriptê di sazkariyên gerokê xwe de çalak bike.';
$messages['messageissent'] = 'Peyam jixwe hatibû şandin, lê hîn nehatiye tomarkirin. Dixwazî ​​niha tomar bikî?';
$messages['errnotfound'] = 'Pel nehat dîtin';
$messages['errnotfoundexplain'] = 'Çavkaniya daxwazkirî nehat dîtin';
$messages['errfailedrequest'] = 'Daxwaza têkçûyî';
$messages['errauthorizationfailed'] = 'Rastandin têk çû';
$messages['errunauthorizedexplain'] = 'Nekare piştrast bike ku tu mafê te heye ku bigihêjî vê rajekarê!';
$messages['errrequestcheckfailed'] = 'Kontrolkirina daxwazê têk çû';
$messages['errcsrfprotectionexplain'] = "Ji bo parastina te, gihîştina vê çavkaniyê li dijî CSRFê hatiye parastin.\nKu tu vê yekê bibînî, dibe ku tu berî berdana ji sepana tevnê derneketine.\n\nNiha ji bo domandina têkiliya mirovan pêdivî ye.";
$messages['errcontactserveradmin'] = 'Tika ye bi rêvebirê rajekarê xwe re têkeve têkiliyê.';
$messages['clicktoresumesession'] = 'Ji bo domandina danişîna xwe ya berê li vir bitikîne';
$messages['errcomposesession'] = 'Şaşetiiya danişîna nivîsandinê';
$messages['errcomposesessionexplain'] = 'Danişîna nivîsandinê ya daxwazkirî nehat dîtin.';
$messages['clicktocompose'] = 'Ji bo nivîsandina e-nameyeke nû li vir bitikîne.';
$messages['nosupporterror'] = 'Ev taybetmendî ji aliyê geroka te ya tevnê ve nayê piştgirîkirin.';
$messages['siginserted'] = 'Îmze bi serkeftî hate têxistin.';
$messages['responseinserted'] = 'Bersîv bi serkeftî hate têxistin.';
$messages['noresponsesavailable'] = 'Ti bersiv tine ne';
$messages['listempty'] = 'Lîste vala ye';
$messages['listusebutton'] = 'Ji bo tevlîkirina tomareke nû, bişkoka bifarîne bi kar bîne.';
$messages['keypaircreatesuccess'] = 'Cotek kilîtên nû bi serkeftî ji bo $identity hate afirandin.';
$messages['emptyattachment'] = 'Ev pêvek vala xuya dike. <br>Tika ye bi kesê ku ev şandiye re kontrol bike.';
$messages['oauthloginfailed'] = 'Têketina OAuth têk çû.Tika ye dîsa hewl bide.';
$messages['oauthinvalidrequest'] = 'Daxwaza rastandinê nederbasdar an kêm bû.';
$messages['oauthaccessdenied'] = 'Rajekarê rastandinê yan jî bikarhêner daxwaz nepejirand.';
