<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Enigma plugin              |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['encryption'] = 'Şîfrekirin';
$labels['enigmacerts'] = 'Bawernamyên S/MIME';
$labels['enigmakeys'] = 'Kilîtên PGP';
$labels['keysfromto'] = 'Kilît $ji bo $to ji $count';
$labels['keyname'] = 'Nav';
$labels['keyid'] = 'ID a kilîtê';
$labels['keyuserid'] = 'ID a bikarhêner';
$labels['keytype'] = 'Cûreya kilîtê';
$labels['fingerprint'] = 'Îmzeyê tiliyan';
$labels['subkeys'] = 'Binkilît';
$labels['keyprops'] = 'Taybetmendiyên kilîtê';
$labels['basicinfo'] = 'Zanyariyên bingehîn';
$labels['userids'] = 'Bikarhênerên din';
$labels['typepublickey'] = 'Kilîta giştî';
$labels['typekeypair'] = 'Cota kilîtê';
$labels['typesign'] = 'Têkeve';
$labels['subkeyid'] = 'ID';
$labels['subkeycreated'] = 'Hat afirandin';
$labels['subkeyusage'] = 'Bikaranîn';
$labels['expiresnever'] = 'ti car';
$labels['unknown'] = 'nenas';
$labels['uservalid'] = 'Derbasdar';
$labels['userid'] = 'ID';
$labels['valid'] = 'derbasdar';
$labels['nminutes'] = '$m xulek';
$labels['keyremove'] = 'Rake';
$labels['keychpass'] = 'Şîfreyê biguherîne';
$labels['newkeypass'] = 'Borînpeyv';
$labels['newkeypassconfirm'] = 'Borînpeyvê biperjîne';
$labels['newkeytype'] = 'Cûreya kilîtê';
$messages['nokeysfound'] = 'Ti kilît nehatin dîtin';
$messages['keynotfound'] = 'Kilît nehat dîtin!';
$messages['keyremoving'] = 'Kilît tên jêbirin...';
$messages['keyremoveconfirm'] = 'Tu dixwazî kilîtên hilbijartî jê bibî?';
$messages['nonameident'] = 'Divê ji bo nasnamê navekî bikarhêner hatibe pênasekirin!';
$labels['newkeysize'] = 'Mezinahiya kilîtê';
$labels['key2048'] = '2048 bit - berdest';
$labels['key4096'] = '4096 bît - ewletir';
