<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail MarkdownEditor plugin      |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['editor_icon_alt'] = 'Edîtorê Markdown';
$labels['editor_button_title'] = 'Peyamê bi Markdown binivîse û wekî HTML bişîne';
$labels['toolbar_button_quit'] = 'Vegere edîtorê nivîsê sade';
$labels['toolbar_button_help'] = 'Rêberê hevoksazîya markdownê di çarçoveyeke nû de veke';
$labels['toolbar_button_preview'] = 'HTMLê wekî ku wê were şandin pêşdîtin bike';
$labels['toolbar_button_bold'] = 'Qalind';
$labels['toolbar_button_italic'] = 'Xwar';
$labels['toolbar_button_strike'] = 'Ser xêz bike';
$labels['toolbar_button_h1'] = 'Asta sernavê 1';
$labels['toolbar_button_h2'] = 'Asta sernavê 2';
$labels['toolbar_button_h3'] = 'Asta sernavê 3';
$labels['toolbar_button_h4'] = 'Asta sernavê 4';
$labels['toolbar_button_h5'] = 'Asta sernavê 5';
$labels['toolbar_button_h6'] = 'Asta sernavê 6';
$labels['toolbar_button_blockquote'] = 'Jêwergirtin';
$labels['toolbar_button_unordered_list'] = ' Lîsteya nerêzkirî';
$labels['toolbar_button_ordered_list'] = 'Lîsteya rêzkirî';
$labels['toolbar_button_link'] = 'Girêdan';
$labels['toolbar_button_image'] = 'Wêne';
$labels['toolbar_button_undo'] = 'Vegere';
$labels['toolbar_button_redo'] = 'Dûbare bike';
