<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['welcome'] = 'Esiet laipni lūgti $product';
$labels['username'] = 'Lietotājvārds';
$labels['password'] = 'Parole';
$labels['server'] = 'Serveris';
$labels['login'] = 'Autorizēties';
$labels['oauthlogin'] = 'Autorizēties ar $provider';
$labels['menu'] = 'Izvēlne';
$labels['logout'] = 'Iziet';
$labels['mail'] = 'E-pasts';
$labels['settings'] = 'Iestatījumi';
$labels['addressbook'] = 'Adrešu grāmata';
$labels['darkmode'] = 'Tumšais režīms';
$labels['lightmode'] = 'Gaišais režīms';
$labels['inbox'] = 'Ienākošās';
$labels['drafts'] = 'Uzmetumi';
$labels['sent'] = 'Nosūtītās';
$labels['trash'] = 'Papīrgrozs';
$labels['junk'] = 'Mēstules';
$labels['show_real_foldernames'] = 'Sistēmas mapēm rādīt īstos nosaukumus';
$labels['subject'] = 'Temats';
$labels['from'] = 'No';
$labels['sender'] = 'Sūtītājs';
$labels['to'] = 'Kam';
$labels['cc'] = 'Cc';
$labels['bcc'] = 'Bcc';
$labels['replyto'] = 'Atbildēt-Uz';
$labels['followupto'] = 'Sekot-Uz';
$labels['date'] = 'Datums';
$labels['size'] = 'Izmērs';
$labels['priority'] = 'Prioritāte';
$labels['organization'] = 'Uzņēmums';
$labels['readstatus'] = 'Izlasīšanas statuss';
$labels['listoptions'] = 'Vēstuļu saraksta attēlošanas iestatījumi...';
$labels['listoptionstitle'] = 'Saraksta parametri';
$labels['mailboxlist'] = 'Mapes';
$labels['messagesfromto'] = 'Vēstules $from līdz $to no $count';
$labels['threadsfromto'] = 'Vijumi $from līdz $to no $count';
$labels['messagenrof'] = '$nr. vēstule no $count';
$labels['fromtoshort'] = '$from – $to no $count';
$labels['copy'] = 'Kopēt';
$labels['move'] = 'Pārvietot';
$labels['moveto'] = 'Pārvietot uz...';
$labels['copyto'] = 'Kopēt uz ...';
$labels['download'] = 'lejupielādēt';
$labels['open'] = 'Atvērt';
$labels['showattachment'] = 'Rādīt';
$labels['showanyway'] = 'Vienalga rādīt';
$labels['filename'] = 'Faila nosaukums';
$labels['filesize'] = 'Faila izmērs';
$labels['addtoaddressbook'] = 'Pievienot adrešu grāmatai';
$labels['sun'] = 'Sv';
$labels['mon'] = 'P';
$labels['tue'] = 'O';
$labels['wed'] = 'T';
$labels['thu'] = 'C';
$labels['fri'] = 'P';
$labels['sat'] = 'Se';
$labels['sunday'] = 'Svētdiena';
$labels['monday'] = 'Pirmdiena';
$labels['tuesday'] = 'Otrdiena';
$labels['wednesday'] = 'Trešdiena';
$labels['thursday'] = 'Ceturtdiena';
$labels['friday'] = 'Piektdiena';
$labels['saturday'] = 'Sestdiena';
$labels['jan'] = 'Jan';
$labels['feb'] = 'Feb';
$labels['mar'] = 'Mar';
$labels['apr'] = 'Apr';
$labels['may'] = 'Maijs';
$labels['jun'] = 'Jūn';
$labels['jul'] = 'Jūl';
$labels['aug'] = 'Aug';
$labels['sep'] = 'Sep';
$labels['oct'] = 'Okt';
$labels['nov'] = 'Nov';
$labels['dec'] = 'Dec';
$labels['longjan'] = 'Janvāris';
$labels['longfeb'] = 'Februāris';
$labels['longmar'] = 'Marts';
$labels['longapr'] = 'Aprīlis';
$labels['longmay'] = 'Maijs';
$labels['longjun'] = 'Jūnijs';
$labels['longjul'] = 'Jūlijs';
$labels['longaug'] = 'Augusts';
$labels['longsep'] = 'Septembris';
$labels['longoct'] = 'Oktobris';
$labels['longnov'] = 'Novembris';
$labels['longdec'] = 'Decembris';
$labels['today'] = 'Šodien';
$labels['refresh'] = 'Atjaunot';
$labels['checkmail'] = 'Pārbaudīt e-pastu';
$labels['compose'] = 'Rakstīt vēstuli';
$labels['writenewmessage'] = 'Rakstīt jaunu vēstuli';
$labels['reply'] = 'Atbildēt';
$labels['replytomessage'] = 'Atbildēt sūtītājam';
$labels['replytoallmessage'] = 'Atbildēt sūtītājam vai listei un visiem adresātiem';
$labels['replyall'] = 'Atbildēt visiem';
$labels['replylist'] = 'Atbildēt listei';
$labels['forward'] = 'Pārsūtīt';
$labels['forwardinline'] = 'Pārsūtīt iekļaujot vēstulē';
$labels['forwardattachment'] = 'Pārsūtīt kā pielikumu';
$labels['forwardmessage'] = 'Pārsūtīt vēstuli';
$labels['bouncemsg'] = 'Sūtīt atkārtoti (bounce)';
$labels['bounce'] = 'Sūtīt atkārtoti';
$labels['deletemessage'] = 'Dzēst vēstuli';
$labels['undeletemessage'] = 'Atjaunot vēstuli';
$labels['movemessagetotrash'] = 'Pārvietot vēstuli uz papīrgrozu';
$labels['printmessage'] = 'Izdrukāt šo vēstuli';
$labels['previousmessage'] = 'Parādīt iepriekšējo vēstuli';
$labels['firstmessage'] = 'Parādīt pirmo vēstuli';
$labels['nextmessage'] = 'Parādīt nākamo vēstuli';
$labels['lastmessage'] = 'Parādīt pēdējo vēstuli';
$labels['backtolist'] = 'Atpakaļ uz vēstuļu sarakstu';
$labels['viewsource'] = 'Parādīt pirmtekstu';
$labels['mark'] = 'Atzīmēt';
$labels['markmessages'] = 'Atzīmēt vēstules:';
$labels['markread'] = 'kā lasītas';
$labels['markunread'] = 'kā nelasītas';
$labels['markflagged'] = 'kā atzīmētas';
$labels['markunflagged'] = 'kā neatzīmētas';
$labels['markundeleted'] = 'Tā kā nav izdzēstas';
$labels['markasread'] = 'Atzīmēt kā lasītu';
$labels['markasunread'] = 'Atzīmēt kā nelasītu';
$labels['markasflagged'] = 'Atzīmēt kā marķētu';
$labels['markasunflagged'] = 'Atzīmēt kā nemarķētu';
$labels['moreactions'] = 'Papildus darbības...';
$labels['markallread'] = 'Atzīmēt visus kā izlasītus';
$labels['folders-cur'] = 'Tikai atzīmēto mapi';
$labels['folders-sub'] = 'Atzīmēt mapi un tās apakšmapes';
$labels['folders-all'] = 'Visas mapes';
$labels['more'] = 'Vairāk';
$labels['back'] = 'Atpakaļ';
$labels['options'] = 'Opcijas';
$labels['composeoptions'] = 'Rakstīšanas iestatījumi';
$labels['optionsandattachments'] = 'Opcijas un pielikumi';
$labels['actions'] = 'Darbību saraksts';
$labels['first'] = 'Pirmā';
$labels['last'] = 'Pēdējā';
$labels['previous'] = 'Iepriekšējā';
$labels['next'] = 'Nākošā';
$labels['select'] = 'Atzīmēt';
$labels['selection'] = 'Atlase';
$labels['all'] = 'Visas';
$labels['none'] = 'Nevienu';
$labels['currpage'] = 'Pašreizējā lapa';
$labels['isread'] = 'Lasīt';
$labels['unread'] = 'Nelasītās';
$labels['flagged'] = 'Atzīmētās';
$labels['unflagged'] = 'Nav atzīmēta';
$labels['unanswered'] = 'Neatbildētās';
$labels['withattachment'] = 'Ar pielikumu';
$labels['deleted'] = 'Dzēstās';
$labels['undeleted'] = 'Nav izdzēstas';
$labels['replied'] = 'Atbildēta';
$labels['forwarded'] = 'Pārsūtīta';
$labels['invert'] = 'Pretēji';
$labels['filter'] = 'Filtrēt';
$labels['list'] = 'Rādīt kā sarakstu';
$labels['threads'] = 'Rādīt kā vijumus';
$labels['expand-all'] = 'Izvērst visus';
$labels['expand-unread'] = 'Izvērst neizlasītās';
$labels['collapse-all'] = 'Sakļaut visas';
$labels['threaded'] = 'Rādīt vijumus';
$labels['showunread'] = 'Parādīt neizlasītās vēstules';
$labels['autoexpand_threads'] = 'Izvērst vēstuļu vijumus';
$labels['do_expand'] = 'visus vijumus';
$labels['expand_only_unread'] = 'tikai ar neizlasītām vēstulēm';
$labels['fromto'] = 'No/Kam';
$labels['flag'] = 'Atzīmēt';
$labels['attachment'] = 'Pielikums';
$labels['nonesort'] = 'Neviena';
$labels['sentdate'] = 'Nosūtīšanas datums';
$labels['arrival'] = 'Pienākšanas datums';
$labels['asc'] = 'augoša';
$labels['desc'] = 'dilstoša';
$labels['listcolumns'] = 'Saraksta kolonnas';
$labels['listsorting'] = 'Kārtošanas kolonnas';
$labels['listorder'] = 'Kārtošanas secība';
$labels['listmode'] = 'Attēlošanas veids';
$labels['lmode'] = 'Attēlošanas veids';
$labels['layout'] = 'Izklājums';
$labels['layoutwidescreen'] = 'Platekrāns';
$labels['layoutdesktop'] = 'Darba virsma';
$labels['layoutlist'] = 'Saraksts';
$labels['layoutwidescreendesc'] = 'Platekrāna (3 kolonnu skats)';
$labels['layoutdesktopdesc'] = 'Datorskats (plats skats ar e-pasta priekšskatījumu apakšā)';
$labels['layoutlistdesc'] = 'Saraksts (bez e-pasta prieksškatīšanas)';
$labels['folderactions'] = 'Darbības ar mapēm...';
$labels['compact'] = 'Saspiest';
$labels['empty'] = 'Iztukšot';
$labels['importmessages'] = 'Importēt vēstules';
$labels['mailimportdesc'] = 'Jūs varat augšupielādēt e-pastu izmantojot <a href="https://en.wikipedia.org/wiki/Email#Message_format">MIME</a> vai <a href="https://en.wikipedia.org/wiki/Mbox">Mbox</a> formāta failus.';
$labels['mailimportzip'] = 'Vairāki faili var tikt sakompresēti zip arhīvos.';
$labels['quota'] = 'Kvota';
$labels['unknown'] = 'nezināms';
$labels['unlimited'] = 'neierobežots';
$labels['quotatype'] = 'Kvotas tips';
$labels['quotatotal'] = 'Limits';
$labels['quotaused'] = 'Izlietots';
$labels['quotastorage'] = 'Kvota';
$labels['quotamessage'] = 'Vēstuļu skaits';
$labels['shortheaderdate'] = 'Datums $date';
$labels['shortheaderto'] = 'Adresāts $to datumā $date';
$labels['shortheaderfrom'] = 'No $from datumā $date';
$labels['quicksearch'] = 'Ārtā meklēšana';
$labels['searchplaceholder'] = 'Meklēt...';
$labels['resetsearch'] = 'Atstatīt meklēšanu';
$labels['searchmod'] = 'Meklēšanas modifikatori:';
$labels['msgtext'] = 'Visā vēstulē';
$labels['body'] = 'Pamatteksts';
$labels['type'] = 'Tips';
$labels['namex'] = 'Vārds';
$labels['searchscope'] = 'Kur meklēt';
$labels['currentfolder'] = 'Pašreizējā mape';
$labels['subfolders'] = 'Šī un apakšmapes';
$labels['allfolders'] = 'Visas mapes';
$labels['searchinterval-1W'] = 'vecākas par nedēļu';
$labels['searchinterval-1M'] = 'vecākas par mēnesi';
$labels['searchinterval-1Y'] = 'vecākas par gadu';
$labels['searchinterval1W'] = 'nedēļu vecas';
$labels['searchinterval1M'] = 'mēnesi vecas';
$labels['searchinterval1Y'] = 'gadu vecas';
$labels['infolder'] = 'Mape: $folder';
$labels['currentaddressbook'] = 'Adrešu grāmata';
$labels['alladdressbooks'] = 'Visas adrešu grāmatas';
$labels['openinextwin'] = 'Atvērt jaunā logā';
$labels['emlsave'] = 'lejupielādēt (.eml)';
$labels['changeformattext'] = 'Rādīt kā neformatētu tekstu';
$labels['changeformathtml'] = 'Rādīt kā HTML formatētu';
$labels['editasnew'] = 'Rediģēt kā jaunu';
$labels['send'] = 'Sūtīt';
$labels['sendmessage'] = 'Sūtīt vēstuli';
$labels['savemessage'] = 'Saglabāt kā uzmetumu';
$labels['addattachment'] = 'Pievienot failu';
$labels['charset'] = 'Rakstzīmju kopa';
$labels['editortype'] = 'Redaktora tips';
$labels['returnreceipt'] = 'Saņemšanas apstiprinājums';
$labels['dsn'] = 'Piegādes atskaite';
$labels['keepformatting'] = 'Saglabāt formatēšanu';
$labels['mailreplyintro'] = '$sender @ $date rakstīja:';
$labels['originalmessage'] = 'Sākotnējā vēstule';
$labels['selectimage'] = 'Atzīmēt attēlu';
$labels['addimage'] = 'Pievienot attēlu';
$labels['selectmedia'] = 'Atzīmēt video';
$labels['addmedia'] = 'Pievienot video';
$labels['encrypt'] = 'Šifrēt';
$labels['encryptmessage'] = 'Šifrēt vēstuli';
$labels['encryptmessagemailvelope'] = 'Šifrēt vēstuli ar "Mailenvelope"';
$labels['importpubkeys'] = 'Importēt publiskās atslēgas';
$labels['encryptedsendialog'] = 'Sūta šifrēto vēstuli';
$labels['encryptandsign'] = 'Šifrēt un parakstīt';
$labels['keyid'] = 'Atslēgas ID';
$labels['keylength'] = 'Biti';
$labels['keyexpired'] = 'Beidzies termiņš';
$labels['keyrevoked'] = 'Atsaukta';
$labels['bccinstead'] = 'Lietot Bcc';
$labels['addheader'] = 'Pievienot lauku (Cc, Bcc, ...)';
$labels['insert'] = 'Ievietot';
$labels['insertcontact'] = 'Pievienot kontaktu(s)';
$labels['recipient'] = 'Saņēmējs';
$labels['recipientedit'] = 'Rediģēt saņēmēju';
$labels['editidents'] = 'Rediģēt identitātes';
$labels['spellcheck'] = 'Izrunāt';
$labels['checkspelling'] = 'Pārbaudīt pareizrakstību';
$labels['resumeediting'] = 'Turpināt rediģēšanu';
$labels['revertto'] = 'Atgriezt uz';
$labels['restore'] = 'Atjaunot';
$labels['restoremessage'] = 'Atjaunot vēstuli?';
$labels['ignore'] = 'Ignorēt';
$labels['responses'] = 'Atbildes';
$labels['insertresponse'] = 'Ievietot atbildi';
$labels['manageresponses'] = 'Pārvaldīt atbildes';
$labels['newresponse'] = 'Izveidot jaunu atbildi';
$labels['addresponse'] = 'Pievienot atbildi';
$labels['editresponse'] = 'Rediģēt atbildi';
$labels['editresponses'] = 'Rediģēt atbildes';
$labels['responsename'] = 'Vārds';
$labels['responsetext'] = 'Atbildes teksts';
$labels['attach'] = 'Pievienot';
$labels['attachments'] = 'Pielikumi';
$labels['upload'] = 'Augšupielādēt';
$labels['uploadprogress'] = '$percent ($current no $total)';
$labels['close'] = 'Aizvērt';
$labels['messageoptions'] = 'Vēstuļu iestatījumi...';
$labels['togglecomposeoptions'] = 'Parādīt rakstīšanas iestatījumus';
$labels['attachmentrename'] = 'Pārsaukt pielikumu';
$labels['low'] = 'Zema';
$labels['lowest'] = 'Zemākā';
$labels['normal'] = 'Normāla';
$labels['high'] = 'Augsta';
$labels['highest'] = 'Augstākā';
$labels['nosubject'] = '(bez tēmas)';
$labels['showimages'] = 'Rādīt attēlus';
$labels['allow'] = 'Atļaut';
$labels['alwaysshow'] = 'Vienmēr rādīt attēlus vēstulēs, kuras sūtījis $sender';
$labels['alwaysallow'] = 'Vienmēr atļaut no sūtītāja $sender';
$labels['isdraft'] = 'Šis ir melnraksts.';
$labels['andnmore'] = '$nr vairāk...';
$labels['details'] = 'Detaļas';
$labels['summary'] = 'Kopsavilkums';
$labels['headers'] = 'Galvene';
$labels['allheaders'] = 'Visas galvenes';
$labels['togglemoreheaders'] = 'Rādīt galvenes papildus informāciju';
$labels['togglefullheaders'] = 'Slēpt galvenes papildus informāciju';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'Vienkāršs teksts';
$labels['savesentmessagein'] = 'Saglabāt nosūtīto vēstuli mapē';
$labels['dontsave'] = 'nesaglabāt';
$labels['maxuploadsize'] = 'Maksimālais atļautais faila izmērs ir $size';
$labels['addcc'] = 'Pievienot Cc';
$labels['addbcc'] = 'Pievienot Bcc';
$labels['addreplyto'] = 'Pievienot Atbildēt-Uz';
$labels['addfollowupto'] = 'Pievienot Followup-To';
$labels['sendreceipt'] = 'Vai nosūtīt izlasīšanas paziņojumu?';
$labels['mdnrequest'] = 'Šīs vēstules sūtītājs vēlas redzēt vēstules saņemšanas apstiprinājumu. Vai Jūs vēlaties nosūtīt šo apstiprinājumu?';
$labels['receiptread'] = 'Saņemšanas apstiprinājums';
$labels['yourmessage'] = 'Šis ir Jūsu nosūtītās vēstules saņemšanas apstiprinājums';
$labels['receiptnote'] = 'Piezīme: Šis apsiprinājums nozīmē tikai to, ka vēstule tika parādīta uz saņēmāja datora. Tas nenozīmē, ka saņēmējs ir izlasījis vai sapratis vēstules saturu.';
$labels['sendalwaysto'] = 'Vienmēr sūtīt uz $email';
$labels['zoomin'] = 'Pietuvināt';
$labels['zoomout'] = 'Attālināt';
$labels['rotate'] = 'Pagriezt';
$labels['increaseimage'] = 'Palielināt attēla izmēru';
$labels['decreaseimage'] = 'Samazināt attēla izmēru';
$labels['rotateimage'] = 'Pagriezt attēlu';
$labels['showtools'] = 'Rādīt attēla rīkus';
$labels['hidetools'] = 'Paslēpt attēla rīkus';
$labels['name'] = 'Uzrādītais vārds';
$labels['firstname'] = 'Vārds';
$labels['surname'] = 'Uzvārds';
$labels['middlename'] = 'Otrais vārds';
$labels['nameprefix'] = 'Prefikss';
$labels['namesuffix'] = 'Sufikss';
$labels['nickname'] = 'Segvārds';
$labels['jobtitle'] = 'Amats';
$labels['department'] = 'Nodaļa';
$labels['gender'] = 'Dzimums';
$labels['maidenname'] = 'Pirmslaulības uzvārds';
$labels['email'] = 'E-pasts';
$labels['phone'] = 'Tālrunis';
$labels['address'] = 'Adrese';
$labels['street'] = 'Iela';
$labels['locality'] = 'Pilsēta';
$labels['zipcode'] = 'Pasta indekss';
$labels['region'] = 'Novads';
$labels['country'] = 'Pilsēta';
$labels['birthday'] = 'Dzimšanas diena';
$labels['anniversary'] = 'Gadadiena';
$labels['website'] = 'Mājaslapa';
$labels['instantmessenger'] = 'IM';
$labels['notes'] = 'Piezīmes';
$labels['male'] = 'vīrietis';
$labels['female'] = 'sieviete';
$labels['nonbinary'] = 'nebinārs';
$labels['othergender'] = 'cits';
$labels['manager'] = 'Menedžeris';
$labels['assistant'] = 'Asistents';
$labels['spouse'] = 'Laulātais';
$labels['allfields'] = 'Visi lauki';
$labels['search'] = 'Meklēt';
$labels['searchresult'] = 'Meklēšanas rezultāts';
$labels['advsearch'] = 'Paplašinātā meklēšana';
$labels['advanced'] = 'Paplašinātie iestatījumi';
$labels['other'] = 'Cits';
$labels['printcontact'] = 'Drukāt kontaktu';
$labels['qrcode'] = 'QR kods';
$labels['typehome'] = 'Mājas';
$labels['typework'] = 'Darbs';
$labels['typeother'] = 'Cits';
$labels['typemobile'] = 'Mobilais tālrunis';
$labels['typemain'] = 'Galvenais';
$labels['typehomefax'] = 'Fakss mājās';
$labels['typeworkfax'] = 'Fakss darbā';
$labels['typecar'] = 'Auto';
$labels['typepager'] = 'Peidžeris';
$labels['typevideo'] = 'Video';
$labels['typeassistant'] = 'Asistents';
$labels['typehomepage'] = 'Mājaslapa';
$labels['typeblog'] = 'Blogs';
$labels['typeprofile'] = 'Profils';
$labels['addfield'] = 'Pievienot lauku...';
$labels['addcontact'] = 'Pievienot kontaktu';
$labels['editcontact'] = 'Rediģēt kontaktu';
$labels['contacts'] = 'Kontakti';
$labels['contactproperties'] = 'Kontakta īpašības';
$labels['contactnameandorg'] = 'Vārds un organizācija';
$labels['personalinfo'] = 'Personīgā informācija';
$labels['personal'] = 'Personīgās';
$labels['contactphoto'] = 'Kontakta attēls';
$labels['edit'] = 'Rediģēt';
$labels['cancel'] = 'Atcelt';
$labels['save'] = 'Saglabāt';
$labels['delete'] = 'Dzēst';
$labels['discard'] = 'Nesaglabāt';
$labels['continue'] = 'Turpināt';
$labels['ok'] = 'LABI';
$labels['rename'] = 'Pārdēvēt';
$labels['addphoto'] = 'Pievienot';
$labels['replacephoto'] = 'Aizvietot';
$labels['uploadphoto'] = 'Augšupielādēt fotogrāfiju';
$labels['choosefile'] = 'Norādīt failu...';
$labels['choosefiles'] = 'Norādīt failus...';
$labels['browse'] = 'Pārlūkot';
$labels['newcontact'] = 'Izveidot jaunu kontaktu';
$labels['deletecontact'] = 'Dzēst atzīmētos kontaktus';
$labels['composeto'] = 'Rakstīt vēstuli';
$labels['contactsfromto'] = 'Ieraksti no $from līdz $to - kopā $count';
$labels['print'] = 'Drukāt';
$labels['export'] = 'Eksportēt';
$labels['exportall'] = 'Eksportēt visu';
$labels['exportsel'] = 'Eksportēt atzīmēto';
$labels['exportvcards'] = 'Eksportēt kontaktus vCard formātā';
$labels['newgroup'] = 'Izveidot jaunu grupu';
$labels['addgroup'] = 'Pievienot grupu';
$labels['grouprename'] = 'Pārdēvēt grupu';
$labels['groupdelete'] = 'Izdzēst grupu';
$labels['groupassign'] = 'Pievienot grupai...';
$labels['groupremove'] = 'Dzēst no grupas...';
$labels['groupremoveselected'] = 'Dzēst atzīmētos kontaktus no grupas';
$labels['uponelevel'] = 'Vienu līmeni uz augšu';
$labels['previouspage'] = 'Parādīt iepriekšējo lapu';
$labels['firstpage'] = 'Parādīt pirmo lapu';
$labels['nextpage'] = 'Parādīt nākamo lapu';
$labels['lastpage'] = 'Parādīt pēdējo lapu';
$labels['group'] = 'Grupa';
$labels['groups'] = 'Grupas';
$labels['listgroup'] = 'Rādīt grupas kontaktus';
$labels['personaladrbook'] = 'Personīgās adreses';
$labels['searchsave'] = 'Saglabāt meklēšanas pieprasījumu';
$labels['searchdelete'] = 'Dzēst saglabāto meklēšanas pieprasījumu';
$labels['import'] = 'Importēt';
$labels['importcontacts'] = 'Importēt kontaktus';
$labels['importfromfile'] = 'Importēt no faila';
$labels['importtarget'] = 'Kontaktus pievienot';
$labels['importreplace'] = 'Aizvietot visu adrešu grāmatu';
$labels['importgroups'] = 'Importēt grupu piesaistes';
$labels['importgroupsall'] = 'Visus (ja nepieciešams, izveidojiet grupas)';
$labels['importgroupsexisting'] = 'Tikai esošām grupām';
$labels['importdesc'] = 'Jūs varat augšupielādēt kontaktus no jau esošas adrešu grāmatas.<br/>Tiek atbalstīta adrešu importēšana no <a href="https://en.wikipedia.org/wiki/VCard">vCard</a> or CSV (ar komatu-dalīta) datu formāta.';
$labels['importmapdesc'] = 'Pirms turpināt CSV (komatiem atdalītu) datu importēšanu, pārliecinieties, ka zemāk esošā lauku kartēšanas informācija ir pareiza.';
$labels['fieldnotmapped'] = 'Lauks nav kartēts (neimportēt)';
$labels['skipheader'] = 'Neimportēt pirmo rindu (galvenes)';
$labels['done'] = 'Pabeigts';
$labels['birth_day'] = 'Dzimšanas diena';
$labels['birth_month'] = 'Dzimšanas mēnesis';
$labels['birth_year'] = 'Dzimšanas gads';
$labels['settingsfor'] = 'Iestatījumi';
$labels['about'] = 'Par';
$labels['preferences'] = 'Iestatījumi';
$labels['userpreferences'] = 'Lietotāja iestatījumi';
$labels['editpreferences'] = 'Rediģēt iestatījumus';
$labels['identities'] = 'Identitātes';
$labels['manageidentities'] = 'Rediģēt identitātes';
$labels['newidentity'] = 'Izveidot jaunu identitāti';
$labels['addidentity'] = 'Pievienot identitāti';
$labels['editidentity'] = 'Rediģēt identitāti';
$labels['identityencryption'] = 'Šifrēšana';
$labels['preferhtml'] = 'Rādīt HTML formatētās vēstules';
$labels['defaultcharset'] = 'Noklusētā rakstzīmju kopa';
$labels['htmlmessage'] = 'HTML formatēta vēstule';
$labels['messagepart'] = 'Daļa';
$labels['digitalsig'] = 'Digitālais paraksts';
$labels['dateformat'] = 'Datuma formāts';
$labels['timeformat'] = 'Laika formāts';
$labels['prettydate'] = 'Rādīt īsos datumus';
$labels['setdefault'] = 'Uzlikt kā noklusēto';
$labels['autodetect'] = 'Automātiska';
$labels['language'] = 'Valoda';
$labels['timezone'] = 'Laika zona';
$labels['pagesize'] = 'Rindas lapā';
$labels['signature'] = 'Paraksts';
$labels['dstactive'] = 'Vasaras/ziemas laiks';
$labels['showinextwin'] = 'Vēstules atvērt jaunā logā';
$labels['composeextwin'] = 'Vēstuli rakstīt jaunā logā';
$labels['htmleditor'] = 'Rakstīt HTML formatētas vēstules';
$labels['htmlonreply'] = 'tikai atbildot uz HTML formatētām vēstulēm';
$labels['htmlonreplyandforward'] = 'tikai pārsūtot vai atbildot uz HTML formatētu vēstuli';
$labels['htmlsignature'] = 'HTML formatēts paraksts';
$labels['showemail'] = 'Pie vārda rādīt arī e-pasta adresi';
$labels['previewpane'] = 'Rādīt priekšskatījuma paneli';
$labels['skin'] = 'Saskarnes izskats';
$labels['logoutclear'] = 'Izejot no e-pasta, iztīrīt papīrgrozu';
$labels['logoutcompact'] = 'Izejot no e-pasta, saspiest iesūtni';
$labels['uisettings'] = 'Lietotāja saskarne';
$labels['serversettings'] = 'Servera iestatījumi';
$labels['mailboxview'] = 'Pastkastes skats';
$labels['mdnrequests'] = 'Vēstules izlasīšanas atskaites sūtīšana';
$labels['askuser'] = 'jautāt man vai sūtīt';
$labels['autosend'] = 'sūtīt automātiski';
$labels['autosendknown'] = 'automātiski sūtīt ja pieprasītājs ir manos kontaktos, par citiem jautāt';
$labels['autosendknownignore'] = 'automātiski sūtīt ja pieprasītājs ir manos kontaktos, citiem ignorēt un nesūtīt';
$labels['autosendtrusted'] = 'sūtīt saņemšanas apstiprinājumu uzticamiem sūtītājiem, pretējā gadījumā jautāt man';
$labels['autosendtrustedignore'] = 'sūtīt saņemšanas apstiprinājumu uzticamajiem sūtītājiem, pretējā gadījumā ignorēt';
$labels['ignorerequest'] = 'ignorēt pieprasījumu';
$labels['readwhendeleted'] = 'Dzēšot vēstules tās atzīmēt kā izlasītas';
$labels['flagfordeletion'] = 'Dzēšot vēstules tās nedzēst, bet marķēt kā dzēšamas';
$labels['skipdeleted'] = 'Nerādīt dzēstās vēstules';
$labels['deletealways'] = 'Izdzēst vēstules, ja tās neizdodas pārvietot uz papīrgrozu';
$labels['deletejunk'] = 'Automātiski dzēst vēstules no mēstuļu mapītes';
$labels['showremoteimages'] = 'Rādīt vēstulēs attēlus, kuri atrodas uz cita servera';
$labels['allowremoteresources'] = 'Atļaut ārējus resursus (attēli, stili)';
$labels['fromknownsenders'] = 'tikai no zināmiem sūtītājiem';
$labels['fromtrustedsenders'] = 'no uzticamajiem sūtītājiem';
$labels['frommycontacts'] = 'no maniem kontaktiem';
$labels['always'] = 'vienmēr';
$labels['alwaysbutplain'] = 'vienmēr, izņemot gadījumus, kad tiek atbildēts "parastā teksta" vēstulēm';
$labels['showinlineimages'] = 'Rādīt pielikuma attēlus zem vēstules';
$labels['autosavedraft'] = 'Automātiski saglabāt vēstules uzmetumu';
$labels['everynminutes'] = 'ik pēc $n minūtes(ēm)';
$labels['refreshinterval'] = 'Pārbaudīt jaunās vēstules';
$labels['never'] = 'nekad';
$labels['immediately'] = 'nekavējoties';
$labels['messagesdisplaying'] = 'Vēstuļu attēlošana';
$labels['messagescomposition'] = 'Vēstuļu rakstīšana';
$labels['mimeparamfolding'] = 'Pielikumu nosaukumi';
$labels['2231folding'] = 'Pilns RFC 2231 (Thunderbird)';
$labels['miscfolding'] = 'RFC 2047/2231 (MS Outlook)';
$labels['2047folding'] = 'Pilns RFC 2047 (citi)';
$labels['force7bit'] = 'Izmantot MIME kodējumu 8-bitu simboliem';
$labels['savelocalstorage'] = "Saglabāt pārlūka atmiņā (pagaidu)";
$labels['advancedoptions'] = 'Paplašinātie iestatījumi';
$labels['toggleadvancedoptions'] = 'Parādīt paplašinātos iestatījumus';
$labels['focusonnewmessage'] = 'Uzstādīt pārlūka fokusu uz jaunu vēstuli';
$labels['checkallfolders'] = 'Meklēt visās mapēs jaunās vēstules';
$labels['displaynext'] = 'Pēc vēstules dzēšanas/pārvietošanas rādīt nākamo vēstuli';
$labels['defaultfont'] = 'Noklusētais fonts vēstulēm HTML formātā';
$labels['mainoptions'] = 'Galvenie iestatījumi';
$labels['browseroptions'] = 'Pārlūka iestatījumi';
$labels['section'] = 'Sadaļa';
$labels['maintenance'] = 'Uzturēšana';
$labels['newmessage'] = 'Vēstuļu pienākšana';
$labels['signatureoptions'] = 'Paraksta iestatījumi';
$labels['whenreplying'] = 'Atbildot';
$labels['replyempty'] = 'neiekļaut vēstules sākotnējo tekstu';
$labels['replytopposting'] = 'sākt jaunu vēstuli virs oriģināla';
$labels['replytoppostingnoindent'] = 'sākt jaunu ziņu virs citēšanas (bez identācijas)';
$labels['replybottomposting'] = 'sākt jaunu vēstuli zem oriģināla';
$labels['replyremovesignature'] = 'Atbildot izņemt oriģinālo parakstu no vēstules';
$labels['autoaddsignature'] = 'Automātiski pievienot parakstu';
$labels['newmessageonly'] = 'tikai jaunām vēstulēm';
$labels['replyandforwardonly'] = 'tikai atbildēm un pārsūtījumiem';
$labels['insertsignature'] = 'Ievietot parakstu';
$labels['sigbelow'] = 'Parakstu novietot zem sūtītās vēstules oriģinālā';
$labels['sigseparator'] = 'Parakstam obligāti izmantot standarta dalītāju';
$labels['automarkread'] = 'Atzīmēt vēstules kā lasītas';
$labels['afternseconds'] = 'pēc $n sekundēm';
$labels['reqmdn'] = 'Vienmēr pieprasīt saņemšanas apstiprinājumu';
$labels['reqdsn'] = 'Vienmēr pieprasīt atskati par piegādi';
$labels['alwayskeepformatting'] = 'Vienmēr lietot oriģinālo teksta formatējumu';
$labels['replysamefolder'] = 'Glabāt atbildes tajā pašā mapē, kurā ir vēstule, uz kuru tika atbildēts';
$labels['defaultabook'] = 'Noklusētā adrešu grāmata';
$labels['autocompletesingle'] = 'Automātiski aizpildot, nerādīt alternatīvās e-pasta adreses';
$labels['listnamedisplay'] = 'Rādīt kontaktus kā';
$labels['contactformmode'] = 'Kontaktu formas režīms';
$labels['privatemode'] = 'Privāts (Mājas)';
$labels['businessmode'] = 'Biznesa (Darba)';
$labels['collectedaddresses'] = 'Uzkrātās adreses';
$labels['collectedrecipients'] = 'Uzkrātie saņēmēji';
$labels['collectedrecipientsopt'] = 'Uzkrāt izejošo e-pastu adresātus iekš';
$labels['collectedsendersopt'] = 'Uzkrāt uzticamos sūtītājus iekš';
$labels['trustedsenders'] = 'Uzticamie sūtītāji';
$labels['spellcheckbeforesend'] = 'Pirms vēstules nosūtīšanas pārbaudīt pareizrakstību';
$labels['spellcheckoptions'] = 'Pareizrakstības iestatījumi';
$labels['spellcheckignoresyms'] = 'Ignorēt vārdus, kuri satur simbolus';
$labels['spellcheckignorenums'] = 'Ignorēt vārdus, kuri satur skaitļus';
$labels['spellcheckignorecaps'] = 'Ignorēt vārdus, kuri rakstīti ar lielajiem burtiem';
$labels['addtodict'] = 'Pievienot vārdnīcai';
$labels['editoroptions'] = 'Redaktora iestatījumi';
$labels['enableautolink'] = 'Automātiski konvertēt korektus URL uz hipersaitēm';
$labels['mailtoprotohandler'] = 'Atverot mailto: saites, lietot šo e-pasta programmu';
$labels['standardwindows'] = 'Izlēcošie logi kā parasti logi';
$labels['forwardmode'] = 'Vēstuļu pārsūtīšana';
$labels['inline'] = 'iekļaujot';
$labels['asattachment'] = 'kā pielikumu';
$labels['replyallmode'] = '[Atbildēt visiem] pogas noklusētā darbība';
$labels['replyalldefault'] = 'atbildēt visiem';
$labels['replyalllist'] = 'atbildēt tikai sarakstei (ja tāda tiek atrasta)';
$labels['allmessages'] = 'visām vēstulēm';
$labels['olderxdays'] = 'vecākas par $x dienām';
$labels['folder'] = 'Mapi';
$labels['folders'] = 'Mapes';
$labels['foldername'] = 'Mapes nosaukums';
$labels['subscribed'] = 'Abonēta';
$labels['messagecount'] = 'Vēstules';
$labels['create'] = 'Izveidot';
$labels['createfolder'] = 'Izveidot jaunu mapi';
$labels['managefolders'] = 'Rediģēt mapes';
$labels['specialfolders'] = 'Īpašās mapes';
$labels['properties'] = 'Īpašības';
$labels['folderproperties'] = 'Mapes īpašības';
$labels['parentfolder'] = 'Virsmape';
$labels['location'] = 'Atrašanās vieta';
$labels['info'] = 'Informācija';
$labels['getfoldersize'] = 'Uzklikšķiniet, lai uzzinātu mapes izmēru';
$labels['changesubscription'] = 'Uzklikšķiniet, lai mainītu abonēšanas iestatījumus';
$labels['foldertype'] = 'Mapes tips';
$labels['personalfolder'] = 'Privāta mape';
$labels['otherfolder'] = 'Cita lietotāja mape';
$labels['sharedfolder'] = 'Publiska mape';
$labels['findfolders'] = 'Meklēt mapes';
$labels['findcontacts'] = 'Atrast kontaktus';
$labels['findmail'] = 'Atrast epastus';
$labels['namespace.personal'] = 'Personīgās';
$labels['namespace.other'] = 'Citi lietotāji';
$labels['namespace.shared'] = 'Koplietota';
$labels['dualuselabel'] = 'Drīkst saturēt tikai';
$labels['dualusemail'] = 'vēstules';
$labels['dualusefolder'] = 'mapes';
$labels['generate'] = 'Ģenerēt';
$labels['encryptioncreatekey'] = 'Izveidot jaunu atslēgu pāri';
$labels['openmailvelopesettings'] = 'Parādīt "Mailvelope" iestatījumus';
$labels['encryptionprivkeysinmailvelope'] = 'Jūsu Mailvelope keyringā ir saglabātas $nr atbilstošas privātās atslēgas:';
$labels['encryptionnoprivkeysinmailvelope'] = 'Šai sūtītāja identitātei vēl nav saglabāta PGP privātā atslēga jūsu Mailvelope paplašinājumā. Vai vēlaties izveidot jaunu, lai ieslēgtu šifrētu saziņu?';
$labels['encryption'] = 'Šifrēšana';
$labels['mailvelopeoptions'] = 'Mailvelope opcijas';
$labels['mailvelopemainkeyring'] = 'Izmantojiet Mailvelope galveno "keyring"';
$labels['mailvelopenotfound'] = 'Mailvelope paplašinājums Jūsu interneta pārlūkā nav iespējots/uzinstalēts.';
$labels['mailvelopeenable'] = 'Ieslēgt';
$labels['sortby'] = 'Kārtot pēc';
$labels['sortasc'] = 'Kārtot augošā secībā';
$labels['sortdesc'] = 'Kārtot dilstošā secībā';
$labels['undo'] = 'Atsaukt';
$labels['installedplugins'] = 'Uzstādītie spraudņi';
$labels['plugin'] = 'Spraudnis';
$labels['version'] = 'Versija';
$labels['source'] = 'Oriģināls';
$labels['destination'] = 'Galamērķis';
$labels['license'] = 'Licence';
$labels['skinauthor'] = 'no $author';
$labels['support'] = 'Atbalsts';
$labels['savedsearches'] = 'Saglabātie mekkējumi';
$labels['dateformatY'] = 'YYYY';
$labels['dateformaty'] = 'YY';
$labels['dateformatm'] = 'MM';
$labels['dateformatd'] = 'DD';
$labels['dateformatj'] = 'D';
$labels['dateformatn'] = 'M';
$labels['B'] = 'B';
$labels['KB'] = 'kB';
$labels['MB'] = 'MB';
$labels['GB'] = 'GB';
$labels['unicode'] = 'Unikods';
$labels['english'] = 'Angļu';
$labels['westerneuropean'] = 'Rietumeiropas';
$labels['easterneuropean'] = 'Austrumeiropas';
$labels['southeasterneuropean'] = 'Dienvidaustrumu Eiropas';
$labels['baltic'] = 'Baltijas';
$labels['cyrillic'] = 'Kirilicas';
$labels['arabic'] = 'Arābu';
$labels['greek'] = 'Grieķu';
$labels['hebrew'] = 'Ebreju';
$labels['turkish'] = 'Turku';
$labels['nordic'] = 'Ziemeļvalstu';
$labels['thai'] = 'Taizemes';
$labels['celtic'] = 'Ķeltu';
$labels['vietnamese'] = 'Vjetnamiešu';
$labels['japanese'] = 'Japāņu';
$labels['korean'] = 'Korejiešu';
$labels['chinese'] = 'Ķīniešu';
$labels['arialabeltopnav'] = 'Loga kontorle';
$labels['arialabeltasknav'] = 'Programmas uzdevumi';
$labels['arialabeltoolbar'] = 'Programmas rīkjosla';
$labels['arialabellistnav'] = 'Saraksta navigācija';
$labels['arialabelactivetask'] = 'Aktīvā darbība';
$labels['arialabelmessagessearchfilter'] = 'Epastu saraksta filtrs';
$labels['arialabelmailsearchform'] = 'Epastu meklēšanas forma';
$labels['arialabelcontactsearchform'] = 'Kontaktu meklēšanas forma';
$labels['arialabelmailquicksearchbox'] = 'Epastu meklēšanas ievadlauks';
$labels['arialabelquicksearchbox'] = 'Meklēšanas ievadlauks';
$labels['arialabelfoldersearchfilter'] = 'Mapju saraksta filtrs';
$labels['arialabelfoldersearchform'] = 'Mapju meklēšanas forma';
$labels['arialabelfolderlist'] = 'Epastu mapju atzīmēšana';
$labels['arialabelmessagelist'] = 'Epastu saraksts';
$labels['arialabelmailpreviewframe'] = 'Ziņojuma priekšskats';
$labels['arialabelmailboxmenu'] = 'Izvēlne darbībām ar mapēm';
$labels['arialabellistselectmenu'] = 'Izvēlne sarakstu atzīmēšanai';
$labels['arialabelthreadselectmenu'] = 'Vēstuļu vijumu saraksta izvēlne';
$labels['arialabelmessagelistoptions'] = 'Vēstuļu attēlošanas un šķirošanas iestatījumi';
$labels['arialabelmailimportdialog'] = 'Vēstuļu importēšanas dialogs';
$labels['arialabelmessagenav'] = 'Vēstuļu navigācija';
$labels['arialabelmessagebody'] = 'Vēstules teksts';
$labels['arialabelmessageactions'] = 'Darbības ar vēstuli';
$labels['arialabelcontactquicksearch'] = 'Kontaktu meklēšanas forma';
$labels['arialabelcontactsearchbox'] = 'Kontaktu meklēšanas ievadlauks';
$labels['arialabelmessageheaders'] = 'Ziņojuma galvenes';
$labels['arialabelforwardingoptions'] = 'Pārsūtīšanas iestatījumi';
$labels['arialabelreplyalloptions'] = 'Atbildēt-visiem iestatījumi';
$labels['arialabelmoremessageactions'] = 'Citas darbības ar vēstulēm';
$labels['arialabelmorecontactactions'] = 'Citas darbības ar kontaktiem';
$labels['arialabelmarkmessagesas'] = 'Atzīmēt norādītās vēstules kā ...';
$labels['arialabelcomposeoptions'] = 'Rakstīšanas iestatījumi';
$labels['arialabelresponsesmenu'] = 'Gatavo atbilžu izvēlne';
$labels['arialabelattachmentuploadform'] = 'Pielikuma augšupielādes forma';
$labels['arialabelattachmentmenu'] = 'Pielikuma parametri';
$labels['arialabelmailtomenu'] = 'E-pasta adreses opcijas';
$labels['arialabelattachmentpreview'] = 'Pielikuma priekšskats';
$labels['ariasummarycomposecontacts'] = 'Kontaktu un grupu saraksts ko norādīt kā saņēmējus';
$labels['arialabelcontactexportoptions'] = 'Kontaktu eksportēšanas iestatījumi';
$labels['arialabelabookgroupoptions'] = 'Adrešu grāmatas/grupas iestatījumi';
$labels['arialabelpreferencesform'] = 'Iestatījumu forma';
$labels['arialabelidentityeditfrom'] = 'Identitātes rediģēšanas forma';
$labels['arialabelresponseeditfrom'] = 'Atbildes rediģēšanas forma';
$labels['arialabelsearchterms'] = 'Meklēšanas termini';
$labels['arialabeldropactionmenu'] = '"Velc un Noliec" darbības izvēlne';
$labels['arialabelheadersmenu'] = 'Adresāta (galvenē) pievienošanas izvēlne';
$labels['arialabelimagetools'] = 'Attēla rīki';
$labels['helplistnavigation'] = 'Parādīt klaviatūras īsos taustiņus';
$labels['helplistkeyboardnavigation'] = "Bultiņas augšup/lejup: Mainīt rindas izsgaismošanu/atzīmēšanu.
Garais taustiņš: Atzīmēt izgaismoto rindu.
Shift + augšup/lejup: Atzīmēt papildus rindas augšup/lejup.
Ctrl + Garais taustiņš: Pievienot vai noņemt izgaismoto rindu no atzīmēto saraksta.";
$labels['helplistkeyboardnavmessages'] = "Bultiņas pa labi/kreisi: atvērt vai aizvērt vēstules vijumu (tikai vijumu režīmā)
Enter: Atvērt atzīmēto/izgaismoto vēstuli.
Dzēst: Pārvietot atzīmēto vēstuli uz papīrgrozu.";
$labels['helplistkeyboardnavcontacts'] = "Enter: atvērt iezīmētos/izgaismotos kontaktus.";
