<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['welcome'] = '$product ته ښه راغلاست';
$labels['username'] = 'کارن نوم';
$labels['password'] = 'پټنوم';
$labels['server'] = 'برابرونکی';
$labels['login'] = 'ننوتون';
$labels['logout'] = 'وتون';
$labels['mail'] = 'برېښناليک';
$labels['settings'] = 'ځاني برابرونې';
$labels['addressbook'] = 'پتې کتاب';
$labels['inbox'] = 'راغلي ليکونه';
$labels['drafts'] = 'بارليک';
$labels['sent'] = 'لېږل شوي ليکونه';
$labels['trash'] = 'کثافت دانۍ';
$labels['junk'] = 'جنک';
$labels['subject'] = 'مضمون';
$labels['from'] = 'استوونکی';
$labels['to'] = 'ترلاسه کوونکی';
$labels['cc'] = 'لمېسل';
$labels['bcc'] = 'پټليکی';
$labels['replyto'] = 'ځوابول';
$labels['date'] = 'نېټه';
$labels['size'] = 'کچه';
$labels['priority'] = 'لومړيتوب';
$labels['organization'] = 'ټولنه';
$labels['mailboxlist'] = 'پوښۍ';
$labels['messagesfromto'] = 'له ټاکلي استوزو څخه ټاکلي شمېرل شوو استوزو ته';
$labels['messagenrof'] = 'له $nr ځخه استوزو $count استوزو ته';
$labels['copy'] = 'لمېسل';
$labels['moveto'] = 'ته خوځوي';
$labels['download'] = 'ښکته کول';
$labels['filename'] = 'فايل نوم';
$labels['filesize'] = 'فايل کچه';
$labels['addtoaddressbook'] = 'د پتو کتاب ته يې ورزيات کړئ';
$labels['sun'] = 'يوه نۍ';
$labels['mon'] = 'دوه نۍ';
$labels['tue'] = 'درې نۍ';
$labels['wed'] = 'څلورنۍ';
$labels['thu'] = 'پنځنۍ';
$labels['fri'] = 'جمعه';
$labels['sat'] = 'نۍ';
$labels['sunday'] = 'يوه نۍ';
$labels['monday'] = 'دوه نۍ';
$labels['tuesday'] = 'درې نۍ';
$labels['wednesday'] = 'منځنۍ';
$labels['thursday'] = 'پنځنۍ';
$labels['friday'] = 'جمعه';
$labels['saturday'] = 'نۍ';
$labels['jan'] = 'حنوري';
$labels['feb'] = 'فبروري';
$labels['mar'] = 'مارچ';
$labels['apr'] = 'اپريل';
$labels['may'] = 'مئ';
$labels['jun'] = 'جون';
$labels['jul'] = 'جولاي';
$labels['aug'] = 'اګست';
$labels['sep'] = 'سپتمپر';
$labels['oct'] = 'اکتوبر';
$labels['nov'] = 'نومبر';
$labels['dec'] = 'ډسمبر';
$labels['longjan'] = 'جنوري';
$labels['longfeb'] = 'فبروري';
$labels['longmar'] = 'مارچ';
$labels['longapr'] = 'اپريل';
$labels['longmay'] = 'مئ';
$labels['longjun'] = 'جون';
$labels['longjul'] = 'جولای';
$labels['longaug'] = 'اګست';
$labels['longsep'] = 'سپتمبر';
$labels['longoct'] = 'اکتوبر';
$labels['longnov'] = 'نومبر';
$labels['longdec'] = 'ډسمبر';
$labels['today'] = 'نن';
$labels['checkmail'] = 'نوي استوزي وګوره';
$labels['compose'] = 'استوزه وليکه';
$labels['writenewmessage'] = 'نوي استوزي جوړول';
$labels['replytomessage'] = 'استوونکي ته ځواب ورکړئ';
$labels['replytoallmessage'] = 'استوونکي او ټولو ترلاسه کوونکو ته ځواب لېږل';
$labels['forwardmessage'] = 'استوزه بل ته استول';
$labels['deletemessage'] = 'استوزه ړنګول';
$labels['movemessagetotrash'] = 'استوزه کثافت داني ته واستوه';
$labels['printmessage'] = 'دا استوزه چاپ کړه';
$labels['previousmessage'] = 'پخوانۍ استوزه وښيه';
$labels['firstmessage'] = 'لومړی استوزه وښيه';
$labels['nextmessage'] = 'ورپسې استوزه وښيه';
$labels['lastmessage'] = 'پای /آخري استوزه وښيه';
$labels['backtolist'] = 'بيرته د استوزو لست ته';
$labels['viewsource'] = 'سرچينه وښيه';
$labels['markmessages'] = 'استوزي په نښه کړئ';
$labels['markread'] = 'لوستل شوي په توګه';
$labels['markunread'] = 'د نالوستل شوي په توګه';
$labels['markflagged'] = 'د بي کاره په توګه';
$labels['markunflagged'] = 'د کارونې په توګه';
$labels['select'] = 'ټاکل';
$labels['all'] = 'ټول';
$labels['none'] = 'هېڅ';
$labels['unread'] = 'نالوستي';
$labels['flagged'] = 'بې کاره';
$labels['unanswered'] = 'ناځواب شوي';
$labels['filter'] = 'چڼول';
$labels['nonesort'] = 'هېڅ';
$labels['compact'] = 'کېښکلی';
$labels['empty'] = 'تش';
$labels['quota'] = 'ټيکلي لارښود';
$labels['unknown'] = 'نامعلوم';
$labels['unlimited'] = 'بي کچه';
$labels['quicksearch'] = 'ژر پلټنه';
$labels['resetsearch'] = 'د پلټنې بياسمون';
$labels['openinextwin'] = 'په نوي کړکۍ کې پرانيزه';
$labels['sendmessage'] = 'اوس يې واستوه';
$labels['savemessage'] = 'دا ګارليک خوندي کړه';
$labels['addattachment'] = 'يو فايل ونښلوه';
$labels['charset'] = 'چيرست';
$labels['editortype'] = 'د ټايب سمونګر';
$labels['returnreceipt'] = 'د رسليک راګرځېدل';
$labels['checkspelling'] = 'ليکدود کتنه';
$labels['resumeediting'] = 'کارمخينې سمونه';
$labels['revertto'] = 'ته بېرته اړول';
$labels['attachments'] = 'نښلني';
$labels['upload'] = 'پورته کول';
$labels['close'] = 'بندول';
$labels['low'] = 'ټيټ';
$labels['lowest'] = 'خورا ټيټ';
$labels['normal'] = 'نورمال';
$labels['high'] = 'لوړ';
$labels['highest'] = 'خورا لوړ';
$labels['nosubject'] = 'هېڅ موضوع';
$labels['showimages'] = 'انځورونه وښيه';
$labels['alwaysshow'] = 'تل له $استوونکي څخه انځورونه وښيه';
$labels['htmltoggle'] = 'ايچ ټی ايمل ال';
$labels['plaintoggle'] = 'ساده متن';
$labels['savesentmessagein'] = 'استول شوي استوزه په خوندي کړه';
$labels['dontsave'] = 'مه ساته';
$labels['maxuploadsize'] = 'لږترلږه د اجازه شوي فايل کچه $وي';
$labels['addcc'] = 'څرګندليک';
$labels['addbcc'] = 'پټليک';
$labels['addreplyto'] = 'ته ورزيات کړه';
$labels['mdnrequest'] = 'ددې استوزي استوونکی پوښتي چېد استوزي لوستلو سره سم تاسې خبر کړي،.    غواړئ چې استوونکی خبرشي؟';
$labels['receiptread'] = 'رسليک راګرځېدل (لوستل';
$labels['yourmessage'] = 'دا رسليک راګرځېدل ستاسې استوزي لپاره دی';
$labels['receiptnote'] = 'يادونه: دا رسليک تاسې ته يوازې ددې خبرتيا درکوي چې کله استوزی د ترلاسه کوونکي په کمپيوټر کې څرګند شي،  ددې هيڅ ډاډګيرنه نشته چې ترلاسه کوونکي د  استوزي متن لوستی او يا پرې پوه شوی دی';
$labels['name'] = 'نوم ښوونه';
$labels['firstname'] = 'نوم';
$labels['surname'] = 'کورنی نوم';
$labels['email'] = 'برېښناليک';
$labels['editcontact'] = 'اړيکلوري سمون';
$labels['edit'] = 'سمون';
$labels['cancel'] = 'لري کول';
$labels['save'] = 'ساتل';
$labels['delete'] = 'ړنګول';
$labels['deletecontact'] = 'ټاکل شوي اړيکلوري ړنګ کړه';
$labels['composeto'] = 'ته ليک وليکه';
$labels['contactsfromto'] = 'له دومره اړيکلورو څخه دومره شمېرل شوي Contacts $from to $to of $count';
$labels['print'] = 'چاپ';
$labels['export'] = 'بهرول';
$labels['exportvcards'] = 'اړيکلوري د ويکارډ په بڼه واستوئ';
$labels['previouspage'] = 'پخوانی غونډ وښيه';
$labels['firstpage'] = 'لومړی غونډ وښيه';
$labels['nextpage'] = 'ورپسې غونډ وښيه';
$labels['lastpage'] = 'پای غونډ وښيه';
$labels['groups'] = 'ډلې';
$labels['personaladrbook'] = 'ځاني پتې';
$labels['import'] = 'رانقلول';
$labels['importcontacts'] = 'اړيکلوري نقل کړئ';
$labels['importreplace'] = 'ټول ادرس کتاب بدل کړئ';
$labels['done'] = 'ترسره شو';
$labels['settingsfor'] = 'لپاره برابرونې';
$labels['preferences'] = 'غورونې';
$labels['userpreferences'] = 'کارن غورونې';
$labels['editpreferences'] = 'د کارن غورونو سمون';
$labels['identities'] = 'پېژندنې';
$labels['preferhtml'] = 'ايچ ټي ام ايل ښوون';
$labels['htmlmessage'] = 'ايچ ټي ام ايل استوزه';
$labels['prettydate'] = 'په زړه پورې نېټې';
$labels['setdefault'] = 'تلوالي برابرول';
$labels['autodetect'] = 'په خپلواکه توګه';
$labels['language'] = 'ژبه';
$labels['timezone'] = 'سيميز وخت';
$labels['pagesize'] = 'په هر مخ پرتې کښې';
$labels['signature'] = 'لاسليک';
$labels['dstactive'] = 'ورځنيو کارونو لنډيز ساتل';
$labels['htmleditor'] = 'ايچ ټي‌ام ايل استوزي وليکه';
$labels['htmlsignature'] = 'ايچ ټي ام ايل لاسليک';
$labels['previewpane'] = 'پخوانی چوکاټ وښييه';
$labels['skin'] = 'انټرفيس بڼه';
$labels['logoutclear'] = 'کثافت داني د وتنې په وخت کې پاکه کړه';
$labels['logoutcompact'] = 'د وتنې په وخت کې ليکبکس ونښلوه';
$labels['uisettings'] = 'د کاروونکي برسېر';
$labels['serversettings'] = 'سرور برابرونې';
$labels['mailboxview'] = 'ليکبکس ښکار کړه';
$labels['mdnrequests'] = 'د استوونکي خبرتياوې';
$labels['askuser'] = 'له کاروونکي څخه وپوښته';
$labels['autosend'] = 'په خپلواکه توګه واستوه';
$labels['readwhendeleted'] = 'په ړنګ شوو کې استوزي د لوستل شوي  په توګه په نښه کړه';
$labels['flagfordeletion'] = 'استوزه د ړنګ شوي پرځای بېکاره کړه';
$labels['skipdeleted'] = 'ړنګ شوي استوزي مه ښکاره کوه';
$labels['showremoteimages'] = 'انځورونه له لري په ليکه کې ښکاره کړه';
$labels['fromknownsenders'] = 'له اشنا استوونکو څخه';
$labels['always'] = 'تل';
$labels['showinlineimages'] = 'نښلول شوي انځورونه تر استوزې لاندې ښکاره کړه';
$labels['autosavedraft'] = 'بارليک په خپل سري توګه  خوندي‌کړه';
$labels['everynminutes'] = 'هر ه ګڼه په دقيقو کې';
$labels['never'] = 'هېڅ';
$labels['messagesdisplaying'] = 'استوزي ښيي';
$labels['messagescomposition'] = 'استوزي ليکي';
$labels['mimeparamfolding'] = 'د نښلول شوو نومونه';
$labels['2231folding'] = 'بشپړ RFC 2231 (Thunderbird)';
$labels['miscfolding'] = 'RFC 2047/2231 (MS Outlook)';
$labels['2047folding'] = 'Full RFC 2047 (نور)';
$labels['advancedoptions'] = 'پرمختللي لارې';
$labels['focusonnewmessage'] = 'فوکاس براوسر کړکۍ په نوي استوزي کې';
$labels['checkallfolders'] = 'په ټولو پوښيو کې نوي استوزي وګورئ';
$labels['folder'] = 'پوښۍ';
$labels['folders'] = 'پوښۍ';
$labels['foldername'] = 'پوښۍ نوم';
$labels['subscribed'] = 'ګډ شو';
$labels['messagecount'] = 'استوزي';
$labels['create'] = 'جوړول، رامنځ ته کول';
$labels['createfolder'] = 'نوې پوښۍ جوړ کړه';
$labels['managefolders'] = 'پوښيو څارل';
$labels['specialfolders'] = 'ځانګړي پوښۍۍ';
$labels['sortby'] = 'اڼل';
$labels['sortasc'] = 'له پورته نه ښکته خوا ته برابرول';
$labels['sortdesc'] = 'له ښکته نه پورته خوا ته برابرول';
$labels['B'] = 'بي';
$labels['KB'] = 'کي بي';
$labels['MB'] = 'ام بي';
$labels['GB'] = 'جي بي';
