<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Archive plugin             |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$messages['missingattachment'] = "Manque-t-il un fichier joint ?";
$messages['forgotattachment'] = "Avez-vous oublié de joindre un fichier ?";
$messages['reminderoption'] = "Rappel sur les fichiers joints oubliés";
$messages['keywords'] = "fichier joint,pièce jointe,fichier,joindre,joins,joint,attaché,inclus,ci-inclus,CV, lettre d’accompagnement, PJ, P.J";
