<roundcube:include file="includes/layout.html" />

<h1 class="voice"><roundcube:label name="addressbook" /> : <roundcube:label name="advsearch" /></h1>

<div class="formcontent">
	<roundcube:object name="searchform" id="advsearchform" class="tabbed propform" short-legend-labels="true" />
</div>

<roundcube:include file="includes/footer.html" />
