<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail New Mail Notifier plugin   |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['basic'] = 'Agahdariyên gerokê li ser peyama nû nîşan bide';
$labels['desktop'] = 'Agahdariyên sermaseyê li ser peyama nû nîşan bide';
$labels['sound'] = 'Dema peyama nû hat dengê bilizîne';
$labels['test'] = 'Test';
$labels['title'] = 'Enameya nû!';
$labels['body'] = 'Te peyameke nû wergirt.';
$labels['testbody'] = 'Ev agahdariyeke testê ye.';
$labels['desktopdisabled'] = 'Agahdariyên sermasê di geroka te de girtî ne. ';
$labels['desktopunsupported'] = 'Geroka te piştgiriya agahdariyên sermaseyê nake.';
$labels['desktoptimeout'] = 'Agahadariya sermaseyê bigire';
