<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail MarkdownEditor plugin      |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['editor_icon_alt'] = 'Editor Markdown';
$labels['editor_button_title'] = 'Escreva a mensagem em Markdown e envie-a como HTML.';
$labels['toolbar_button_quit'] = 'Voltar ao editor de texto simples';
$labels['toolbar_button_help'] = 'Abra um guia de sintaxe Markdown numa nova janela.';
$labels['toolbar_button_preview'] = 'Pré-visualizar o HTML tal como será enviado.';
$labels['toolbar_button_bold'] = 'Negrito';
$labels['toolbar_button_italic'] = 'Itálico';
$labels['toolbar_button_strike'] = 'Rasurado';
$labels['toolbar_button_h1'] = 'Nível de cabeçalho 1';
$labels['toolbar_button_h2'] = 'Nível de cabeçalho 2';
$labels['toolbar_button_h3'] = 'Nível de cabeçalho 3';
$labels['toolbar_button_h4'] = 'Nível de cabeçalho 4';
$labels['toolbar_button_h5'] = 'Nível de cabeçalho 5';
$labels['toolbar_button_h6'] = 'Nível de cabeçalho 6';
$labels['toolbar_button_blockquote'] = 'Citação em bloco';
$labels['toolbar_button_unordered_list'] = 'Lista não ordenada';
$labels['toolbar_button_ordered_list'] = 'Lista ordenada';
$labels['toolbar_button_link'] = 'Link';
$labels['toolbar_button_image'] = 'Imagem';
$labels['toolbar_button_undo'] = 'Anular';
$labels['toolbar_button_redo'] = 'Refazer';
