<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['welcome'] = 'Fáilte go $product';
$labels['username'] = 'Úsáideoir';
$labels['password'] = 'Pasfhocal';
$labels['server'] = 'Freastalaí';
$labels['login'] = 'Logáil isteach';
$labels['menu'] = 'Roghchlár';
$labels['logout'] = 'Scoir';
$labels['mail'] = 'Postas';
$labels['settings'] = 'Socruithe Pearsanta';
$labels['addressbook'] = 'Leabhair Seoltaí';
$labels['inbox'] = 'Isteach';
$labels['drafts'] = 'Dréachtaí';
$labels['sent'] = 'Amach';
$labels['trash'] = 'Bosca bruscair';
$labels['junk'] = 'Dramhaíl';
$labels['show_real_foldernames'] = 'Taispeáin fíorainmneacha i gcomhair fillteáin faoi leith';
$labels['subject'] = 'Ábhair';
$labels['from'] = 'Seolaí';
$labels['sender'] = 'Seoltóir';
$labels['to'] = 'Chuig';
$labels['cc'] = 'Cc';
$labels['bcc'] = 'Cóip cheilte';
$labels['replyto'] = 'Freagair go';
$labels['date'] = 'Dáta';
$labels['size'] = 'Méid';
$labels['priority'] = 'Tosaíocht';
$labels['organization'] = 'Eagraíocht';
$labels['mailboxlist'] = 'Fillteán';
$labels['messagesfromto'] = 'Teachtaireachta as $from go $to as $count';
$labels['messagenrof'] = 'Teachtaireacht $nr as $count';
$labels['fromtoshort'] = '$from – $to as $count';
$labels['copy'] = 'Macasamhlaigh';
$labels['move'] = 'Bog';
$labels['moveto'] = 'Bog chuig...';
$labels['copyto'] = 'Macasamhlaigh chuig...';
$labels['download'] = 'Íosluchtú';
$labels['open'] = 'Oscail';
$labels['showattachment'] = 'Taispeáin';
$labels['showanyway'] = 'Taispeáin é ar aon nós';
$labels['filename'] = 'Ainm an chomhaid';
$labels['filesize'] = 'Toirt';
$labels['addtoaddressbook'] = 'Sábháil i mo leabhair seoltaí';
$labels['sun'] = 'Do';
$labels['mon'] = 'Lu';
$labels['tue'] = 'Má';
$labels['wed'] = 'Cé';
$labels['thu'] = 'Dé';
$labels['fri'] = 'Ao';
$labels['sat'] = 'Sa';
$labels['sunday'] = 'Domhnach';
$labels['monday'] = 'An Luan';
$labels['tuesday'] = 'An Mháirt';
$labels['wednesday'] = 'An Chéadaoin';
$labels['thursday'] = 'An Déardaoin';
$labels['friday'] = 'Aoine';
$labels['saturday'] = 'An Satharn';
$labels['jan'] = 'Ean';
$labels['feb'] = 'Fea';
$labels['mar'] = 'Már';
$labels['apr'] = 'Aib';
$labels['may'] = 'Bea';
$labels['jun'] = 'Mei';
$labels['jul'] = 'Iúi';
$labels['aug'] = 'Lún';
$labels['sep'] = 'MFó';
$labels['oct'] = 'DFó';
$labels['nov'] = 'Sam';
$labels['dec'] = 'Nol';
$labels['longjan'] = 'Eanáir';
$labels['longfeb'] = 'Feabhra';
$labels['longmar'] = 'Márta';
$labels['longapr'] = 'Aibreán';
$labels['longmay'] = 'Bealtaine';
$labels['longjun'] = 'Meitheamh';
$labels['longjul'] = 'Iúil';
$labels['longaug'] = 'Lúnasa';
$labels['longsep'] = 'Meán Fómhair';
$labels['longoct'] = 'Deireadh Fómhair';
$labels['longnov'] = 'Samhain';
$labels['longdec'] = 'Nollaig';
$labels['today'] = 'Inniu';
$labels['refresh'] = 'Athnuaigh';
$labels['checkmail'] = 'Seiceáil chun teachtaireacht nua';
$labels['compose'] = 'Scríobh teachtaireacht';
$labels['writenewmessage'] = 'Scríobh teachtaireacht nua';
$labels['reply'] = 'Freagair';
$labels['replytomessage'] = 'Scríobh freagra chun an seolaí';
$labels['replytoallmessage'] = 'Scríobh freagra chun an seolaí agus na faighteoir';
$labels['replyall'] = 'Freagra gach';
$labels['forward'] = 'Cur ar aghaidh';
$labels['forwardattachment'] = 'Seol ar aghaidh mar cheangaltán é';
$labels['forwardmessage'] = 'Seol ar aghaidh an teachtaireacht';
$labels['bouncemsg'] = 'Athsheol';
$labels['bounce'] = 'Athsheol';
$labels['deletemessage'] = 'Scrois an teachtaireacht';
$labels['movemessagetotrash'] = 'Bog an teachtaireacht chuig an bosca bruscair';
$labels['printmessage'] = 'Clóbhuail an teachtaireacht seo';
$labels['previousmessage'] = 'Taispeáin an teachtaireacht roimhe seo';
$labels['firstmessage'] = 'Taispeáin an chéad teachtaireacht eile';
$labels['nextmessage'] = 'Taispeáin an teachtaireacht ina dhiaidh sin';
$labels['lastmessage'] = 'Taispeáin an teachtaireacht deireanach';
$labels['backtolist'] = 'Téigh ar ais go dtí an liosta teachtaireachta';
$labels['viewsource'] = 'Éiriú bunchód';
$labels['mark'] = 'Rianaigh';
$labels['markmessages'] = 'Rianaigh teachtaireachtaí';
$labels['markread'] = 'Léite';
$labels['markunread'] = 'Mar neamhléite';
$labels['moreactions'] = 'Tuilleadh gníomhartha...';
$labels['markallread'] = 'Rianaigh uile mar léite';
$labels['folders-cur'] = 'An fillteán roghnaithe amháin';
$labels['folders-sub'] = 'An fillteán roghnaithe agus a fhofhillteáin';
$labels['folders-all'] = 'Gach fillteán';
$labels['more'] = 'Tuilleadh';
$labels['back'] = 'Siar';
$labels['options'] = 'Roghanna';
$labels['composeoptions'] = 'Roghanna cumadóireachta';
$labels['optionsandattachments'] = 'Roghanna agus ceangaltáin';
$labels['actions'] = 'Gníomhartha';
$labels['first'] = 'Céad';
$labels['last'] = 'Deireanach';
$labels['previous'] = 'Roimhe';
$labels['next'] = 'Ar aghaidh';
$labels['select'] = 'Roghnaigh';
$labels['selection'] = 'Roghnúchán';
$labels['all'] = 'Uile';
$labels['none'] = 'Dada';
$labels['currpage'] = 'An leathanach reatha';
$labels['isread'] = 'Léite';
$labels['unread'] = 'Neamhléite';
$labels['flagged'] = 'Bratach curtha leis';
$labels['unanswered'] = 'Gan fhreagra';
$labels['withattachment'] = 'Le ceangaltán';
$labels['deleted'] = 'Scriosta';
$labels['undeleted'] = 'Nach bhfuil scriosta';
$labels['replied'] = 'Freagartha';
$labels['forwarded'] = 'Curtha ar aghaidh';
$labels['invert'] = 'Aisiompaigh';
$labels['filter'] = 'Scag';
$labels['list'] = 'Liosta';
$labels['threads'] = 'Snáitheanna';
$labels['expand-all'] = 'Fairsingigh Uile';
$labels['expand-unread'] = 'Fairsingigh na cinn neamhléite';
$labels['collapse-all'] = 'Leacaigh uile';
$labels['threaded'] = 'Snáithithe';
$labels['showunread'] = 'Taispeáin teachtaireachtaí neamhéite';
$labels['do_expand'] = 'gach snáithe';
$labels['expand_only_unread'] = 'le teachtaireachtaí neamhléite amháin';
$labels['fromto'] = 'Ó/Chuig';
$labels['flag'] = 'Cuir Bratach Air';
$labels['attachment'] = 'Ceangaltáin';
$labels['nonesort'] = 'Aon cheann';
$labels['sentdate'] = 'An dáta ar a seoladh é';
$labels['arrival'] = 'An dáta ar a shroich sé ';
$labels['asc'] = 'ag dul suas';
$labels['desc'] = 'ag dul síos';
$labels['layout'] = 'Leagan amach';
$labels['layoutwidescreen'] = 'Scáileán leathan';
$labels['layoutdesktop'] = 'Ríomhaire ar an gcrinlín';
$labels['layoutlist'] = 'Liosta';
$labels['folderactions'] = 'Gníomhartha do na fillteáin...';
$labels['compact'] = 'Comhbhrúigh';
$labels['empty'] = 'Folmhaigh';
$labels['importmessages'] = 'Tabhair teachtaireachtaí isteach';
$labels['quota'] = 'Toilleadh diosca atá athláimhe';
$labels['unknown'] = 'gan aithne';
$labels['unlimited'] = 'gan teorainn';
$labels['quotatotal'] = 'Teorainn';
$labels['quotaused'] = 'Úsáidte';
$labels['quotastorage'] = 'Slí ar an diosca';
$labels['quotamessage'] = 'Líon na dteachtaireachtaí';
$labels['shortheaderdate'] = 'Ar $date';
$labels['shortheaderto'] = 'Chuig $to ar $date';
$labels['shortheaderfrom'] = 'Ó $from ar an $date';
$labels['quicksearch'] = 'Mearcuardaigh';
$labels['searchplaceholder'] = 'Cuardaigh...';
$labels['resetsearch'] = 'Athshocraigh an cuardach';
$labels['msgtext'] = 'An teachtaireacht ar fad';
$labels['body'] = 'Colainn';
$labels['type'] = 'Cineál';
$labels['namex'] = 'Ainm';
$labels['searchscope'] = 'Cuimse';
$labels['currentfolder'] = 'An fillteán reatha';
$labels['subfolders'] = 'An ceann seo agus fofhillteáin';
$labels['allfolders'] = 'Gach fillteán';
$labels['searchinterval-1W'] = 'níos sine ná seachtain';
$labels['searchinterval-1M'] = 'níos sine ná mí';
$labels['searchinterval-1Y'] = 'níos sine ná bliain';
$labels['searchinterval1W'] = 'níos úire na seachtain';
$labels['searchinterval1M'] = 'níos úire ná mí';
$labels['searchinterval1Y'] = 'níos úire ná bliain';
$labels['openinextwin'] = 'Oscail i bhfuinneog nua';
$labels['emlsave'] = 'Íosluchtú (.eml)';
$labels['editasnew'] = 'Cuir in eagar mar cheann nua';
$labels['send'] = 'Seol';
$labels['sendmessage'] = 'Seol mo teachtaireacht láithreach bonn';
$labels['savemessage'] = 'Sábháil an dréachta seo';
$labels['addattachment'] = 'Suimigh Iatán';
$labels['charset'] = 'Foireann carachtar';
$labels['editortype'] = 'Sort eagarthóir';
$labels['returnreceipt'] = 'Admháil léite';
$labels['mailreplyintro'] = 'Ar an $date, scríobh $sender:';
$labels['originalmessage'] = 'An teachtaireacht bhunaidh';
$labels['selectimage'] = 'Roghnaigh íomhá';
$labels['addimage'] = 'Cuir íomhá leis';
$labels['selectmedia'] = 'Roghnaigh scannán';
$labels['addmedia'] = 'Cuir scannán leis';
$labels['encrypt'] = 'Criptigh';
$labels['encryptmessage'] = 'Criptigh an teachtaireacht';
$labels['encryptandsign'] = 'Criptigh agus sínigh';
$labels['keylength'] = 'Bearta';
$labels['keyexpired'] = 'Éagtha';
$labels['keyrevoked'] = 'Aisghairmthe';
$labels['bccinstead'] = 'Bain feidhm as Bcc';
$labels['insert'] = 'Ionsáigh';
$labels['recipient'] = 'Faighteoir';
$labels['spellcheck'] = 'Litrigh';
$labels['checkspelling'] = 'Fiosrú ar mo litriú';
$labels['resumeediting'] = 'Athdhúisigh eagarthóireacht';
$labels['revertto'] = 'Filleadh ar';
$labels['restore'] = 'Cuir ar ais';
$labels['restoremessage'] = 'Cuir an teachtaireacht ar ais?';
$labels['ignore'] = 'Ná bac leis';
$labels['responses'] = 'Freagraí';
$labels['insertresponse'] = 'Cuir isteach freagra';
$labels['newresponse'] = 'Cruthaigh freagra nua';
$labels['addresponse'] = 'Cuir freagra leis';
$labels['editresponse'] = 'Cuir an freagra in eagar';
$labels['editresponses'] = 'Cuir na freagraí in eagar';
$labels['responsename'] = 'Ainm';
$labels['responsetext'] = 'Téacs an fhreagra';
$labels['attach'] = 'Ceangail';
$labels['attachments'] = 'Iatání';
$labels['upload'] = 'Aistriú suas';
$labels['uploadprogress'] = '$percent ($current as $total)';
$labels['close'] = 'Dún';
$labels['messageoptions'] = 'Roghanna teachtaireachtaí...';
$labels['attachmentrename'] = 'Athainmnigh an ceangaltán';
$labels['low'] = 'Íseal';
$labels['lowest'] = 'Is Ísle';
$labels['normal'] = 'Gnách';
$labels['high'] = 'Ard';
$labels['highest'] = 'Is Airde';
$labels['nosubject'] = '(Níl aon Ábhair)';
$labels['showimages'] = 'Taispeáin na híomhánna';
$labels['allow'] = 'Ceadaigh';
$labels['alwaysshow'] = 'Taispeáin íomhánna ó $sender i gcónaí';
$labels['isdraft'] = 'Seo dréachttheachtaireacht.';
$labels['andnmore'] = '$nr eile...';
$labels['details'] = 'Mionsonraí';
$labels['summary'] = 'Achoimre';
$labels['headers'] = 'Ceannteidil';
$labels['allheaders'] = 'Gach ceannteideal...';
$labels['togglemoreheaders'] = 'Taispeáin tuilleadh ceannteidil theachtaireachtaí';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'Téacs amháin';
$labels['savesentmessagein'] = 'Coimeád an teachtaireacht seolta i';
$labels['dontsave'] = 'ná coimeád é';
$labels['addcc'] = 'Cuir Cc leis';
$labels['addbcc'] = 'Cuir Bcc leis';
$labels['receiptread'] = 'Admháil fillte (léite)';
$labels['zoomin'] = 'Gluais Isteach';
$labels['zoomout'] = 'Gluais Amach';
$labels['rotate'] = 'Rothlaigh';
$labels['increaseimage'] = 'Méadaigh méid na híomhá';
$labels['decreaseimage'] = 'Laghdaigh méid na híomhá';
$labels['rotateimage'] = 'Rothlaigh an íomhá';
$labels['showtools'] = 'Taispeáin uirlisí don íomhánna';
$labels['hidetools'] = 'Folaigh uirlisí don íomhá';
$labels['name'] = 'Leasainm';
$labels['firstname'] = 'Ainm baiste';
$labels['surname'] = 'Sloinne';
$labels['middlename'] = 'An Dara hAinm';
$labels['nameprefix'] = 'Réimír';
$labels['namesuffix'] = 'Iarmhír';
$labels['nickname'] = 'Leasainm';
$labels['jobtitle'] = 'Teideal oibre';
$labels['department'] = 'Rannóg';
$labels['gender'] = 'Gnéas';
$labels['maidenname'] = 'Sloinne roimh phósadh';
$labels['email'] = 'Ríomhphost';
$labels['phone'] = 'Uimhir ghutháin';
$labels['address'] = 'Seoladh';
$labels['street'] = 'Sráid';
$labels['locality'] = 'Cathair';
$labels['zipcode'] = 'Cód Poist';
$labels['region'] = 'Stát/Cúige';
$labels['country'] = 'Tír';
$labels['birthday'] = 'Lá breithe';
$labels['anniversary'] = 'Cothrom lae';
$labels['website'] = 'Suíomh gréasáin';
$labels['instantmessenger'] = 'TM';
$labels['notes'] = 'Nótaí';
$labels['male'] = 'fireann';
$labels['female'] = 'baineann';
$labels['manager'] = 'Bainisteoir';
$labels['assistant'] = 'Cúntóir';
$labels['spouse'] = 'Céile';
$labels['allfields'] = 'Gach réimse';
$labels['search'] = 'Cuardaigh';
$labels['searchresult'] = 'Toradh an chuardaigh';
$labels['advsearch'] = 'Cuardach casta';
$labels['advanced'] = 'Ardroghanna';
$labels['other'] = 'Eile';
$labels['printcontact'] = 'Cuir an teagmháil i gcló';
$labels['qrcode'] = 'Cód QR';
$labels['typehome'] = 'Baile';
$labels['typework'] = 'Obair';
$labels['typeother'] = 'Eile';
$labels['typemobile'] = 'Soghluaiste';
$labels['typemain'] = 'Príomh';
$labels['typehomefax'] = 'Faics baile';
$labels['typeworkfax'] = 'Faics oibre';
$labels['typecar'] = 'Gluaisteán';
$labels['typepager'] = 'Glaoire';
$labels['typevideo'] = 'Físeán';
$labels['typeassistant'] = 'Cúntóir';
$labels['typehomepage'] = 'Leathanach baile';
$labels['typeblog'] = 'Blag';
$labels['typeprofile'] = 'Beathaisnéisín';
$labels['addfield'] = 'Cuir réimse leis...';
$labels['addcontact'] = 'Cuir teagmháil leis';
$labels['editcontact'] = 'Chuir chara in eagar';
$labels['contacts'] = 'Teagmhálacha';
$labels['contactproperties'] = 'Airíonna na teagmhálaí';
$labels['contactnameandorg'] = 'Ainm agus Eagraíocht';
$labels['personalinfo'] = 'Faisnéis phearsanta';
$labels['personal'] = 'Pearsanta';
$labels['contactphoto'] = 'Grianghraf den teagmhálaí';
$labels['edit'] = 'Athraigh';
$labels['cancel'] = 'Cealaigh';
$labels['save'] = 'Sábháil';
$labels['delete'] = 'Scrios';
$labels['discard'] = 'Cuileáil';
$labels['continue'] = 'Lean ar aghaidh';
$labels['ok'] = 'Tá go maith';
$labels['rename'] = 'Athainmnigh';
$labels['addphoto'] = 'Cuir leis';
$labels['replacephoto'] = 'Ionadaigh';
$labels['uploadphoto'] = 'Uasluchtaigh grianghraf';
$labels['choosefile'] = 'Roghnaigh comhad...';
$labels['choosefiles'] = 'Roghnaigh comhaid...';
$labels['browse'] = 'Siortaigh';
$labels['newcontact'] = 'Cruthaigh teagmháil nua';
$labels['deletecontact'] = 'Scrios na daoine seo';
$labels['composeto'] = 'Scríobh teachtaireacht go';
$labels['contactsfromto'] = 'Daoine as $from to $to as $count';
$labels['print'] = 'Priontáil';
$labels['export'] = 'Easportáil';
$labels['exportall'] = 'Tabhair amach uile';
$labels['exportsel'] = 'Bain amach an ní roghnaithe';
$labels['newgroup'] = 'Cruthaigh baicle nua';
$labels['addgroup'] = 'Cuir baicle leis';
$labels['grouprename'] = 'Athainmnigh an bhaicle';
$labels['groupdelete'] = 'Scrios an bhaicle';
$labels['uponelevel'] = 'Suas';
$labels['previouspage'] = 'Taispeáin an foireann roimhe seo';
$labels['firstpage'] = 'Taispeáin an céad foireann';
$labels['nextpage'] = 'Taispeáin an foireann ina dhiaidh sin';
$labels['lastpage'] = 'Taispeáin an foireann deireanach';
$labels['group'] = 'Baicle';
$labels['groups'] = 'Grúpaí';
$labels['personaladrbook'] = 'Seoltaí Pearsanta';
$labels['searchdelete'] = 'Scrios an cuardach';
$labels['import'] = 'Tabhair isteach';
$labels['importfromfile'] = 'Tabhair isteach ó chomhad';
$labels['importtarget'] = 'Cuir teagmhálaithe le';
$labels['importreplace'] = 'Ionadaigh an leabhar seoltaí iomlán';
$labels['done'] = 'Déanta';
$labels['settingsfor'] = 'Socruithe chun';
$labels['about'] = 'Maidir le';
$labels['preferences'] = 'Tosaíocht';
$labels['userpreferences'] = 'Tosaíocht Pearsanta';
$labels['editpreferences'] = 'Athraigh tosaíocht pearsanta';
$labels['identities'] = 'Céannachtaí';
$labels['addidentity'] = 'Cuir céannacht leis';
$labels['editidentity'] = 'Cuir céannacht in eagar';
$labels['identityencryption'] = 'Criptiúchán';
$labels['preferhtml'] = 'Taispeáin an HTML';
$labels['htmlmessage'] = 'Teachtaireacht HTML';
$labels['messagepart'] = 'Cuid';
$labels['digitalsig'] = 'Síniú Digiteach';
$labels['dateformat'] = 'Leagan amach an dáta';
$labels['timeformat'] = 'Leagan amach an am';
$labels['prettydate'] = 'Dátaí Dheas';
$labels['setdefault'] = 'Socraigh an réamhshocraithe';
$labels['autodetect'] = 'Uathoibríoch';
$labels['language'] = 'Teanga';
$labels['timezone'] = 'Crios ama';
$labels['pagesize'] = 'Rónna in aghaidh gach leathanach';
$labels['signature'] = 'Mana clabhsúir';
$labels['dstactive'] = 'Laethúil um shamhradh';
$labels['showinextwin'] = 'Oscail an teachtaireacht i bhfuinneog nua';
$labels['composeextwin'] = 'Cum i bhfuinneog nua';
$labels['htmleditor'] = 'Scríobh teachtaireachta HTML';
$labels['htmlsignature'] = 'Mana clabhsúir HTML';
$labels['showemail'] = 'Taispeáin an seoladh ríomhphoist leis an ainm taispeána';
$labels['previewpane'] = 'Taispeáin an pána réamhamharc';
$labels['skin'] = 'Craiceann an comhéadain';
$labels['logoutclear'] = 'Glan Bruscar nuair a scoirtear';
$labels['logoutcompact'] = 'Comhbhrúigh an Bosca Isteach nuair a scoirtear';
$labels['uisettings'] = 'Comhéadan';
$labels['serversettings'] = 'Socruithe an Fhreastalaithe';
$labels['mailboxview'] = 'Amharc Bosca Poist';
$labels['askuser'] = 'iarr orm';
$labels['autosend'] = 'seol admháil';
$labels['ignorerequest'] = 'Ná bac leis an iarratas';
$labels['readwhendeleted'] = 'Rianaigh an teachtaireacht mar léite nuair a scriostar í';
$labels['skipdeleted'] = 'Ná taispeáin teachtaireachtaí scriosta';
$labels['fromknownsenders'] = 'ó sheoltóirí a bhfuil aithne orthu';
$labels['always'] = 'riamh';
$labels['showinlineimages'] = 'Taispeáin na híomhánna ceangailte faoin teachtaireacht';
$labels['autosavedraft'] = 'Sábháil dréachta go huathoibríoch';
$labels['everynminutes'] = 'gach $n nóiméad';
$labels['refreshinterval'] = 'Athnuaigh (lorg teachtaireachtaí nua, agus araile)';
$labels['never'] = 'riamh';
$labels['immediately'] = 'láithreach';
$labels['messagesdisplaying'] = 'Ag taispeáint na teachtaireachtaí';
$labels['messagescomposition'] = 'Ag cumadh na teachtaireachtaí';
$labels['2231folding'] = 'RFC 2231 iomlán (Thunderbird)';
$labels['miscfolding'] = 'RFC 2047/2231 (MS Outlook)';
$labels['2047folding'] = 'RFC 2047 iomlán (eile)';
$labels['advancedoptions'] = 'Ardroghanna';
$labels['toggleadvancedoptions'] = 'Scoránaigh na hardroghanna';
$labels['focusonnewmessage'] = 'Dírigh fuinneog an líonléitheora ar theachtaireacht nua';
$labels['checkallfolders'] = 'Dearbháil gach fillteán do theachtaireachtaí nua';
$labels['mainoptions'] = 'Príomhroghanna';
$labels['browseroptions'] = 'Roghanna líonléitheora';
$labels['section'] = 'Roinn';
$labels['maintenance'] = 'Cothabháil';
$labels['newmessage'] = 'Teachtaireacht Nua';
$labels['signatureoptions'] = 'Roghanna don Síniú';
$labels['whenreplying'] = 'Nuair atá freagra á thabhairt';
$labels['replyempty'] = 'ná luaigh an teachtaireacht bhunaidh';
$labels['replytopposting'] = 'tosaigh an teachtaireacht nua os cionn an lua';
$labels['replybottomposting'] = 'tosaigh an teachtaireacht nua faoin lua';
$labels['newmessageonly'] = 'teachtaireacht nua amháin';
$labels['replyandforwardonly'] = 'freagraí agus teachtaireachtaí curtha ar aghaidh amháin';
$labels['insertsignature'] = 'Ionsáigh an síniú';
$labels['automarkread'] = 'Rianaigh teachtaireachtaí mar léite';
$labels['afternseconds'] = 'tar éis $n soicindí';
$labels['defaultabook'] = 'An leabhar seoltaí réamhshocraithe';
$labels['privatemode'] = 'Príobháideach (Baile)';
$labels['businessmode'] = 'Gnó (Obair)';
$labels['spellcheckoptions'] = 'Roghanna litreora';
$labels['addtodict'] = 'Cuir leis an bhfoclóir é';
$labels['inline'] = 'i líne';
$labels['asattachment'] = 'mar cheangaltán';
$labels['replyalldefault'] = 'freagair uile';
$labels['allmessages'] = 'gach teachtaireacht';
$labels['folder'] = 'Fillteán';
$labels['folders'] = 'Fillteán';
$labels['foldername'] = 'Ainm fillteán';
$labels['subscribed'] = 'Síntiú';
$labels['messagecount'] = 'Teachtaireachtaí';
$labels['create'] = 'Cruthaigh';
$labels['createfolder'] = 'Cruthaigh fillteán nua';
$labels['managefolders'] = 'Stiúir na fillteán';
$labels['specialfolders'] = 'Sainfhillteáin';
$labels['properties'] = 'Airíonna';
$labels['folderproperties'] = 'Airíonna an fhillteáin';
$labels['parentfolder'] = 'An máthairfhillteán';
$labels['location'] = 'Suíomh';
$labels['info'] = 'Faisnéis';
$labels['getfoldersize'] = 'Brúigh chun méid an fhillteáin a fháil';
$labels['foldertype'] = 'An cineál fillteán';
$labels['personalfolder'] = 'Fillteán príobháideach';
$labels['sharedfolder'] = 'Fillteán poiblí';
$labels['findfolders'] = 'Aimsigh fillteáin';
$labels['findmail'] = 'Aimsigh teachtaireachtaí poist';
$labels['namespace.personal'] = 'Pearsanta';
$labels['namespace.other'] = 'Daoine eile';
$labels['namespace.shared'] = 'Comhroinnte';
$labels['dualuselabel'] = 'Ina bhfuil amháin';
$labels['dualusemail'] = 'teachtaireachtaí';
$labels['dualusefolder'] = 'fillteáin';
$labels['generate'] = 'Cruthaigh';
$labels['openmailvelopesettings'] = 'Oscail Socruithe Mailvelope';
$labels['encryption'] = 'Criptiúchán';
$labels['sortby'] = 'Sórtáil trí';
$labels['sortasc'] = 'Sórtáil in ord méadaitheach';
$labels['sortdesc'] = 'Sórtáil in ord neartaitheach';
$labels['undo'] = 'Cealaigh';
$labels['installedplugins'] = 'Breiseáin suiteáilte';
$labels['plugin'] = 'Breiseán';
$labels['version'] = 'Leagan';
$labels['source'] = 'Foinse';
$labels['license'] = 'Ceadúnas';
$labels['support'] = 'Faigh tacaíocht';
$labels['dateformatY'] = 'BBBB';
$labels['dateformaty'] = 'BB';
$labels['dateformatm'] = 'MM';
$labels['dateformatd'] = 'LL';
$labels['dateformatj'] = 'L';
$labels['dateformatn'] = 'M';
$labels['B'] = 'B';
$labels['KB'] = 'KB';
$labels['MB'] = 'MB';
$labels['GB'] = 'GB';
$labels['unicode'] = 'Unicode';
$labels['english'] = 'Béarla';
$labels['westerneuropean'] = 'Iarthar na hEorpach';
$labels['easterneuropean'] = 'Oirthear na hEorpa';
$labels['hebrew'] = 'Eabhrais';
$labels['turkish'] = 'Tuircis';
$labels['celtic'] = 'Ceilteach';
$labels['chinese'] = 'Síneach';
$labels['arialabeltopnav'] = 'Rialtán fuinneoige';
$labels['arialabelmailpreviewframe'] = 'Réamhamharc ar an teachtaireacht';
$labels['arialabelmessagebody'] = 'Corp na Teachtaireachta';
$labels['arialabelmessageactions'] = 'Gníomhartha na teachtaireachta';
$labels['arialabelmessageheaders'] = 'Ceanntáisc na teachtaireachta';
$labels['arialabelforwardingoptions'] = 'Roghanna cur ar aghaidh';
$labels['arialabelmarkmessagesas'] = 'Rianaigh na teachtaireachtaí roghnaithe mar...';
$labels['arialabelcomposeoptions'] = 'Roghanna do chumadh teachtaireachta';
$labels['arialabelattachmentmenu'] = 'Roghanna do cheangaltáin';
$labels['arialabelmailtomenu'] = 'Roghanna do sheoltaí ríomhphoist';
$labels['arialabelattachmentpreview'] = 'Réamhamharc ar cheangaltáin';
$labels['arialabelsearchterms'] = 'Téarmaí cuardaigh';
$labels['arialabelimagetools'] = 'Uirlisí don íomhá';
