<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Archive plugin             |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['buttontext'] = 'Arxiv';
$labels['buttontitle'] = 'Bu xatni arxivlang';
$labels['archived'] = 'Arxivlandi';
$labels['archivedreload'] = 'Arxivlandi. Yangi arxiv papkalarini ko‘rish uchun sahifani qayta yuklang.';
$labels['archiveerror'] = 'Ba‘zi xatlarni arxivlab bo‘lmaydi.';
$labels['archivefolder'] = 'Arxiv';
$labels['settingstitle'] = 'Arxiv';
$labels['archivetype'] = 'Arxivni ... ga ko‘ra bo\'lish';
$labels['archivetypeyear'] = 'Yil (masalan Arxiv/2012)';
$labels['archivetypemonth'] = 'Oy (masalan Arxiv/2012/06)';
$labels['archivetypetbmonth'] = 'Oy Thunderbirdga moslangan (masalan Arxiv/2012/2012-06)';
$labels['archivetypefolder'] = 'Asl papka';
$labels['archivetypesender'] = 'Jo‘natuvchi elektron manzili';
$labels['unkownsender'] = 'noma’lum';
$labels['readonarchive'] = 'Arxivda xatni o‘qilgan deb belgilang';
