<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail ACL plugin                 |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['sharing'] = 'Delen';
$labels['myrights'] = 'Toegangsrechten';
$labels['username'] = 'Gebruiker:';
$labels['advanced'] = 'Geavanceerde modus';
$labels['add'] = 'Voeg toe';
$labels['newuser'] = 'Item toevoegen';
$labels['editperms'] = 'Rechten bewerken';
$labels['actions'] = 'Toegangsrechtenopties...';
$labels['anyone'] = 'Alle gebruikers (iedereen)';
$labels['anonymous'] = 'Gasten (anoniem)';
$labels['identifier'] = 'Identificatie';
$labels['acll'] = 'Opzoeken';
$labels['aclr'] = 'Berichten lezen';
$labels['acls'] = 'Onthoud gelezen-status';
$labels['aclw'] = 'Markeringen instellen';
$labels['acli'] = 'Invoegen (kopiëren naar)';
$labels['aclp'] = 'Plaatsen';
$labels['aclc'] = 'Submappen aanmaken';
$labels['aclk'] = 'Submappen aanmaken';
$labels['acld'] = 'Berichten verwijderen';
$labels['aclt'] = 'Berichten verwijderen';
$labels['acle'] = 'Vernietigen';
$labels['aclx'] = 'Map verwijderen';
$labels['acla'] = 'Beheren';
$labels['acln'] = 'Annoteer berichten';
$labels['aclfull'] = 'Volledige toegang';
$labels['aclother'] = 'Overig';
$labels['aclread'] = 'Lezen';
$labels['aclwrite'] = 'Schrijven';
$labels['acldelete'] = 'Verwijderen';
$labels['shortacll'] = 'Opzoeken';
$labels['shortaclr'] = 'Lezen';
$labels['shortacls'] = 'Behouden';
$labels['shortaclw'] = 'Schrijven';
$labels['shortacli'] = 'Invoegen';
$labels['shortaclp'] = 'Plaatsen';
$labels['shortaclc'] = 'Aanmaken';
$labels['shortaclk'] = 'Aanmaken';
$labels['shortacld'] = 'Verwijderen';
$labels['shortaclt'] = 'Verwijderen';
$labels['shortacle'] = 'Vernietigen';
$labels['shortaclx'] = 'Map verwijderen';
$labels['shortacla'] = 'Beheren';
$labels['shortacln'] = 'Annoteren';
$labels['shortaclother'] = 'Overig';
$labels['shortaclread'] = 'Lezen';
$labels['shortaclwrite'] = 'Schrijven';
$labels['shortacldelete'] = 'Verwijderen';
$labels['longacll'] = 'De map is zichtbaar in lijsten en het is mogelijk om te abonneren op deze map';
$labels['longaclr'] = 'De map kan geopend worden om te lezen';
$labels['longacls'] = 'De berichtmarkering \'Gelezen\' kan aangepast worden';
$labels['longaclw'] = 'Berichtmarkeringen en labels kunnen aangepast worden, behalve \'Gelezen\' en \'Verwijderd\'';
$labels['longacli'] = 'Berichten kunnen opgesteld worden of gekopieerd worden naar deze map';
$labels['longaclp'] = 'Berichten kunnen geplaatst worden in deze map';
$labels['longaclc'] = 'Mappen kunnen aangemaakt of hernoemd worden rechtstreeks onder deze map';
$labels['longaclk'] = 'Mappen kunnen aangemaakt of hernoemd worden rechtstreeks onder deze map';
$labels['longacld'] = 'De berichtmarkering \'Verwijderd\' kan aangepast worden';
$labels['longaclt'] = 'De berichtmarkering \'Verwijderd\' kan aangepast worden';
$labels['longacle'] = 'Berichten kunnen vernietigd worden';
$labels['longaclx'] = 'De map kan verwijderd of hernoemd worden';
$labels['longacla'] = 'De toegangsrechten voor deze map kunnen veranderd worden';
$labels['longacln'] = 'Gedeelde metadata (annotaties) van berichten kan aangepast worden';
$labels['longaclfull'] = 'Volledige controle inclusief mappenbeheer';
$labels['longaclread'] = 'De map kan geopend worden om te lezen';
$labels['longaclwrite'] = 'Berichten kunnen gemarkeerd worden, opgesteld worden of gekopieerd worden naar deze map';
$labels['longacldelete'] = 'Berichten kunnen verwijderd worden';
$labels['longaclother'] = 'Overige toegangsrechten';
$labels['ariasummaryacltable'] = 'Lijst van toegangsrechten';
$labels['arialabelaclactions'] = 'Lijstacties';
$labels['arialabelaclform'] = 'Formulier voor toegangsrechten';
$messages['deleting'] = 'Toegangsrechten worden verwijderd...';
$messages['saving'] = 'Toegangsrechten worden opgeslagen...';
$messages['updatesuccess'] = 'Toegangsrechten succesvol veranderd';
$messages['deletesuccess'] = 'Toegangsrechten succesvol verwijderd';
$messages['createsuccess'] = 'Toegangsrechten succesvol toegevoegd';
$messages['updateerror'] = 'Toegangsrechten kunnen niet bijgewerkt worden';
$messages['deleteerror'] = 'Toegangsrechten kunnen niet verwijderd worden';
$messages['createerror'] = 'Toegangsrechten kunnen niet toegevoegd worden';
$messages['deleteconfirm'] = 'Weet u zeker dat u de toegangsrechten van de geselecteerde gebruiker(s) wilt verwijderen?';
$messages['norights'] = 'Er zijn geen toegangsrechten opgegeven!';
$messages['nouser'] = 'Er is geen gebruikersnaam opgegeven!';
