<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Managesieve plugin         |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['filters'] = 'سۈزگۈچلەر';
$labels['managefilters'] = 'كەلگەن خەت سۈزگۈچلىرىنى باشقۇرۇش';
$labels['filtername'] = 'سۈزگۈچ نامى';
$labels['newfilter'] = 'يېڭى سۈزگۈچ';
$labels['filteradd'] = 'سۈزگۈچ قېتىش';
$labels['filterdel'] = 'سۈزگۈچ ئۆچۈرۈش';
$labels['rules'] = 'قائىدىلەر';
$labels['actions'] = 'ھەركەتلەر';
$labels['scope'] = 'دائىرە';
$labels['moveup'] = 'ئۈستىگە يۆتكەش';
$labels['movedown'] = 'ئاستىغا يۆتكەش';
$labels['filterallof'] = 'تۆۋەندىكى ھەممە قائىدىلەرگە ماس كىلىدىغان';
$labels['filteranyof'] = 'تۆۋەندىكى قائىدىلەرنىڭ بىرىگە ماس كىلىدىغان';
$labels['filterany'] = 'بارلىق خەتلەر';
$labels['filtercontains'] = 'ئۆز-ئىچىگە ئېلىش';
$labels['filternotcontains'] = 'ئۆز-ئىچىگە ئالماسلىق';
$labels['filteris'] = 'تەڭ';
$labels['filterisnot'] = 'تەڭ ئەمەس';
$labels['filterexists'] = 'مەۋجۇت';
$labels['filternotexists'] = 'مەۋجۇت ئەمەس';
$labels['filtermatches'] = 'ئىپادىگە ماس كىلىدۇ';
$labels['filternotmatches'] = 'ئىپادىگە ماس كەلمەيدۇ';
$labels['filterregex'] = 'ئادەتتىكى ئىپادىگە ماس كىلىدۇ';
$labels['filternotregex'] = 'ئادەتتىكى ئىپادىگە ماس كەلمەيدۇ';
$labels['filterunder'] = 'ئاستىدا';
$labels['filterover'] = 'ئۈستىدە';
$labels['mime'] = 'MIME:';
$labels['mimepart'] = 'MIME قىسمى:';
$labels['mime-message'] = 'ئۇچۇر';
$labels['mime-anychild'] = 'ھەرقانداق';
$labels['mime-type'] = 'تۈر';
$labels['mime-subtype'] = 'بالا-تۈر';
$labels['mime-contenttype'] = 'مەزمۇن تۈرى';
$labels['mime-param'] = 'پارامىتىر';
$labels['addrule'] = 'قائىدە قۇشۇش';
$labels['delrule'] = 'قائىدە ئۆچۈرۈش';
$labels['messagemoveto'] = 'خەتنى يۆتكەش';
$labels['messageredirect'] = 'خەتنى يەتكۈزۈش';
$labels['messagecopyto'] = 'خەتنى كۆچۈرۈش';
$labels['messagesendcopy'] = 'خەت كۆچۈرمىسىنى ئەۋەتىش';
$labels['messagereply'] = 'خەت بىلەن جاۋاپ قايتۇرۇش';
$labels['messagedelete'] = 'خەتنى ئۆچۈرۈش';
$labels['messagediscard'] = 'خەت بىلەن تاشلىۋېتىش';
$labels['messagekeep'] = 'خەتنى كىلىش ساندۇقىدا ساقلاش';
$labels['messagesrules'] = 'كەلگەن خەت ئۈچۈن:';
$labels['messagesactions'] = '...تۆۋەندىكى ھەركەتلەرنى ئورۇنداش:';
$labels['add'] = 'قېتىش';
$labels['del'] = 'ئۆچۈرۈش';
$labels['sender'] = 'ئەۋەتكۈچى';
$labels['recipient'] = 'تاپشۇرۋالغۇچى';
$labels['vacationaddr'] = 'مېنىڭ ئېلىخەت ئادىرسلىرىم:';
$labels['vacationdays'] = 'قانچە  ئۇزۇندا (كۈندە) خەت يوللايسىز:';
$labels['vacationinterval'] = 'قانچە ئۇزۇندا خەت يوللايسىز:';
$labels['vacationreason'] = 'خەت مەزمۇنى (تەتىل سەۋەبى):';
$labels['vacationfrom'] = 'ئەۋەتكۈچى ئادىرسىغا جاۋاپ قايتۇرۇش:';
$labels['vacationsubject'] = 'خەت تېمىسى';
$labels['days'] = 'كۈنلەر';
$labels['seconds'] = 'سىكۇنتلار';
$labels['rulestop'] = 'تەكشۈرۈش قائىدىلىرىنى بىكار قىلىش';
$labels['enable'] = 'بار/يوق قىلىش';
$labels['filterset'] = 'سۈزگۈچ يۈرۈشى';
$labels['filtersets'] = 'سۈزگۈچ يۈرۈشلىرى';
$labels['filtersetadd'] = 'سۈزگۈچ يۈرۈشى قېتىش';
$labels['filtersetdel'] = 'سۈزگۈچ يۈرۈشىنى ئۆچۈرۈش';
$labels['filtersetact'] = 'نۆۋەتتىكى سۈزگۈچ يۈرۈشىنى قوزغىتىش';
$labels['filtersetdeact'] = 'نۆۋەتتىكى سۈزگۈچ يۈرۈشىنى توختىتىش';
$labels['filterseteditraw'] = 'سۈزگۈچ يۈرۈشىنى تەھرىرلەش';
$labels['filtersetswitch'] = 'سۈزگۈچ يۈرۈشىنى بار/يوق قىلىش';
$labels['filterdef'] = 'سۈزگۈچ بېكىتىش';
$labels['filtersetname'] = 'سۈزگۈچ يۈرۈشى نامى';
$labels['newfilterset'] = 'يېڭى سۈزگۈچ يۈرۈشى';
$labels['active'] = 'جانلىق';
$labels['none'] = 'يوق';
$labels['fromset'] = 'يۈرۈشتىن';
$labels['fromfile'] = 'ھۆججەتتىن';
$labels['filterdisabled'] = 'سۈزگۈچنى يوق بولدى';
$labels['filterenabled'] = 'سۈزگۈچ بار بولدى';
$labels['countisgreaterthan'] = 'سانىغۇچ بولسا چوڭ';
$labels['countisgreaterthanequal'] = 'سانىغۇچ چوڭ ياكى تەڭ';
$labels['countislessthan'] = 'سانىغۇچ كىچىك';
$labels['countislessthanequal'] = 'سانىغۇچ كىچىك ياكى تەڭ';
$labels['countequals'] = 'سانىغۇچ تەڭ';
$labels['countnotequals'] = 'سانىغۇچ تەڭ ئەمەس';
$labels['valueisgreaterthan'] = 'قىممەت چوڭ';
$labels['valueisgreaterthanequal'] = 'قىممەت چوڭ ياكى تەڭ';
$labels['valueislessthan'] = 'قىممەت كىچىك';
$labels['valueislessthanequal'] = 'قىممەت كىچىك ياكى تەڭ';
$labels['valueequals'] = 'قىممەت تەڭ';
$labels['valuenotequals'] = 'قىممەت تەڭ ئەمەس';
$labels['setflags'] = 'بۇ ئۇچۇرغا بايراق بەلگىلەش';
$labels['addflags'] = 'بۇ ئۇچۇرغا بايراق قېتىش';
$labels['removeflags'] = 'بۇ ئۇچۇردىن بايراقلارنى ئۆچۈرۈش';
$labels['flagread'] = 'ئۇقۇغان';
$labels['flagdeleted'] = 'ئۆچۈرۋەتكەن';
$labels['flaganswered'] = 'جاۋاپ قايتۇرغان';
$labels['flagflagged'] = 'بايراقلانغان';
$labels['flagdraft'] = 'قوليازما';
$labels['addheader'] = 'بۇ خەتكە باشلانما قۇشۇش';
$labels['deleteheader'] = 'بۇ خەتتىن باشلانمىنى ئۆچۈرۈش';
$labels['headername'] = 'باشلانما نامى';
$labels['headervalue'] = 'باشلانما قىممىتى';
$labels['headerpos'] = 'باشلانما ئورنى';
$labels['headeratstart'] = 'باشتا';
$labels['headeratend'] = 'ئاخىردا';
$labels['headeroccurrence'] = 'باشلانما كۆرسىتىش/ئورۇن';
$labels['headerfromstart'] = 'باشلىنىشتىن';
$labels['headerfromend'] = 'ئاخىردىن';
$labels['headerpatterns'] = 'باشلانما قىممەت ئۇسلۇبلىرى';
$labels['headermatchtype'] = 'ماسلىق تۈرى:';
$labels['setvariable'] = 'ئۆزگىرىشچان مىقدار بېكىتىش';
$labels['setvarname'] = 'ئۆزگىرىشچان مىقدار نامى:';
$labels['setvarvalue'] = 'ئۆزگىرىشچان مىقدار قىممىتى:';
$labels['setvarmodifiers'] = 'ئۆزگەرتكۈچ:';
$labels['varlower'] = 'كىچىك';
$labels['varupper'] = 'چوڭ';
$labels['varlowerfirst'] = 'تۇنجى ھەرىپ كىچىك';
$labels['varupperfirst'] = 'تۇنجى ھەرىپ چوڭ';
$labels['varquotewildcard'] = 'ئالاھىدە ھەرىپلەرنى نەقىللەش';
$labels['varlength'] = 'ئۇزۇنلۇق';
$labels['varencodeurl'] = 'پىرسەنت-شىفىرلىق(ئۇلىنىشلار ئۈچۈن)';
$labels['notify'] = 'ئۇقتۇرۇش ئەۋەتىش';
$labels['notifytarget'] = 'ئۇقتۇرۇش نىشانى:';
$labels['notifymessage'] = 'ئۇقتۇرۇش ئۇچۇرى (ئىختىيارى):';
$labels['notifyoptions'] = 'ئۇقتۇرۇش تاللانمىلىرى (ئىختىيارى):';
$labels['notifyfrom'] = 'ئۇقتۇرۇش ئەۋەتكۈچى (ئىختىيارى):';
$labels['notifyimportance'] = 'مۇھىملىقى:';
$labels['notifyimportancelow'] = 'تۆۋەت';
$labels['notifyimportancenormal'] = 'ئوتتۇراھال';
$labels['notifyimportancehigh'] = 'يۇقىرى';
$labels['notifymethodmailto'] = 'ئېلىخەت';
$labels['notifymethodtel'] = 'تېلىفۇن';
$labels['notifymethodsms'] = 'ئۇچۇر';
$labels['filtercreate'] = 'سۈزگۈچ قۇرۇش';
$labels['usedata'] = 'سۈزگۈچتە تۆۋەندىكى ئۇچۇرنى ئىشلىتىڭ:';
$labels['nextstep'] = 'كىيىنكى قەدەم';
$labels['...'] = '...';
$labels['string'] = 'تېكىست';
$labels['currdate'] = 'ھازىرقى چېسلا';
$labels['datetest'] = 'چېسلا';
$labels['dateheader'] = 'باشلانما:';
$labels['year'] = 'يىل';
$labels['month'] = 'ئاي';
$labels['day'] = 'كۈن';
$labels['date'] = 'چېسلا (يىل-ئاي-كۈن)';
$labels['julian'] = 'چېسلا (جۇلىئان)';
$labels['hour'] = 'سائەت';
$labels['minute'] = 'مىنۇت';
$labels['second'] = 'سېكۇنت';
$labels['time'] = 'ۋاقىت (سائەت:مىنۇت:سېكۇنت)';
$labels['iso8601'] = 'چېسلا (ISO8601)';
$labels['std11'] = 'چېسلا (RFC2822)';
$labels['zone'] = 'ۋاقىت رايۇنى';
$labels['weekday'] = 'ھەپتە كۈنلىرى(0-6)';
$labels['advancedopts'] = 'ئالاھىدە تاللانمىلار';
$labels['body'] = 'مەزمۇن';
$labels['address'] = 'ئادىرىس';
$labels['envelope'] = 'كونۋېرت';
$labels['modifier'] = 'ئۆزگەرتكۈچ:';
$labels['text'] = 'تېكىست';
$labels['undecoded'] = 'شىفىرسىزلانمىغان (خام)';
$labels['contenttype'] = 'مەزمۇن تۈرى';
$labels['modtype'] = 'تۈر:';
$labels['allparts'] = 'ھەممە';
$labels['domain'] = 'دائىرە';
$labels['localpart'] = 'يەرلىك قىسىم';
$labels['user'] = 'ئىشلەتكۈچى';
$labels['detail'] = 'تەپسىلات';
$labels['comparator'] = 'سېلىشتۇرما:';
$labels['default'] = 'سۈكۈت';
$labels['octet'] = 'قەتئىي (سەككىرلىك)';
$labels['asciicasemap'] = 'چوڭ-كىچىكلىكى پەرىقسىز (ascii خەرىتىسى)';
$labels['asciinumeric'] = 'سان (ascii-سانلىق)';
$labels['index'] = 'ئىندىكىس:';
$labels['indexlast'] = 'ئارقىغا';
$labels['spamtest'] = 'ئالدامچىلىق دەرىجىسى';
$labels['spamtestisgreaterthan'] = 'چوڭ';
$labels['spamtestisgreaterthanequal'] = 'چوڭ ياكى تەڭ';
$labels['spamtestislessthan'] = 'كىچىك';
$labels['spamtestislessthanequal'] = 'كىچىك ياكى تەڭ';
$labels['spamtestequals'] = 'تەڭ';
$labels['spamtestnotequals'] = 'تەڭ ئەمەس';
$labels['spamtestisunknown'] = 'نامەلۇم';
$labels['vacation'] = 'ئىشخانىنىڭ سىرتىدا';
$labels['vacation.reply'] = 'خەتكە جاۋاپ يېزىش';
$labels['vacation.advanced'] = 'ئالىي تەڭشەكلەر';
$labels['vacation.from'] = 'ئەۋەتكۈچى ئادىرسىغا جاۋاپ قايتۇرۇش';
$labels['vacation.subject'] = 'تېما';
$labels['vacation.body'] = 'مەزمۇن';
$labels['vacation.start'] = 'باشلاش ۋاقتى';
$labels['vacation.end'] = 'ئاخىرلىشىش ۋاقتى';
$labels['vacation.status'] = 'ھالەت';
$labels['vacation.on'] = 'بار';
$labels['vacation.off'] = 'يوق';
$labels['vacation.addresses'] = 'مېنىڭ ئېلىخەت ئادىرسىم';
$labels['vacation.interval'] = 'جاۋاپ قايتۇرۇش ئارلىقى';
$labels['vacation.after'] = 'ئارقىدىن ئىشخانا-سىرتىدا قائىدىسىنى قۇيۇش';
$labels['vacation.saving'] = 'ئۇچۇرنى ساقلاۋاتىدۇ...';
$labels['vacation.action'] = 'كەلگەن خەت ھەركىتى';
$labels['vacation.keep'] = 'ساقلاش';
$labels['vacation.discard'] = 'تاشلاش';
$labels['vacation.redirect'] = 'يەتكۈزۈش';
$labels['vacation.copy'] = 'بىر نۇسخىسىنى ئەۋەتىش';
$labels['forward'] = 'يەتكۈزۈش';
$labels['forward.redirect'] = 'يەتكۈزۈش';
$labels['forward.copy'] = 'بىر نۇسخىسىنى ئەۋەتىش';
$labels['forward.on'] = 'بار';
$labels['forward.off'] = 'يوق';
$labels['forward.status'] = 'ھالەت:';
$labels['forward.action'] = 'كەلگەن خەتلەرگە تۆۋەندىكى ھەركەتنى ئورۇنداڭ:';
$labels['forward.saving'] = 'ئۇچۇرنى ساقلاۋاتىدۇ...';
$labels['filladdresses'] = 'مېنىڭ بارلىق ئادىرسلىرىم بىلەن تولدۇرۇڭ';
$labels['arialabelfiltersetactions'] = 'سۈزگۈچ يۈرۈشى ھەركىتى';
$labels['arialabelfilteractions'] = 'سۈزگۈچ ھەركەتلىرى';
$labels['arialabelfilterform'] = 'سۈزگۈچ خاسلىقى';
$labels['ariasummaryfilterslist'] = 'سۈزگۈچلەرنى تىزىش';
$labels['ariasummaryfiltersetslist'] = 'سۈزگۈچ يۈرۈشى تىزىملىكى';
$labels['filterstitle'] = 'كەلگەن خەت سۈزگۈچلىرىنى تەھرىرلەش';
$labels['vacationtitle'] = 'ئىشخانا-سىرتىدا قائىدىسىنى تەھرىرلەش';
$labels['forwardtitle'] = 'خەت يەتكۈزۈش قائىدىسىنى تەھرىرلەش';
$labels['message'] = 'ئۇچۇر';
$labels['duplicate'] = 'تەكرارلانغان';
$labels['notduplicate'] = 'تەكرارلانمىغان';
$labels['duplicate.handle'] = 'بىر-تەرەپ قىلىش:';
$labels['duplicate.header'] = 'باشلانما:';
$labels['duplicate.uniqueid'] = 'بەلگە:';
$labels['duplicate.seconds'] = 'قالغان ۋاقىت(سىكۇنتلار):';
$labels['duplicate.last'] = 'ئاخىرقى ئىجراغا نىسپىي';
$messages['filterunknownerror'] = 'نامەلۇم مۇلازىمېتىر خاتالىقى.';
$messages['filterconnerror'] = 'مۇلازىمېتىرغا ئۇلىغىلى بولمىدى.';
$messages['filterdeleteerror'] = 'سۈزگۈچنى ئۆچۈرگىلى بولمىدى. مۇلازىمېتىر خاتالىقى كۆرۈلدى.';
$messages['filterdeleted'] = 'سۈزگۈچ مۇۋاپىقىيەتلىك ئۆچۈرۈلدى.';
$messages['filtersaved'] = 'سۈزگۈچ مۇۋاپىقىيەتلىك ساقلاندى.';
$messages['filtersaveerror'] = 'سۈزگۈچنى ساقلىغىلى بولمىدى. مۇلازىمېتىر خاتالىقى كۆرۈلدى.';
$messages['filterformerror'] = 'سۈزگۈچ جەدىۋېلىدە خاتالىق بار.';
$messages['filterdeleteconfirm'] = 'سىز تاللانغان سۈزگۈچنى راستىنلا ئۆچۈرەمسىز؟';
$messages['ruledeleteconfirm'] = 'سىز تاللانغان قائىدىنى راستىنلا ئۆچۈرەمسىز؟';
$messages['actiondeleteconfirm'] = 'سىز تاللانغان ھەركەتنى راستىنلا ئۆچۈرەمسىز؟';
$messages['forbiddenchars'] = 'ئارلىقتا مەنئىي قىلىنغان بەلگىلەر بار.';
$messages['cannotbeempty'] = 'بۇ ئورۇن بوش قالسا بولمايدۇ.';
$messages['ruleexist'] = 'بۇ ئىسىمدىكى سۈزگۈچ مەۋجۇت.';
$messages['setactivateerror'] = 'تاللانغان سۈزگۈچ يۈرۈشىنى قوزغاتقىلى بولمىدى. مۇلازىمىتىر خاتالىقى كۆرۈلدى.';
$messages['setdeactivateerror'] = 'تاللانغان سۈزگۈچ يۈرۈشىنى توختاتقىلى بولمىدى. مۇلازىمېتىر خاتالىقى كۆرۈلدى.';
$messages['setdeleteerror'] = 'تاللانغان سۈزگۈچ يۈرۈشىنى ئۆچۈرگىلى بولمىدى. مۇلازىمېتىر خاتالىقى كۆرۈلدى.';
$messages['setactivated'] = 'سۈزگۈچ يۈرۈشى مۇۋاپىقىيەتلىك قوزغىتىلدى.';
$messages['setdeactivated'] = 'سۈزگۈچ يۈرۈشى مۇۋاپىقىيەتلىك توختىتىلدى.';
$messages['setdeleted'] = 'سۈزگۈچ يۈرۈشى مۇۋاپىقىيەتلىك ئۆچۈرۈلدى.';
$messages['setupdated'] = 'سۈزگۈچ يۈرۈشى مۇۋاپىقىيەتلىك يېڭىلاندى.';
$messages['setdeleteconfirm'] = 'سىز تاللانغان سۈزگۈچ يۈرۈشىنى ئۆچۈرۈشنى جەزىملەشتۈرەمسىز؟';
$messages['setcreateerror'] = 'سۈزگۈچ يۈرۈشىنى قۇرۇشقا بولمىدى. مۇلازىمېتىر خاتالىقى كۆرۈلدى.';
$messages['setcreated'] = 'سۈزگۈچ يۈرۈشى مۇۋاپىقىيەتلىك قۇرۇلدى.';
$messages['activateerror'] = 'تاللانغان سۈزگۈچ(لەر)نى قوزغاتقىلى بولمىدى. مۇلازىمېتىر خاتالىقى كۆرۈلدى.';
$messages['deactivateerror'] = 'تاللانغان سۈزگۈچ(لەر)نى توختاتقىلى بولمىدى. مۇلازىمېتىر خاتالىقى كۆرۈلدى.';
$messages['deactivated'] = 'سۈزگۈچ(لەر) مۇۋاپىقىيەتلىك توختىدى.';
$messages['activated'] = 'سۈزگۈچ(لەر) مۇۋاپىقىيەتلىك قوزغالدى.';
$messages['moved'] = 'سۈزگۈچ مۇۋاپىقىيەتلىك يۆتكەلدى.';
$messages['moveerror'] = 'تاللانغان سۈزگۈچنى يۆتكىگىلى بولمىدى. مۇلازىمېتىر خاتالىقى كۆرۈلدى.';
$messages['nametoolong'] = 'ئىسىم بەك ئۇزۇن.';
$messages['namereserved'] = 'ئالاھىدە ھوقوقلۇق ئىسىم.';
$messages['setexist'] = 'يۈرۈش ئاللىبۇرۇن مەۋجۇت.';
$messages['nodata'] = 'ئەڭ كەمدە بىر ئورۇن تاللىنىشى كېرەك!';
$messages['invaliddateformat'] = 'ئىناۋەتسىز چېسلا ياكى چېسلا شەكلى';
$messages['saveerror'] = 'ئۇچۇرنى ساقلىغىلى بولمىدى. مۇلازىمېتىر خاتالىقى كۆرۈلدى.';
$messages['vacationsaved'] = 'ئىشخانا-سىرتىدا ئۇچۇرى مۇۋاپىقىيەتلىك ساقلاندى.';
$messages['forwardsaved'] = 'يەتكۈزۈش ئۇچۇرى مۇۋاپىقىيەتلىك ساقلاندى.';
$messages['emptyvacationbody'] = 'تەتىل خېتىنىڭ مەزمۇنى تەلەپ قىلىندى!';
$messages['duplicate.conflict.err'] = 'باشلانما ھەمدە ئۆزگىچە بەلگىنىڭ ھەر ئىككىلىسىگە يول قۇيۇلمايدۇ.';
$messages['disabledaction'] = 'ھەركەتكە يول قۇيۇلمايدۇ.';
$messages['lastindexempty'] = 'ئاخىردىن سانىغاندا ئىندىكىس تەلەپ قىلىنىدۇ';
$messages['noflagset'] = 'ئەڭ كەمدە بىر بايراق تاللىنىشى كېرەك.';
