<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail ACL plugin                 |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['sharing'] = 'Споделяне';
$labels['myrights'] = 'Права за достъп';
$labels['username'] = 'Потребител:';
$labels['advanced'] = 'Разширен режим';
$labels['add'] = 'Добави';
$labels['newuser'] = 'Добавяне на запис';
$labels['editperms'] = 'Редакция на права';
$labels['actions'] = 'Действия на права за достъп...';
$labels['anyone'] = 'Всички потребители (който и да е)';
$labels['anonymous'] = 'Гости (анонимни)';
$labels['identifier'] = 'Индентификатор';
$labels['acll'] = 'Претърсване';
$labels['aclr'] = 'Четене на писма';
$labels['acls'] = 'Запазване на Видяно';
$labels['aclw'] = 'Записване на флагове';
$labels['acli'] = 'Вмъкване (Копиране в)';
$labels['aclp'] = 'Изпращане';
$labels['aclc'] = 'Създаване на подпапки';
$labels['aclk'] = 'Създаване на подпапки';
$labels['acld'] = 'Изтриване на писма';
$labels['aclt'] = 'Изтриване на писмо';
$labels['acle'] = 'Заличаване';
$labels['aclx'] = 'Изтриване на папка';
$labels['acla'] = 'Администриране';
$labels['acln'] = 'Анотиране на писма';
$labels['aclfull'] = 'Пълен контрол';
$labels['aclother'] = 'Други';
$labels['aclread'] = 'Четене';
$labels['aclwrite'] = 'Писане';
$labels['acldelete'] = 'Изтриване';
$labels['shortacll'] = 'Търсене';
$labels['shortaclr'] = 'Четене';
$labels['shortacls'] = 'Запазване';
$labels['shortaclw'] = 'Писане';
$labels['shortacli'] = 'Вмъкване';
$labels['shortaclp'] = 'Изпращане';
$labels['shortaclc'] = 'Създаване';
$labels['shortaclk'] = 'Създаване';
$labels['shortacld'] = 'Изтриване';
$labels['shortaclt'] = 'Изтриване';
$labels['shortacle'] = 'Заличаване';
$labels['shortaclx'] = 'Изтриване на папка';
$labels['shortacla'] = 'Администриране';
$labels['shortacln'] = 'Анотирай';
$labels['shortaclother'] = 'Други';
$labels['shortaclread'] = 'Четене';
$labels['shortaclwrite'] = 'Писане';
$labels['shortacldelete'] = 'Изтриване';
$labels['longacll'] = 'Папката е видима в списъците и може да се абонирате';
$labels['longaclr'] = 'Папката може да бъде отворена за четене';
$labels['longacls'] = 'Флаг Видяно може да бъде променен.';
$labels['longaclw'] = 'Флаговете и кл. думи за писмата могат да бъдат променяни, без Видяно и Изтрито.';
$labels['longacli'] = 'Писмата могат да бъдат писани или копирани към папката.';
$labels['longaclp'] = 'Писмата могат да бъдат писани в папката';
$labels['longaclc'] = 'Папките могат да бъдат създавани (или преименувани) директно в тази папка';
$labels['longaclk'] = 'Папките могат да бъдат създавани (или преименувани) в тази основна папка';
$labels['longacld'] = 'Флагът Изтрито може да бъде променян';
$labels['longaclt'] = 'Флагът Изтрито може да бъде променян';
$labels['longacle'] = 'Писмата могат да бъдат заличавани';
$labels['longaclx'] = 'Папката може да бъде изтривана или преименувана';
$labels['longacla'] = 'Правата за достъп до папката могат да бъдат променяни';
$labels['longacln'] = 'Могат да се променят споделените метаданни (анотации) на писмата';
$labels['longaclfull'] = 'Пълен контрол, включително и администриране на папките';
$labels['longaclread'] = 'Папката може да бъде отворена за четене';
$labels['longaclwrite'] = 'Писмата могат да бъдат маркирани, записвани или копирани в папката';
$labels['longacldelete'] = 'Писмата могат да бъдат изтривани';
$labels['longaclother'] = 'Други права за достъп';
$labels['ariasummaryacltable'] = 'Списък с права за достъп';
$labels['arialabelaclactions'] = 'Списък с действия';
$labels['arialabelaclform'] = 'Форма с права за достъп';
$messages['deleting'] = 'Изтриване на права за достъп...';
$messages['saving'] = 'Запазване на права за достъп...';
$messages['updatesuccess'] = 'Правата за достъп са променени успешно';
$messages['deletesuccess'] = 'Правата за достъп са изтрити успешно';
$messages['createsuccess'] = 'Правата за достъп са добавени успешно';
$messages['updateerror'] = 'Невъзможно модифициране на правата за достъп';
$messages['deleteerror'] = 'Невъзможно изтриване на права за достъп';
$messages['createerror'] = 'Невъзможно добавяне на права за достъп';
$messages['deleteconfirm'] = 'Сигурни ли сте, че желаете да премахнате правата за достъп от избраните потребители?';
$messages['norights'] = 'Няма указани права!';
$messages['nouser'] = 'Няма указано потребителско име!';
