<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail New Mail Notifier plugin   |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['basic'] = 'Amosar notificacións no navegador cando entre unha mensaxe nova';
$labels['desktop'] = 'Amosar notificacións no escritorio cando entre unha mensaxe nova';
$labels['sound'] = 'Reproducir un son cando entre unha mensaxe nova';
$labels['test'] = 'Proba';
$labels['title'] = 'Correo novo!';
$labels['body'] = 'Recibiches unha nova mensaxe.';
$labels['testbody'] = 'Esta é unha notificación de proba.';
$labels['desktopdisabled'] = 'As notificacións de escritorio están desactivadas no teu navegador.';
$labels['desktopunsupported'] = 'O teu navegador non soporta notificacións de escritorio.';
$labels['desktoptimeout'] = 'Pechar notificación de escritorio';
