<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$messages['errortitle']  = 'Ocurreu un erro!';
$messages['loginfailed']  = 'Erro ao iniciar sesión.';
$messages['cookiesdisabled'] = 'O teu navegador non acepta cookies.';
$messages['sessionerror'] = 'A túa sesión non é válida ou expirou.';
$messages['cookiesmismatch'] = 'Detectouse un erro nas cookies. Por favor, borra as cookies do teu navegador.';
$messages['storageerror'] = 'Erro na conexión co servidor IMAP.';
$messages['servererror'] = 'Erro do servidor!';
$messages['servererrormsg'] = 'Erro do servidor: $msg';
$messages['accountlocked'] = 'Demasiados intentos de inicio de sesión sen éxito. Inténtao máis tarde.';
$messages['connerror'] = 'Erro de conexión (non se puido acceder ao servidor)!';
$messages['dberror'] = 'Erro da base de datos!';
$messages['dbconnerror'] = 'Non é posible conectarse á base de datos!';
$messages['windowopenerror'] = 'Bloqueouse a ventá emerxente!';
$messages['requesttimedout'] = 'A solicitude expirou';
$messages['errorreadonly'] = 'Non é posible realizar a operación. O cartafol é de só lectura.';
$messages['errornoperm'] = 'Non é posible realizar a operación. Permiso denegado.';
$messages['erroroverquota'] = 'Non é posible realizar a operación. Non hai espazo libre no disco.';
$messages['erroroverquotadelete'] = 'Non hai espazo libre no disco. Usa Maiús+Supr para borrar unha mensaxe.';
$messages['invalidrequest'] = 'Solicitude non válida! Non se gardou ningún dato.';
$messages['invalidhost'] = 'O nome do servidor non é válido.';
$messages['nomessagesfound'] = 'Non se atoparon mensaxes nesta caixa de correo.';
$messages['loggedout'] = 'Pechaches a sesión con éxito. Ata pronto!';
$messages['mailboxempty'] = 'A caixa de correo está baleira';
$messages['nomessages'] = 'Non hai mensaxes';
$messages['refreshing'] = 'Refrescando...';
$messages['loading'] = 'Cargando...';
$messages['uploading'] = 'Cargando arquivo...';
$messages['attaching'] = 'Anexando arquivo...';
$messages['uploadingmany'] = 'Cargando arquivos...';
$messages['loadingdata'] = 'Cargando datos...';
$messages['checkingmail'] = 'Buscando novas mensaxes...';
$messages['sendingmessage'] = 'Enviando mensaxe...';
$messages['messagesent'] = 'A mensaxe enviouse correctamente.';
$messages['savingmessage'] = 'Gardando mensaxe...';
$messages['messagesaved'] = 'A mensaxe gardouse en Borradores.';
$messages['successfullysaved'] = 'Gardado correctamente.';
$messages['savingresponse'] = 'Gardando resposta...';
$messages['deleteresponseconfirm'] = 'Seguro/a que queres borrar esta resposta?';
$messages['nocontactselected'] = 'Aínda non seleccionaches ningún contacto.';
$messages['addedsuccessfully'] = 'Contacto engadido con éxito á axenda de enderezos.';
$messages['contactexists'] = 'Xa existe un contacto co mesmo enderezo electrónico.';
$messages['contactnameexists'] = 'Xa existe un contacto con este nome.';
$messages['blockedimages'] = 'As imaxes remotas están bloqueadas nesta mensaxe para protexer a túa privacidade.';
$messages['blockedresources'] = 'Bloqueáronse os recursos remotos para protexer a túa privacidade.';
$messages['suspiciousemail'] = 'Esta mensaxe contén enderezos electrónicos sospeitosos que poden ser fraudulentos.';
$messages['bccemail'] = 'As mensaxes reenviadas conteñen destinatarios confidenciais (CCO).';
$messages['bouncehint'] = 'A mensaxe enviarase sen modificacións, é dicir, utilizando o corpo, as cabeceiras e os destinatarios orixinais.';
$messages['encryptedmessage'] = 'Sentímolo! Non é posible amosar a mensaxe porque está cifrada.';
$messages['externalmessagedecryption'] = 'Trátase dunha mensaxe cifrada que pode descifrarse coa extensión do teu navegador.';
$messages['nopubkeyfor'] = 'Non se atopou unha clave pública válida para $email';
$messages['nopubkeyforsender'] = 'Non se atopou ningunha clave pública válida para a túa identidade de remitente. Desexas cifrar a mensaxe só para os destinatarios?';
$messages['encryptnoattachments'] = 'Non é posible cifrar os arquivos anexos xa cargados. Volve engadilos no editor de cifraxe.';
$messages['searchpubkeyservers'] = 'Queres buscar as claves perdidas nos servidores de claves públicas?';
$messages['encryptpubkeysfound'] = 'Atopáronse as seguintes claves públicas:';
$messages['keyservererror'] = 'Non se puido obter a clave do servidor de claves.';
$messages['keyimportsuccess'] = 'Clave pública $key importada correctamente no teu almacén de claves.';
$messages['nocontactsfound'] = 'Non se atoparon contactos.';
$messages['contactnotfound'] = 'Non se atopou o contacto solicitado.';
$messages['contactsearchonly'] = 'Tes que utilizar un formulario de busca para ver os contactos da axenda seleccionada.';
$messages['sendingfailed'] = 'Non se puido enviar a mensaxe.';
$messages['senttooquickly'] = 'Por favor, agarda $sec segundo(s) antes de enviar esta mensaxe.';
$messages['errorsavingsent'] = 'Produciuse un erro ao gardar a mensaxe enviada.';
$messages['errorsaving'] = 'Produciuse un erro ao gardar.';
$messages['errormoving'] = 'Non foi posible mover a(s) mensaxe(s).';
$messages['errorcopying'] = 'Non foi posible copiar a(s) mensaxe(s).';
$messages['errordeleting'] = 'Non foi posible eliminar a(s) mensaxe(s).';
$messages['errormarking'] = 'Non foi posible marcar a(s) mensaxe(s).';
$messages['alerttitle'] = 'Atención';
$messages['confirmationtitle'] = 'Estás seguro/a...';
$messages['deletecontactconfirm']  = 'Seguro/a que queres eliminar o(s) contacto(s) seleccionado(s)?';
$messages['deletegroupconfirm']  = 'Seguro/a que queres eliminar o grupo seleccionado?';
$messages['deletemessagesconfirm'] = 'Seguro/a que queres eliminar a(s) mensaxe(s) seleccionadas?';
$messages['deletefolderconfirm']  = 'Seguro/a que queres eliminar este cartafol?';
$messages['movefolderconfirm']  = 'Seguro/a que queres mover este cartafol?';
$messages['purgefolderconfirm']  = 'Seguro/a que queres eliminar todas as mensaxes neste cartafol?';
$messages['contactdeleting'] = 'Eliminando o(s) contacto(s)...';
$messages['groupdeleting'] = 'Eliminando o grupo...';
$messages['folderdeleting'] = 'Eliminando o cartafol...';
$messages['foldermoving'] = 'Movendo o cartafol...';
$messages['foldersubscribing'] = 'Subscribindo o cartafol...';
$messages['folderunsubscribing'] = 'Desubscribindo o cartafol...';
$messages['formincomplete'] = 'O formulario non se cubriu por completo.';
$messages['noemailwarning'] = 'Por favor, engade un enderezo electrónico válido.';
$messages['nonamewarning']  = 'Por favor, engade un nome.';
$messages['nopagesizewarning'] = 'Por favor, engade un tamaño de páxina.';
$messages['nosenderwarning'] = 'Por favor, introduce o enderezo electrónico do remitente.';
$messages['recipientsadded'] = 'Destinatario(s) engadido(s) correctamente.';
$messages['norecipientwarning'] = 'Por favor, engade polo menos un destinatario.';
$messages['disclosedrecipwarning'] = 'Todos os destinatarios verán os enderezos electrónico dos demais. Para evitalo e protexer a súa privacidade, podes usar o campo CCO.';
$messages['disclosedreciptitle'] = 'Demasiados destinatarios públicos';
$messages['nosubjectwarning']  = 'O campo "Asunto" está baleiro. Queres completalo?';
$messages['nosubjecttitle']  = 'Sen asunto';
$messages['nobodywarning'] = 'Queres enviar esta mensaxe sen texto?';
$messages['notsentwarning'] = 'A mensaxe non se enviou e hai cambios sen gardar. Queres descartar os cambios?';
$messages['restoresavedcomposedata'] = 'Atopouse unha mensaxe redactada sen enviar.\n\nSubject: $subject\nSaved: $date\n\nQueres restaurar esta mensaxe?';
$messages['nosearchname'] = 'Por favor, engade un nome de contacto ou un enderezo electrónico.';
$messages['notuploadedwarning'] = 'Aínda non se cargaron tódolos ficheiros. Por favor, agarde ou cancele a carga.';
$messages['searchsuccessful'] = 'Atopáronse $nr mensaxes.';
$messages['contactsearchsuccessful'] = 'Atopáronse $nr contactos.';
$messages['searchnomatch'] = 'A busca non atopou coincidencias.';
$messages['searching'] = 'Buscando...';
$messages['checking'] = 'Comprobando...';
$messages['stillsearching'] = 'Seguimos buscando...';
$messages['nospellerrors'] = 'Non se atoparon erros ortográficos.';
$messages['folderdeleted'] = 'Cartafol eliminado correctamente.';
$messages['foldersubscribed'] = 'Cartafol subscrito correctamente.';
$messages['folderunsubscribed'] = 'Cartafol desubscrito correctamente.';
$messages['folderpurged'] = 'Cartafol baleirado correctamente.';
$messages['folderexpunged'] = 'Cartafol compactado correctamente.';
$messages['deletedsuccessfully'] = 'Eliminado correctamente.';
$messages['converting'] = 'Eliminando o formato da mensaxe...';
$messages['messageopenerror'] = 'Non foi posible cargar a mensaxe desde o servidor.';
$messages['filelinkerror'] = 'Erro ao anexar o arquivo.';
$messages['fileuploaderror'] = 'Erro ao cargar o arquivo.';
$messages['csvfilemismatch'] = 'Non é posible importar varios arquivos CSV con campos diferentes.';
$messages['filesizeerror'] = 'O arquivo cargado supera o tamaño máximo de $size.';
$messages['filecounterror'] = 'Podes cargar un máximo de $count arquivos á vez.';
$messages['msgsizeerror'] = 'Non se puido anexar un arquivo. Superouse o tamaño máximo dunha mensaxe ($size).';
$messages['msgsizeerrorfwd'] = 'Superouse o tamaño máximo dunha mensaxe ($size). Non se anexaron $num mensaxe(s).';
$messages['copysuccess'] = '$nr contactos copiados correctamente.';
$messages['movesuccess'] = '$nr contactos movidos correctamente.';
$messages['copyerror'] = 'Non foi posible copiar ningún contacto.';
$messages['moveerror'] = 'Non foi posible mover ningún contacto.';
$messages['sourceisreadonly'] = 'Este enderezo de orixe é de só lectura.';
$messages['errorsavingcontact'] = 'Non foi posible gardar o enderezo de contacto.';
$messages['movingmessage'] = 'Movendo a(s) mensaxe(s)...';
$messages['copyingmessage'] = 'Copiando a(s) mensaxe(s)...';
$messages['copyingcontact'] = 'Copiando o(s) contacto(s)...';
$messages['movingcontact'] = 'Movendo o(s) contacto(s)...';
$messages['deletingmessage'] = 'Eliminando a(s) mensaxe(s)...';
$messages['markingmessage'] = 'Marcando a(s) mensaxe(s)...';
$messages['addingmember'] = 'Engadindo o(s) contacto(s) ao grupo...';
$messages['removingmember'] = 'Eliminando o(s) contacto(s) do grupo...';
$messages['receiptsent'] = 'Confirmación de lectura enviada correctamente.';
$messages['errorsendingreceipt'] = 'Non foi posible enviar a confirmación de lectura.';
$messages['deleteidentityconfirm'] = 'Seguro/a que queres eliminar esta identidade?';
$messages['nodeletelastidentity'] = 'Non podes eliminar esta identidade, é a última.';
$messages['forbiddencharacter'] = 'O nome do cartafol contén un carácter non válido.';
$messages['selectimportfile'] = 'Por favor, escolle un arquivo para cargar.';
$messages['addresswriterror'] = 'Non é posible escribir na axenda de enderezos escollida.';
$messages['contactaddedtogroup'] = 'Contactos engadidos correctamente a este grupo.';
$messages['contactremovedfromgroup'] = 'Contactos eliminados correctamente deste grupo.';
$messages['nogroupassignmentschanged'] = 'Non cambiou ningunha asignación de grupo.';
$messages['importwait'] = 'Importando, por favor agarda...';
$messages['importformaterror'] = 'Erro de importación! O arquivo cargado non é un arquivo de importación válido.';
$messages['importconfirm'] = '<b>$inserted contactos importados correctamente</b>';
$messages['importconfirmskipped'] = '$skipped entradas existentes omitidas';
$messages['importconfirminvalid'] = '$skipped entradas non válidas omitidas';
$messages['importconfirmerrors'] = 'Non se importaron $errors entradas válidas';
$messages['importmessagesuccess'] = '$nr mensaxes importadas correctamente';
$messages['importmessageerror'] = 'Erro de importación! O arquivo cargado non é un arquivo de correo nin unha mensaxe válida';
$messages['opnotpermitted'] = 'Operación non permitida!';
$messages['nofromaddress'] = 'Falta o enderezo electrónico na identidade seleccionada.';
$messages['editorwarning'] = 'Cambiar o tipo de editor pode facer que se perda o formato do texto. Queres continuar?';
$messages['httpreceivedencrypterror'] = 'Produciuse un erro fatal de configuración. Contacta co administrador inmediatamente. <b>Non se enviou a túa mensaxe.</b>';
$messages['smtpconnerror'] = 'Erro SMTP ($code): Erro de conexión co servidor.';
$messages['smtpautherror'] = 'Erro SMTP ($code): Erro de autenticación.';
$messages['smtpfromerror'] = 'Erro SMTP ($code): Erro ao establecer o remitente "$from" ($msg).';
$messages['smtptoerror'] = 'Erro SMTP ($code): Erro ao engadir o destinatario "$to" ($msg).';
$messages['smtprecipientserror'] = 'Erro SMTP: Non é posible analizar a lista de destinatarios.';
$messages['smtputf8error'] = 'Erro SMTP: O servidor non admite Unicode no enderezo electrónico.';
$messages['smtpsizeerror'] = 'Erro SMTP: O tamaño da mensaxe supera o límite do servidor ($limit)';
$messages['smtperror'] = 'Erro SMTP: $msg';
$messages['emailformaterror'] = 'Enderezo electrónico non válido: $email';
$messages['toomanyrecipients'] = 'Demasiados destinatarios. Reduce o número de destinatarios a $max.';
$messages['maxgroupmembersreached'] = 'O número de integrantes do grupo supera o máximo de $max.';
$messages['internalerror'] = 'Produciuse un erro interno. Por favor, inténtao de novo.';
$messages['contactdelerror'] = 'Non foi posible eliminar o(s) contacto(s).';
$messages['contactdeleted'] = 'Contacto(s) eliminado(s) correctamente.';
$messages['contactrestoreerror'] = 'Non foi posible restaurar o(s) contacto(s) eliminado(s).';
$messages['contactrestored'] = 'Contacto(s) restaurado(s) correctamente.';
$messages['groupdeleted'] = 'Grupo eliminado correctamente.';
$messages['grouprenamed'] = 'Nome do grupo cambiado correctamente.';
$messages['groupcreated'] = 'Grupo creado correctamente.';
$messages['savedsearchdeleted'] = 'Busca gardada eliminada correctamente.';
$messages['savedsearchdeleteerror'] = 'Non foi posible eliminar a busca gardada.';
$messages['savedsearchcreated'] = 'Busca gardada creada correctamente.';
$messages['savedsearchcreateerror'] = 'Non foi posible crear a busca gardada.';
$messages['messagedeleted'] = 'Mensaxe(s) borrada(s) correctamente.';
$messages['messagemoved'] = 'Mensaxe(s) movida(s) correctamente.';
$messages['messagemovedtotrash'] = 'Mensaxe(s) movida(s) á Papeleira correctamente.';
$messages['messagecopied'] = 'Mensaxe(s) copiada(s) correctamente.';
$messages['messagemarked'] = 'Mensaxe(s) marcada(s) correctamente.';
$messages['autocompletechars'] = 'Introduce polo menos $min caracteres para autocompletar.';
$messages['autocompletemore'] = 'Atopáronse máis entradas concidentes. Por favor, introduce máis caracteres.';
$messages['namecannotbeempty'] = 'O nome non pode estar baleiro.';
$messages['nametoolong'] = 'O nome é demasiado longo.';
$messages['namedotforbidden'] = 'O nome do cartafol non pode empezar por un punto.';
$messages['folderupdated'] = 'Cartafol actualizado correctamente.';
$messages['foldercreated'] = 'Cartafol creado correctamente.';
$messages['invalidimageformat'] = 'O formato da imaxe non é válido.';
$messages['mispellingsfound'] = 'Atopáronse erros ortográficos na mensaxe.';
$messages['parentnotwritable'] = 'Non é posible crear o cartafol ou movelo para o cartafol principal seleccionado porque non tes permisos.';
$messages['messagetoobig'] = 'A mensaxe é demasiado longa para procesala.';
$messages['attachmentvalidationerror'] = 'Este anexo é sospeitoso porque o seu tipo de editor non coincide co declarado na mensaxe. Se non confías no remitente, non debes abrilo porque pode conter contido malicioso.<br/><br/><em>Prevista: $expected; detectada: $detected</em>';
$messages['noscriptwarning'] = 'Atención: Este servicio de correo web precisa de Javascript!. Por favor, active javascript na configuración do seu navegador. ';
$messages['messageissent'] = 'A mensaxe xa se enviou, pero aínda non se gardou. Queres gardala agora?';
$messages['errnotfound'] = 'Arquivo non atopado';
$messages['errnotfoundexplain'] = 'Non se atopou o recurso solicitado!';
$messages['errfailedrequest'] = 'Solicitude denegada.';
$messages['errauthorizationfailed'] = 'Autorización denegada.';
$messages['errunauthorizedexplain'] = 'Non se puido verificar que esteas autorizado para acceder a este servizo.';
$messages['errrequestcheckfailed'] = 'Solicitude de comprobación denegada.';
$messages['errcsrfprotectionexplain'] = "Para a túa protección, o acceso a este recurso está protexido contra CSRF.\nlfSe ves isto, probablemente non pechaches a sesión antes de saír da aplicación web.\n\nAgora requírese interacción humana para continuar.";
$messages['errcontactserveradmin'] = 'Por favor, contacta co administrador do teu servidor.';
$messages['clicktoresumesession'] = 'Pulsa aquí para recuperar a túa sesión anterior';
$messages['errcomposesession'] = 'Erro de sesión de redacción';
$messages['errcomposesessionexplain'] = 'Non se atopou a sesión de redacción solicitada.';
$messages['clicktocompose'] = 'Pulsa aquí para redactar unha nova mensaxe';
$messages['nosupporterror'] = 'O teu navegador non admite esta función.';
$messages['siginserted'] = 'Sinatura introducida correctamente.';
$messages['responseinserted'] = 'Resposta introducida correctamente.';
$messages['noresponsesavailable'] = 'Non hai respostas dispoñibles.';
$messages['listempty'] = 'A lista está baleira.';
$messages['listusebutton'] = 'Usa o botón Crear para engadir un novo rexistro.';
$messages['keypaircreatesuccess'] = 'Novo par de claves creado para $identity.';
$messages['emptyattachment'] = 'Este anexo parece estar baleiro.<br>Por favor, consúltao coa persoa que o enviou.';
$messages['oauthloginfailed'] = 'Erro ao iniciar sesión OAuth. Por favor, inténtao de novo.';
$messages['oauthinvalidrequest'] = 'A petición de autorización foi inválida ou incompleta. ';
$messages['oauthaccessdenied'] = 'O servidor de autorización ou o usuario denegaron a solicitude';
