<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail ACL plugin                 |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['sharing'] = '共享';
$labels['myrights'] = '访问权限';
$labels['username'] = '用户：';
$labels['advanced'] = '高级模式';
$labels['add'] = '添加';
$labels['newuser'] = '新增条目';
$labels['editperms'] = '编辑权限';
$labels['actions'] = '权限设置...';
$labels['anyone'] = '所有用户(任何人)';
$labels['anonymous'] = '来宾(匿名)';
$labels['identifier'] = '标识符';
$labels['acll'] = '查找';
$labels['aclr'] = '读取消息';
$labels['acls'] = '保存已读状态';
$labels['aclw'] = '写入标志';
$labels['acli'] = '插入(复制至)';
$labels['aclp'] = '发送';
$labels['aclc'] = '创建子文件夹';
$labels['aclk'] = '创建子文件夹';
$labels['acld'] = '删除消息';
$labels['aclt'] = '删除消息';
$labels['acle'] = '清除';
$labels['aclx'] = '删除文件夹';
$labels['acla'] = '管理';
$labels['acln'] = '注释消息';
$labels['aclfull'] = '全部控制';
$labels['aclother'] = '其它';
$labels['aclread'] = '读取';
$labels['aclwrite'] = '写入';
$labels['acldelete'] = '删除';
$labels['shortacll'] = '查找';
$labels['shortaclr'] = '读取';
$labels['shortacls'] = '保存';
$labels['shortaclw'] = '写入';
$labels['shortacli'] = '插入';
$labels['shortaclp'] = '发送';
$labels['shortaclc'] = '新建';
$labels['shortaclk'] = '新建';
$labels['shortacld'] = '删除';
$labels['shortaclt'] = '删除';
$labels['shortacle'] = '清除';
$labels['shortaclx'] = '删除文件夹';
$labels['shortacla'] = '管理';
$labels['shortacln'] = '注释';
$labels['shortaclother'] = '其他';
$labels['shortaclread'] = '读取';
$labels['shortaclwrite'] = '写入';
$labels['shortacldelete'] = '删除';
$labels['longacll'] = '该文件夹在列表上可见且可被订阅';
$labels['longaclr'] = '该文件夹可被打开阅读';
$labels['longacls'] = '已读消息标识可以改变';
$labels['longaclw'] = '除已读和删除表示外其他消息标识可以改变';
$labels['longacli'] = '消息可被标记，撰写或复制至文件夹中';
$labels['longaclp'] = '消息可以发到此文件夹';
$labels['longaclc'] = '文件夹可被创建(或改名)于现有目录下';
$labels['longaclk'] = '文件夹可直接在此目录下创建（或改名）';
$labels['longacld'] = '消息已删除标识可以改变';
$labels['longaclt'] = '消息已删除标识可以改变';
$labels['longacle'] = '消息可被清除';
$labels['longaclx'] = '该文件夹可被删除或重命名';
$labels['longacla'] = '文件夹访问权限可被修改';
$labels['longacln'] = '消息共享元数据（注释）可以改变';
$labels['longaclfull'] = '完全控制，包括文件夹管理';
$labels['longaclread'] = '该文件夹可被打开阅读';
$labels['longaclwrite'] = '消息可被标记，撰写或复制至文件夹中';
$labels['longacldelete'] = '信息可被删除';
$labels['longaclother'] = '其他访问权限';
$labels['ariasummaryacltable'] = '访问权限列表';
$labels['arialabelaclactions'] = '列出操作';
$labels['arialabelaclform'] = '访问权限从';
$messages['deleting'] = '删除访问权限中…';
$messages['saving'] = '保存访问权限中…';
$messages['updatesuccess'] = '成功修改访问权限';
$messages['deletesuccess'] = '成功删除访问权限';
$messages['createsuccess'] = '成功添加访问权限';
$messages['updateerror'] = '无法更新访问权限';
$messages['deleteerror'] = '无法删除访问权限';
$messages['createerror'] = '无法添加访问权限';
$messages['deleteconfirm'] = '您确定要移除选中用户的访问权限吗?';
$messages['norights'] = '没有已指定的权限!';
$messages['nouser'] = '没有已指定的用户名!';
