<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail New Mail Notifier plugin   |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['basic'] = 'Прикажи известувања на прелистувачот за нова порака ';
$labels['desktop'] = 'Прикажи известувања на работната површина за нова порака';
$labels['sound'] = 'Пушти го звукот за нова порака ';
$labels['test'] = 'Тест';
$labels['title'] = 'Нова електронска пошта';
$labels['body'] = 'Имаш нова порака ';
$labels['testbody'] = 'Ова е тест известување ';
$labels['desktopdisabled'] = 'Известувањата на работната површина се исклучени во твојот прелистувач ';
$labels['desktopunsupported'] = 'Твојот прелистувач не подржува известувања на работната површина ';
$labels['desktoptimeout'] = 'Исклучи известувања на работната површина';
