<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Zipdownload plugin         |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['downloadall'] = 'تحميل جميع المرفقات';
$labels['export'] = 'تصدّير...';
$labels['downloadmbox'] = 'تنسيق Mbox (.zip)';
$labels['downloadmaildir'] = 'تنسيق Maildir (.zip)';
$labels['downloademl'] = 'المصدر (.eml)';
$labels['sizelimiterror'] = 'إجمالي حجم الرسائل المحددة يتجاوز الحد ($size)';
$labels['exportmenu'] = 'قائمة خيارات تصدير الرسائل';
$labels['download'] = 'تحميل...';
