<?php

// autoload_static.php @generated by Composer

namespace Composer\Autoload;

class ComposerStaticInit1fb782e4b7a1beaef51a787f2b6eb5b9
{
    public static $files = array (
        '6e3fae29631ef280660b3cdad06f25a8' => __DIR__ . '/..' . '/symfony/deprecation-contracts/function.php',
        'a4a119a56e50fbb293281d9a48007e0e' => __DIR__ . '/..' . '/symfony/polyfill-php80/bootstrap.php',
        '7b11c4dc42b3b3023073cb14e519683c' => __DIR__ . '/..' . '/ralouphie/getallheaders/src/getallheaders.php',
        '37a3dc5111fe8f707ab4c132ef1dbc62' => __DIR__ . '/..' . '/guzzlehttp/guzzle/src/functions_include.php',
        '606a39d89246991a373564698c2d8383' => __DIR__ . '/..' . '/symfony/polyfill-php85/bootstrap.php',
    );

    public static $prefixLengthsPsr4 = array (
        'S' =>
        array (
            'Symfony\\Polyfill\\Php85\\' => 23,
            'Symfony\\Polyfill\\Php80\\' => 23,
        ),
        'R' =>
        array (
            'RtfHtmlPhp\\' => 11,
            'Roundcube\\Composer\\' => 19,
        ),
        'P' =>
        array (
            'Psr\\Http\\Message\\' => 17,
            'Psr\\Http\\Client\\' => 16,
            'Psr\\EventDispatcher\\' => 20,
        ),
        'N' =>
        array (
            'Nette\\' => 6,
        ),
        'M' =>
        array (
            'Masterminds\\' => 12,
        ),
        'L' =>
        array (
            'League\\Config\\' => 14,
            'League\\CommonMark\\' => 18,
        ),
        'I' =>
        array (
            'IPLib\\' => 6,
        ),
        'G' =>
        array (
            'GuzzleHttp\\Psr7\\' => 16,
            'GuzzleHttp\\Promise\\' => 19,
            'GuzzleHttp\\' => 11,
        ),
        'D' =>
        array (
            'Dflydev\\DotAccessData\\' => 22,
            'DASPRiD\\Enum\\' => 13,
        ),
        'B' =>
        array (
            'BaconQrCode\\' => 12,
        ),
    );

    public static $prefixDirsPsr4 = array (
        'Symfony\\Polyfill\\Php85\\' =>
        array (
            0 => __DIR__ . '/..' . '/symfony/polyfill-php85',
        ),
        'Symfony\\Polyfill\\Php80\\' =>
        array (
            0 => __DIR__ . '/..' . '/symfony/polyfill-php80',
        ),
        'RtfHtmlPhp\\' =>
        array (
            0 => __DIR__ . '/..' . '/roundcube/rtf-html-php/src',
        ),
        'Roundcube\\Composer\\' =>
        array (
            0 => __DIR__ . '/..' . '/roundcube/plugin-installer/src',
        ),
        'Psr\\Http\\Message\\' =>
        array (
            0 => __DIR__ . '/..' . '/psr/http-factory/src',
            1 => __DIR__ . '/..' . '/psr/http-message/src',
        ),
        'Psr\\Http\\Client\\' =>
        array (
            0 => __DIR__ . '/..' . '/psr/http-client/src',
        ),
        'Psr\\EventDispatcher\\' =>
        array (
            0 => __DIR__ . '/..' . '/psr/event-dispatcher/src',
        ),
        'Nette\\' =>
        array (
            0 => __DIR__ . '/..' . '/nette/schema/src',
            1 => __DIR__ . '/..' . '/nette/utils/src',
        ),
        'Masterminds\\' =>
        array (
            0 => __DIR__ . '/..' . '/masterminds/html5/src',
        ),
        'League\\Config\\' =>
        array (
            0 => __DIR__ . '/..' . '/league/config/src',
        ),
        'League\\CommonMark\\' =>
        array (
            0 => __DIR__ . '/..' . '/league/commonmark/src',
        ),
        'IPLib\\' =>
        array (
            0 => __DIR__ . '/..' . '/mlocati/ip-lib/src',
        ),
        'GuzzleHttp\\Psr7\\' =>
        array (
            0 => __DIR__ . '/..' . '/guzzlehttp/psr7/src',
        ),
        'GuzzleHttp\\Promise\\' =>
        array (
            0 => __DIR__ . '/..' . '/guzzlehttp/promises/src',
        ),
        'GuzzleHttp\\' =>
        array (
            0 => __DIR__ . '/..' . '/guzzlehttp/guzzle/src',
        ),
        'Dflydev\\DotAccessData\\' =>
        array (
            0 => __DIR__ . '/..' . '/dflydev/dot-access-data/src',
        ),
        'DASPRiD\\Enum\\' =>
        array (
            0 => __DIR__ . '/..' . '/dasprid/enum/src',
        ),
        'BaconQrCode\\' =>
        array (
            0 => __DIR__ . '/..' . '/bacon/bacon-qr-code/src',
        ),
    );

    public static $prefixesPsr0 = array (
        'N' =>
        array (
            'Net' =>
            array (
                0 => __DIR__ . '/..' . '/pear/net_smtp',
                1 => __DIR__ . '/..' . '/pear/net_socket',
            ),
        ),
        'M' =>
        array (
            'Mail' =>
            array (
                0 => __DIR__ . '/..' . '/pear/mail_mime',
            ),
        ),
        'C' =>
        array (
            'Console' =>
            array (
                0 => __DIR__ . '/..' . '/pear/console_getopt',
            ),
        ),
        'A' =>
        array (
            'Auth' =>
            array (
                0 => __DIR__ . '/..' . '/pear/auth_sasl',
            ),
        ),
    );

    public static $classMap = array (
        'Attribute' => __DIR__ . '/..' . '/symfony/polyfill-php80/Resources/stubs/Attribute.php',
        'Composer\\InstalledVersions' => __DIR__ . '/..' . '/composer/InstalledVersions.php',
        'Crypt\\Console\\PinCliParameters' => __DIR__ . '/..' . '/pear/crypt_gpg/Crypt/Console/PinCliParameters.php',
        'Crypt\\Console\\SimpleCliWrapper' => __DIR__ . '/..' . '/pear/crypt_gpg/Crypt/Console/SimpleCliWrapper.php',
        'Crypt_GPG' => __DIR__ . '/..' . '/pear/crypt_gpg/Crypt/GPG.php',
        'Crypt_GPGAbstract' => __DIR__ . '/..' . '/pear/crypt_gpg/Crypt/GPGAbstract.php',
        'Crypt_GPG_BadPassphraseException' => __DIR__ . '/..' . '/pear/crypt_gpg/Crypt/GPG/Exceptions.php',
        'Crypt_GPG_DeletePrivateKeyException' => __DIR__ . '/..' . '/pear/crypt_gpg/Crypt/GPG/Exceptions.php',
        'Crypt_GPG_Engine' => __DIR__ . '/..' . '/pear/crypt_gpg/Crypt/GPG/Engine.php',
        'Crypt_GPG_Exception' => __DIR__ . '/..' . '/pear/crypt_gpg/Crypt/GPG/Exceptions.php',
        'Crypt_GPG_FileException' => __DIR__ . '/..' . '/pear/crypt_gpg/Crypt/GPG/Exceptions.php',
        'Crypt_GPG_InvalidKeyParamsException' => __DIR__ . '/..' . '/pear/crypt_gpg/Crypt/GPG/Exceptions.php',
        'Crypt_GPG_InvalidOperationException' => __DIR__ . '/..' . '/pear/crypt_gpg/Crypt/GPG/Exceptions.php',
        'Crypt_GPG_Key' => __DIR__ . '/..' . '/pear/crypt_gpg/Crypt/GPG/Key.php',
        'Crypt_GPG_KeyGenerator' => __DIR__ . '/..' . '/pear/crypt_gpg/Crypt/GPG/KeyGenerator.php',
        'Crypt_GPG_KeyNotCreatedException' => __DIR__ . '/..' . '/pear/crypt_gpg/Crypt/GPG/Exceptions.php',
        'Crypt_GPG_KeyNotFoundException' => __DIR__ . '/..' . '/pear/crypt_gpg/Crypt/GPG/Exceptions.php',
        'Crypt_GPG_NoDataException' => __DIR__ . '/..' . '/pear/crypt_gpg/Crypt/GPG/Exceptions.php',
        'Crypt_GPG_OpenSubprocessException' => __DIR__ . '/..' . '/pear/crypt_gpg/Crypt/GPG/Exceptions.php',
        'Crypt_GPG_PinEntry' => __DIR__ . '/..' . '/pear/crypt_gpg/Crypt/GPG/PinEntry.php',
        'Crypt_GPG_ProcessControl' => __DIR__ . '/..' . '/pear/crypt_gpg/Crypt/GPG/ProcessControl.php',
        'Crypt_GPG_ProcessHandler' => __DIR__ . '/..' . '/pear/crypt_gpg/Crypt/GPG/ProcessHandler.php',
        'Crypt_GPG_Signature' => __DIR__ . '/..' . '/pear/crypt_gpg/Crypt/GPG/Signature.php',
        'Crypt_GPG_SignatureCreationInfo' => __DIR__ . '/..' . '/pear/crypt_gpg/Crypt/GPG/SignatureCreationInfo.php',
        'Crypt_GPG_SubKey' => __DIR__ . '/..' . '/pear/crypt_gpg/Crypt/GPG/SubKey.php',
        'Crypt_GPG_UserId' => __DIR__ . '/..' . '/pear/crypt_gpg/Crypt/GPG/UserId.php',
        'DelayedTargetValidation' => __DIR__ . '/..' . '/symfony/polyfill-php85/Resources/stubs/DelayedTargetValidation.php',
        'Filter\\FilterException' => __DIR__ . '/..' . '/symfony/polyfill-php85/Resources/stubs/Filter/FilterException.php',
        'Filter\\FilterFailedException' => __DIR__ . '/..' . '/symfony/polyfill-php85/Resources/stubs/Filter/FilterFailedException.php',
        'Net_LDAP2' => __DIR__ . '/..' . '/pear/net_ldap2/Net/LDAP2.php',
        'Net_LDAP2_Entry' => __DIR__ . '/..' . '/pear/net_ldap2/Net/LDAP2/Entry.php',
        'Net_LDAP2_Error' => __DIR__ . '/..' . '/pear/net_ldap2/Net/LDAP2.php',
        'Net_LDAP2_Filter' => __DIR__ . '/..' . '/pear/net_ldap2/Net/LDAP2/Filter.php',
        'Net_LDAP2_LDIF' => __DIR__ . '/..' . '/pear/net_ldap2/Net/LDAP2/LDIF.php',
        'Net_LDAP2_RootDSE' => __DIR__ . '/..' . '/pear/net_ldap2/Net/LDAP2/RootDSE.php',
        'Net_LDAP2_Schema' => __DIR__ . '/..' . '/pear/net_ldap2/Net/LDAP2/Schema.php',
        'Net_LDAP2_SchemaCache' => __DIR__ . '/..' . '/pear/net_ldap2/Net/LDAP2/SchemaCache.interface.php',
        'Net_LDAP2_Search' => __DIR__ . '/..' . '/pear/net_ldap2/Net/LDAP2/Search.php',
        'Net_LDAP2_SimpleFileSchemaCache' => __DIR__ . '/..' . '/pear/net_ldap2/Net/LDAP2/SimpleFileSchemaCache.php',
        'Net_LDAP2_Util' => __DIR__ . '/..' . '/pear/net_ldap2/Net/LDAP2/Util.php',
        'Net_LDAP3' => __DIR__ . '/..' . '/kolab/net_ldap3/lib/Net/LDAP3.php',
        'Net_LDAP3_Result' => __DIR__ . '/..' . '/kolab/net_ldap3/lib/Net/LDAP3/Result.php',
        'Net_Sieve' => __DIR__ . '/..' . '/pear/net_sieve/Sieve.php',
        'Nette\\ArgumentOutOfRangeException' => __DIR__ . '/..' . '/nette/utils/src/exceptions.php',
        'Nette\\DeprecatedException' => __DIR__ . '/..' . '/nette/utils/src/exceptions.php',
        'Nette\\DirectoryNotFoundException' => __DIR__ . '/..' . '/nette/utils/src/exceptions.php',
        'Nette\\FileNotFoundException' => __DIR__ . '/..' . '/nette/utils/src/exceptions.php',
        'Nette\\HtmlStringable' => __DIR__ . '/..' . '/nette/utils/src/HtmlStringable.php',
        'Nette\\IOException' => __DIR__ . '/..' . '/nette/utils/src/exceptions.php',
        'Nette\\InvalidArgumentException' => __DIR__ . '/..' . '/nette/utils/src/exceptions.php',
        'Nette\\InvalidStateException' => __DIR__ . '/..' . '/nette/utils/src/exceptions.php',
        'Nette\\Iterators\\CachingIterator' => __DIR__ . '/..' . '/nette/utils/src/Iterators/CachingIterator.php',
        'Nette\\Iterators\\Mapper' => __DIR__ . '/..' . '/nette/utils/src/Iterators/Mapper.php',
        'Nette\\Localization\\ITranslator' => __DIR__ . '/..' . '/nette/utils/src/compatibility.php',
        'Nette\\Localization\\Translator' => __DIR__ . '/..' . '/nette/utils/src/Translator.php',
        'Nette\\MemberAccessException' => __DIR__ . '/..' . '/nette/utils/src/exceptions.php',
        'Nette\\NotImplementedException' => __DIR__ . '/..' . '/nette/utils/src/exceptions.php',
        'Nette\\NotSupportedException' => __DIR__ . '/..' . '/nette/utils/src/exceptions.php',
        'Nette\\OutOfRangeException' => __DIR__ . '/..' . '/nette/utils/src/exceptions.php',
        'Nette\\Schema\\Context' => __DIR__ . '/..' . '/nette/schema/src/Schema/Context.php',
        'Nette\\Schema\\DynamicParameter' => __DIR__ . '/..' . '/nette/schema/src/Schema/DynamicParameter.php',
        'Nette\\Schema\\Elements\\AnyOf' => __DIR__ . '/..' . '/nette/schema/src/Schema/Elements/AnyOf.php',
        'Nette\\Schema\\Elements\\Base' => __DIR__ . '/..' . '/nette/schema/src/Schema/Elements/Base.php',
        'Nette\\Schema\\Elements\\Structure' => __DIR__ . '/..' . '/nette/schema/src/Schema/Elements/Structure.php',
        'Nette\\Schema\\Elements\\Type' => __DIR__ . '/..' . '/nette/schema/src/Schema/Elements/Type.php',
        'Nette\\Schema\\Expect' => __DIR__ . '/..' . '/nette/schema/src/Schema/Expect.php',
        'Nette\\Schema\\Helpers' => __DIR__ . '/..' . '/nette/schema/src/Schema/Helpers.php',
        'Nette\\Schema\\Message' => __DIR__ . '/..' . '/nette/schema/src/Schema/Message.php',
        'Nette\\Schema\\Processor' => __DIR__ . '/..' . '/nette/schema/src/Schema/Processor.php',
        'Nette\\Schema\\Schema' => __DIR__ . '/..' . '/nette/schema/src/Schema/Schema.php',
        'Nette\\Schema\\ValidationException' => __DIR__ . '/..' . '/nette/schema/src/Schema/ValidationException.php',
        'Nette\\ShouldNotHappenException' => __DIR__ . '/..' . '/nette/utils/src/exceptions.php',
        'Nette\\SmartObject' => __DIR__ . '/..' . '/nette/utils/src/SmartObject.php',
        'Nette\\StaticClass' => __DIR__ . '/..' . '/nette/utils/src/StaticClass.php',
        'Nette\\UnexpectedValueException' => __DIR__ . '/..' . '/nette/utils/src/exceptions.php',
        'Nette\\Utils\\ArrayHash' => __DIR__ . '/..' . '/nette/utils/src/Utils/ArrayHash.php',
        'Nette\\Utils\\ArrayList' => __DIR__ . '/..' . '/nette/utils/src/Utils/ArrayList.php',
        'Nette\\Utils\\Arrays' => __DIR__ . '/..' . '/nette/utils/src/Utils/Arrays.php',
        'Nette\\Utils\\AssertionException' => __DIR__ . '/..' . '/nette/utils/src/Utils/exceptions.php',
        'Nette\\Utils\\Callback' => __DIR__ . '/..' . '/nette/utils/src/Utils/Callback.php',
        'Nette\\Utils\\DateTime' => __DIR__ . '/..' . '/nette/utils/src/Utils/DateTime.php',
        'Nette\\Utils\\FileInfo' => __DIR__ . '/..' . '/nette/utils/src/Utils/FileInfo.php',
        'Nette\\Utils\\FileSystem' => __DIR__ . '/..' . '/nette/utils/src/Utils/FileSystem.php',
        'Nette\\Utils\\Finder' => __DIR__ . '/..' . '/nette/utils/src/Utils/Finder.php',
        'Nette\\Utils\\Floats' => __DIR__ . '/..' . '/nette/utils/src/Utils/Floats.php',
        'Nette\\Utils\\Helpers' => __DIR__ . '/..' . '/nette/utils/src/Utils/Helpers.php',
        'Nette\\Utils\\Html' => __DIR__ . '/..' . '/nette/utils/src/Utils/Html.php',
        'Nette\\Utils\\IHtmlString' => __DIR__ . '/..' . '/nette/utils/src/compatibility.php',
        'Nette\\Utils\\Image' => __DIR__ . '/..' . '/nette/utils/src/Utils/Image.php',
        'Nette\\Utils\\ImageColor' => __DIR__ . '/..' . '/nette/utils/src/Utils/ImageColor.php',
        'Nette\\Utils\\ImageException' => __DIR__ . '/..' . '/nette/utils/src/Utils/exceptions.php',
        'Nette\\Utils\\ImageType' => __DIR__ . '/..' . '/nette/utils/src/Utils/ImageType.php',
        'Nette\\Utils\\Iterables' => __DIR__ . '/..' . '/nette/utils/src/Utils/Iterables.php',
        'Nette\\Utils\\Json' => __DIR__ . '/..' . '/nette/utils/src/Utils/Json.php',
        'Nette\\Utils\\JsonException' => __DIR__ . '/..' . '/nette/utils/src/Utils/exceptions.php',
        'Nette\\Utils\\ObjectHelpers' => __DIR__ . '/..' . '/nette/utils/src/Utils/ObjectHelpers.php',
        'Nette\\Utils\\Paginator' => __DIR__ . '/..' . '/nette/utils/src/Utils/Paginator.php',
        'Nette\\Utils\\Random' => __DIR__ . '/..' . '/nette/utils/src/Utils/Random.php',
        'Nette\\Utils\\Reflection' => __DIR__ . '/..' . '/nette/utils/src/Utils/Reflection.php',
        'Nette\\Utils\\ReflectionMethod' => __DIR__ . '/..' . '/nette/utils/src/Utils/ReflectionMethod.php',
        'Nette\\Utils\\RegexpException' => __DIR__ . '/..' . '/nette/utils/src/Utils/exceptions.php',
        'Nette\\Utils\\Strings' => __DIR__ . '/..' . '/nette/utils/src/Utils/Strings.php',
        'Nette\\Utils\\Type' => __DIR__ . '/..' . '/nette/utils/src/Utils/Type.php',
        'Nette\\Utils\\UnknownImageFileException' => __DIR__ . '/..' . '/nette/utils/src/Utils/exceptions.php',
        'Nette\\Utils\\Validators' => __DIR__ . '/..' . '/nette/utils/src/Utils/Validators.php',
        'NoDiscard' => __DIR__ . '/..' . '/symfony/polyfill-php85/Resources/stubs/NoDiscard.php',
        'OS_Guess' => __DIR__ . '/..' . '/pear/pear-core-minimal/src/OS/Guess.php',
        'PEAR' => __DIR__ . '/..' . '/pear/pear-core-minimal/src/PEAR.php',
        'PEAR_Error' => __DIR__ . '/..' . '/pear/pear-core-minimal/src/PEAR.php',
        'PEAR_ErrorStack' => __DIR__ . '/..' . '/pear/pear-core-minimal/src/PEAR/ErrorStack.php',
        'PEAR_Exception' => __DIR__ . '/..' . '/pear/pear_exception/PEAR/Exception.php',
        'PhpToken' => __DIR__ . '/..' . '/symfony/polyfill-php80/Resources/stubs/PhpToken.php',
        'Stringable' => __DIR__ . '/..' . '/symfony/polyfill-php80/Resources/stubs/Stringable.php',
        'System' => __DIR__ . '/..' . '/pear/pear-core-minimal/src/System.php',
        'UnhandledMatchError' => __DIR__ . '/..' . '/symfony/polyfill-php80/Resources/stubs/UnhandledMatchError.php',
        'ValueError' => __DIR__ . '/..' . '/symfony/polyfill-php80/Resources/stubs/ValueError.php',
        'html' => __DIR__ . '/../..' . '/program/lib/Roundcube/html.php',
        'html_button' => __DIR__ . '/../..' . '/program/lib/Roundcube/html.php',
        'html_checkbox' => __DIR__ . '/../..' . '/program/lib/Roundcube/html.php',
        'html_hiddenfield' => __DIR__ . '/../..' . '/program/lib/Roundcube/html.php',
        'html_inputfield' => __DIR__ . '/../..' . '/program/lib/Roundcube/html.php',
        'html_passwordfield' => __DIR__ . '/../..' . '/program/lib/Roundcube/html.php',
        'html_radiobutton' => __DIR__ . '/../..' . '/program/lib/Roundcube/html.php',
        'html_select' => __DIR__ . '/../..' . '/program/lib/Roundcube/html.php',
        'html_table' => __DIR__ . '/../..' . '/program/lib/Roundcube/html.php',
        'html_textarea' => __DIR__ . '/../..' . '/program/lib/Roundcube/html.php',
        'rcmail' => __DIR__ . '/../..' . '/program/include/rcmail.php',
        'rcmail_action' => __DIR__ . '/../..' . '/program/include/rcmail_action.php',
        'rcmail_action_contacts_copy' => __DIR__ . '/../..' . '/program/actions/contacts/copy.php',
        'rcmail_action_contacts_delete' => __DIR__ . '/../..' . '/program/actions/contacts/delete.php',
        'rcmail_action_contacts_edit' => __DIR__ . '/../..' . '/program/actions/contacts/edit.php',
        'rcmail_action_contacts_export' => __DIR__ . '/../..' . '/program/actions/contacts/export.php',
        'rcmail_action_contacts_group_addmembers' => __DIR__ . '/../..' . '/program/actions/contacts/group_addmembers.php',
        'rcmail_action_contacts_group_create' => __DIR__ . '/../..' . '/program/actions/contacts/group_create.php',
        'rcmail_action_contacts_group_delete' => __DIR__ . '/../..' . '/program/actions/contacts/group_delete.php',
        'rcmail_action_contacts_group_delmembers' => __DIR__ . '/../..' . '/program/actions/contacts/group_delmembers.php',
        'rcmail_action_contacts_group_rename' => __DIR__ . '/../..' . '/program/actions/contacts/group_rename.php',
        'rcmail_action_contacts_import' => __DIR__ . '/../..' . '/program/actions/contacts/import.php',
        'rcmail_action_contacts_index' => __DIR__ . '/../..' . '/program/actions/contacts/index.php',
        'rcmail_action_contacts_list' => __DIR__ . '/../..' . '/program/actions/contacts/list.php',
        'rcmail_action_contacts_mailto' => __DIR__ . '/../..' . '/program/actions/contacts/mailto.php',
        'rcmail_action_contacts_move' => __DIR__ . '/../..' . '/program/actions/contacts/move.php',
        'rcmail_action_contacts_photo' => __DIR__ . '/../..' . '/program/actions/contacts/photo.php',
        'rcmail_action_contacts_print' => __DIR__ . '/../..' . '/program/actions/contacts/print.php',
        'rcmail_action_contacts_qrcode' => __DIR__ . '/../..' . '/program/actions/contacts/qrcode.php',
        'rcmail_action_contacts_save' => __DIR__ . '/../..' . '/program/actions/contacts/save.php',
        'rcmail_action_contacts_search' => __DIR__ . '/../..' . '/program/actions/contacts/search.php',
        'rcmail_action_contacts_search_create' => __DIR__ . '/../..' . '/program/actions/contacts/search_create.php',
        'rcmail_action_contacts_search_delete' => __DIR__ . '/../..' . '/program/actions/contacts/search_delete.php',
        'rcmail_action_contacts_show' => __DIR__ . '/../..' . '/program/actions/contacts/show.php',
        'rcmail_action_contacts_undo' => __DIR__ . '/../..' . '/program/actions/contacts/undo.php',
        'rcmail_action_contacts_upload_photo' => __DIR__ . '/../..' . '/program/actions/contacts/upload_photo.php',
        'rcmail_action_login_oauth' => __DIR__ . '/../..' . '/program/actions/login/oauth.php',
        'rcmail_action_login_oauth_backchannel' => __DIR__ . '/../..' . '/program/actions/login/oauth_backchannel.php',
        'rcmail_action_mail_addcontact' => __DIR__ . '/../..' . '/program/actions/mail/addcontact.php',
        'rcmail_action_mail_attachment_delete' => __DIR__ . '/../..' . '/program/actions/mail/attachment_delete.php',
        'rcmail_action_mail_attachment_display' => __DIR__ . '/../..' . '/program/actions/mail/attachment_display.php',
        'rcmail_action_mail_attachment_rename' => __DIR__ . '/../..' . '/program/actions/mail/attachment_rename.php',
        'rcmail_action_mail_attachment_upload' => __DIR__ . '/../..' . '/program/actions/mail/attachment_upload.php',
        'rcmail_action_mail_autocomplete' => __DIR__ . '/../..' . '/program/actions/mail/autocomplete.php',
        'rcmail_action_mail_bounce' => __DIR__ . '/../..' . '/program/actions/mail/bounce.php',
        'rcmail_action_mail_check_recent' => __DIR__ . '/../..' . '/program/actions/mail/check_recent.php',
        'rcmail_action_mail_compose' => __DIR__ . '/../..' . '/program/actions/mail/compose.php',
        'rcmail_action_mail_copy' => __DIR__ . '/../..' . '/program/actions/mail/copy.php',
        'rcmail_action_mail_delete' => __DIR__ . '/../..' . '/program/actions/mail/delete.php',
        'rcmail_action_mail_folder_expunge' => __DIR__ . '/../..' . '/program/actions/mail/folder_expunge.php',
        'rcmail_action_mail_folder_purge' => __DIR__ . '/../..' . '/program/actions/mail/folder_purge.php',
        'rcmail_action_mail_get' => __DIR__ . '/../..' . '/program/actions/mail/get.php',
        'rcmail_action_mail_getunread' => __DIR__ . '/../..' . '/program/actions/mail/getunread.php',
        'rcmail_action_mail_group_expand' => __DIR__ . '/../..' . '/program/actions/mail/group_expand.php',
        'rcmail_action_mail_headers' => __DIR__ . '/../..' . '/program/actions/mail/headers.php',
        'rcmail_action_mail_import' => __DIR__ . '/../..' . '/program/actions/mail/import.php',
        'rcmail_action_mail_index' => __DIR__ . '/../..' . '/program/actions/mail/index.php',
        'rcmail_action_mail_list' => __DIR__ . '/../..' . '/program/actions/mail/list.php',
        'rcmail_action_mail_list_contacts' => __DIR__ . '/../..' . '/program/actions/mail/list_contacts.php',
        'rcmail_action_mail_mark' => __DIR__ . '/../..' . '/program/actions/mail/mark.php',
        'rcmail_action_mail_move' => __DIR__ . '/../..' . '/program/actions/mail/move.php',
        'rcmail_action_mail_pagenav' => __DIR__ . '/../..' . '/program/actions/mail/pagenav.php',
        'rcmail_action_mail_search' => __DIR__ . '/../..' . '/program/actions/mail/search.php',
        'rcmail_action_mail_search_contacts' => __DIR__ . '/../..' . '/program/actions/mail/search_contacts.php',
        'rcmail_action_mail_send' => __DIR__ . '/../..' . '/program/actions/mail/send.php',
        'rcmail_action_mail_sendmdn' => __DIR__ . '/../..' . '/program/actions/mail/sendmdn.php',
        'rcmail_action_mail_show' => __DIR__ . '/../..' . '/program/actions/mail/show.php',
        'rcmail_action_mail_viewsource' => __DIR__ . '/../..' . '/program/actions/mail/viewsource.php',
        'rcmail_action_settings_about' => __DIR__ . '/../..' . '/program/actions/settings/about.php',
        'rcmail_action_settings_folder_create' => __DIR__ . '/../..' . '/program/actions/settings/folder_create.php',
        'rcmail_action_settings_folder_delete' => __DIR__ . '/../..' . '/program/actions/settings/folder_delete.php',
        'rcmail_action_settings_folder_edit' => __DIR__ . '/../..' . '/program/actions/settings/folder_edit.php',
        'rcmail_action_settings_folder_purge' => __DIR__ . '/../..' . '/program/actions/settings/folder_purge.php',
        'rcmail_action_settings_folder_rename' => __DIR__ . '/../..' . '/program/actions/settings/folder_rename.php',
        'rcmail_action_settings_folder_save' => __DIR__ . '/../..' . '/program/actions/settings/folder_save.php',
        'rcmail_action_settings_folder_size' => __DIR__ . '/../..' . '/program/actions/settings/folder_size.php',
        'rcmail_action_settings_folder_subscribe' => __DIR__ . '/../..' . '/program/actions/settings/folder_subscribe.php',
        'rcmail_action_settings_folder_unsubscribe' => __DIR__ . '/../..' . '/program/actions/settings/folder_unsubscribe.php',
        'rcmail_action_settings_folders' => __DIR__ . '/../..' . '/program/actions/settings/folders.php',
        'rcmail_action_settings_identities' => __DIR__ . '/../..' . '/program/actions/settings/identities.php',
        'rcmail_action_settings_identity_create' => __DIR__ . '/../..' . '/program/actions/settings/identity_create.php',
        'rcmail_action_settings_identity_delete' => __DIR__ . '/../..' . '/program/actions/settings/identity_delete.php',
        'rcmail_action_settings_identity_edit' => __DIR__ . '/../..' . '/program/actions/settings/identity_edit.php',
        'rcmail_action_settings_identity_save' => __DIR__ . '/../..' . '/program/actions/settings/identity_save.php',
        'rcmail_action_settings_index' => __DIR__ . '/../..' . '/program/actions/settings/index.php',
        'rcmail_action_settings_prefs_edit' => __DIR__ . '/../..' . '/program/actions/settings/prefs_edit.php',
        'rcmail_action_settings_prefs_save' => __DIR__ . '/../..' . '/program/actions/settings/prefs_save.php',
        'rcmail_action_settings_response_create' => __DIR__ . '/../..' . '/program/actions/settings/response_create.php',
        'rcmail_action_settings_response_delete' => __DIR__ . '/../..' . '/program/actions/settings/response_delete.php',
        'rcmail_action_settings_response_edit' => __DIR__ . '/../..' . '/program/actions/settings/response_edit.php',
        'rcmail_action_settings_response_get' => __DIR__ . '/../..' . '/program/actions/settings/response_get.php',
        'rcmail_action_settings_response_save' => __DIR__ . '/../..' . '/program/actions/settings/response_save.php',
        'rcmail_action_settings_responses' => __DIR__ . '/../..' . '/program/actions/settings/responses.php',
        'rcmail_action_settings_upload' => __DIR__ . '/../..' . '/program/actions/settings/upload.php',
        'rcmail_action_settings_upload_display' => __DIR__ . '/../..' . '/program/actions/settings/upload_display.php',
        'rcmail_action_utils_error' => __DIR__ . '/../..' . '/program/actions/utils/error.php',
        'rcmail_action_utils_html2text' => __DIR__ . '/../..' . '/program/actions/utils/html2text.php',
        'rcmail_action_utils_killcache' => __DIR__ . '/../..' . '/program/actions/utils/killcache.php',
        'rcmail_action_utils_modcss' => __DIR__ . '/../..' . '/program/actions/utils/modcss.php',
        'rcmail_action_utils_save_pref' => __DIR__ . '/../..' . '/program/actions/utils/save_pref.php',
        'rcmail_action_utils_spell' => __DIR__ . '/../..' . '/program/actions/utils/spell.php',
        'rcmail_action_utils_spell_html' => __DIR__ . '/../..' . '/program/actions/utils/spell_html.php',
        'rcmail_action_utils_text2html' => __DIR__ . '/../..' . '/program/actions/utils/text2html.php',
        'rcmail_attachment_handler' => __DIR__ . '/../..' . '/program/include/rcmail_attachment_handler.php',
        'rcmail_bounce_stream_filter' => __DIR__ . '/../..' . '/program/include/rcmail_resend_mail.php',
        'rcmail_healthchecker' => __DIR__ . '/../..' . '/program/include/rcmail_healthchecker.php',
        'rcmail_html_page' => __DIR__ . '/../..' . '/program/include/rcmail_html_page.php',
        'rcmail_install' => __DIR__ . '/../..' . '/program/include/rcmail_install.php',
        'rcmail_oauth' => __DIR__ . '/../..' . '/program/include/rcmail_oauth.php',
        'rcmail_output' => __DIR__ . '/../..' . '/program/include/rcmail_output.php',
        'rcmail_output_cli' => __DIR__ . '/../..' . '/program/include/rcmail_output_cli.php',
        'rcmail_output_html' => __DIR__ . '/../..' . '/program/include/rcmail_output_html.php',
        'rcmail_output_json' => __DIR__ . '/../..' . '/program/include/rcmail_output_json.php',
        'rcmail_resend_mail' => __DIR__ . '/../..' . '/program/include/rcmail_resend_mail.php',
        'rcmail_sendmail' => __DIR__ . '/../..' . '/program/include/rcmail_sendmail.php',
        'rcmail_string_replacer' => __DIR__ . '/../..' . '/program/include/rcmail_string_replacer.php',
        'rcmail_utils' => __DIR__ . '/../..' . '/program/include/rcmail_utils.php',
        'rcube' => __DIR__ . '/../..' . '/program/lib/Roundcube/rcube.php',
        'rcube_addressbook' => __DIR__ . '/../..' . '/program/lib/Roundcube/rcube_addressbook.php',
        'rcube_addresses' => __DIR__ . '/../..' . '/program/lib/Roundcube/rcube_addresses.php',
        'rcube_base_replacer' => __DIR__ . '/../..' . '/program/lib/Roundcube/rcube_base_replacer.php',
        'rcube_browser' => __DIR__ . '/../..' . '/program/lib/Roundcube/rcube_browser.php',
        'rcube_cache' => __DIR__ . '/../..' . '/program/lib/Roundcube/rcube_cache.php',
        'rcube_cache_apcu' => __DIR__ . '/../..' . '/program/lib/Roundcube/cache/apcu.php',
        'rcube_cache_db' => __DIR__ . '/../..' . '/program/lib/Roundcube/cache/db.php',
        'rcube_cache_memcache' => __DIR__ . '/../..' . '/program/lib/Roundcube/cache/memcache.php',
        'rcube_cache_memcached' => __DIR__ . '/../..' . '/program/lib/Roundcube/cache/memcached.php',
        'rcube_cache_redis' => __DIR__ . '/../..' . '/program/lib/Roundcube/cache/redis.php',
        'rcube_charset' => __DIR__ . '/../..' . '/program/lib/Roundcube/rcube_charset.php',
        'rcube_config' => __DIR__ . '/../..' . '/program/lib/Roundcube/rcube_config.php',
        'rcube_contacts' => __DIR__ . '/../..' . '/program/lib/Roundcube/rcube_contacts.php',
        'rcube_content_filter' => __DIR__ . '/../..' . '/program/lib/Roundcube/rcube_content_filter.php',
        'rcube_csv2vcard' => __DIR__ . '/../..' . '/program/lib/Roundcube/rcube_csv2vcard.php',
        'rcube_db' => __DIR__ . '/../..' . '/program/lib/Roundcube/rcube_db.php',
        'rcube_db_mysql' => __DIR__ . '/../..' . '/program/lib/Roundcube/db/mysql.php',
        'rcube_db_param' => __DIR__ . '/../..' . '/program/lib/Roundcube/db/param.php',
        'rcube_db_pgsql' => __DIR__ . '/../..' . '/program/lib/Roundcube/db/pgsql.php',
        'rcube_db_sqlite' => __DIR__ . '/../..' . '/program/lib/Roundcube/db/sqlite.php',
        'rcube_dummy_plugin_api' => __DIR__ . '/../..' . '/program/lib/Roundcube/rcube.php',
        'rcube_enriched' => __DIR__ . '/../..' . '/program/lib/Roundcube/rcube_enriched.php',
        'rcube_html2text' => __DIR__ . '/../..' . '/program/lib/Roundcube/rcube_html2text.php',
        'rcube_image' => __DIR__ . '/../..' . '/program/lib/Roundcube/rcube_image.php',
        'rcube_imap' => __DIR__ . '/../..' . '/program/lib/Roundcube/rcube_imap.php',
        'rcube_imap_cache' => __DIR__ . '/../..' . '/program/lib/Roundcube/rcube_imap_cache.php',
        'rcube_imap_generic' => __DIR__ . '/../..' . '/program/lib/Roundcube/rcube_imap_generic.php',
        'rcube_imap_search' => __DIR__ . '/../..' . '/program/lib/Roundcube/rcube_imap_search.php',
        'rcube_imap_search_job' => __DIR__ . '/../..' . '/program/lib/Roundcube/rcube_imap_search.php',
        'rcube_ldap' => __DIR__ . '/../..' . '/program/lib/Roundcube/rcube_ldap.php',
        'rcube_ldap_generic' => __DIR__ . '/../..' . '/program/lib/Roundcube/rcube_ldap_generic.php',
        'rcube_markdown' => __DIR__ . '/../..' . '/program/lib/Roundcube/rcube_markdown.php',
        'rcube_message' => __DIR__ . '/../..' . '/program/lib/Roundcube/rcube_message.php',
        'rcube_message_header' => __DIR__ . '/../..' . '/program/lib/Roundcube/rcube_message_header.php',
        'rcube_message_header_sorter' => __DIR__ . '/../..' . '/program/lib/Roundcube/rcube_message_header.php',
        'rcube_message_part' => __DIR__ . '/../..' . '/program/lib/Roundcube/rcube_message_part.php',
        'rcube_mime' => __DIR__ . '/../..' . '/program/lib/Roundcube/rcube_mime.php',
        'rcube_mime_decode' => __DIR__ . '/../..' . '/program/lib/Roundcube/rcube_mime_decode.php',
        'rcube_output' => __DIR__ . '/../..' . '/program/lib/Roundcube/rcube_output.php',
        'rcube_plugin' => __DIR__ . '/../..' . '/program/lib/Roundcube/rcube_plugin.php',
        'rcube_plugin_api' => __DIR__ . '/../..' . '/program/lib/Roundcube/rcube_plugin_api.php',
        'rcube_result_index' => __DIR__ . '/../..' . '/program/lib/Roundcube/rcube_result_index.php',
        'rcube_result_multifolder' => __DIR__ . '/../..' . '/program/lib/Roundcube/rcube_result_multifolder.php',
        'rcube_result_set' => __DIR__ . '/../..' . '/program/lib/Roundcube/rcube_result_set.php',
        'rcube_result_thread' => __DIR__ . '/../..' . '/program/lib/Roundcube/rcube_result_thread.php',
        'rcube_session' => __DIR__ . '/../..' . '/program/lib/Roundcube/rcube_session.php',
        'rcube_session_db' => __DIR__ . '/../..' . '/program/lib/Roundcube/session/db.php',
        'rcube_session_memcache' => __DIR__ . '/../..' . '/program/lib/Roundcube/session/memcache.php',
        'rcube_session_memcached' => __DIR__ . '/../..' . '/program/lib/Roundcube/session/memcached.php',
        'rcube_session_php' => __DIR__ . '/../..' . '/program/lib/Roundcube/session/php.php',
        'rcube_session_redis' => __DIR__ . '/../..' . '/program/lib/Roundcube/session/redis.php',
        'rcube_smtp' => __DIR__ . '/../..' . '/program/lib/Roundcube/rcube_smtp.php',
        'rcube_spellchecker' => __DIR__ . '/../..' . '/program/lib/Roundcube/rcube_spellchecker.php',
        'rcube_spellchecker_atd' => __DIR__ . '/../..' . '/program/lib/Roundcube/spellchecker/atd.php',
        'rcube_spellchecker_enchant' => __DIR__ . '/../..' . '/program/lib/Roundcube/spellchecker/enchant.php',
        'rcube_spellchecker_engine' => __DIR__ . '/../..' . '/program/lib/Roundcube/spellchecker/engine.php',
        'rcube_spellchecker_googie' => __DIR__ . '/../..' . '/program/lib/Roundcube/spellchecker/googie.php',
        'rcube_spellchecker_pspell' => __DIR__ . '/../..' . '/program/lib/Roundcube/spellchecker/pspell.php',
        'rcube_spoofchecker' => __DIR__ . '/../..' . '/program/lib/Roundcube/rcube_spoofchecker.php',
        'rcube_storage' => __DIR__ . '/../..' . '/program/lib/Roundcube/rcube_storage.php',
        'rcube_string_replacer' => __DIR__ . '/../..' . '/program/lib/Roundcube/rcube_string_replacer.php',
        'rcube_text2html' => __DIR__ . '/../..' . '/program/lib/Roundcube/rcube_text2html.php',
        'rcube_tnef_decoder' => __DIR__ . '/../..' . '/program/lib/Roundcube/rcube_tnef_decoder.php',
        'rcube_uploads' => __DIR__ . '/../..' . '/program/lib/Roundcube/rcube_uploads.php',
        'rcube_user' => __DIR__ . '/../..' . '/program/lib/Roundcube/rcube_user.php',
        'rcube_utils' => __DIR__ . '/../..' . '/program/lib/Roundcube/rcube_utils.php',
        'rcube_vcard' => __DIR__ . '/../..' . '/program/lib/Roundcube/rcube_vcard.php',
        'rcube_washtml' => __DIR__ . '/../..' . '/program/lib/Roundcube/rcube_washtml.php',
    );

    public static function getInitializer(ClassLoader $loader)
    {
        return \Closure::bind(function () use ($loader) {
            $loader->prefixLengthsPsr4 = ComposerStaticInit1fb782e4b7a1beaef51a787f2b6eb5b9::$prefixLengthsPsr4;
            $loader->prefixDirsPsr4 = ComposerStaticInit1fb782e4b7a1beaef51a787f2b6eb5b9::$prefixDirsPsr4;
            $loader->prefixesPsr0 = ComposerStaticInit1fb782e4b7a1beaef51a787f2b6eb5b9::$prefixesPsr0;
            $loader->classMap = ComposerStaticInit1fb782e4b7a1beaef51a787f2b6eb5b9::$classMap;

        }, null, ClassLoader::class);
    }
}
