<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Managesieve plugin         |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['filters'] = 'Filtros';
$labels['managefilters'] = 'Xestionar os filtros de correo recibido';
$labels['filtername'] = 'Nome do filtro';
$labels['newfilter'] = 'Novo filtro';
$labels['filteradd'] = 'Engadir filtro';
$labels['filterdel'] = 'Eliminar filtro';
$labels['rules'] = 'Regras';
$labels['actions'] = 'Accións';
$labels['scope'] = 'Ámbito';
$labels['moveup'] = 'Mover arriba';
$labels['movedown'] = 'Mover abaixo';
$labels['filterallof'] = 'coincidir con todas as regras seguintes';
$labels['filteranyof'] = 'coincidir con algunha das regras seguintes';
$labels['filterany'] = 'todas as mensaxes';
$labels['filtercontains'] = 'contén';
$labels['filternotcontains'] = 'non contén';
$labels['filteris'] = 'é igual a';
$labels['filterisnot'] = 'non é igual a';
$labels['filterexists'] = 'existe';
$labels['filternotexists'] = 'non existe';
$labels['filtermatches'] = 'coincide coa expresión';
$labels['filternotmatches'] = 'non coincide coa expresión';
$labels['filterregex'] = 'coincide coa expresión regular';
$labels['filternotregex'] = 'non coincide coa expresión regular';
$labels['filterunder'] = 'baixo';
$labels['filterover'] = 'sobre';
$labels['mime'] = 'MIME:';
$labels['mimepart'] = 'Parte MIME:';
$labels['mime-message'] = 'mensaxe';
$labels['mime-anychild'] = 'algunha';
$labels['mime-type'] = 'tipo';
$labels['mime-subtype'] = 'subtipo';
$labels['mime-contenttype'] = 'tipo de contido';
$labels['mime-param'] = 'parámetro';
$labels['addrule'] = 'Engadir regra';
$labels['delrule'] = 'Eliminar regra';
$labels['messagemoveto'] = 'Mover a mensaxe a';
$labels['messageredirect'] = 'Redirixir a mensaxe a';
$labels['messagecopyto'] = 'Copiar a mensaxe en';
$labels['messagesendcopy'] = 'Enviar copia da mensaxe a';
$labels['messagereply'] = 'Responder cunha mensaxe';
$labels['messagedelete'] = 'Eliminar a mensaxe';
$labels['messagediscard'] = 'Descartar cunha mensaxe';
$labels['messagekeep'] = 'Manter a mensaxe na caixa de entrada';
$labels['messagesrules'] = 'Para o correo recibido:';
$labels['messagesactions'] = '... executar as seguintes accións:';
$labels['add'] = 'Engadir';
$labels['del'] = 'Eliminar';
$labels['sender'] = 'Remitente';
$labels['recipient'] = 'Destinatario';
$labels['vacationaddr'] = 'Os meus enderezos electrónicos:';
$labels['vacationdays'] = 'Frecuencia de envío das mensaxes (en días):';
$labels['vacationinterval'] = 'Frecuencia de envío das mensaxes:';
$labels['vacationreason'] = 'Corpo da mensaxe (por vacacións):';
$labels['vacationfrom'] = 'Enderezo do remitente da resposta:';
$labels['vacationsubject'] = 'Asunto da mensaxe:';
$labels['days'] = 'días';
$labels['seconds'] = 'segundos';
$labels['rulestop'] = 'Deter a avaliación das regras';
$labels['enable'] = 'Activar/Desactivar';
$labels['filterset'] = 'Conxunto de filtros';
$labels['filtersets'] = 'Conxuntos de filtros';
$labels['filtersetadd'] = 'Engadir conxunto de filtros';
$labels['filtersetdel'] = 'Eliminar conxunto de filtros';
$labels['filtersetact'] = 'Activar conxunto de filtros actual';
$labels['filtersetdeact'] = 'Desactivar conxunto de filtros actual';
$labels['filterseteditraw'] = 'Editar conxunto de filtros';
$labels['filtersetswitch'] = 'Activar/desactivar conxunto de filtros';
$labels['filterdef'] = 'Definición dos filtros';
$labels['filtersetname'] = 'Nome do conxunto de filtros';
$labels['newfilterset'] = 'Novo conxunto de filtros';
$labels['active'] = 'activo';
$labels['none'] = 'ningún';
$labels['fromset'] = 'desde o conxunto';
$labels['fromfile'] = 'desde arquivo';
$labels['filterdisabled'] = 'Filtro desactivado';
$labels['filterenabled'] = 'Filtro activado';
$labels['countisgreaterthan'] = 'o reconto é maior que';
$labels['countisgreaterthanequal'] = 'o reconto é maior ou igual a';
$labels['countislessthan'] = 'o reconto é menor que';
$labels['countislessthanequal'] = 'o reconto é menor ou igual a';
$labels['countequals'] = 'o reconto é igual a';
$labels['countnotequals'] = 'o reconto non é igual a';
$labels['valueisgreaterthan'] = 'o valor é maior que ';
$labels['valueisgreaterthanequal'] = 'o valor é maior ou igual a';
$labels['valueislessthan'] = 'o valor é menor que';
$labels['valueislessthanequal'] = 'o valor é menor ou igual a';
$labels['valueequals'] = 'o valor é igual a';
$labels['valuenotequals'] = 'o valor non é igual a';
$labels['setflags'] = 'Marcar a mensaxe';
$labels['addflags'] = 'Engadirlle marcadores á mensaxe';
$labels['removeflags'] = 'Eliminar marcadores da mensaxe';
$labels['flagread'] = 'Lida';
$labels['flagdeleted'] = 'Eliminada';
$labels['flaganswered'] = 'Respondida';
$labels['flagflagged'] = 'Marcada';
$labels['flagdraft'] = 'Borrador';
$labels['addheader'] = 'Engadir cabeceira á mensaxe';
$labels['deleteheader'] = 'Eliminar cabeceira da mensaxe';
$labels['headername'] = 'Nome da cabeceira';
$labels['headervalue'] = 'Valor da cabeceira';
$labels['headerpos'] = 'Posición da cabeceira';
$labels['headeratstart'] = 'ao comezo';
$labels['headeratend'] = 'ao final';
$labels['headeroccurrence'] = 'Posición da cabeceira';
$labels['headerfromstart'] = 'desde o inicio';
$labels['headerfromend'] = 'desde o final';
$labels['headerpatterns'] = 'Padróns de valores da cabeceira';
$labels['headermatchtype'] = 'tipo de coincidencia:';
$labels['setvariable'] = 'Establecer variable';
$labels['setvarname'] = 'Nome da variable:';
$labels['setvarvalue'] = 'Valor da variable:';
$labels['setvarmodifiers'] = 'Modificadores:';
$labels['varlower'] = 'minúscula';
$labels['varupper'] = 'maiúscula';
$labels['varlowerfirst'] = 'primeira letra minúscula';
$labels['varupperfirst'] = 'primeira letra maiúscula';
$labels['varquotewildcard'] = 'poñer entre comiñas os caracteres especiais';
$labels['varlength'] = 'lonxitude';
$labels['varencodeurl'] = 'código porcento (para URL)';
$labels['notify'] = 'Enviar notificación';
$labels['notifytarget'] = 'Destino da notificación:';
$labels['notifymessage'] = 'Mensaxe da notificación (opcional):';
$labels['notifyoptions'] = 'Opcións da notificación (opcional):';
$labels['notifyfrom'] = 'Remitente da notificación (opcional):';
$labels['notifyimportance'] = 'Importancia:';
$labels['notifyimportancelow'] = 'baixa';
$labels['notifyimportancenormal'] = 'normal';
$labels['notifyimportancehigh'] = 'alta';
$labels['notifymethodmailto'] = 'Correo electrónico';
$labels['notifymethodtel'] = 'Teléfono';
$labels['notifymethodsms'] = 'SMS';
$labels['filtercreate'] = 'Crear filtro';
$labels['usedata'] = 'Usar os seguintes datos no filtro:';
$labels['nextstep'] = 'Seguinte paso';
$labels['...'] = '...';
$labels['string'] = 'Cadea';
$labels['currdate'] = 'Data actual';
$labels['datetest'] = 'Data';
$labels['dateheader'] = 'cabeceira:';
$labels['year'] = 'ano';
$labels['month'] = 'mes';
$labels['day'] = 'día';
$labels['date'] = 'data (aaaa-mm-dd)';
$labels['julian'] = 'data (xuliana)';
$labels['hour'] = 'hora';
$labels['minute'] = 'minuto';
$labels['second'] = 'segundo';
$labels['time'] = 'tempo (hh:mm:ss)';
$labels['iso8601'] = 'data (ISO8601)';
$labels['std11'] = 'data (RFC2822)';
$labels['zone'] = 'fuso horario';
$labels['weekday'] = 'día da semana (0-6)';
$labels['advancedopts'] = 'Opcións avanzadas';
$labels['body'] = 'Corpo';
$labels['address'] = 'enderezo';
$labels['envelope'] = 'sobre';
$labels['modifier'] = 'modificador:';
$labels['text'] = 'texto';
$labels['undecoded'] = 'sen descodificar (en bruto)';
$labels['contenttype'] = 'tipo de contido';
$labels['modtype'] = 'tipo:';
$labels['allparts'] = 'todos';
$labels['domain'] = 'dominio';
$labels['localpart'] = 'parte local';
$labels['user'] = 'usuario';
$labels['detail'] = 'detalle';
$labels['comparator'] = 'comparador:';
$labels['default'] = 'predeterminado';
$labels['octet'] = 'estrito (octeto)';
$labels['asciicasemap'] = 'non distingue maiúsculas de minúsculas (ascii-casemap)';
$labels['asciinumeric'] = 'numérico (ascii-numeric)';
$labels['index'] = 'índice:';
$labels['indexlast'] = 'cara atrás';
$labels['spamtest'] = 'Nivel de correo lixo';
$labels['spamtestisgreaterthan'] = 'é maior que';
$labels['spamtestisgreaterthanequal'] = 'é maior ou igual a';
$labels['spamtestislessthan'] = 'é menor que';
$labels['spamtestislessthanequal'] = 'é menor ou igual a';
$labels['spamtestequals'] = 'é igual a';
$labels['spamtestnotequals'] = 'non é igual a';
$labels['spamtestisunknown'] = 'non se coñece';
$labels['vacation'] = 'Fóra da oficina';
$labels['vacation.reply'] = 'Resposta';
$labels['vacation.advanced'] = 'Opcións avanzadas';
$labels['vacation.from'] = 'Enderezo do remitente da resposta';
$labels['vacation.subject'] = 'Asunto';
$labels['vacation.body'] = 'Corpo';
$labels['vacation.start'] = 'Hora de inicio';
$labels['vacation.end'] = 'Hora de remate';
$labels['vacation.status'] = 'Estado';
$labels['vacation.on'] = 'Activar';
$labels['vacation.off'] = 'Desactivar';
$labels['vacation.addresses'] = 'Os meus enderezos electrónicos';
$labels['vacation.interval'] = 'Intervalo de resposta';
$labels['vacation.after'] = 'Activar a regra de Fóra da oficina despois';
$labels['vacation.saving'] = 'Gardando datos...';
$labels['vacation.action'] = 'Acción de mensaxe recibida';
$labels['vacation.keep'] = 'Manter';
$labels['vacation.discard'] = 'Descartar';
$labels['vacation.redirect'] = 'Redirixir a';
$labels['vacation.copy'] = 'Enviar copia a';
$labels['forward'] = 'Reenviar';
$labels['forward.redirect'] = 'Redirixir a';
$labels['forward.copy'] = 'Enviar copia a';
$labels['forward.on'] = 'Activar';
$labels['forward.off'] = 'Desactivar';
$labels['forward.status'] = 'Estado:';
$labels['forward.action'] = 'Executar a seguinte acción para os correos recibidos:';
$labels['forward.saving'] = 'Gardando datos...';
$labels['filladdresses'] = 'Cubrir con todos os meus enderezos.';
$labels['arialabelfiltersetactions'] = 'Accións de conxunto de filtros';
$labels['arialabelfilteractions'] = 'Accións de filtrado';
$labels['arialabelfilterform'] = 'Propiedades dos filtros';
$labels['ariasummaryfilterslist'] = 'Lista de filtros';
$labels['ariasummaryfiltersetslist'] = 'Lista de conxunto de filtros';
$labels['filterstitle'] = 'Editar filtros de correo recibido';
$labels['vacationtitle'] = 'Editar regra de Fóra da oficina';
$labels['forwardtitle'] = 'Editar regra de reenvío de correos';
$labels['message'] = 'Mensaxe';
$labels['duplicate'] = 'está duplicada';
$labels['notduplicate'] = 'non está duplicada';
$labels['duplicate.handle'] = 'correo:';
$labels['duplicate.header'] = 'cabeceira:';
$labels['duplicate.uniqueid'] = 'identificador:';
$labels['duplicate.seconds'] = 'tiempo de espera (segundos):';
$labels['duplicate.last'] = 'en relación coa última execución';
$messages['filterunknownerror'] = 'Erro descoñecido do servidor.';
$messages['filterconnerror'] = 'Non é posible conectar co servidor.';
$messages['filterdeleteerror'] = 'Non é posible eliminar o filtro. Erro do servidor.';
$messages['filterdeleted'] = 'Filtro eliminado correctamente.';
$messages['filtersaved'] = 'Filtro gardado correctamente.';
$messages['filtersaveerror'] = 'Non é posible gardar o filtro. Erro do servidor.';
$messages['filterformerror'] = 'O formulario do filtro contén erros.';
$messages['filterdeleteconfirm'] = 'Seguro/a que queres eliminar o filtro seleccionado?';
$messages['ruledeleteconfirm'] = 'Seguro/a que queres eliminar a regra seleccionada?';
$messages['actiondeleteconfirm'] = 'Seguro/a que queres eliminar a acción seleccionada?';
$messages['forbiddenchars'] = 'Caracteres non permitidos no campo.';
$messages['cannotbeempty'] = 'O campo non pode estar baleiro.';
$messages['ruleexist'] = 'Xa existe un filtro co nome especificado.';
$messages['setactivateerror'] = 'Non é posible activar o conxunto de filtros seleccionado. Erro do servidor.';
$messages['setdeactivateerror'] = 'Non é posible desactivar o conxunto de filtros seleccionado. Erro do servidor.';
$messages['setdeleteerror'] = 'Non é posible eliminar o conxunto de filtros seleccionado. Erro do servidor.';
$messages['setactivated'] = 'Conxunto de filtros activado correctamente.';
$messages['setdeactivated'] = 'Conxunto de filtros desactivado correctamente.';
$messages['setdeleted'] = 'Conxunto de filtros eliminado correctamente.';
$messages['setupdated'] = 'Conxunto de filtros actualizado correctamente.';
$messages['setdeleteconfirm'] = 'Seguro/a que queres eliminar o conxunto de filtros seleccionado?';
$messages['setcreateerror'] = 'Non é posible crear o conxunto de filtros. Erro do servidor.';
$messages['setcreated'] = 'Conxunto de filtros creado correctamente.';
$messages['activateerror'] = 'Non é posible activar o(s) filtro(s) seleccionado(s). Erro do servidor.';
$messages['deactivateerror'] = 'Non é posible desactivar o(s) filtro(s) seleccionado(s). Erro do servidor.';
$messages['deactivated'] = 'Filtro(s) desactivado(s) correctamente.';
$messages['activated'] = 'Filtro(s) activado(s) correctamente.';
$messages['moved'] = 'Filtro movido correctamente.';
$messages['moveerror'] = 'Non é posible mover o filtro seleccionado. Erro do servidor.';
$messages['nametoolong'] = 'O nome é demasiado longo.';
$messages['namereserved'] = 'Nome reservado.';
$messages['setexist'] = 'Este conxunto xa existe.';
$messages['nodata'] = 'É preciso seleccionar polo menos unha posición!';
$messages['invaliddateformat'] = 'Formato non válido da data ou de parte da data';
$messages['saveerror'] = 'Non é posible gardar os datos. Erro do servidor.';
$messages['vacationsaved'] = 'Datos de Fóra da oficina gardados correctamente.';
$messages['forwardsaved'] = 'Datos gardados correctamente.';
$messages['emptyvacationbody'] = 'É preciso que a mensaxe de vacacións teña un corpo!';
$messages['duplicate.conflict.err'] = 'Non se permiten nin a cabeceira nin o identificador único.';
$messages['disabledaction'] = 'Acción non permitida.';
$messages['lastindexempty'] = 'O índice é necesario cando se conta desde o final';
$messages['noflagset'] = 'É preciso seleccionar polo menos un marcador.';
