<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Zipdownload plugin         |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['downloadall'] = '모든 첨부파일을 다운로드';
$labels['downloadmbox'] = 'Mbox 형식 (.zip)';
$labels['downloadmaildir'] = 'Maildir 형식 (.zip)';
$labels['downloademl'] = '소스 (.eml)';
$labels['sizelimiterror'] = '선택한 메시지의 전체 크기가 최대 크기인 ($size)을(를) 초과함';
$labels['download'] = '다운로드...';
