<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail New Mail Notifier plugin   |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['basic'] = 'Ցուցադրել զննարկչի ծանուցում նոր հաղորդագրություն ստանալիս';
$labels['desktop'] = 'Ցուցադրել սեղանադրի ծանուցում նոր հաղորդագրություն ստանալիս';
$labels['sound'] = 'Ձայն հանել նոր հաղորդագրություն ստանալիս';
$labels['test'] = 'փորձարկում';
$labels['title'] = 'Նոր էլփոստ';
$labels['body'] = 'Դուք ստացաք նոր հաղորդագրություն';
$labels['testbody'] = 'Սա փորձնական ծանուցում է';
$labels['desktopdisabled'] = 'Սեղանադրի ծանուցումները Ձեր զննարկչում անջատված են';
$labels['desktopunsupported'] = 'Ձեր զննարկիչը չունի սեղանադրի ծանուցումների հնարավորություն։';
$labels['desktoptimeout'] = 'Փակել սեղանադրի ծանուցումը';
