<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['welcome'] = 'ยินดีต้อนรับสู่ $product';
$labels['username'] = 'บัญชีผู้ใช้';
$labels['password'] = 'รหัสผ่าน';
$labels['server'] = 'เซิร์ฟเวอร์';
$labels['login'] = 'เข้าสู่ระบบ';
$labels['menu'] = 'เมนู';
$labels['logout'] = 'ออกจากระบบ';
$labels['mail'] = 'อีเมล์';
$labels['settings'] = 'ปรับแต่งค่าส่วนตัว';
$labels['addressbook'] = 'สมุดรายชื่อ';
$labels['inbox'] = 'กล่องขาเข้า';
$labels['drafts'] = 'กล่องจดหมายร่าง';
$labels['sent'] = 'กล่องขาออก';
$labels['trash'] = 'ถังขยะ';
$labels['junk'] = 'กล่องจดหมายขยะ';
$labels['show_real_foldernames'] = 'แสดงชื่อจริงสำหรับโฟลเดอร์พิเศษ';
$labels['subject'] = 'หัวจดหมาย';
$labels['from'] = 'ผู้ส่ง';
$labels['sender'] = 'ผู้ส่ง';
$labels['to'] = 'ผู้รับ';
$labels['cc'] = 'คัดลอก';
$labels['bcc'] = 'แอบสำเนาถึง';
$labels['replyto'] = 'ตอบกลับ';
$labels['followupto'] = 'ส่งต่อ';
$labels['date'] = 'วันที่';
$labels['size'] = 'ขนาด';
$labels['priority'] = 'ระดับความสำคัญ';
$labels['organization'] = 'องค์กร';
$labels['readstatus'] = 'สถานะการเปิดอ่าน';
$labels['listoptions'] = 'ตัวเลือกการแสดงรายการ';
$labels['listoptionstitle'] = 'รายการตั้งค่า';
$labels['mailboxlist'] = 'กล่องจดหมาย';
$labels['messagesfromto'] = 'จดหมายจาก $from ถึง $to จำนวน $count ฉบับ';
$labels['messagenrof'] = 'จดหมายฉบับที่ $nr จาก $count ฉบับ';
$labels['copy'] = 'คัดลอก';
$labels['move'] = 'ย้าย';
$labels['moveto'] = 'ย้ายไป...';
$labels['copyto'] = 'คัดลอกไป...';
$labels['download'] = 'ดาวน์โหลด';
$labels['open'] = 'เปิด';
$labels['showattachment'] = 'แสดง';
$labels['showanyway'] = 'แสดงตลอด';
$labels['filename'] = 'ชื่อไฟล์';
$labels['filesize'] = 'ขนาดไฟล์';
$labels['addtoaddressbook'] = 'บันทึกในสมุดรายชื่อ';
$labels['sun'] = 'อา';
$labels['mon'] = 'จ';
$labels['tue'] = 'อ';
$labels['wed'] = 'พ';
$labels['thu'] = 'พฤ';
$labels['fri'] = 'ศ';
$labels['sat'] = 'ส';
$labels['sunday'] = 'วันอาทิตย์';
$labels['monday'] = 'วันจันทร์';
$labels['tuesday'] = 'วันอังคาร';
$labels['wednesday'] = 'วันพุธ';
$labels['thursday'] = 'วันพฤหัสบดี';
$labels['friday'] = 'วันศุกร์';
$labels['saturday'] = 'วันเสาร์';
$labels['jan'] = 'ม.ค.';
$labels['feb'] = 'ก.พ.';
$labels['mar'] = 'มี.ค.';
$labels['apr'] = 'เม.ย.';
$labels['may'] = 'พ.ค.';
$labels['jun'] = 'มิ.ย.';
$labels['jul'] = 'ก.ค.';
$labels['aug'] = 'ส.ค.';
$labels['sep'] = 'ก.ย.';
$labels['oct'] = 'ต.ค.';
$labels['nov'] = 'พ.ย.';
$labels['dec'] = 'ธ.ค.';
$labels['longjan'] = 'มกราคม';
$labels['longfeb'] = 'กุมภาพันธ์';
$labels['longmar'] = 'มีนาคม';
$labels['longapr'] = 'เมษายน';
$labels['longmay'] = 'พ.ค.';
$labels['longjun'] = 'มิถุนายน';
$labels['longjul'] = 'กรกฎาคม';
$labels['longaug'] = 'สิงหาคม';
$labels['longsep'] = 'กันยายน';
$labels['longoct'] = 'ตุลาคม';
$labels['longnov'] = 'พฤศจิกายน';
$labels['longdec'] = 'ธันวาคม';
$labels['today'] = 'วันนี้';
$labels['refresh'] = 'รีเฟรช';
$labels['checkmail'] = 'ตรวจสอบจดหมายใหม่';
$labels['compose'] = 'เขียนจดหมายใหม่';
$labels['writenewmessage'] = 'สร้างจดหมายใหม่';
$labels['reply'] = 'ตอบกลับ';
$labels['replytomessage'] = 'ตอบกลับจดหมาย';
$labels['replytoallmessage'] = 'ตอบกลับถึงทุกคนในจดหมาย';
$labels['replyall'] = 'ตอบกลับทั้งหมด';
$labels['replylist'] = 'รายชื่อตอบกลับ';
$labels['forward'] = 'ส่งต่อ';
$labels['forwardinline'] = 'ส่งต่อในบรรทัด';
$labels['forwardattachment'] = 'ส่งต่อเป็นไฟล์แนบ';
$labels['forwardmessage'] = 'ส่งต่อจดหมาย';
$labels['bouncemsg'] = 'ส่งอีกครั้ง (ตีกลับ)';
$labels['bounce'] = 'ส่งอีกครั้ง';
$labels['deletemessage'] = 'ลบจดหมาย';
$labels['movemessagetotrash'] = 'ย้ายข้อความไปไว้ในถังขยะ';
$labels['printmessage'] = 'พิมพ์จดหมาย';
$labels['previousmessage'] = 'แสดงจดหมายฉบับที่แล้ว';
$labels['firstmessage'] = 'แสดงจดหมายฉบับแรก';
$labels['nextmessage'] = 'แสดงจดหมายฉบับต่อไป';
$labels['lastmessage'] = 'แสดงจดหมายฉบับล่าสุด';
$labels['backtolist'] = 'กลับไปยังรายการจดหมาย';
$labels['viewsource'] = 'แสดง source';
$labels['mark'] = 'ทำเครื่องหมาย';
$labels['markmessages'] = 'ทำเครื่องหมายข้อความ';
$labels['markread'] = 'ว่าอ่านแล้ว';
$labels['markunread'] = 'ว่ายังไม่ได้อ่าน';
$labels['markflagged'] = 'ถูกตั้งค่าสถานะ';
$labels['markunflagged'] = 'ไม่ถูกตั้งค่าสถานะ';
$labels['moreactions'] = 'การกระทำเพิ่มเติม...';
$labels['markallread'] = 'ทำว่าอ่านแล้ว';
$labels['folders-cur'] = 'เลือกเฉพาะโฟเดอร์';
$labels['folders-sub'] = 'เลือกโฟเดอร์และโฟเดอร์ย่อย';
$labels['folders-all'] = 'ทุกโฟเดอร์';
$labels['more'] = 'เพิ่มเติม';
$labels['back'] = 'ย้อนกลับ';
$labels['options'] = 'ตัวเลือก';
$labels['first'] = 'แรก';
$labels['last'] = 'ล่าสุด';
$labels['previous'] = 'ก่อนหน้า';
$labels['next'] = 'ถัดไป';
$labels['select'] = 'เลือก';
$labels['all'] = 'ทั้งหมด';
$labels['none'] = 'ไม่เลือก';
$labels['currpage'] = 'หน้าปัจจุบัน';
$labels['isread'] = 'อ่าน';
$labels['unread'] = 'จดหมายที่ไม่ได้อ่าน';
$labels['flagged'] = 'ปักธง';
$labels['unflagged'] = 'ไม่ปักธง';
$labels['unanswered'] = 'ยังไม่ได้ตอบ';
$labels['withattachment'] = 'พร้อมแนบ';
$labels['deleted'] = 'ลบแล้ว';
$labels['undeleted'] = 'ยังไม่ได้ลบ';
$labels['replied'] = 'ตอบกลับ';
$labels['forwarded'] = 'ส่งต่อแล้ว';
$labels['invert'] = 'กลับกัน';
$labels['filter'] = 'ตัวกรองข้อมูล';
$labels['list'] = 'รายการ';
$labels['threads'] = 'หัวข้อ';
$labels['expand-all'] = 'แสดงทั้งหมด';
$labels['expand-unread'] = 'แสดงเฉพาะที่ยังไม่ได้อ่าน';
$labels['collapse-all'] = 'ปิดทั้งหมด';
$labels['autoexpand_threads'] = 'ขยายเธรดข้อความ';
$labels['do_expand'] = 'หัวข้อทั้งหมด';
$labels['expand_only_unread'] = 'เฉพาะกับข้อความที่ยังไม่ได้อ่าน';
$labels['fromto'] = 'จาก/ถึง';
$labels['flag'] = 'ปักธง';
$labels['attachment'] = 'ไฟล์แนบ';
$labels['nonesort'] = 'ไม่เลือก';
$labels['sentdate'] = 'วันที่ส่ง';
$labels['arrival'] = 'วันที่มาถึง';
$labels['asc'] = 'เรียงจากน้อยมามาก';
$labels['desc'] = 'เรีียงจากมากไปน้อย';
$labels['listcolumns'] = 'แสดงคอลัมน์';
$labels['listsorting'] = 'จัดเรียงคอลัมน์';
$labels['listorder'] = 'เรียงลำดับ';
$labels['listmode'] = 'โหมดดูรายการ';
$labels['layout'] = 'แบบ';
$labels['layoutwidescreen'] = 'Widescreen';
$labels['layoutdesktop'] = 'เดสก์ทอป';
$labels['layoutlist'] = 'รายการ';
$labels['layoutwidescreendesc'] = 'Widescreen (3-column view)';
$labels['layoutdesktopdesc'] = 'เดสก์ท็อป (รายการแบบกว้าง ๆ และตัวอย่างอีเมลด้านล่าง)';
$labels['layoutlistdesc'] = 'รายการ (ไม่มีตัวอย่างจดหมาย)';
$labels['folderactions'] = 'การทำงานของโฟลเดอร์ ...';
$labels['compact'] = 'แบบย่อ';
$labels['empty'] = 'ว่างเปล่า';
$labels['importmessages'] = 'นำเข้าข้อความ';
$labels['quota'] = 'พื้นที่ใช้งาน';
$labels['unknown'] = 'ไม่ทราบ';
$labels['unlimited'] = 'ไม่จำกัด';
$labels['quotatype'] = 'ประเภทโควต้า';
$labels['quotatotal'] = 'จำกัด';
$labels['quotaused'] = 'ใช้';
$labels['quotastorage'] = 'พื้นที่ว่าง';
$labels['quotamessage'] = 'จำนวนข้อความ';
$labels['quicksearch'] = 'ค้นหาแบบด่วน';
$labels['searchplaceholder'] = 'ค้นหา...';
$labels['resetsearch'] = 'ล้างการค้นหา';
$labels['searchmod'] = 'แก้ไขการค้นหา';
$labels['msgtext'] = 'ทั้งข้อความ';
$labels['body'] = 'เนื้อหา';
$labels['type'] = 'ชนิด';
$labels['namex'] = 'ชื่อ';
$labels['searchscope'] = 'ขอบเขต';
$labels['currentfolder'] = 'โฟลเดอร์ปัจจุบัน';
$labels['subfolders'] = 'โฟลเดอร์นี้และโฟลเดอร์ย่อย';
$labels['allfolders'] = 'ทุกโฟลเดอร์';
$labels['searchinterval-1W'] = 'เก่ากว่าหนึ่งสัปดาห์';
$labels['searchinterval-1M'] = 'เก่ากว่าหนึ่งเดือน';
$labels['searchinterval-1Y'] = 'เก่ากว่าหนึ่งปี';
$labels['searchinterval1W'] = 'น้อยกว่าหนึ่งสัปดาห์';
$labels['searchinterval1M'] = 'น้อยกว่าหนึ่งเดือน';
$labels['searchinterval1Y'] = 'น้อยกว่าหนึ่งปี';
$labels['openinextwin'] = 'เปิดไปหน้าต่างใหม่';
$labels['emlsave'] = 'ดาวน์โหลด (.eml)';
$labels['changeformattext'] = 'แสดงแบบข้อความธรรมดา';
$labels['changeformathtml'] = 'แสดงแบบ HTML';
$labels['editasnew'] = 'แก้ไขใหม่';
$labels['send'] = 'ส่ง';
$labels['sendmessage'] = 'ส่งจดหมาย';
$labels['savemessage'] = 'บันทึกฉบับร่าง';
$labels['addattachment'] = 'แนบไฟล์';
$labels['charset'] = 'Charset';
$labels['editortype'] = 'ประเภทตัวแก้ไข';
$labels['returnreceipt'] = 'ตอบกลับผู้รับ';
$labels['dsn'] = 'การแจ้งเตือนสถานะการจัดส่ง';
$labels['mailreplyintro'] = 'On $date, $sender wrote:';
$labels['originalmessage'] = 'ข้อความเดิม';
$labels['selectimage'] = 'เลือกรูป';
$labels['addimage'] = 'เพิ่มรูป';
$labels['selectmedia'] = 'เลือกวีดีโอ';
$labels['addmedia'] = 'เพิ่มวีดีโอ';
$labels['encrypt'] = 'เข้ารหัส';
$labels['encryptmessage'] = 'เข้ารหัสข้อความ';
$labels['encryptmessagemailvelope'] = 'เข้ารหัสข้อความด้วย Mailvelope';
$labels['importpubkeys'] = 'นำเข้าคีย์สาธารณะ';
$labels['encryptedsendialog'] = 'กำลังส่งข้อความที่เข้ารหัส';
$labels['keyid'] = 'คีย์ไอดี';
$labels['keylength'] = 'บิต';
$labels['keyexpired'] = 'หมดอายุ';
$labels['keyrevoked'] = 'ยกเลิก';
$labels['bccinstead'] = 'ใช้สำเนาลับ';
$labels['insert'] = 'แทรก';
$labels['recipient'] = 'ผู้รับ';
$labels['editidents'] = 'แก้ไขข้อมูลประจำตัว';
$labels['spellcheck'] = 'สะกด';
$labels['checkspelling'] = 'ตรวจสอบคำผิด';
$labels['resumeediting'] = 'แก้ไขต่อ';
$labels['revertto'] = 'ย้นกลับไปยัง';
$labels['restore'] = 'กู้คืน';
$labels['restoremessage'] = 'กู้คืนข้อความ?';
$labels['ignore'] = 'ไม่สนใจ';
$labels['responses'] = 'การตอบกลับ';
$labels['insertresponse'] = 'แทรกการตอบกลับ';
$labels['manageresponses'] = 'จัดการตอบกลับ';
$labels['newresponse'] = 'สร้างการตอบกลับใหม่';
$labels['addresponse'] = 'เพิ่มการตอบกลับ';
$labels['editresponse'] = 'แก้ไขการตอบกลับ';
$labels['editresponses'] = 'แก้ไขการตอบกลับ';
$labels['responsename'] = 'ชื่อ';
$labels['responsetext'] = 'ข้อความตอบกลับ';
$labels['attach'] = 'ไฟลแนบ';
$labels['attachments'] = 'ไฟล์แนบ';
$labels['upload'] = 'อัพโหลด';
$labels['uploadprogress'] = '$percent ($current of $total)';
$labels['close'] = 'ปิด';
$labels['messageoptions'] = 'ตั้งค่าข้อความ...';
$labels['togglecomposeoptions'] = 'สลับตัวเลือกองค์ประกอบ';
$labels['attachmentrename'] = 'เปลี่ยนชื่อไฟล์แนบ';
$labels['low'] = 'ต่ำ';
$labels['lowest'] = 'ต่ำสุด';
$labels['normal'] = 'ปกติ';
$labels['high'] = 'สูง';
$labels['highest'] = 'สูงสุด';
$labels['nosubject'] = '(ไม่มีหัวข้อ)';
$labels['showimages'] = 'แสดงรูป';
$labels['alwaysshow'] = 'โชว์รูปจาก $sender เสมอ';
$labels['isdraft'] = 'นี้คือจดหมายร่าง';
$labels['andnmore'] = '$nr อื่น...';
$labels['togglemoreheaders'] = 'โชว์หัวจดหมายเพิ่มเติม';
$labels['togglefullheaders'] = 'Toggle raw message headers';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'Plain text';
$labels['savesentmessagein'] = 'บันทึกจดหมายขาออกที่';
$labels['dontsave'] = 'ไม่บันทึก';
$labels['maxuploadsize'] = 'ขนาดไฟล์สูงสุดที่อนุญาตคือ $size';
$labels['addcc'] = 'เพิ่ม สำเนาถึง';
$labels['addbcc'] = 'เพิ่มสำเนาลับ';
$labels['addreplyto'] = 'เพิ่ม ตอบกลับ ถึง';
$labels['addfollowupto'] = 'เพิ่ม ส่งต่อ ถึง';
$labels['mdnrequest'] = 'ผู้ส่งข้อความนี้ได้ขอให้คุณได้รับแจ้งเมื่อคุณอ่านข้อความนี้ คุณต้องการแจ้งผู้ส่งหรือไม่?';
$labels['receiptread'] = 'ยืนยันการอ่าน';
$labels['yourmessage'] = 'นี่คือการตอบรับการอ่าน สำหรับข้อความของคุณ';
$labels['receiptnote'] = 'หมายเหตุ: ข้อความของคุณถูกเปิดอ่าน ไม่มีการรับประกันว่าผู้รับได้อ่านหรือเข้าใจเนื้อหาของข้อความแล้ว';
$labels['name'] = 'ชื่อแสดง';
$labels['firstname'] = 'ชื่อ';
$labels['surname'] = 'สกุล';
$labels['middlename'] = 'ชื่อกลาง';
$labels['nameprefix'] = 'คำนำหน้า';
$labels['namesuffix'] = 'คำต่อท้ายชื่อ';
$labels['nickname'] = 'ชื่อเล่น';
$labels['jobtitle'] = 'ตำแหน่งงาน';
$labels['department'] = 'แผนก';
$labels['gender'] = 'เพศ';
$labels['maidenname'] = 'นามสกุลเดิม';
$labels['email'] = 'อีเมล์';
$labels['phone'] = 'โทรศัพท์';
$labels['address'] = 'ที่อยู่';
$labels['street'] = 'ถนน';
$labels['locality'] = 'เมือง';
$labels['zipcode'] = 'รหัสไปรษณีย์';
$labels['region'] = 'รัฐ/จังหวัด';
$labels['country'] = 'ประเทศ';
$labels['birthday'] = 'วันเกิด';
$labels['anniversary'] = 'ครบรอบ';
$labels['website'] = 'เว็บไซต์';
$labels['instantmessenger'] = 'IM';
$labels['notes'] = 'หมายเหตุ';
$labels['male'] = 'ชาย';
$labels['female'] = 'หญิง';
$labels['manager'] = 'ผู้จัดการ';
$labels['assistant'] = 'ผู้ช่วย';
$labels['spouse'] = 'คู่สมรส';
$labels['allfields'] = 'ช่องข้อมูลทั้่งหมด';
$labels['search'] = 'ค้นหา';
$labels['searchresult'] = 'ผลการค้นหา';
$labels['advsearch'] = 'ค้นหาขั้นสูง';
$labels['advanced'] = 'ขั้นสูง';
$labels['other'] = 'อื่นๆ';
$labels['printcontact'] = 'พิมพ์รายชื่อติดต่อ';
$labels['qrcode'] = 'QR Code';
$labels['typehome'] = 'บ้าน';
$labels['typework'] = 'สถานที่ทำงาน';
$labels['typeother'] = 'อื่นๆ';
$labels['typemobile'] = 'มือถือ';
$labels['typemain'] = 'หลัก';
$labels['typehomefax'] = 'โทรสารที่บ้าน';
$labels['typeworkfax'] = 'โทรสารที่ทำงาน';
$labels['typecar'] = 'รถ';
$labels['typepager'] = 'เพจเจอร์';
$labels['typevideo'] = 'วีดีโอ';
$labels['typeassistant'] = 'ผู้ช่วย';
$labels['typehomepage'] = 'โฮมเพจ';
$labels['typeblog'] = 'บล็อก';
$labels['typeprofile'] = 'โปรไฟล์';
$labels['addfield'] = 'เพิ่มช่องข้อมูล...';
$labels['addcontact'] = 'เพิ่มผู้ติดต่อ';
$labels['editcontact'] = 'แก้ไขรายชื่อ';
$labels['contacts'] = 'ผู้ติดต่อ';
$labels['contactproperties'] = 'คุณสมบัติการติดต่อ';
$labels['contactnameandorg'] = 'ชื่อและองค์กร';
$labels['personalinfo'] = 'ข้อมูลส่วนบุคคล';
$labels['contactphoto'] = 'รูปผู้ติดต่อ';
$labels['edit'] = 'แก้ไข';
$labels['cancel'] = 'ยกเลิก';
$labels['save'] = 'บันทึก';
$labels['delete'] = 'ลบ';
$labels['rename'] = 'เปลี่ยนชื่อ';
$labels['addphoto'] = 'เพิ่ม';
$labels['replacephoto'] = 'แทนที่';
$labels['uploadphoto'] = 'อัพโหลดรูป';
$labels['newcontact'] = 'สร้างผู้ติดต่อใหม่';
$labels['deletecontact'] = 'ลบรายชื่อที่เลือก';
$labels['composeto'] = 'เขียนจดหมายถึง';
$labels['contactsfromto'] = 'รายชื่อ $from ถึง $to จำนวน $count';
$labels['print'] = 'พิมพ์';
$labels['export'] = 'ส่งออก';
$labels['exportall'] = 'ส่งออกทั้งหมด';
$labels['exportsel'] = 'ส่งออกเฉพาะที่เลือก';
$labels['exportvcards'] = 'นำออกรายชื่อผู้ติดต่อ (vCard)';
$labels['newgroup'] = 'สร้างกลุ่มใหม่';
$labels['addgroup'] = 'เพิ่มกลุ่ม';
$labels['grouprename'] = 'เปลี่ยนชื่อกลุ่ม';
$labels['groupdelete'] = 'ลบกลุ่ม';
$labels['groupremoveselected'] = 'ลบรายชื่อผู้ติดต่อที่เลือกจากกลุ่ม';
$labels['uponelevel'] = 'ขยับขึ้นหนึ่งระดับ';
$labels['previouspage'] = 'หน้าที่แล้ว';
$labels['firstpage'] = 'แสดงหน้าแรก';
$labels['nextpage'] = 'หน้าถัดไป';
$labels['lastpage'] = 'แสดงหน้าสุดท้าย';
$labels['group'] = 'กลุ่ม';
$labels['groups'] = 'กลุ่ม';
$labels['listgroup'] = 'แสดงสมาชิกกลุ่ม';
$labels['personaladrbook'] = 'สมุดรายชื่อส่วนตัว';
$labels['searchsave'] = 'บันทึกการค้นหา';
$labels['searchdelete'] = 'ลบการค้นหา';
$labels['import'] = 'นำเข้า';
$labels['importcontacts'] = 'นำเข้าผู้ติดต่อ';
$labels['importtarget'] = 'เพิ่มผู้ติดต่อถึง';
$labels['importreplace'] = 'แทนที่ทั้งหมดในสมุดรายชื่อ';
$labels['importgroups'] = 'นำเข้ากลุ่มที่ได้รับมอบหมาย';
$labels['importgroupsall'] = 'ทั้งหมด (สร้างกลุ่มหากจำเป็น)';
$labels['importgroupsexisting'] = 'เฉพาะสำหรับกลุ่มที่มีอยู่เท่านั้น';
$labels['done'] = 'สำเร็จ';
$labels['settingsfor'] = 'ตั้งค่าสำหรับ';
$labels['about'] = 'เกี่ยวกับ';
$labels['preferences'] = 'ปรับแต่ง';
$labels['userpreferences'] = 'ข้อมูลส่วนตัว';
$labels['editpreferences'] = 'แก้ไขข้อมูลส่วนตัว';
$labels['identities'] = 'ชื่อแสดงตัว';
$labels['manageidentities'] = 'จัดการข้อมูลประจำตัว';
$labels['newidentity'] = 'สร้างข้อมูลประจำตัวใหม่';
$labels['addidentity'] = 'เพิ่มข้อมูลประจำตัว';
$labels['editidentity'] = 'แก้ไขข้อมูลประจำตัว';
$labels['preferhtml'] = 'อ่านแบบ HTML';
$labels['defaultcharset'] = 'ชุดอักขระเริ่มต้น';
$labels['htmlmessage'] = 'จดหมาย HTML';
$labels['messagepart'] = 'ส่วนหนึ่ง';
$labels['digitalsig'] = 'ลายเซ็นดิจิตอล';
$labels['dateformat'] = 'รูปแบบวันที่';
$labels['timeformat'] = 'รูปแบบเวลา';
$labels['prettydate'] = 'แสดงวันที่แบบย่อ';
$labels['setdefault'] = 'ตั้งเป็นค่าใช้งาน';
$labels['autodetect'] = 'อัตโนมัติ';
$labels['language'] = 'ภาษา';
$labels['timezone'] = 'เขตเวลา';
$labels['pagesize'] = 'จำนวนจดหมายต่อหน้า';
$labels['signature'] = 'ลายมือชื่อ';
$labels['dstactive'] = 'Daylight savings';
$labels['showinextwin'] = 'เปิดข้อความไปที่หน้าต่างใหม่';
$labels['composeextwin'] = 'เขียนในหน้าต่างใหม่';
$labels['htmleditor'] = 'เขียนจดหมายแบบ HTML';
$labels['htmlonreply'] = 'ตอบกลับในแบบ HTML';
$labels['htmlonreplyandforward'] = 'ส่งต่อ หรือ ตอบกลับ ในแบบ HTML';
$labels['htmlsignature'] = 'ลายมือชื่อแบบ HTML';
$labels['showemail'] = 'แสดงที่อยู่อีเมลที่ชื่อ';
$labels['previewpane'] = 'แสดงหน้าต่างตัวอย่างแสดงผล';
$labels['skin'] = 'Interface skin';
$labels['logoutclear'] = 'ลบเมล์ในถึงขยะเมื่อออกจากระบบ';
$labels['logoutcompact'] = 'กระชับกล่องจดหมายเข้าเมื่อออกจากระบบ';
$labels['uisettings'] = 'หน้าจอผู้ใช้';
$labels['serversettings'] = 'Server Settings';
$labels['mailboxview'] = 'มุมมองกล่องจดหมาย';
$labels['mdnrequests'] = 'ร้องขอการยืนยันการอ่าน';
$labels['askuser'] = 'ถามฉัน';
$labels['autosend'] = 'ส่ง ตอบรับ';
$labels['autosavedraft'] = 'บันทึกเป็นจดหมายร่างอัตโนมัติ';
$labels['never'] = 'ไม่ใช้';
$labels['advancedoptions'] = 'ตัวเลือกขั้นสูง';
$labels['newmessage'] = 'ข้อความใหม่';
$labels['signatureoptions'] = 'ตัวเลือกสำหรับลายเซ็็นต์';
$labels['whenreplying'] = 'เมื่อตอบกลับ';
$labels['autoaddsignature'] = 'เพิ่มลายเซ็นต์เข้าไปอัตโนมัติ';
$labels['newmessageonly'] = 'เฉพาะข้อความใหม่เท่านั้น';
$labels['replyandforwardonly'] = 'ตอบกลับและส่งต่อเท่านั้น';
$labels['insertsignature'] = 'แทรกลายเซ็นต์';
$labels['asattachment'] = 'เป็นไฟล์แนบ';
$labels['allmessages'] = 'ข้อความทั้งหมด';
$labels['folder'] = 'กล่องจดหมาย';
$labels['folders'] = 'กล่องจดหมาย';
$labels['foldername'] = 'ชื่อกล่องจดหมาย';
$labels['subscribed'] = 'ลงชื่อ';
$labels['messagecount'] = 'ข้อความ';
$labels['create'] = 'สร้าง';
$labels['createfolder'] = 'สร้างกล่องจดหมาย';
$labels['managefolders'] = 'จัดการกล่องจดหมาย';
$labels['specialfolders'] = 'โฟลเดอร์พิเศษ';
$labels['properties'] = 'คุณสมบัติ';
$labels['folderproperties'] = 'คุณสมบัติเกี่ยวกับโฟลเดอร์';
$labels['parentfolder'] = 'โฟลเดอร์แม่';
$labels['info'] = 'ข้อมูล';
$labels['foldertype'] = 'ประเภทโฟลเดอร์';
$labels['personalfolder'] = 'โฟลเดอร์ส่วนตัว';
$labels['sharedfolder'] = 'โฟลเดอร์สาธารณะ';
$labels['sortby'] = 'เรียงตาม';
$labels['sortasc'] = 'เรียงจากหน้าไปหลัง';
$labels['sortdesc'] = 'เรียงจากหลังไปหน้า';
$labels['undo'] = 'เลิกทำ';
$labels['installedplugins'] = 'ปลั๊กอินที่ติดตั้ง';
$labels['plugin'] = 'ปลั๊กอิน';
$labels['version'] = 'รุ่น';
$labels['license'] = 'สัญญาอนุญาต';
$labels['B'] = 'B';
$labels['KB'] = 'KB';
$labels['MB'] = 'MB';
$labels['GB'] = 'GB';
$labels['unicode'] = 'Unicode';
