<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail New Mail Notifier plugin   |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['desktop'] = 'إظهار إخطارات عند تلقي رسائل جديدة';
$labels['sound'] = 'إصدار نغمة عند وصول رسالة جديدة';
$labels['test'] = 'تجريب';
$labels['title'] = 'رسالة إلكترونية جديدة !';
$labels['body'] = 'لقد تلقيتَ رسالة جديدة.';
$labels['testbody'] = 'هذا إخطار تجريبي.';
$labels['desktopunsupported'] = 'إنَّ متصفحك لا يدعم الإخطارات المكتبية.';
$labels['desktoptimeout'] = 'إغلاق إخطارات المكتب';
