<?php

// autoload_namespaces.php @generated by Composer

$vendorDir = dirname(__DIR__);
$baseDir = dirname($vendorDir);

return array(
    'Net' => array($vendorDir . '/pear/net_smtp', $vendorDir . '/pear/net_socket'),
    'Mail' => array($vendorDir . '/pear/mail_mime'),
    'Console' => array($vendorDir . '/pear/console_getopt'),
    'Auth' => array($vendorDir . '/pear/auth_sasl'),
);
