<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Archive plugin             |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['buttontext'] = 'ارشیو';
$labels['buttontitle'] = 'ارشیو این پیام';
$labels['archived'] = 'با موفقیت ارشیو شد';
$labels['archivefolder'] = 'ارشیو';
$labels['settingstitle'] = 'ارشیو';
$labels['archivetypefolder'] = 'پوشه اصلی';
$labels['archivetypesender'] = 'ایمیل فرستنده';
$labels['unkownsender'] = 'نا شناس';
