<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail ACL plugin                 |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['sharing'] = 'مشاركة';
$labels['myrights'] = 'حقوق الوصول';
$labels['username'] = 'مستخدم:';
$labels['advanced'] = 'وضع متقدم';
$labels['add'] = 'إضافة';
$labels['newuser'] = 'اضافة مدخل';
$labels['editperms'] = 'تعديل الصلاحيات';
$labels['actions'] = 'اجراءات حقوق الوصول...';
$labels['anyone'] = 'كل المستخدمين(اي شخص)';
$labels['anonymous'] = 'ضيف (مجهول)';
$labels['identifier'] = 'معرف';
$labels['acll'] = 'بحث';
$labels['aclr'] = 'قراءة الرسائل';
$labels['acls'] = 'ابقاء حالة الزيارة';
$labels['aclw'] = 'اكتب رمز';
$labels['acli'] = 'ادخل (نسخ الى)';
$labels['aclp'] = 'نشر';
$labels['aclc'] = 'إنشاء مجلدات فرعية';
$labels['aclk'] = 'إنشاء مجلدات فرعية';
$labels['acld'] = 'حذف الرسائل';
$labels['aclt'] = 'حذف الرسائل';
$labels['acle'] = 'حُذف';
$labels['aclx'] = 'حذف المجلد';
$labels['acla'] = 'ادارة';
$labels['acln'] = 'التعليق على الرسائل';
$labels['aclfull'] = 'تحكم كامل';
$labels['aclother'] = 'اخرى';
$labels['aclread'] = 'قراءة ';
$labels['aclwrite'] = 'كتابة';
$labels['acldelete'] = 'حذف';
$labels['shortacll'] = 'بحث';
$labels['shortaclr'] = 'قراءة ';
$labels['shortacls'] = 'ابقاء';
$labels['shortaclw'] = 'قراءة';
$labels['shortacli'] = 'ادراج';
$labels['shortaclp'] = 'نشر';
$labels['shortaclc'] = 'أنشئ';
$labels['shortaclk'] = 'أنشئ';
$labels['shortacld'] = 'حذف';
$labels['shortaclt'] = 'حذف';
$labels['shortacle'] = 'حُذف';
$labels['shortaclx'] = 'حذف المجلد';
$labels['shortacla'] = 'ادارة';
$labels['shortacln'] = 'كتابة تعليق';
$labels['shortaclother'] = 'اخرى';
$labels['shortaclread'] = 'قراءة ';
$labels['shortaclwrite'] = 'كتابة';
$labels['shortacldelete'] = 'حذف';
$labels['longacll'] = 'المجلد مرئي في القائمة وبالامكان ايضا الاشتراك';
$labels['longaclr'] = 'من الممكن فتح المجلد للقراءة';
$labels['longacls'] = 'وسم الزيارة في الرسائل بالامكان تغييره';
$labels['longaclw'] = 'وسم والكلمات الرئيسية في الرسائل يمكن تغييره, ماعدا الزيارة والحذف ';
$labels['longacli'] = 'بالامكان كتابة الرسائل ونسخها الى هذا المجلد';
$labels['longaclp'] = 'بالامكان نشر الرسائل الى هذ المجلد';
$labels['longaclc'] = 'بالامكان انشاء المجلدات ( او اعادة التسمية ) مباشرة تحت هذا المجلد';
$labels['longaclk'] = 'بالامكان انشاء المجلدات ( او اعادة التسمية ) مباشرة تحت هذا المجلد';
$labels['longacld'] = 'حذف وسم الرسائل من الممكن تغييرة';
$labels['longaclt'] = 'حذف وسم الرسائل من الممكن تغييرة';
$labels['longacle'] = 'بالامكان شطب الرسائل';
$labels['longaclx'] = 'هذا المجلد بالامكان حذفة او اعادة تسميته';
$labels['longacla'] = 'حقوق الوصول لهذا المجلد بالامكان تغييره';
$labels['longacln'] = 'يمكن تغيير البيانات الوصفية (التعليقات) المشتركة بين الرسائل';
$labels['longaclfull'] = 'التحكم الكامل يتضمن ادارة المجلدات';
$labels['longaclread'] = 'من الممكن فتح المجلد للقراءة';
$labels['longaclwrite'] = 'لا يمكن وضع علامة على الرسائل, كتبت او نسخة الى هذا المجلد';
$labels['longacldelete'] = 'لا يمكن حذف الرسائل';
$labels['longaclother'] = 'حقوق الوصول الأخرى';
$labels['ariasummaryacltable'] = 'قائمة حقوق الوصول';
$labels['arialabelaclactions'] = 'قائمة الإجراءات';
$labels['arialabelaclform'] = 'نموذج حقوق الوصول';
$messages['deleting'] = 'جاري حذف حقوق الوصول...';
$messages['saving'] = 'جاري حفظ حقوق الوصول...';
$messages['updatesuccess'] = 'تم تغيير حقوق الوصول بنجاح';
$messages['deletesuccess'] = 'تم حذف حقوق الوصول بنجاح';
$messages['createsuccess'] = 'تم اضافة حقوق الوصول بنجاح';
$messages['updateerror'] = 'لا يمكن تحديث حقوق الوصول';
$messages['deleteerror'] = 'لا يمكن حذف حقوق الوصول';
$messages['createerror'] = 'لا يمكن اضافة حقوق الوصول';
$messages['deleteconfirm'] = 'هل تريد فعلاً حذف حقوق الوصول لـ المستخدمين المحددين ؟';
$messages['norights'] = 'لم يتم تحديد حقوق وصول!';
$messages['nouser'] = 'لم يتم تحديد اسم مستخدم!';
