<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Mark-As-Junk plugin        |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['buttonjunk'] = 'Esta mensagem é lixo';
$labels['asjunk'] = 'Como lixo';
$labels['markasjunk'] = 'Marcar como lixo';
$labels['buttonnotjunk'] = 'Esta mensagem não é lixo';
$labels['asnotjunk'] = 'Como não lixo';
$labels['markasnotjunk'] = 'Marcar como não lixo';
$labels['notjunk'] = 'Não é lixo';
$messages['reportedasjunk'] = 'Reportado como lixo com sucesso';
$messages['reportedasnotjunk'] = 'Reportado como não lixo com sucesso';
