<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Managesieve plugin         |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['filters'] = 'Фільтры';
$labels['managefilters'] = 'Парадкаваць фільтры атрыманай пошты';
$labels['filtername'] = 'Назва фільтра';
$labels['newfilter'] = 'Новы фільтр';
$labels['filteradd'] = 'Дадаць фільтр';
$labels['filterdel'] = 'Выдаліць фільтр';
$labels['actions'] = 'Дзеянні';
$labels['scope'] = 'Абсяг';
$labels['moveup'] = 'Пасунуць уверх';
$labels['movedown'] = 'Пасунуць уніз';
$labels['filterallof'] = 'выконваюцца ўсе наступныя правілы';
$labels['filteranyof'] = 'выконваецца любое з наступных правіл';
$labels['filterany'] = 'усе паведамленні';
$labels['filtercontains'] = 'змяшчае';
$labels['filternotcontains'] = 'не змяшчае';
$labels['filteris'] = 'роўна';
$labels['filterisnot'] = 'не роўна';
$labels['filterexists'] = 'існуе';
$labels['filternotexists'] = 'не існуе';
$labels['filtermatches'] = 'задавальняе выразу';
$labels['filternotmatches'] = 'не задавальняе выразу';
$labels['filterregex'] = 'задавальняе рэгулярнаму выразу';
$labels['filternotregex'] = 'не задавальняе рэгулярнаму выразу';
$labels['filterunder'] = 'менш';
$labels['filterover'] = 'больш';
$labels['addrule'] = 'Дадаць правіла';
$labels['delrule'] = 'Выдаліць правіла';
$labels['messagemoveto'] = 'Перамясціць паведамленне ў';
$labels['messageredirect'] = 'Перанакіраваць паведамленне на';
$labels['messagecopyto'] = 'Скапіяваць паведамленне ў';
$labels['messagesendcopy'] = 'Даслаць копію на';
$labels['messagereply'] = 'Адказаць наступнае';
$labels['messagedelete'] = 'Выдаліць паведамленне';
$labels['messagediscard'] = 'Скасаваць з паведамленнем';
$labels['messagekeep'] = 'Пакінуць паведамленне ў Атрыманых';
$labels['messagesrules'] = 'Для атрыманай пошты:';
$labels['messagesactions'] = '...выконваць наступныя дзеянні:';
$labels['add'] = 'Дадаць';
$labels['del'] = 'Выдаліць';
$labels['sender'] = 'Ад каго';
$labels['recipient'] = 'Каму';
$labels['vacationdays'] = 'Як часта дасылаць паведамленні (у днях):';
$labels['vacationinterval'] = 'Як часта дасылаць паведамленні:';
$labels['vacationreason'] = 'Цела паведамлення (прычына вакацый):';
$labels['vacationsubject'] = 'Тэма паведамлення:';
$labels['days'] = 'дзён';
$labels['seconds'] = 'секунд';
$labels['rulestop'] = 'Перастаць выконваць праверку правілаў';
$labels['enable'] = 'Уключыць/Выключыць';
$labels['filtersets'] = 'Наборы фільтраў';
$labels['filterdef'] = 'Вызначэнне фільтра';
$labels['active'] = 'актыўны';
$labels['none'] = 'няма';
$labels['fromset'] = 'з набору';
$labels['fromfile'] = 'з файла';
$labels['filterdisabled'] = 'Фільтр адключаны';
$labels['countisgreaterthan'] = 'лік большы за';
$labels['countisgreaterthanequal'] = 'лік большы за альбо роўны';
$labels['countislessthan'] = 'лік меншы за';
$labels['countislessthanequal'] = 'лік меншы за альбо роўны';
$labels['countequals'] = 'лік роўны';
$labels['countnotequals'] = 'лік не роўны';
$labels['valueisgreaterthan'] = 'значэнне большае за';
$labels['valueisgreaterthanequal'] = 'значэнне большае за альбо роўнае';
$labels['valueislessthan'] = 'значэнне меншае за';
$labels['valueislessthanequal'] = 'значэнне меншае за альбо роўнае';
$labels['valueequals'] = 'значэнне роўнае';
$labels['valuenotequals'] = 'значэнне не роўнае';
$labels['setflags'] = 'Устанавіць флагі на паведамленне';
$labels['addflags'] = 'Дадаць флагі да паведамлення';
$labels['removeflags'] = 'Выдаліць флагі з паведамлення';
$labels['flagread'] = 'Прачытана';
$labels['flagdeleted'] = 'Выдалена';
$labels['flaganswered'] = 'З адказам';
$labels['flagflagged'] = 'Пазначана';
$labels['flagdraft'] = 'Чарнавік';
$labels['setvariable'] = 'Устанавіць зменную';
$labels['setvarname'] = 'Імя зменнай:';
$labels['setvarvalue'] = 'Значэнне зменнай:';
$labels['setvarmodifiers'] = 'Мадыфікатары:';
$labels['varlower'] = 'ніжні рэгістр';
$labels['varupper'] = 'верхні рэгістр';
$labels['varlowerfirst'] = 'першы знак у ніжнім рэгістры';
$labels['varupperfirst'] = 'першы знак у верхнім рэгістры';
$labels['varquotewildcard'] = 'службовыя знакі забіраць у апострафы';
$labels['varlength'] = 'даўжыня';
$labels['notify'] = 'Паслаць апавяшчэнне';
$labels['notifyimportance'] = 'Важнасць:';
$labels['notifyimportancelow'] = 'нізкая';
$labels['notifyimportancenormal'] = 'звычайная';
$labels['notifyimportancehigh'] = 'высокая';
$labels['notifymethodmailto'] = 'Эл. пошта';
$labels['notifymethodtel'] = 'Тэлефон';
$labels['filtercreate'] = 'Стварыць фільтр';
$labels['usedata'] = 'Ужываць наступныя дадзеныя ў фільтры:';
$labels['nextstep'] = 'Наступны крок';
$labels['...'] = '...';
$labels['currdate'] = 'Бягучая дата';
$labels['datetest'] = 'Дата';
$labels['dateheader'] = 'загаловак:';
$labels['year'] = 'год';
$labels['month'] = 'месяц';
$labels['day'] = 'дзень';
$labels['date'] = 'дата (гггг-мм-дд)';
$labels['julian'] = 'дата (юліянская)';
$labels['hour'] = 'гадзіна';
$labels['minute'] = 'мінута';
$labels['second'] = 'секунда';
$labels['time'] = 'час (гг:мм:сс)';
$labels['iso8601'] = 'дата (ISO8601)';
$labels['std11'] = 'дата (RFC2822)';
$labels['zone'] = 'часавая зона';
$labels['weekday'] = 'дзень тыдня (0-6)';
$labels['advancedopts'] = 'Дадатковыя параметры';
$labels['body'] = 'Цела';
$labels['address'] = 'адрас';
$labels['envelope'] = 'канверт';
$labels['modifier'] = 'мадыфікатар:';
$labels['text'] = 'тэкст';
$labels['undecoded'] = 'неапрацаваны (сыры)';
$labels['contenttype'] = 'тып змесціва';
$labels['modtype'] = 'пошук у адрасах:';
$labels['allparts'] = 'усюль';
$labels['domain'] = 'у імені дамена';
$labels['localpart'] = 'толькі ў імені карыстальніка, без дамена';
$labels['user'] = 'у поўным імені карыстальніка';
$labels['detail'] = 'у дадатковых звестках';
$labels['comparator'] = 'спосаб параўнання:';
$labels['default'] = 'стандартны';
$labels['octet'] = 'строгі (octet)';
$labels['asciicasemap'] = 'без уліку рэгістру (ascii-casemap)';
$labels['asciinumeric'] = 'лікавы (ascii-numeric)';
$labels['index'] = 'індэкс:';
$labels['indexlast'] = 'назад';
$labels['spamtestequals'] = 'роўна';
$labels['spamtestnotequals'] = 'не роўна';
$labels['vacation.subject'] = 'Тэма';
$labels['vacation.body'] = 'Цела';
$labels['vacation.keep'] = 'Пакінуць';
$labels['vacation.discard'] = 'Адкінуць';
$labels['duplicate.header'] = 'загаловак:';
$messages['filterunknownerror'] = 'Невядомая памылка сервера.';
$messages['filterconnerror'] = 'Не ўдалося злучыцца з серверам.';
$messages['filterdeleteerror'] = 'Не ўдалося выдаліць фільтр. Памылка на серверы.';
$messages['filterdeleted'] = 'Фільтр выдалены.';
$messages['filtersaved'] = 'Фільтр захаваны.';
$messages['filtersaveerror'] = 'Не ўдалося захаваць фільтр. Памылка на серверы.';
$messages['filterdeleteconfirm'] = 'Напраўду выдаліць абраны фільтр?';
$messages['ruledeleteconfirm'] = 'Напраўду выдаліць абранае правіла?';
$messages['actiondeleteconfirm'] = 'Напраўду выдаліць абранае дзеянне?';
$messages['forbiddenchars'] = 'Забароненыя знакі ў полі.';
$messages['cannotbeempty'] = 'Поле не можа быць пустым.';
$messages['ruleexist'] = 'Фільтр з гэтай назвай ужо існуе.';
$messages['activateerror'] = 'Не ўдалося ўключыць абраны(я) фільтры. Памылка на серверы.';
$messages['deactivateerror'] = 'Не ўдалося адключыць абраны(я) фільтры. Памылка на серверы.';
$messages['deactivated'] = 'Фільтр(ы) адключаны.';
$messages['activated'] = 'Фільтр(ы) уключаны.';
$messages['moved'] = 'Фільтр перамешчаны.';
$messages['moveerror'] = 'Не ўдалося перамясціць абраны фільтр. Памылка на серверы.';
$messages['nametoolong'] = 'Задаўгая назва.';
$messages['namereserved'] = 'Зарэзерваваная назва.';
$messages['setexist'] = 'Набор ужо існуе.';
$messages['nodata'] = 'Мінімум адна пазіцыя павінна быць вылучана!';
$messages['invaliddateformat'] = 'Няслушная дата альбо фармат даты';
