<?php

// include_paths.php @generated by Composer

$vendorDir = dirname(__DIR__);
$baseDir = dirname($vendorDir);

return array(
    $vendorDir . '/pear/pear_exception',
    $vendorDir . '/pear/console_getopt',
    $vendorDir . '/pear/pear-core-minimal/src',
    $vendorDir . '/pear/net_ldap2',
    $vendorDir . '/pear/auth_sasl',
    $vendorDir . '/pear/mail_mime',
    $vendorDir . '/pear/net_socket',
    $vendorDir . '/pear/net_smtp',
    $vendorDir . '/pear/crypt_gpg',
);
