<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Password plugin            |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['curpasswd']  = 'رمز عبور کنونی';
$labels['newpasswd']  = 'رمز عبور جدید';
$labels['confpasswd']  = 'تایید رمز عبور جدید';
$messages['nopassword'] = 'لطفا رمز عبور جدیدی وارد کنید';
$messages['nocurpassword'] = 'لطفا رمز عبور کنونی را وارد کنید';
$messages['passwordincorrect'] = 'رمز عبور کنونی اشتباه است';
$messages['passwordinconsistency'] = 'رمزهای عبور با هم مطابقت ندارند، لطفا دوباره سعی کنید';
$messages['crypterror'] = 'امکان ذخیره رمز عبور جدید وجود ندارد. تابع رمزگذاری یافت نشد';
$messages['connecterror'] = 'امکان ذخیره رمز عبور جدید وجود ندارد. لطفا دوباره سعی کنید';
$messages['internalerror'] = 'امکان ذخیره رمز عبور جدید وجود ندارد';
$messages['passwordshort'] = 'طول رمز عبور می بایست حداقل به طول $length کاراکتر باشد';
$messages['passwordweak'] = 'رمز عبور می بایست دارای حداقل یک عدد و یک کاراکتر علامت گذاری باشد';
$messages['passwordforbidden'] = 'رمز عبور شامل کاراکترهای غیر مجاز است';
