<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail ACL plugin                 |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['sharing'] = '共有';
$labels['myrights'] = 'アクセス権';
$labels['username'] = 'ユーザー:';
$labels['advanced'] = '詳細なモード';
$labels['add'] = '追加';
$labels['newuser'] = '項目を追加';
$labels['editperms'] = '編集の権限';
$labels['actions'] = 'アクセス権の動作...';
$labels['anyone'] = '(誰でも)すべてのユーザー';
$labels['anonymous'] = 'ゲスト(匿名)';
$labels['identifier'] = '識別子';
$labels['acll'] = '検索';
$labels['aclr'] = 'メッセージを読む';
$labels['acls'] = '既読の状態を保持';
$labels['aclw'] = '書き込みフラッグ';
$labels['acli'] = '挿入(中に複製)';
$labels['aclp'] = '投稿';
$labels['aclc'] = 'サブフォルダを作成';
$labels['aclk'] = 'サブフォルダを作成';
$labels['acld'] = 'メッセージを削除';
$labels['aclt'] = 'メッセージを削除';
$labels['acle'] = '抹消';
$labels['aclx'] = 'フォルダーを削除';
$labels['acla'] = '管理';
$labels['acln'] = 'メッセージに注釈';
$labels['aclfull'] = '完全な制御';
$labels['aclother'] = 'その他';
$labels['aclread'] = '読み込み';
$labels['aclwrite'] = '書き込み';
$labels['acldelete'] = '削除';
$labels['shortacll'] = '検索';
$labels['shortaclr'] = '読み込み';
$labels['shortacls'] = '保持';
$labels['shortaclw'] = '書き込み';
$labels['shortacli'] = '挿入';
$labels['shortaclp'] = '投稿';
$labels['shortaclc'] = '作成';
$labels['shortaclk'] = '作成';
$labels['shortacld'] = '削除';
$labels['shortaclt'] = '削除';
$labels['shortacle'] = '抹消';
$labels['shortaclx'] = 'フォルダーの削除';
$labels['shortacla'] = '管理';
$labels['shortacln'] = '注釈';
$labels['shortaclother'] = 'その他';
$labels['shortaclread'] = '読み込み';
$labels['shortaclwrite'] = '書き込み';
$labels['shortacldelete'] = '削除';
$labels['longacll'] = 'フォルダーをリストに見えるようにして登録可能:';
$labels['longaclr'] = 'フォルダーを読むことを可能';
$labels['longacls'] = 'メッセージの既読のフラッグの変更を可能';
$labels['longaclw'] = '既読と削除のフラッグを除く、メッセージのフラッグとキーワードの変更を可能';
$labels['longacli'] = 'メッセージに書き込みとフォルダーへの複製を可能';
$labels['longaclp'] = 'メッセージをこのフォルダーに投稿を可能';
$labels['longaclc'] = 'このフォルダーの直下にフォルダーの作成と名前の変更を可能';
$labels['longaclk'] = 'このフォルダーの直下にフォルダーの作成と名前の変更を可能';
$labels['longacld'] = 'メッセージの削除フラッグの変更を可能';
$labels['longaclt'] = 'メッセージの削除フラッグの変更を可能';
$labels['longacle'] = 'メッセージの抹消を可能';
$labels['longaclx'] = 'このフォルダーの削除や名前の変更を可能';
$labels['longacla'] = 'フォルダーのアクセス権の変更を可能';
$labels['longacln'] = 'メッセージの共有されるメタデータ(注釈)の変更を可能';
$labels['longaclfull'] = 'フォルダーの管理を含めた完全な制御を可能';
$labels['longaclread'] = 'フォルダーを読むことを可能';
$labels['longaclwrite'] = 'メッセージにマークの設定、書き込み、フォルダーに複製を可能';
$labels['longacldelete'] = 'メッセージの削除を可能';
$labels['longaclother'] = '他のアクセス権';
$labels['ariasummaryacltable'] = 'アクセス権の一覧';
$labels['arialabelaclactions'] = '動作を一覧';
$labels['arialabelaclform'] = 'アクセス権の欄';
$messages['deleting'] = 'アクセス権を削除中...';
$messages['saving'] = 'アクセス権を保存中...';
$messages['updatesuccess'] = 'アクセス権を変更しました。';
$messages['deletesuccess'] = 'アクセス権を削除しました。';
$messages['createsuccess'] = 'アクセス権を追加しました。';
$messages['updateerror'] = 'アクセス権を更新できません。';
$messages['deleteerror'] = 'アクセス権を削除できません。';
$messages['createerror'] = 'アクセス権を追加できません。';
$messages['deleteconfirm'] = '選択したユーザーのアクセス件を本当に削除したいですか?';
$messages['norights'] = '何の権限も指定されていません!';
$messages['nouser'] = 'ユーザー名を指定していません!';
